/*
 * Copyright (C) 2003 - 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.chart;

import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.Rectangle;

import java.awt.geom.Rectangle2D;

import java.util.List;

/**
 * Name: BarChart2D<br>
 * Description: A class rendering two dimensional bar charts.
 * 
 * @author lauerc
 */
public class BarChart2D extends Base2DScaleChart {

  /**
   * @see org.ujac.chart.Chart#draw(java.awt.geom.Rectangle2D, java.awt.Graphics2D)
   */
  public Rectangle2D draw(Rectangle2D viewport, Graphics2D graphics) 
    throws ChartException {
    
    Rectangle2D localViewport = super.draw(viewport, graphics);
    if ((model == null) || (model.getChartData() == null)) {
      return localViewport;
    }

    /** The segment colors. */
    Color[] segmentColors = attributes.getColorArray(ATTR_SEGMENT_COLORS); 

    List chartData = model.getChartData();
    int numSegments = chartData.size();
    
    // calculating the effective viewport
    Rectangle effectiveViewport = calcViewport(localViewport, graphics);
    // drawing the scale
    drawScale(localViewport, effectiveViewport, graphics);
    // drawing the legend
    drawLegend(localViewport, graphics);
    
    float horizontalScale = this.horizontalScale;
    
    float barsWidth = horizontalScale * 0.8F;

    float nullPos = calculateBaseLinePosition();

    double[] row = (double[]) chartData.get(0);
    float barStep = barsWidth / row.length;
    float barWidth = barStep * 0.8F;
    
    float barOffset = -(barsWidth / 2.0F) * 0.9F;
    int[] barOffsets = new int[row.length];
    for (int i = 0; i < barOffsets.length; i++) {
      barOffsets[i] = (int) barOffset;
      barOffset += barStep;
    }

    int shadowOffsetX = (int) getShadowLength();
    int shadowOffsetY = shadowOffsetX;
    if (shadowOffsetY > 2) {
      shadowOffsetY -= 1;
    }

    if (shadowOffsetX > 0)  {
      graphics.setColor(getShadowColor());
      for (int i = 0; i < numSegments; i++) {
        row = (double[]) chartData.get(i);
        float curPos = horizontalPositions[i];
        for (int j = 0; j < row.length; j++) {
          float yPos = calculateVerticalPosition(row[j]);
          int barOffs = barOffsets[j];
          if (yPos < nullPos) {
            graphics.fill(new Rectangle2D.Float(
                curPos + barOffs + shadowOffsetX, yPos + shadowOffsetY, 
                barWidth, nullPos - yPos
            ));
          } else {
            graphics.fill(new Rectangle2D.Float(
                curPos + barOffs + shadowOffsetX, nullPos + shadowOffsetY, 
                barWidth, yPos - nullPos
            ));
          }
        }
      }
    }
    
    for (int i = 0; i < numSegments; i++) {
      row = (double[]) chartData.get(i);
      float curPos = horizontalPositions[i];
      for (int j = 0; j < row.length; j++) {
        float yPos = calculateVerticalPosition(row[j]);
        int barOffs = barOffsets[j];
        graphics.setColor(segmentColors[j]);
        if (yPos < nullPos) {
          graphics.fill(new Rectangle2D.Float(
              curPos + barOffs, yPos, 
              barWidth, nullPos - yPos
          ));
        } else {
          graphics.fill(new Rectangle2D.Float(
              curPos + barOffs, nullPos, 
              barWidth, yPos - nullPos
          ));
        }
      }
    }

    return localViewport;
  }

}
