/*
 * Copyright (C) 2003, 2004, 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more etails.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.chart;

import java.util.List;

/**
 * Name: Base2DStackedChart<br>
 * Description: A base class for two dimensional stacked charts.
 * 
 * @author lauerc
 */
public class Base2DStackedChart extends Base2DScaleChart {

  /** The minimum chart value. */
  private double minValue = 0.0;
  /** The maximum chart value. */
  private double maxValue = 0.0;

  /**
   * Sets the chart model.
   * @param model The chart model to set.
   * @exception ChartException In case the givem model contained invalid data. 
   */
  public void setModel(ChartModel model) throws ChartException {
    super.setModel(model);
    updateMinMaxValues();
  }

  /**
   * Tells, whether the chart supports negative values or not.
   * @return true, in case the chart supports negative values else false.
   */
  public boolean supportsNegativeValues() {
    return false;
  }
  
  /**
   * Updates the minimum / maximum values for the current chart model.
   */
  private void updateMinMaxValues() {
    if (model == null) {
      return;
    }
    
    List chartData = model.getChartData();
    int numSegments = chartData.size();
    double min = 0.0;
    double max = 0.0;
    for (int i = 0; i < numSegments; i++) {
      double[] row = (double[]) chartData.get(i);
      double areaSum = 0.0;
      for (int j = 0; j < row.length; j++) {
        areaSum += row[j];
      }
      min = Math.min(min, areaSum);
      max = Math.max(max, areaSum);
    }
    minValue = min;
    maxValue = max;
  }

  /**
   * Gets the minimum value from the chart data.
   * @return The minimum chart data value.
   */
  protected double getMinValue() {
    return minValue;
  }

  /**
   * Gets the maximum value from the chart data.
   * @return The maximum chart data value.
   */
  protected double getMaxValue() {
    return maxValue;
  }

}
