/*
 * Copyright (C) 2003 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.chart;

/**
 * Name: BasePieChart3D<br>
 * Description: A base class for rendering 3D pie charts.
 * 
 * @author lauerc
 */
public abstract class BasePieChart3D extends BasePieChart {

  /** The default pie size. */
  public static final float DEFAULT_PIE_HEIGHT = 10.0F;

  /** The height for the slices. */
  private int sliceHeight = 0;

  /**
   * Gets the vertical delta factor for the pie height.
   * @return The vertival delta factor for the pie size.
   */
  protected double getDeltaY() {
    return 0.75;
  }

  /**
   * Gets the pie height.
   * @return The current pie height.
   */
  public float getPieHeight() {
    if (attributes.isDefined(ATTR_PIE_HEIGHT)) {
      return attributes.getFloat(ATTR_PIE_HEIGHT);      
    }
    return DEFAULT_PIE_HEIGHT;
  }

  /**
   * Gets the height of the slices.
   * @return The height of the slices.
   */
  protected int getSliceHeight() {
    return sliceHeight;
  }

  /**
   * @see org.ujac.chart.BasePieChart#init(int)
   */
  protected void init(int numSegments) {
    this.sliceHeight = (int) (getPieSize().getHeight() * getPieHeight() / 100.0);
    super.init(numSegments);
  }

}
