/*
 * Copyright (C) 2003, 2004, 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.chart;

import java.awt.Graphics2D;

import java.awt.geom.Rectangle2D;

import java.util.List;

/**
 * Name: Chart<br>
 * Description: Base interface for all UJAC charts.
 * 
 * @author lauerc
 */
public interface Chart {
  
  /** Constant for the attribute 'background-color'. */
  String ATTR_BACKGROUND_COLOR = "background-color";
  /** Constant for the attribute 'border-width'. */
  String ATTR_BORDER_WIDTH = "border-width";
  /** Constant for the attribute 'title-font'. */
  String ATTR_TITLE_FONT = "title-font";
  /** 
   * Constant for the attribute 'area-labels'.
   * @deprecated Use property ChartModel.areaLabels instead
   */
  String ATTR_AREA_LABELS = "area-labels";
  /**
   *  Constant for the attribute 'segment-labels'.
   *  @deprecated Use property ChartModel.segmentLabels instead
   */
  String ATTR_SEGMENT_LABELS = "segment-labels";
  /** Constant for the attribute 'description-font'. */
  String ATTR_DESCRIPTION_FONT = "description-font";
  /** Constant for the attribute name 'description-pattern'. */
  String ATTR_DESCRIPTION_PATTERN = "description-pattern";
  /** Constant for the attribute 'description-line-width'. */
  String ATTR_DESCRIPTION_LINE_WIDTH = "description-line-width";
  /** Constant for the attribute 'description-color'. */
  String ATTR_DESCRIPTION_COLOR = "description-color";
  /** Constant for the attribute 'value-format'. */
  String ATTR_VALUE_FORMAT = "value-format";
  /** Constant for the attribute 'percent-format'. */
  String ATTR_PERCENT_FORMAT = "percent-format";
  /** Constant for the attribute 'segment-colors'. */
  String ATTR_SEGMENT_COLORS = "segment-colors";
  /** Constant for the attribute 'padding'. */
  String ATTR_PADDING = "padding";
  /** Constant for the attribute 'padding-left'. */
  String ATTR_PADDING_LEFT = "padding-left";
  /** Constant for the attribute 'padding-right'. */
  String ATTR_PADDING_RIGHT = "padding-right";
  /** Constant for the attribute 'padding-top'. */
  String ATTR_PADDING_TOP = "padding-top";
  /** Constant for the attribute 'padding-bottom'. */
  String ATTR_PADDING_BOTTOM = "padding-bottom";
  /** Constant for the attribute 'shadow-color'. */
  String ATTR_SHADOW_COLOR = "shadow-color";
  /** Constant for the attribute 'shadow-offset'. */
  String ATTR_SHADOW_OFFSET = "shadow-offset";

  /** Constant for the attribute 'pie-height', only supported for 3D pie charts. */
  String ATTR_PIE_HEIGHT = "pie-height";
  /** 
   * Constant for the attribute 'pie-description-layout', only supported for pie charts.
   * Possible values are: 'BORDER', 'ROUND'. 
   */
  String ATTR_PIE_DESCRIPTION_LAYOUT = "pie-description-layout";
  /** Constant for the attribute 'pie-description-anchor-ratio', only supported for pie charts. */
  String ATTR_PIE_DESCRIPTION_ANCHOR_RATIO = "pie-description-anchor-ratio";
  /** Constant for the attribute 'pie-description-baseline-ratiot', only supported for pie charts. */
  String ATTR_PIE_DESCRIPTION_BASELINE_RATIO = "pie-description-baseline-ratio";
    
  /** Constant for the attribute 'line-width', only supported for 2D scale charts. */
  String ATTR_LINE_WIDTH = "line-width";
  /** Constant for the attribute 'scale-mark-length', only supported for 2D scale charts. */
  String ATTR_SCALE_MARK_LENGTH = "scale-mark-length";
  /** Constant for the attribute 'view-legend', only supported for 2D scale charts. */
  String ATTR_VIEW_LEGEND = "view-legend";
  /** Constant for the attribute 'value-step-size', only supported for 2D scale charts. */
  String ATTR_VALUE_STEP_SIZE = "value-step-size";
  /** Constant for the attribute 'view-scale-arrows', only supported for 2D scale charts. */
  String ATTR_VIEW_SCALE_ARROWS = "view-scale-arrows";
  /** Constant for the attribute 'scale-arrowhead-length', only supported for 2D scale charts. */
  String ATTR_SCALE_ARROWHEAD_LENGTH = "scale-arrowhead-length";
  /** Constant for the attribute 'scale-arrowhead-length', only supported for 2D scale charts. */
  String ATTR_SCALE_ARROWHEAD_WIDTH = "scale-arrowhead-width";
  /** Constant for the attribute 'scale-arrowhead-style', only supported for 2D scale charts. */
  String ATTR_SCALE_ARROWHEAD_STYLE = "scale-arrowhead-style";
  /** Constant for the attribute 'scale-value-format'. */
  String ATTR_SCALE_VALUE_FORMAT = "scale-value-format";
  /** 
   * Constant for the attribute 'segment-mark-style', only supported for 2D scale charts.
   * Valid values are: 'border' and 'center'.
   */
  String ATTR_SEGMENT_MARK_STYLE = "segment-mark-style";
  /** Constant for the attribute 'view-grid', only supported for 2D scale charts. */
  String ATTR_VIEW_GRID = "view-grid";
  /** Constant for the attribute 'grid-color', only supported for 2D scale charts. */
  String ATTR_GRID_COLOR = "grid-color";
  /** Constant for the attribute 'grid-bgcolor', only supported for 2D scale charts. */
  String ATTR_GRID_BACKGROUND_COLOR = "grid-bgcolor";

  /** Constant for the attribute 'fill-area', only supported for line chart. */
  String ATTR_FILL_AREA = "fill-area";

  /** Constant for the attribute 'value-scale-description'. */
  String ATTR_VALUE_SCALE_DESCRIPTION = "value-scale-description";
  /** Constant for the attribute 'segment-scale-description'. */
  String ATTR_SEGMENT_SCALE_DESCRIPTION = "segment-scale-description";
  
  /**
   * Gets the chart model.
   * @return The chart model.
   */
  ChartModel getModel();
  /**
   * Sets the chart model.
   * @param model The chart model to set.
   * @exception ChartException In case the model contained invalid data for the chart.
   */
  void setModel(ChartModel model) throws ChartException;

  /**
   * Tells, whether the chart supports negative values or not.
   * @return true, in case the chart supports negative values else false.
   */
  boolean supportsNegativeValues();

  /**
   * Gets a list of supported attributes for the chart.
   * @return The map of supported attributes for the chart.
   */
  List getSupportedAttributes();

  /**
   * Gets the chart attributes.
   * @return The attribute set.
   */
  ChartAttributes getAttributes();
  /**
   * Sets the chart attributes.
   * @param attributes The chart attributes to set.
   */
  void setAttributes(ChartAttributes attributes);
  
  /**
   * Draws the chart to the given chart output.
   * @param viewport The viewport for chart output.
   * @param graphics The graphics object used for chart output.
   * @return The effective drawing area for the chart.
   * @exception ChartException In case the rendering failed.
   */
  Rectangle2D draw(Rectangle2D viewport, Graphics2D graphics)
    throws ChartException;
}
