/*
 * Copyright (C) 2003 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.chart;

import org.ujac.util.UjacTypes;

/**
 * Name: ChartAttributeDefinition<br>
 * Description: Defines chart attributes.
 * 
 * @author lauerc
 */
public class ChartAttributeDefinition implements UjacTypes {

  /** Constant for font type. */
  public static final int TYPE_FONT = 20;
  /** Constant for Format type. */
  public static final int TYPE_FORMAT = 21;
  /** Constant for Color type. */
  public static final int TYPE_COLOR = 22;
  /** Constant for text items. */
  public static final int TYPE_TEXT_ITEM = 23;
  
  /** The name attribute. */
  private String name = null;
  /** The parameter type. */
  private int type = TYPE_STRING;
  /** The list flag. */
  private boolean list = false;
  /** The optional flag. */
  private boolean optional = false;

  /**
   * Constructs a ChartAttributeDefinition instance with specific attributes.
   * @param name The attribute name.
   * @param type The attribute type.
   * @param list The list flag.
   * @param optional The optional flag.
   */
  public ChartAttributeDefinition(String name, int type, boolean list, boolean optional) {
    this.name = name;
    this.type = type;
    this.list = list;
    this.optional = optional;
  }

  /**
   * Gets the parameter name.
   * @return The parameter name.
   */
  public String getName() {
    return this.name;
  }

  /**
   * Gets the parameter type.
   * @return The parameter type.
   */
  public int getType() {
    return this.type;
  }

  /**
   * Gets the list flag
   * @return The list flag.
   */
  public boolean isList() {
    return this.list;
  }

  /**
   * Gets the optional flag
   * @return The optional flag.
   */
  public boolean isOptional() {
    return this.optional;
  }

}
