/*
 * Copyright (C) 2003 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.chart;

import org.ujac.util.UjacException;

/**
 * Name: ChartException<br>
 * Description: A class for chart related exceptions.
 * 
 * @author lauerc
 */
public class ChartException extends UjacException {

  /** The serial version UID. */
  private static final long serialVersionUID = 3256445811104494896L;
  
  /** The original cause. */
  private Throwable cause = null;
  
  /**
   * Constructs a ChartException instance with specific attributes.
   * @param message The error message.
   */
  public ChartException(String message) {
    super(message);
  }

  /**
   * Constructs a ChartException instance with specific attributes.
   * @param message The error message.
   * @param cause The original exception.
   */
  public ChartException(String message, Throwable cause) {
    super(message);
    this.cause = cause;
  }

  /**
   * Constructs a ChartException instance with specific attributes.
   * @param cause The original exception.
   */
  public ChartException(Throwable cause) {
    this.cause = cause;
  }
  
  /**
   * Gets the original cause of the exception.
   * @return The current value of property cause.
   */
  public Throwable getCause() {
    return cause;
  }

}
