/*
 * Copyright (C) 2003 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.chart;

import java.awt.Graphics2D;

import java.awt.geom.Rectangle2D;

/**
 * Name: ChartItem<br>
 * Description: Interface for chart items.
 * 
 * @author lauerc
 */
public interface ChartItem {

  /**
   * Gets the position of the chart item.
   * @return The current position.
   */
  ChartItemPosition getPosition();

  /**
   * Gets the output area ot the chart item.
   * @param viewport The viewport for chart output.
   * @param graphics The graphics object, needed to calculate the metrics.
   * @return The output area the item will be rendered to.
   */
  Rectangle2D getOutputArea(Rectangle2D viewport, Graphics2D graphics);

  /**
   * Resets the calculated metrics to enforce re-calculation of the
   * item's output area.
   */
  void resetMetrics();

  /** 
   * Draws the item to the given graphic instance.
   * @param viewport The viewport for chart output.
   * @param graphics The graphics object, used for output.
   */
  void draw(Rectangle2D viewport, Graphics2D graphics);

  /**
   * Gets the width of the item box.
   * @param viewport The viewport for chart output.
   * @param graphics The graphics object, used for output.
   * @return The width of the item box.
   */
  double getWidth(Rectangle2D viewport, Graphics2D graphics);
  
  /**
   * Gets the height of the item box.
   * @param viewport The viewport for chart output.
   * @param graphics The graphics object, used for output.
   * @return The height of the item box.
   */
  double getHeight(Rectangle2D viewport, Graphics2D graphics);

  /**
   * Moves the item position.
   * @param x The number of pixels by which to move the item horizontally.
   * @param y The number of pixels by which to move the item vertically.
   */
  void move(double x, double y);

  /**
   * Moves the item to the desired position.
   * @param x The new horizontal position.
   * @param y The new vertical position.
   */
  void moveTo(double x, double y);

  /**
   * Aligns the item inside the given viewport.
   * @param viewport The area to place the item.
   */
  void alignItem(Rectangle2D viewport);
  
}
