/*
 * Copyright (C) 2003 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.chart;

/**
 * Name: ChartItemPosition<br>
 * Description: A class defining chart item positions.
 * 
 * @author lauerc
 */
public class ChartItemPosition {

  /** Constant telling that the item should be placed at an absolutely defined position. */
  public static final short ABSOLUTE = 0;
   
  /** Constant telling that the item should be placed at the left side. */
  public static final short LEFT = 1; 
  /** Constant telling that the item should be centered horizontally. */
  public static final short CENTER = 2; 
  /** Constant telling that the item should be placed at the right side. */
  public static final short RIGHT = 3; 

  /** Constant telling that the item should be placed at the top side. */
  public static final short TOP = 4; 
  /** Constant telling that the item should be centered vertically. */
  public static final short MIDDLE = 5; 
  /** Constant telling that the item should be placed at the bottom side. */
  public static final short BOTTOM = 6; 

  /** The hozizontal position mode. */
  private short horizontalPositionMode = ABSOLUTE;
  /** The vertical position mode. */
  private short verticalPositionMode = ABSOLUTE;

  /** The absolute hozizontal position. */
  private double x = 0.0;
  /** The absolute vertical position. */
  private double y = 0.0;

  /**
   * Constructs a ChartItemPosition instance with specific attributes.
   * @param horizontalPositionMode The hozizontal position mode.
   * @param verticalPositionMode The vertical position mode.
   */
  public ChartItemPosition(short horizontalPositionMode, short verticalPositionMode) {
    this.horizontalPositionMode = horizontalPositionMode;
    this.verticalPositionMode = verticalPositionMode;
  }

  /**
   * Constructs a ChartItemPosition instance with specific attributes.
   * @param x The hozizontal position.
   * @param verticalPositionMode The vertical position mode.
   */
  public ChartItemPosition(double x, short verticalPositionMode) {
    this.x = x;
    this.verticalPositionMode = verticalPositionMode;
  }

  /**
   * Constructs a ChartItemPosition instance with specific attributes.
   * @param horizontalPositionMode The hozizontal position mode.
   * @param y The vertical position mode.
   */
  public ChartItemPosition(short horizontalPositionMode, double y) {
    this.horizontalPositionMode = horizontalPositionMode;
    this.y = y;
  }

  /**
   * Constructs a ChartItemPosition instance with specific attributes.
   * @param x The hozizontal position.
   * @param y The vertical position mode.
   */
  public ChartItemPosition(double x, double y) {
    this.x = x;
    this.y = y;
  }
  
  /**
   * Gets the horizontal position mode.
   * @return The horizontal position mode.
   */
  public short getHorizontalPositionMode() {
    return horizontalPositionMode;
  }
  /**
   * Setter method for the the property horizontalPositionMode.
   * @param horizontalPositionMode The value to set for the property horizontalPositionMode.
   */
  public void setHorizontalPositionMode(short horizontalPositionMode) {
    this.horizontalPositionMode = horizontalPositionMode;
  }

  /**
   * Gets the vertical position mode.
   * @return The vertical position mode.
   */
  public short getVerticalPositionMode() {
    return verticalPositionMode;
  }
  /**
   * Setter method for the the property verticalPositionMode.
   * @param verticalPositionMode The value to set for the property verticalPositionMode.
   */
  public void setVerticalPositionMode(short verticalPositionMode) {
    this.verticalPositionMode = verticalPositionMode;
  }

  /**
   * Gets the absolute horizontal position.
   * @return The absolute horizontal position.
   */
  public double getX() {
    return x;
  }
  /**
   * Sets the absolute horizontal position.
   * @param x The absolute horizontal position.
   */
  public void setX(double x) {
    this.x = x;
  }

  /**
   * Gets the absolute vertical position mode.
   * @return The absolute vertical position.
   */
  public double getY() {
    return y;
  }
  /**
   * Sets the absolute horizontal position.
   * @param y The absolute horizontal position.
   */
  public void setY(double y) {
    this.y = y;
  }

}
