/*
 * Copyright (C) 2003, 2004 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.chart;

import java.util.List;

/**
 * Name: ChartModel<br>
 * Description: An interface for chart models.
 * 
 * @author lauerc
 */
public interface ChartModel {

  /**
   * Gets the chart title.
   * @return The chart's title item.
   */
  TextChartItem getTitle();
  /**
   * Sets the chart title.
   * @param title The title item for the chart.
   */
  void setTitle(TextChartItem title);

  /**
   * Gets the chart data as a list of double arrays.
   * @return A list of double arrays.
   */
  List getChartData();
  /**
   * Sets the chart data as a list of double arrays.
   * @param chartData A list of double arrays.
   */
  void setChartData(List chartData);

  /**
   * Gets the chart area labels as a list of Strings.
   * @return A list of Strings.
   */
  List getAreaLabels();
  /**
   * Sets the chart area labels as a list of Strings.
   * @param areaLabels A list of Strings.
   */
  void setAreaLabels(List areaLabels);

  /**
   * Gets the chart segment labels as a list of Strings.
   * @return A list of Strings.
   */
  List getSegmentLabels();
  /**
   * Sets the chart segment labels as a list of Strings.
   * @param segmentLabels A list of Strings.
   */
  void setSegmentLabels(List segmentLabels);

  /**
   * Gets the minimum value from the chart data.
   * @return The minimum chart data value.
   */
  double getMinValue();
  /**
   * Sets the minimum value from the chart data.
   * @param minValue The minimum chart data value.
   */
  void setMinValue(double minValue);

  /**
   * Gets the maximum value from the chart data.
   * @return The maximum chart data value.
   */
  double getMaxValue();
  /**
   * Sets the maximum value from the chart data.
   * @param maxValue The maximum chart data value.
   */
  void setMaxValue(double maxValue);

  /**
   * Gets the number of segments.
   * @return The number of segments.
   */
  int getNumSegments();

  /**
   * Gets the number of areas.
   * @return The number of areas (the segment lengths).
   */
  int getNumAreas();

}
