/*
 * Copyright (C) 2004 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.chart;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;

/**
 * Name: ChartWriter<br>
 * Description: Base class for classes, performing output of charts as images.
 * 
 * @author lauerc
 */
public abstract class ChartWriter {
 
  /** 
   * Renders the chart to the given output stream.
   * @param chart The chart to render.
   * @param os The output stream to render to.
   * @param width The width of the output area.
   * @param height The height of the output area.
   * @exception ChartException In case the chart processing failed.
   * @exception IOException In case an I/O problem occurred.
   */
  public abstract void output(Chart chart, OutputStream os, int width, int height)
    throws ChartException, IOException;
  
  /** 
   * Renders the chart to the given output stream.
   * @param chart The chart to render.
   * @param outputFile The output file to render to.
   * @param width The width of the output area.
   * @param height The height of the output area.
   * @exception ChartException In case the chart processing failed.
   * @exception IOException In case an I/O problem occurred.
   */
  public void output(Chart chart, File outputFile, int width, int height)
    throws ChartException, IOException {
  
    FileOutputStream os = new FileOutputStream(outputFile);
    try {
      output(chart, os, width, height);
    } finally {
      os.close();
    }
  }
  
}
