/*
 * Copyright (C) 2005 - 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.chart;

import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Rectangle;

import java.awt.image.BufferedImage;

import java.io.IOException;
import java.io.OutputStream;

import java.util.Iterator;

import javax.imageio.IIOImage;
import javax.imageio.ImageIO;
import javax.imageio.ImageTypeSpecifier;
import javax.imageio.ImageWriteParam;
import javax.imageio.ImageWriter;

import javax.imageio.stream.ImageOutputStream;

/**
 * Name: ImageIOChartWriter<br>
 * Description: A chart writer using the javax.imageio API, introduced with JDK 1.4.
 * 
 * @author lauerc
 */
public class ImageIOChartWriter extends ChartWriter {
  
  /** The image format name. */
  private String formatName = "jpg";
  /** The quality level (0.0 to 1.0). */
  private float quality = 0.75F;

  /**
   * Constructs a ImageIOChartWriter instance for jpg format with specific attributes.
   * @param quality The quality level (0.0 to 1.0).
   */
  public ImageIOChartWriter(float quality) {
  }

  /**
   * Constructs a ImageIOChartWriter instance with specific attributes.
   * @param formatName The image format name.
   */
  public ImageIOChartWriter(String formatName) {
    this.formatName = formatName;
  }

  /**
   * Constructs a ImageIOChartWriter instance with specific attributes.
   * @param formatName The image format name.
   * @param quality The quality level (0.0 to 1.0).
   */
  public ImageIOChartWriter(String formatName, float quality) {
    this.formatName = formatName;
    this.quality = quality;
  }

  
  /**
   * Getter method for the the property quality.
   * @return The current value of property quality.
   */
  public float getQuality() {
    return quality;
  }
  /**
   * Setter method for the the property quality.
   * @param quality The value to set for the property quality.
   */
  public void setQuality(float quality) {
    this.quality = quality;
  }

  /**
   * Getter method for the the property formatName.
   * @return The current value of property formatName.
   */
  public String getFormatName() {
    return formatName;
  }
  /**
   * Setter method for the the property formatName.
   * @param formatName The value to set for the property formatName.
   */
  public void setFormatName(String formatName) {
    this.formatName = formatName;
  }

  /**
   * @see org.ujac.chart.ChartWriter#output(org.ujac.chart.Chart, java.io.OutputStream, int, int)
   */
  public void output(Chart chart, OutputStream os, int width, int height)
      throws ChartException, IOException {

    ImageOutputStream stream = null;
    ImageWriter writer = null;
    
    try {
      BufferedImage img = new BufferedImage(width, height, BufferedImage.TYPE_INT_RGB);
      Graphics graphics = img.getGraphics();
      chart.draw(new Rectangle(0, 0, width, height), (Graphics2D) graphics);
      graphics.dispose();

      stream = ImageIO.createImageOutputStream(os);
      ImageTypeSpecifier type = ImageTypeSpecifier.createFromRenderedImage(img);
      Iterator iter = ImageIO.getImageWriters(type, "jpg");
      if (iter.hasNext()) {
        writer = (ImageWriter)iter.next();
      }
      if (writer == null) {
        throw new IOException("Failed to get writer for '" + formatName + "' images.");
      }
      writer.setOutput(stream);

      // Set the compression quality
      ImageWriteParam iwparam = writer.getDefaultWriteParam();
      iwparam.setCompressionMode(ImageWriteParam.MODE_EXPLICIT) ;
      iwparam.setCompressionQuality(quality);

      // finally writing the image
      writer.write(null, new IIOImage(img, null, null), iwparam);
    } finally {
      if (stream != null) {
        stream.flush();
      }
      if (writer != null) {
        writer.dispose();
      }
    }
  }

}
