/*
 * Copyright (C) 2003 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.chart;

import java.awt.Font;

/**
 * Name: PieChartDescriptionItem<br>
 * Description: Holds all informations of an pie chart description item.
 * 
 * @author lauerc
 */
public class PieChartDescriptionItem extends TextChartItem implements Comparable {

  /** The item's index. */
  private int itemIdx = 0;

  /**
   * Constructs a PieChartDescriptionItem instance with specific attributes.
   * @param itemIdx The index of the related pie slice.
   * @param position The position of the chart item.
   * @param text The text of the chart item.
   * @param font The font to render with.
   */
  public PieChartDescriptionItem(int itemIdx, ChartItemPosition position, 
                                 String text, Font font) {
    super(position, text, font);
    this.itemIdx = itemIdx;
  }

  /**
   * Constructs a PieChartDescriptionItem instance with specific attributes.
   * @param itemIdx The index of the related pie slice.
   * @param position The position of the chart item.
   * @param maxWidth The maximm width of the text item.
   * @param hAlign The horizontal alignment of the text.
   * @param text The text of the chart item.
   * @param font The font to render with.
   */
  public PieChartDescriptionItem(int itemIdx, ChartItemPosition position, 
                                 int maxWidth, int hAlign, 
                                 String text, Font font) {
    super(position, maxWidth, hAlign, text, font);
    this.itemIdx = itemIdx;
  }
  
  /**
   * Gets the item's index.
   * @return The item's index.
   */
  public int getItemIdx() {
    return itemIdx;
  }

  /**
   * Compares the vertical positions of this item and the given item.
   * @see java.lang.Comparable#compareTo(java.lang.Object)
   */
  public int compareTo(Object o) {
    PieChartDescriptionItem other = (PieChartDescriptionItem) o;
    double myVerticalPos = 0.0;
    if (outputArea != null) {
      myVerticalPos = outputArea.getCenterY();
    } else {
      myVerticalPos = getPosition().getY();
    }
    double otherVerticalPos = 0.0;
    if (outputArea != null) {
      otherVerticalPos = other.outputArea.getCenterY();
    } else {
      otherVerticalPos = other.getPosition().getY();
    }

    if (myVerticalPos == otherVerticalPos) {
      return 0;
    }
    if (myVerticalPos > otherVerticalPos) {
      return 1;
    }
    return -1;
  }

}
