/*
 * Copyright (C) 2005 - 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.chart;

import java.util.ArrayList;
import java.util.List;

/**
 * Name: RealtimeChartModel<br>
 * Description: A ChartModel implementation for real time charts.
 * 
 * @author lauerc
 */
public class RealtimeChartModel extends DefaultChartModel {
  
  /**
   * Constructs a RealtimeChartModel instance with no specific attributes.
   * @param numValues The number of values to plot
   */
  public RealtimeChartModel(int numValues) {
    List values = new ArrayList(numValues + 1);
    for (int i = 0; i < numValues; i++) {
      values.add(new double[0]);
    }
    this.setChartData(values);
  }
  
  /**
   * Adds a set of values to the chart data.
   * @param values The value set to add.
   */
  public void addValue(double[] values) {

    double min = getMinValue();
    double max = getMaxValue();
    for (int i = 0; i < values.length; i++) {
      double val = values[i];
      min = Math.min(min, val);
      max = Math.max(max, val);
    }
    setMinValue(min);
    setMaxValue(max);

    List data = getChartData();
    data.add(values);
    data.remove(0);
  }

}
