/*
 * Copyright (C) 2003 - 2006 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.chart.test;

import java.awt.Color;
import java.awt.Font;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Rectangle;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.util.ArrayList;
import java.util.List;

import javax.swing.JFrame;
import javax.swing.JPanel;

import org.ujac.chart.Chart;
import org.ujac.chart.ChartAttributes;
import org.ujac.chart.ChartException;
import org.ujac.chart.ChartFactory;
import org.ujac.chart.ChartItemPosition;
import org.ujac.chart.ChartModel;
import org.ujac.chart.DefaultChartModel;
import org.ujac.chart.TextChartItem;

/**
 * Name: ChartTester<br>
 * Description: A test class for charts.
 * 
 * @author lauerc
 */
public class ChartTester {

  /**
   * The main method for testing purposes.
   * @param args The command line attribute list.
   */
  public static void main(String[] args) {
    String title = "JAVA Application\nServer Market Share";
    ChartModel cm = new DefaultChartModel();
    cm.setTitle(new TextChartItem(
        new ChartItemPosition(ChartItemPosition.CENTER, ChartItemPosition.TOP), 
        ChartItemPosition.RIGHT, title, 
        new Font("Helvetica", Font.HANGING_BASELINE | Font.BOLD, 20)
    ));
    //cm.setMaxValue(200);
    cm.setMinValue(0);
    List chartData = new ArrayList();
    chartData.add(new double[] {4, 5, 7});
    chartData.add(new double[] {30, 25, 20});
    chartData.add(new double[] {3, 2, 1});
    chartData.add(new double[] {4, 5, 7});
    chartData.add(new double[] {18, 22, 25});
    chartData.add(new double[] {3, 3, 2});
    chartData.add(new double[] {4, 2, 1});
    chartData.add(new double[] {6, 10, 13});
    chartData.add(new double[] {4, 3, 2});
    chartData.add(new double[] {1, 2, 1});
    chartData.add(new double[] {3, 4, 4});
    chartData.add(new double[] {6, 4, 3});
    chartData.add(new double[] {4, 4, 6});
    chartData.add(new double[] {7, 7, 6});
    chartData.add(new double[] {3, 2, 2});
    cm.setChartData(chartData);
    
    ChartAttributes attrs = new ChartAttributes();
    List colors = new ArrayList();
    colors.add(Color.blue);
    colors.add(Color.green);
    colors.add(Color.red);
    colors.add(Color.orange);
    colors.add(Color.yellow);
    colors.add(Color.magenta);
    colors.add(Color.cyan);
    attrs.setList(Chart.ATTR_SEGMENT_COLORS, colors);
    
    List descriptions = new ArrayList();
    descriptions.add("Apache Tomcat");
    descriptions.add("BEA WebLogic");
    descriptions.add("Borland Enterprise Server");
    descriptions.add("Caucho Resin");
    descriptions.add("IBM Websphere");
    descriptions.add("IONA Orbix ASP");
    descriptions.add("Ironflare Orion");
    descriptions.add("JBoss AS");
    descriptions.add("Macromedia JRun");
    descriptions.add("Novell exteNd");
    descriptions.add("Oracle Application Server");
    descriptions.add("Pramati Server");
    descriptions.add("SAP Web Application Server");
    descriptions.add("Sun ONE Application Server");
    descriptions.add("Sybase EAServer");
    cm.setSegmentLabels(descriptions);

    descriptions = new ArrayList();
    descriptions.add("2002");
    descriptions.add("2003");
    descriptions.add("2004");
    cm.setAreaLabels(descriptions);
    
    attrs.setString(Chart.ATTR_DESCRIPTION_PATTERN, "%s (%v Parts, %p%%)");
    attrs.setFloat(Chart.ATTR_BORDER_WIDTH, 1.0F);
    attrs.setFloat(Chart.ATTR_DESCRIPTION_LINE_WIDTH, 2.0F);
    attrs.setFloat(Chart.ATTR_LINE_WIDTH, 5.0F);
    attrs.setBoolean(Chart.ATTR_VIEW_LEGEND, true);
    attrs.setBoolean(Chart.ATTR_FILL_AREA, true);
    //attrs.setFloat(Chart.ATTR_VALUE_STEP_SIZE, 10);
    attrs.setString(Chart.ATTR_SEGMENT_MARK_STYLE, "border");

    attrs.setTextItem(Chart.ATTR_SEGMENT_SCALE_DESCRIPTION, new TextChartItem(
        new ChartItemPosition(ChartItemPosition.CENTER, ChartItemPosition.MIDDLE), 
        ChartItemPosition.RIGHT, "Produkte",
        new Font("Helvetica", Font.BOLD, 18)
    ).setRotate(false));

    attrs.setTextItem(Chart.ATTR_VALUE_SCALE_DESCRIPTION, new TextChartItem(
        new ChartItemPosition(ChartItemPosition.LEFT, ChartItemPosition.MIDDLE),
        240, ChartItemPosition.CENTER, "Aufteilung in %", 
        new Font("Helvetica", Font.BOLD, 18)
    ).setRotate(true));

    try {
      final Chart chart = ChartFactory.createChart("line-2d", cm, attrs);
      
      JFrame frame = new JFrame("Line Chart 2D");
      frame.getContentPane().setLayout(new GridBagLayout());
      GridBagConstraints gbc = new GridBagConstraints();
      gbc.gridx = 0;
      gbc.gridy = 0;
      gbc.fill = GridBagConstraints.BOTH;
      gbc.weightx = 1.0;
      gbc.weighty = 1.0;
      
      frame.getContentPane().add(new JPanel() {
        /** The serial version UID. */
        private static final long serialVersionUID = 3847549872854618631L;

        /**
         * @see java.awt.Component#paint(java.awt.Graphics)
         */
        public void paint(Graphics graphics) {
          // clearing the background area
          int width = this.getWidth();
          int height = this.getHeight();
          graphics.setColor(Color.white);
          graphics.fillRect(0, 0, width, height);
          graphics.setColor(Color.black);
          try {
            chart.draw(new Rectangle(30, 30, getWidth()-60, getHeight()-60), 
                       (Graphics2D) graphics);
            //chart.draw(new Rectangle(0, 0, getWidth(), getHeight()), 
            //           (Graphics2D) graphics);
          } catch (ChartException e) {
            e.printStackTrace();
          }
        }
      }, gbc);
      frame.setSize(800, 600);
      frame.setLocation(100, 100);
      
      frame.addWindowListener(new WindowAdapter() {
        /**
         * @see java.awt.event.WindowAdapter#windowClosing(java.awt.event.WindowEvent)
         */
        public void windowClosing(WindowEvent e) {
          // Killing VM
          System.exit(0);
        }
      });
      
      frame.setVisible(true);
    } catch (Exception ex) {
      ex.printStackTrace();
    }
  }
}
