/*
 * Copyright (C) 2003 - 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.chart.test;

import java.awt.Color;
import java.awt.Font;

import java.io.File;

import java.util.ArrayList;
import java.util.List;

import org.ujac.chart.Chart;
import org.ujac.chart.ChartAttributes;
import org.ujac.chart.ChartFactory;
import org.ujac.chart.ChartItemPosition;
import org.ujac.chart.ChartModel;
import org.ujac.chart.ChartWriter;
import org.ujac.chart.DefaultChartModel;
import org.ujac.chart.ImageIOChartWriter;
import org.ujac.chart.TextChartItem;

/**
 * Name: ChartTester<br>
 * Description: A test class for chart writers.
 * 
 * @author lauerc
 */
public class ChartWriterTester {

  /**
   * The main method for testing purposes.
   */
  public static void usage() {
    System.err.println("usage: org.ujac.test.ChartWriterTester <file name> [<width> <height> <quality>]");
  }
  
  /**
   * The main method for testing purposes.
   * @param args The command line attribute list.
   */
  public static void main(String[] args) {

    int width = 1024;
    int height = 768;
    float quality = 0.75F;
    
    if (args.length == 0) {
      usage();
      return;
    }
    String outputFile = args[0];

    if ((args.length > 1) && (args.length < 3)) {
      usage();
      return;
    }
    if (args.length > 1) {
      try {
        width = Integer.parseInt(args[1]);
        height = Integer.parseInt(args[2]);
      } catch (NumberFormatException ex) {
        usage();
        return;
      }
    }
    
    if (args.length == 4) {
      quality = Float.parseFloat(args[3]);
    }

    String title = "Another Non Sense\nChart Example";
    ChartModel cm = new DefaultChartModel();
    cm.setTitle(new TextChartItem(new ChartItemPosition(ChartItemPosition.CENTER, ChartItemPosition.TOP), 
        ChartItemPosition.LEFT, title, new Font("Helvetica", Font.HANGING_BASELINE | Font.BOLD, 20)));
    cm.setMaxValue(200);
    cm.setMinValue(0);
    List chartData = new ArrayList();
    chartData.add(new double[] {18, 10, 54});
    chartData.add(new double[] {20, 34, 144});
    chartData.add(new double[] {15, 30, 43});
    chartData.add(new double[] {24, 10, 45});
    chartData.add(new double[] {70, 53, 14});
    chartData.add(new double[] {5, 22, 54});
    chartData.add(new double[] {6, 30, 76});
    chartData.add(new double[] {20, 37, 49});
    chartData.add(new double[] {43, 34, 12});
    chartData.add(new double[] {64, 53, 32});
    chartData.add(new double[] {51, 45, 52});
    chartData.add(new double[] {23, 61, 45});
    chartData.add(new double[] {8, 82, 44});
    chartData.add(new double[] {21, 128, 54});
    chartData.add(new double[] {48, 22, 43});
    chartData.add(new double[] {52, 124, 34});
    chartData.add(new double[] {64, 52, 21});
    cm.setChartData(chartData);
    
    ChartAttributes attrs = new ChartAttributes();
    List colors = new ArrayList();
    colors.add(Color.blue);
    colors.add(Color.green);
    colors.add(Color.red);
    colors.add(Color.orange);
    colors.add(Color.yellow);
    colors.add(Color.magenta);
    colors.add(Color.cyan);
    attrs.setList(Chart.ATTR_SEGMENT_COLORS, colors);
    
    List descriptions = new ArrayList();
    //descriptions.add("SAP");
    //descriptions.add("Deutsche Telekom");
    //descriptions.add("Deutsche Post");
    //descriptions.add("Deutsche Bank");
    //descriptions.add("Siemens");
    descriptions.add(null);
    descriptions.add(null);
    descriptions.add(null);
    descriptions.add(null);
    descriptions.add(null);
    descriptions.add("TUI");
    descriptions.add("Allianz AG");
    descriptions.add("Bayer AG");
    descriptions.add("Lufthansa AG");
    descriptions.add("E.ON AG");
    descriptions.add("Thyssen Krupp AG");
    descriptions.add("Schering AG");
    descriptions.add("RWE AG");
    descriptions.add("Volkswagen AG");
    descriptions.add("Metro AG");
    descriptions.add("Infineon Tech AG");
    descriptions.add("Commerzbank AG");
    cm.setSegmentLabels(descriptions);

    descriptions = new ArrayList();
    descriptions.add("DAX Anteile");
    descriptions.add("DAX 50\nAnteile");
    descriptions.add("Portfolio\nAnteile");
    cm.setAreaLabels(descriptions);
    
    attrs.setColor(Chart.ATTR_BACKGROUND_COLOR, Color.white);
    attrs.setString(Chart.ATTR_DESCRIPTION_PATTERN, "%s (%v Parts, %p%%)");
    attrs.setFloat(Chart.ATTR_BORDER_WIDTH, 1.0F);
    attrs.setFloat(Chart.ATTR_DESCRIPTION_LINE_WIDTH, 2.0F);
    attrs.setFloat(Chart.ATTR_LINE_WIDTH, 5.0F);
    attrs.setBoolean(Chart.ATTR_VIEW_LEGEND, true);
    attrs.setBoolean(Chart.ATTR_FILL_AREA, true);
    //attrs.setFloat(Chart.ATTR_VALUE_STEP_SIZE, 20);
    attrs.setString(Chart.ATTR_SEGMENT_MARK_STYLE, "border");
    attrs.setTextItem(
        Chart.ATTR_VALUE_SCALE_DESCRIPTION, 
        new TextChartItem(
            new ChartItemPosition(ChartItemPosition.RIGHT, ChartItemPosition.MIDDLE), 
            "Shares\nin %", new Font("Helvetica", Font.BOLD, 18)
        )
    );
    attrs.setTextItem(
        Chart.ATTR_SEGMENT_SCALE_DESCRIPTION, 
        new TextChartItem(
            new ChartItemPosition(ChartItemPosition.LEFT, ChartItemPosition.TOP), 
            "Stock of Securities", new Font("Helvetica", Font.BOLD, 18)
        )
    );
    
    try {
      final Chart chart = ChartFactory.createChart("stacked-area-2d", cm, attrs);
      //final Chart chart = ChartFactory.createChart("pie-2d", cm, attrs);
      ChartWriter chartWriter = new ImageIOChartWriter(quality);
      chartWriter.output(chart, new File(outputFile), width, height);
    } catch (Exception ex) {
      ex.printStackTrace();
    }
  }
}
