/*
 * Copyright (C) 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print;

import java.util.Collection;

/**
 * Name: AliasTagBuilder<br>
 * Description: Tag builder for tag aliases.
 * 
 * @author lauerc
 */
public class AliasTagBuilder implements TagBuilder {
  
  /** The alias name. */
  private String name = null;
  /** The original tag builder. */
  private TagBuilder originalBuilder = null; 
  
  /**
   * Constructs a AliasTagBuilder instance with specific attributes.
   * @param name The name of the tag.
   * @param originalBuilder The original tag builder instance.
   */
  public AliasTagBuilder(String name, TagBuilder originalBuilder) {
    this.name = name;
    this.originalBuilder = originalBuilder;
    // registering alias at original builder
    originalBuilder.registerAlias(name);
  }
  
  /**
   * @see org.ujac.print.TagBuilder#getName()
   */
  public String getName() {
    return name;
  }

  /**
   * @see org.ujac.print.TagBuilder#createTag(org.ujac.print.DocumentHandler)
   */
  public BaseDocumentTag createTag(DocumentHandler documentHandler)
      throws TagInstantiationException {
    BaseDocumentTag tag = originalBuilder.createTag(documentHandler);
    tag.setName(name);
    return tag;
  }

  /**
   * @see org.ujac.print.TagBuilder#getAliases()
   */
  public Collection getAliases() {
    return null;
  }
  /**
   * @see org.ujac.print.TagBuilder#registerAlias(java.lang.String)
   */
  public void registerAlias(String alias) {
    if (originalBuilder != null) {
      originalBuilder.registerAlias(alias);
    }
  }
  /**
   * @see org.ujac.print.TagBuilder#unregisterAlias(java.lang.String)
   */
  public void unregisterAlias(String alias) {
    if (originalBuilder != null) {
      originalBuilder.unregisterAlias(alias);
    }
  }
  
}
