/*
 * Copyright (C) 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print;

import org.ujac.print.tag.CommonAttributes;

/**
 * Name: BaseCustomTag<br>
 * Description: This is class is intended as a base class for custom tags.
 *   implementations, derived from this class are allowed at any place
 *   in the document structure.
 *  
 * @author lauerc
 */
public abstract class BaseCustomTag extends BaseDocumentTag {

  /**
   * Builds the map of supported attributes.
   * @return The attribute definitions.
   */
  protected AttributeDefinitionMap buildSupportedAttributes() {
    return super.buildSupportedAttributes()
      .addDefinition(CommonAttributes.RENDERED);
  }
  
  /**
   * Tells whether or not to disable checks which test if this tag fits into its parent tag.
   * This method should be overwritten by custom classes which extent the default tag 
   * base of UJAC.
   * @return true if structure checks are disabled for this tag.
   */
  public boolean isStructureChecksDisabled() {
    return true;
  }

}
