/*
 * Copyright (C) 2003, 2004, 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.print;

/**
 * Name: ChildDefinition<br>
 * Description: A class for child definitions.<br>
 * 
 * @author lauerc
 */
public class ChildDefinition {

  /** Constant for the occurrences amount, interpreted as unlimited. */
  public static final int UNLIMITED = 999;

  /** The child type. */
  private Class type;
  /** The minimum occurrences of the item. */
  private int minOccurrences = 0;  
  /** The maximum occurrences of the item (999 means unlimited). */
  private int maxOccurrences = UNLIMITED;
  
  /**
   * Constructs a ChildDefinition instance with specific arguments.
   * @param type The child type.
   * @param minOccurrences The minimum occurrences of the child.
   * @param maxOccurrences The maximum occurrences of the child.
   */  
  public ChildDefinition(Class type, int minOccurrences, int maxOccurrences) {
    this.type = type;
    this.minOccurrences = minOccurrences;
    this.maxOccurrences = maxOccurrences;
  }
  
  /**
   * Gets the child type.
   * @return The child type.
   */
  public Class getType() {
    return type;
  }

  /**
   * Gets the minimum occurrence of the item.
   * @return The minimum occurrence of the item.
   */
  public int getMinOccurrences() {
    return minOccurrences;
  }

  /**
   * Gets the maximum occurrence of the item.
   * @return The maximum occurrence of the item.
   */
  public int getMaxOccurrences() {
    return maxOccurrences;
  }
  
  /**
   * @see java.lang.Object#toString()
   */
  public String toString() {
    return "{class=" + type.getName() + ", minOccurrences=" + minOccurrences + ", maxOccurrences=" + maxOccurrences + "}";
  }
  
  
}
