/*
 * Copyright (C) 2003 - 2007 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.print;

import java.util.Map;
import java.util.List;
import java.util.HashMap;
import java.util.Iterator;
import java.util.ArrayList;

import org.ujac.print.tag.AddRowTag;
import org.ujac.print.tag.AlterColumnTag;
import org.ujac.print.tag.AnchorTag;
import org.ujac.print.tag.AnnotationTag;
import org.ujac.print.tag.AssertTag;
import org.ujac.print.tag.AttributeTag;
import org.ujac.print.tag.BackgroundImageTag;
import org.ujac.print.tag.BarcodePdf417Tag;
import org.ujac.print.tag.BarcodeTag;
import org.ujac.print.tag.BoldTag;
import org.ujac.print.tag.BoxTag;
import org.ujac.print.tag.CaseTag;
import org.ujac.print.tag.ChapterTag;
import org.ujac.print.tag.ColorDefTag;
import org.ujac.print.tag.ColumnTextTag;
import org.ujac.print.tag.CustomTagTag;
import org.ujac.print.tag.DatamatrixTag;
import org.ujac.print.tag.DefineColumnTag;
import org.ujac.print.tag.DefineTableTag;
import org.ujac.print.tag.AddColumnTag;
import org.ujac.print.tag.EncryptionTag;
import org.ujac.print.tag.ExtraRowTag;
import org.ujac.print.tag.HeadTag;
import org.ujac.print.tag.IndexTag;
import org.ujac.print.tag.InsertColumnTag;
import org.ujac.print.tag.InsertDocumentTag;
import org.ujac.print.tag.JavascriptTag;
import org.ujac.print.tag.ListItemTag;
import org.ujac.print.tag.ListSymbolTag;
import org.ujac.print.tag.ListTag;
import org.ujac.print.tag.LogTag;
import org.ujac.print.tag.MetaTag;
import org.ujac.print.tag.ModuleTag;
import org.ujac.print.tag.OverlayTag;
import org.ujac.print.tag.PageFormatTag;
import org.ujac.print.tag.PdfTableRowTag;
import org.ujac.print.tag.PrintFooterRowTag;
import org.ujac.print.tag.PrintGroupRowTag;
import org.ujac.print.tag.PrintGroupTitleRowTag;
import org.ujac.print.tag.PrintHeaderRowTag;
import org.ujac.print.tag.RegisterFontTag;
import org.ujac.print.tag.RegisterTagTag;
import org.ujac.print.tag.RemoveColumnTag;
import org.ujac.print.tag.RowCellTag;
import org.ujac.print.tag.ChartTag;
import org.ujac.print.tag.DateFormatTag;
import org.ujac.print.tag.DefaultTag;
import org.ujac.print.tag.DocumentTag;
import org.ujac.print.tag.ElseTag;
import org.ujac.print.tag.FontDefTag;
import org.ujac.print.tag.FontTag;
import org.ujac.print.tag.FooterPartTag;
import org.ujac.print.tag.FooterTag;
import org.ujac.print.tag.ForeachTag;
import org.ujac.print.tag.HeaderPartTag;
import org.ujac.print.tag.HeaderTag;
import org.ujac.print.tag.IfTag;
import org.ujac.print.tag.ImageTag;
import org.ujac.print.tag.ImportTag;
import org.ujac.print.tag.ItalicTag;
import org.ujac.print.tag.ItemTag;
import org.ujac.print.tag.ItemsTag;
import org.ujac.print.tag.MacroDefTag;
import org.ujac.print.tag.MacroTag;
import org.ujac.print.tag.NewLineTag;
import org.ujac.print.tag.NewPageTag;
import org.ujac.print.tag.NumberFormatTag;
import org.ujac.print.tag.OutlineTag;
import org.ujac.print.tag.ParagraphTag;
import org.ujac.print.tag.ParameterDefTag;
import org.ujac.print.tag.ParameterTag;
import org.ujac.print.tag.PdfCellBlockTag;
import org.ujac.print.tag.PdfCellTag;
import org.ujac.print.tag.PdfTableHeaderTag;
import org.ujac.print.tag.PdfTableSplitTag;
import org.ujac.print.tag.PdfTableTag;
import org.ujac.print.tag.PhraseTag;
import org.ujac.print.tag.PrintRowTag;
import org.ujac.print.tag.PrintTableTag;
import org.ujac.print.tag.ResourceBundleTag;
import org.ujac.print.tag.SectionTag;
import org.ujac.print.tag.SegmentTag;
import org.ujac.print.tag.SetFieldTag;
import org.ujac.print.tag.SetFormatTag;
import org.ujac.print.tag.SetPropertyTag;
import org.ujac.print.tag.SpaceTag;
import org.ujac.print.tag.SpanTag;
import org.ujac.print.tag.StickyTag;
import org.ujac.print.tag.StyleDefTag;
import org.ujac.print.tag.SubscriptTag;
import org.ujac.print.tag.SuperscriptTag;
import org.ujac.print.tag.SwitchTag;
import org.ujac.print.tag.TextChartItemTag;
import org.ujac.print.tag.TocTag;
import org.ujac.print.tag.TogglePropertyTag;
import org.ujac.print.tag.UnderlineTag;
import org.ujac.print.tag.ViewerPreferencesTag;
import org.ujac.print.tag.WatermarkTag;

import org.ujac.print.tag.acroform.CheckBoxAcroFieldTag;
import org.ujac.print.tag.acroform.ComboBoxAcroFieldTag;
import org.ujac.print.tag.acroform.HiddenFieldAcroFieldTag;
import org.ujac.print.tag.acroform.OptionTag;
import org.ujac.print.tag.acroform.PostButtonAcroFieldTag;
import org.ujac.print.tag.acroform.RadioButtonAcroFieldTag;
import org.ujac.print.tag.acroform.RadioGroupAcroFieldTag;
import org.ujac.print.tag.acroform.ResetButtonAcroFieldTag;
import org.ujac.print.tag.acroform.SelectListAcroFieldTag;
import org.ujac.print.tag.acroform.TextFieldAcroFieldTag;
import org.ujac.print.tag.graphics.DrawCircleTag;
import org.ujac.print.tag.graphics.DrawCurveTag;
import org.ujac.print.tag.graphics.DrawEllipseTag;
import org.ujac.print.tag.graphics.DrawLineTag;
import org.ujac.print.tag.graphics.DrawPolyLineTag;
import org.ujac.print.tag.graphics.DrawPolygonTag;
import org.ujac.print.tag.graphics.DrawRectangleTag;
import org.ujac.print.tag.graphics.GraphicsTag;
import org.ujac.print.tag.graphics.PointTag;
import org.ujac.print.tag.graphics.SetFillColorTag;
import org.ujac.print.tag.graphics.SetLineCapTag;
import org.ujac.print.tag.graphics.SetLineDashTag;
import org.ujac.print.tag.graphics.SetLineJoinTag;
import org.ujac.print.tag.graphics.SetLineWidthTag;
import org.ujac.print.tag.graphics.SetStrokeColorTag;

import com.lowagie.text.pdf.Barcode39;

/**
 * Name: DefaultDocumentTagFactory<br>
 * Description: Default document tag factory implementation.<br>
 *
 * @author lauerc
 */
public class DefaultDocumentTagFactory implements DocumentTagFactory {

  /** The default tag factory. */
  private static final DocumentTagFactory DEFAULT_INSTANCE = new DefaultDocumentTagFactory(); 
  /** The tag map. */
  private final Map tagTypes = new HashMap();

  /**
   * Gets the default tag factory.
   * @return The default tag factory instance.
   */
  public static final DocumentTagFactory getInstance() {
    return DEFAULT_INSTANCE;
  }

  /**
   * Constructs a DefaultDocumentTagFactory instance with no specific attributes.
   */  
  public DefaultDocumentTagFactory() {
    // registering default tags
    registerDefaultTags();
  }
  
  /**
   * Gets a new tag instance for the given tag name.
   * @param documentHandler The document handler for which the item is created.
   * @param name The tag name.
   * @return The newly generated tag.
   * @throws TagInstantiationException If the no tag type with the requested name is defined.
   */
  public final BaseDocumentTag createTagInstance(DocumentHandler documentHandler,
                                                 String name) 
    throws TagInstantiationException {
    
    TagBuilder builder = (TagBuilder) tagTypes.get(name);
    if (builder == null) {
      throw new TagInstantiationException(documentHandler.locator(), "Unable to create unknown tag '" + name + "'.");
    }
    BaseDocumentTag tag = builder.createTag(documentHandler);
    tag.setTagFactory(this);
    return tag;
  }

  /**
   * Checks wheter the given tag is supported or not.
   * @param name The tag name to check.
   * @return true if a build was found for the given tag name, else false.
   */
  public final boolean isTagSupported(String name) {
    TagBuilder builder = (TagBuilder) tagTypes.get(name);
    if (builder == null) {
      return false;
    }
    return true;
  }
  
  /**
   * Registers the given document tag.
   * @param name The name of the tag to register.
   * @param tagClazz The tag class to register.
   */
  public final void registerTag(String name, Class tagClazz) {
    tagTypes.put(name, new DefaultTagBuilder(name, tagClazz));
  }

  /**
   * Registers the given document tag.
   * @param name The name of the tag to register.
   * @param tagBuilder The tag builder, which will build the tag handlers for the given name.
   */
  public final void registerTag(String name, TagBuilder tagBuilder) {
    tagTypes.put(name, tagBuilder);
  }

  /**
   * Unregisters the given document tag.
   * @param tagName The name of the tag to unregister
   */
  public final void unregisterTag(String tagName) {
    TagBuilder builder = (TagBuilder) tagTypes.remove(tagName);
    if (builder != null) {
      builder.unregisterAlias(tagName);
    }
  }

  /**
   * Registers an alias for the given document tag.
   * @param tagName The name of the tag to register the alias for.
   * @param alias The name of the alias to register.
   * @exception TagInstantiationException In case the original tag does not exist 
   *     or has not been specified so far.
   */
  public void registerTagAlias(String tagName, String alias) throws TagInstantiationException {
    TagBuilder builder = (TagBuilder) tagTypes.get(tagName);
    if (builder == null) {
      throw new TagInstantiationException(null, "Unknown tag '" + tagName + "'.");
    }
    tagTypes.put(alias, new AliasTagBuilder(alias, builder));
  }

  /**
   * Registers the default document tags.
   */
  protected void registerDefaultTags() {
    registerTag(DocumentTag.TAG_NAME, DocumentTag.class);
    registerTag(PageFormatTag.TAG_NAME, PageFormatTag.class);
    registerTag(RegisterFontTag.TAG_NAME, RegisterFontTag.class);
    registerTag(RegisterTagTag.TAG_NAME, RegisterTagTag.class);
    registerTag(StyleDefTag.TAG_NAME, StyleDefTag.class);
    registerTag(ColorDefTag.TAG_NAME, ColorDefTag.class);
    registerTag(FontDefTag.TAG_NAME, FontDefTag.class);
    registerTag(FontTag.TAG_NAME, FontTag.class);
    registerTag(BoldTag.TAG_NAME, BoldTag.class);
    registerTag(ItalicTag.TAG_NAME, ItalicTag.class);
    registerTag(UnderlineTag.TAG_NAME, UnderlineTag.class);
    registerTag(SpanTag.TAG_NAME, SpanTag.class);
    registerTag(ParagraphTag.TAG_NAME, ParagraphTag.class);
    registerTag(PhraseTag.TAG_NAME, PhraseTag.class);
    //itemTypes.put(TableItem.TAG_NAME, TableItem.class);
    //itemTypes.put(CellItem.TAG_NAME, CellItem.class);
    registerTag(PdfTableTag.TAG_NAME, PdfTableTag.class);
    registerTag(PdfTableHeaderTag.TAG_NAME, PdfTableHeaderTag.class);
    registerTag(PdfTableRowTag.TAG_NAME, PdfTableRowTag.class);
    registerTag(PdfCellTag.TAG_NAME, PdfCellTag.class);
    registerTag(PdfTableSplitTag.TAG_NAME, PdfTableSplitTag.class);
    registerTag(PdfCellBlockTag.TAG_NAME, PdfCellBlockTag.class);
    registerTag(IfTag.TAG_NAME, IfTag.class);
    registerTag(ElseTag.TAG_NAME, ElseTag.class);
    registerTag(ForeachTag.TAG_NAME, ForeachTag.class);
    registerTag(ImageTag.TAG_NAME, ImageTag.class);
    registerTag(StickyTag.TAG_NAME, StickyTag.class);
    registerTag(BackgroundImageTag.TAG_NAME, BackgroundImageTag.class);
    registerTag(WatermarkTag.TAG_NAME, WatermarkTag.class);
    registerTag(HeaderTag.TAG_NAME, HeaderTag.class);
    registerTag(HeaderPartTag.TAG_NAME, HeaderPartTag.class);
    registerTag(FooterTag.TAG_NAME, FooterTag.class);
    registerTag(FooterPartTag.TAG_NAME, FooterPartTag.class);
    registerTag(NewLineTag.TAG_NAME, NewLineTag.class);
    registerTag(NewPageTag.TAG_NAME, NewPageTag.class);
    registerTag(SwitchTag.TAG_NAME, SwitchTag.class);
    registerTag(CaseTag.TAG_NAME, CaseTag.class);
    registerTag(DefaultTag.TAG_NAME, DefaultTag.class);
    registerTag(SpaceTag.TAG_NAME, SpaceTag.class);
    registerTag(NumberFormatTag.TAG_NAME, NumberFormatTag.class);
    registerTag(DateFormatTag.TAG_NAME, DateFormatTag.class);
    registerTag(ChartTag.TAG_NAME, ChartTag.class);
    registerTag(TextChartItemTag.TAG_NAME, TextChartItemTag.class);
    registerTag(BarcodeTag.TAG_NAME, BarcodeTag.class);
    registerTag(DatamatrixTag.TAG_NAME, DatamatrixTag.class);
    registerTag(BarcodePdf417Tag.TAG_NAME, BarcodePdf417Tag.class);
    registerTag(ImportTag.TAG_NAME, ImportTag.class);
    registerTag(MacroTag.TAG_NAME, MacroTag.class);
    registerTag(ParameterTag.TAG_NAME, ParameterTag.class);
    registerTag(ItemTag.TAG_NAME, ItemTag.class);
    registerTag(ItemsTag.TAG_NAME, ItemsTag.class);
    registerTag(MacroDefTag.TAG_NAME, MacroDefTag.class);
    registerTag(ParameterDefTag.TAG_NAME, ParameterDefTag.class);
    registerTag(OutlineTag.TAG_NAME, OutlineTag.class);
    registerTag(SetFormatTag.TAG_NAME, SetFormatTag.class);
    registerTag(SetPropertyTag.TAG_NAME, SetPropertyTag.class);
    registerTag(AssertTag.TAG_NAME, AssertTag.class);
    registerTag(ResourceBundleTag.TAG_NAME, ResourceBundleTag.class);
    registerTag(PrintTableTag.TAG_NAME, PrintTableTag.class);
    registerTag(DefineColumnTag.TAG_NAME, DefineColumnTag.class);
    registerTag(InsertColumnTag.TAG_NAME, InsertColumnTag.class);
    registerTag(AlterColumnTag.TAG_NAME, AlterColumnTag.class);
    registerTag(RemoveColumnTag.TAG_NAME, RemoveColumnTag.class);
    registerTag(PrintRowTag.TAG_NAME, PrintRowTag.class);
    registerTag(PrintHeaderRowTag.TAG_NAME, PrintHeaderRowTag.class);
    registerTag(PrintGroupTitleRowTag.TAG_NAME, PrintGroupTitleRowTag.class);
    registerTag(PrintGroupRowTag.TAG_NAME, PrintGroupRowTag.class);
    registerTag(PrintFooterRowTag.TAG_NAME, PrintFooterRowTag.class);
    registerTag(RowCellTag.TAG_NAME, RowCellTag.class);
    registerTag(ChapterTag.TAG_NAME, ChapterTag.class);
    registerTag(SectionTag.TAG_NAME, SectionTag.class);
    registerTag(AnnotationTag.TAG_NAME, AnnotationTag.class);
    registerTag(AnchorTag.TAG_NAME, AnchorTag.class);
    registerTag(ListTag.TAG_NAME, ListTag.class);
    registerTag(ListSymbolTag.TAG_NAME, ListSymbolTag.class);
    registerTag(ListItemTag.TAG_NAME, ListItemTag.class);
    registerTag(MetaTag.TAG_NAME, MetaTag.class);
    registerTag(CustomTagTag.TAG_NAME, CustomTagTag.class);
    registerTag(AttributeTag.TAG_NAME, AttributeTag.class);
    registerTag(ModuleTag.TAG_NAME, ModuleTag.class);
    registerTag(OverlayTag.TAG_NAME, OverlayTag.class);
    registerTag(BoxTag.TAG_NAME, BoxTag.class);
    registerTag(TogglePropertyTag.TAG_NAME, TogglePropertyTag.class);
    registerTag(ExtraRowTag.TAG_NAME, ExtraRowTag.class);
    registerTag(ColumnTextTag.TAG_NAME, ColumnTextTag.class);
    registerTag(HeadTag.TAG_NAME, HeadTag.class);
    registerTag(TocTag.TAG_NAME, TocTag.class);
    registerTag(IndexTag.TAG_NAME, IndexTag.class);
    registerTag(InsertDocumentTag.TAG_NAME, InsertDocumentTag.class);
    registerTag(SubscriptTag.TAG_NAME, SubscriptTag.class);
    registerTag(SuperscriptTag.TAG_NAME, SuperscriptTag.class);
    registerTag(ViewerPreferencesTag.TAG_NAME, ViewerPreferencesTag.class);
    registerTag(EncryptionTag.TAG_NAME, EncryptionTag.class);
    registerTag(SegmentTag.TAG_NAME, SegmentTag.class);
    registerTag(LogTag.TAG_NAME, LogTag.class);
    registerTag(DefineTableTag.TAG_NAME, DefineTableTag.class);
    registerTag(AddColumnTag.TAG_NAME, AddColumnTag.class);
    registerTag(AddRowTag.TAG_NAME, AddRowTag.class);
    registerTag(SetFieldTag.TAG_NAME, SetFieldTag.class);
    registerTag(JavascriptTag.TAG_NAME, JavascriptTag.class);
    
    registerTag(OptionTag.TAG_NAME, OptionTag.class);
    registerTag(CheckBoxAcroFieldTag.TAG_NAME, CheckBoxAcroFieldTag.class);
    registerTag(ComboBoxAcroFieldTag.TAG_NAME, ComboBoxAcroFieldTag.class);
    registerTag(HiddenFieldAcroFieldTag.TAG_NAME, HiddenFieldAcroFieldTag.class);
    registerTag(PostButtonAcroFieldTag.TAG_NAME, PostButtonAcroFieldTag.class);
    registerTag(ResetButtonAcroFieldTag.TAG_NAME, ResetButtonAcroFieldTag.class);
    registerTag(SelectListAcroFieldTag.TAG_NAME, SelectListAcroFieldTag.class);
    registerTag(TextFieldAcroFieldTag.TAG_NAME, TextFieldAcroFieldTag.class);
    registerTag(RadioGroupAcroFieldTag.TAG_NAME, RadioGroupAcroFieldTag.class);
    registerTag(RadioButtonAcroFieldTag.TAG_NAME, RadioButtonAcroFieldTag.class);
    
    registerTag(GraphicsTag.TAG_NAME, GraphicsTag.class);
    registerTag(SetStrokeColorTag.TAG_NAME, SetStrokeColorTag.class);
    registerTag(SetFillColorTag.TAG_NAME, SetFillColorTag.class);
    registerTag(SetLineWidthTag.TAG_NAME, SetLineWidthTag.class);
    registerTag(SetLineCapTag.TAG_NAME, SetLineCapTag.class);
    registerTag(SetLineJoinTag.TAG_NAME, SetLineJoinTag.class);
    registerTag(SetLineDashTag.TAG_NAME, SetLineDashTag.class);
    registerTag(DrawLineTag.TAG_NAME, DrawLineTag.class);
    registerTag(DrawRectangleTag.TAG_NAME, DrawRectangleTag.class);
    registerTag(DrawCircleTag.TAG_NAME, DrawCircleTag.class);
    registerTag(DrawEllipseTag.TAG_NAME, DrawEllipseTag.class);
    registerTag(DrawCurveTag.TAG_NAME, DrawCurveTag.class);
    registerTag(PointTag.TAG_NAME, PointTag.class);
    registerTag(DrawPolyLineTag.TAG_NAME, DrawPolyLineTag.class);
    registerTag(DrawPolygonTag.TAG_NAME, DrawPolygonTag.class);

    try {
      registerTagAlias(ParagraphTag.TAG_NAME, "p");
      registerTagAlias(PdfTableRowTag.TAG_NAME, "tr");
      registerTagAlias(PdfTableHeaderTag.TAG_NAME, "th");
      registerTagAlias(PdfCellTag.TAG_NAME, "td");
    } catch (Exception ex) {
      ex.printStackTrace();
    }
  }
  
  /**
   * Gets all registered tag types.
   * @return A map containing all registered tag types.
   */
  public Map getTagTypes() {
    return tagTypes;
  }

  /**
   * Gets all possible childs
   * @return all possible childs.
   * @exception TagInstantiationException In case the instantiation of a tag has been failed.
   */
  public List getAllPossibleChilds() throws TagInstantiationException {
    List allChilds = new ArrayList();
    Iterator typeIter = tagTypes.entrySet().iterator();
    while (typeIter.hasNext()) {
      Map.Entry typeEntry = (Map.Entry) typeIter.next();
      String childName = (String) typeEntry.getKey();
      BaseDocumentTag tagInstance = createTagInstance(null, childName);
      if (tagInstance.isDocumentRoot()) {
        // skipping possible root tags
        continue;
      }
      allChilds.add(tagInstance);
    }
    return allChilds;
  }

  /**
   * Finds the supported child tags using the tag informations
   * from the methods getSupportedChilds and getExcludedChilds.
   * @param tag The tag to find the childs for.
   * @return The child definitions.
   * @exception TagInstantiationException In case the method <code>DefaultDocumentTagFactory.getAllPossibleChilds</code> failed.
   */
  public List getSupportedChildTags(BaseDocumentTag tag) throws TagInstantiationException {
    List supportedChildItems = new ArrayList();

    ChildDefinitionMap supportedChilds = tag.getSupportedChilds();
    if (supportedChilds == null) {
      // no child items supported
      return supportedChildItems;
    }

    // gets the list of possible childs
    List possibleChilds = getAllPossibleChilds(); 
    int numPossibleChilds = possibleChilds.size();

    List supportedChildList = supportedChilds.getSortedChilds();
    int numSupportedChilds = supportedChildList.size();
    for (int i = 0; i < numSupportedChilds; i++) {
      ChildDefinition childDef = (ChildDefinition) supportedChildList.get(i);
      Class childType = childDef.getType();
      for (int j = 0; j < numPossibleChilds; j++) {
        Object itemInstance = possibleChilds.get(j);
        if (childType.isInstance(itemInstance)) {
          // OK, supported item detected
          supportedChildItems.add(itemInstance);
        }
      }
    }
    return supportedChildItems;
  }

}
