/*
 * Copyright (C) 2005 - 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print;

import java.util.Map;
import java.util.StringTokenizer;

import org.ujac.print.tag.TagAttributes;

import org.xml.sax.Locator;

/**
 * Name: DefaultStyleParser<br>
 * Description: Default StyleParser implementation.
 * 
 * @author lauerc
 */
public class DefaultStyleParser implements StyleParser, TagAttributes {
  
  /** The attribute handler. */
  private AttributeHandler attributeHandler = null;

  /**
   * Setter method for the the property attributeHandler.
   * @param attributeHandler The value to set for the property attributeHandler.
   */
  public void setAttributeHandler(AttributeHandler attributeHandler) {
    this.attributeHandler = attributeHandler;
  }
  
  /**
   * Scans the styles from the given string.
   * @param locator The tag source locator.
   * @param styleDef The style definition
   *   (eg 'background-color:#cccccc; text-align:center; font-size:12px;...')"), 
   * @param supportedAttributeMap The map of supported attributes.
   * @param styleMap The map to fill the styles in.
   * @return The number of detected style attributes
   * @exception DocumentHandlerException In case the parsing failed.
   */
  public int parseStyle(Locator locator, String styleDef, Map supportedAttributeMap, Map styleMap) 
    throws DocumentHandlerException {
    
    int numParsedArguments = 0;
    int parseState = 0;
    AttributeDefinition attrDef = null;
    String attrName = null;
    String rawAttrValue = null;
    Object attrValue = null;
    StringTokenizer tkn = new StringTokenizer(styleDef, ";: ", true);
    while (tkn.hasMoreTokens()) {
      String t = tkn.nextToken();
      char c = t.charAt(0);
      switch (c) {
        case ';':
          if ((parseState == 3) && (attrName != null) && (attrValue != null)) {
            styleMap.put(attrDef.getName(), attrValue);
            ++numParsedArguments;
          }
          parseState = 0;
          attrName = null;
          attrValue = null;
          break;

        case ':':
          if (parseState != 1) {
            continue;
          }
          parseState = 2;
          break;

        case ' ':
          break;
          
        default:
          switch (parseState) {
            case 0:
              attrName = t;
              attrValue = null;
              parseState = 1;
              break;
              
            case 2:
              rawAttrValue = t;
              parseState = 3;
              attrDef = (AttributeDefinition) supportedAttributeMap.get(attrName);
              if (attrDef == null) {
                continue;
              }
              attrValue = attributeHandler.typeCastAttributeValue(locator, attrDef, attrName, rawAttrValue);
              break;
              
            default:
              throw new DocumentHandlerException(locator, "Encounterered invalid parse state " + parseState + "!");
          }
          break;
      }
    }
    if ((parseState == 3) && (attrName != null) && (attrValue != null)) {
      putStyle(styleMap, attrDef.getName(), attrValue);            
      ++numParsedArguments;
    }
    
    return numParsedArguments;
  }
  
  /**
   * Adds the given style to the alo given style map.
   * @param styleMap The stylmap to manage.
   * @param name The style name.
   * @param value The style value.
   */
  protected void putStyle(Map styleMap, String name, Object value) {
    styleMap.put(name, value);
    if (ATTR_FONT_NAME.equals(name)) {
      styleMap.remove(ATTR_FONT_COLOR);
      styleMap.remove(ATTR_FONT_ENCODING);
      styleMap.remove(ATTR_FONT_FAMILY);
      styleMap.remove(ATTR_FONT_SIZE);
      styleMap.remove(ATTR_FONT_STYLE);
    }
  }

  
}
