/*
 * Copyright (C) 2003 - 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.print;

/**
 * Name: DocumentEvent<br>
 * Description: A class holding document event informations.<br>
 * 
 * @author lauerc
 */
public class DocumentEvent {
  
  /** The open event. */
  public static final int OPEN = 1;
  /** The characters event. */
  public static final int CHARACTERS = 2;
  /** The close event. */
  public static final int CLOSE = 3;
  
  /** The event type. */
  private int type = 0; 
  /** The item itself. */
  private BaseDocumentTag item = null;
  /** The item's content. */
  private String content = null;
  
  /**
   * Constructs a DocumentEvent instance with no specific arguments.
   * @param type The initial event type.
   * @param item The tag, where the event occurred.
   * @param content The item's content at this stage.
   */
  public DocumentEvent(int type, BaseDocumentTag item, String content) {
    this.type = type;
    this.item = item;
    this.content = content;
  }
  
  /**
   * Gets the event type.
   * @return The event type.
   */
  public int getType() {
    return type;
  }
  /**
   * Gets the event type name.
   * @return The event type name.
   */
  public String getTypeName() {
    switch (type) {
      case OPEN:
        return "OPEN";
      case CHARACTERS:
        return "CHARACTERS";
      case CLOSE:
        return "CLOSE";
      default:
        return null;
    }
  }

  /**
   * Gets the item.
   * @return The item.
   */
  public BaseDocumentTag getItem() {
    return item;
  }

  /**
   * Gets the item's content.
   * @return The item's content.
   */
  public String getContent() {
    return content;
  }
  
  /**
   * @see java.lang.Object#toString()
   */
  public String toString() {
    return "{tag=" + item.getName() + ", event type=" + getTypeName() + ", content=" + content + "}";
  }
  
}
