/*
 * Copyright (C) 2003, 2004, 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print;

import java.awt.Font;

import com.lowagie.text.pdf.BaseFont;
import com.lowagie.text.pdf.DefaultFontMapper;
import com.lowagie.text.pdf.FontMapper;

/**
 * Name: DocumentFontMapper<br>
 * Description: UJAC print module specific FontMapper implementation.
 * 
 * @author lauerc
 */
public class DocumentFontMapper implements FontMapper {

  /** The document handler. */
  private DocumentHandler documentHandler = null;
  /** The default font mapper. */
  private static final FontMapper defaultFontMapper = new DefaultFontMapper();
  
  /**
   * Constructs a DocumentFontMapper instance with specific attributes.
   * @param documentHandler The document handler.
   */
  public DocumentFontMapper(DocumentHandler documentHandler) {
    this.documentHandler = documentHandler;
  }

  /**
   * @see com.lowagie.text.pdf.FontMapper#awtToPdf(java.awt.Font)
   */
  public BaseFont awtToPdf(Font font) {
    int style = com.lowagie.text.Font.NORMAL;
    if (font.isBold()) {
      style |= com.lowagie.text.Font.BOLD;
    }
    if (font.isItalic()) {
      style |= com.lowagie.text.Font.ITALIC;
    }
    BaseFont bf = documentHandler.getBaseFont(font.getName(), style);
    if (bf == null) {
      bf = defaultFontMapper.awtToPdf(font);
    }
    return bf;
  }

  /**
   * @see com.lowagie.text.pdf.FontMapper#pdfToAwt(com.lowagie.text.pdf.BaseFont, int)
   */
  public Font pdfToAwt(BaseFont font, int size) {
    return null;
  }

}
