/*
 * Copyright (C) 2003, 2004, 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.print;

import java.io.PrintStream;
import java.io.PrintWriter;

import org.ujac.util.UjacException;

import org.xml.sax.Locator;
import org.xml.sax.helpers.LocatorImpl;

/**
 * Name: DocumentHandlerException.java<br>
 * Description: A class for document handler related exceptions.<br>
 * 
 * @author lauerc
 */
public class DocumentHandlerException extends UjacException {

  /** The serial version UID. */
  static final long serialVersionUID = 2457750442875079475L;

  /** Holds the locator of the XML document, where the exception occured. */
  private Locator locator;
   
  /**
   * Constructs a DocumentHandlerException instance with no specific arguments.
   * @param locator Holds the locator of the XML document, where the exception occured.
   * @param msg The error message.
   */
  public DocumentHandlerException(Locator locator, String msg) {
    this(locator, msg, null);
  }

  /**
   * Constructs a DocumentHandlerException instance with no specific arguments.
   * @param locator Holds the locator of the XML document, where the exception occured.
   * @param msg The error message.
   * @param cause The cause of the error. 
   */
  public DocumentHandlerException(Locator locator, String msg, Throwable cause) {
    super(msg, cause);
    if (locator != null) {
      this.locator = new LocatorImpl(locator);
    }
  }
  
  /**
   * Gets the document locator, where the exception happened.
   * @return The document locator, where the exception happened.
   */
  public Locator getLocator() {
    return locator;
  }

  /**
   * @see java.lang.Throwable#printStackTrace(java.io.PrintStream)
   */
  public void printStackTrace(PrintStream stream) {
    if (locator != null) {
      stream.println("Document processing failure at line " + locator.getLineNumber() + ":");
    }
    super.printStackTrace(stream);
  }

  /**
   * @see java.lang.Throwable#printStackTrace(java.io.PrintWriter)
   */
  public void printStackTrace(PrintWriter writer) {
    if (locator != null) {
      writer.println("Document processing failure at line " + locator.getLineNumber() + ":");
    }
    super.printStackTrace(writer);
  }

}
