/*
 * Copyright (C) 2003, 2004 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print;

import java.io.InputStream;

import java.util.ArrayList;
import java.util.List;

/**
 * Name: DocumentHolder<br>
 * Description: A class holding document data plus extra informations.
 * 
 * @author lauerc
 */
public class DocumentHolder {

  /** The input stream to read the document data from. */
  private InputStream documentStream = null;
  /** The table of contents items. */
  private List tocItems = null;
  /** The table of outline items. */
  private List outlines = null;
  
  /**
   * Constructs a DocumentHolder instance with specific attributes.
   * @param documentStream The input stream to read the document data from.
   * @param tocItems The table of contents items.
   * @param outlines The outline items.
   */
  public DocumentHolder(InputStream documentStream, List tocItems, List outlines) {
    this.documentStream = documentStream;
    this.tocItems = tocItems;
    if (outlines != null) {
      this.outlines = (List) ((ArrayList) outlines).clone();
    }
  }

  /**
   * Gets the document stream.
   * @return The input stream to read the document data from.
   */
  public InputStream getDocumentStream() {
    return documentStream;
  }
  
  /**
   * Getter method for the the property tocItems.
   * @return The current value of property tocItems.
   */
  public List getTocItems() {
    return tocItems;
  }

  /**
   * Getter method for the the property outlines.
   * @return The current value of property outlines.
   */
  public List getOutlines() {
    return outlines;
  }

}
