/*
 * Copyright (C) 2007 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print;

/**
 * Name: DocumentTagInterceptor<br>
 * Description: Interface for tag interceptor classes.
 * 
 * @author lauerc
 */
public interface DocumentTagInterceptor {

  /**
   * Action to do before the open tag method is called.
   * @param tag The tag which is been processed. 
   * @return return true to actually call the openItem method of the tag.  
   * @throws DocumentHandlerException In case something happened which needs to abort the document processing.
   */
  boolean beforeOpen(BaseDocumentTag tag) throws DocumentHandlerException;
  
  /**
   * Action to do before the open tag method is called.
   * @param tag The tag which is been processed. 
s   * @throws DocumentHandlerException In case something happened which needs to abort the document processing.
   */
  void afterOpen(BaseDocumentTag tag) throws DocumentHandlerException;
  
  /**
   * Action to do after the close tag method is called.
   * @param tag The tag which is been processed. 
   * @return return true to actually call the openItem method of the tag.  
   * @throws DocumentHandlerException In case something happened which needs to abort the document processing.
   */
  boolean beforeClose(BaseDocumentTag tag) throws DocumentHandlerException;
  
  /**
   * Action to do after the close tag method is called.
   * @param tag The tag which is been processed. 
   * @throws DocumentHandlerException In case something happened which needs to abort the document processing.
   */
  void afterClose(BaseDocumentTag tag) throws DocumentHandlerException;
  
}
