/*
 * Copyright (C) 2007 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print;

import java.util.ArrayList;
import java.util.List;

/**
 * Name: IndexItem<br>
 * Description: A class for index items.
 * 
 * @author lauerc
 */
public class IndexItem {

  /** The toc level. */
  private int level;
  /** The title */
  private String title;
  /** The list of associated toc items. */
  private List tocItems = new ArrayList();

  /**
   * Constructs a TocItem instance with specific attributes.
   * @param level The level of the toc entry.
   * @param title The title of the item.
   */
  public IndexItem(int level, String title) {
    this.level = level;
    this.title = title;
  }

  /**
   * Constructs a TocItem instance with specific attributes.
   * @param level The level of the toc entry.
   * @param title The title of the item.
   * @param tocItem The associated toc item.
   */
  public IndexItem(int level, String title, TocItem tocItem) {
    this.level = level;
    this.title = title;
    this.tocItems.add(tocItem);
  }

  /**
   * Getter method for the the property level.
   * @return The current value of property level.
   */
  public int getLevel() {
    return level;
  }

  /**
   * Getter method for the the property title.
   * @return The current value of property title.
   */
  public String getTitle() {
    return title;
  }


  /**
   * Getter method for the the property pages.
   * @return The current value of property pages.
   */
  public List getTocItems() {
    return tocItems;
  }
  /**
   * Adds a single TOC item.
   * @param tocItem The toc item to add.
   */
  public void addTocItem(TocItem tocItem) {
    this.tocItems.add(tocItem);
  }

  /**
   * @see java.lang.Object#toString()
   */
  public String toString() {
    return title;
  }

}
