/*
 * Copyright (C) 2003, 2004 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print;

/**
 * Name: OutlineItem<br>
 * Description: A class holding informations about outline items.
 * 
 * @author lauerc
 */
public class OutlineItem {

  /** The name of the outline. */
  private String name;
  /** The page where the outline is located. */
  private int page;
  /** The horizontal position of the area the outline points to. */
  private float x;
  /** The vertical position of the area the outline points to. */
  private float y;
  /** The name of the parent outline. */
  private String parent;
  /** The title of the outline. */
  private String title;
  
  /**
   * Constructs a OutlineItem instance with specific attributes.
   * @param name The name of the outline.
   * @param page The page where the outline is located.
   * @param x The horizontal position of the area the outline points to.
   * @param y The vertical position of the area the outline points to.
   * @param parent The name of the parent outline.
   * @param title The title of the outline.
   */
  public OutlineItem(String name, int page, float x, float y, String parent, String title) {
    this.name = name;
    this.page = page;
    this.x = x;
    this.y = y;
    this.parent = parent;
    this.title = title;
  }
  
  /**
   * Getter method for the the property name.
   * @return The current value of property name.
   */
  public String getName() {
    return name;
  }
  /**
   * Setter method for the the property name.
   * @param name The value to set for the property name.
   */
  public void setName(String name) {
    this.name = name;
  }
  
  /**
   * Getter method for the the property page.
   * @return The current value of property page.
   */
  public int getPage() {
    return page;
  }
  /**
   * Setter method for the the property page.
   * @param page The value to set for the property page.
   */
  public void setPage(int page) {
    this.page = page;
  }
  
  /**
   * Getter method for the the property parent.
   * @return The current value of property parent.
   */
  public String getParent() {
    return parent;
  }
  /**
   * Setter method for the the property parent.
   * @param parent The value to set for the property parent.
   */
  public void setParent(String parent) {
    this.parent = parent;
  }

  /**
   * Getter method for the the property title.
   * @return The current value of property title.
   */
  public String getTitle() {
    return title;
  }
  /**
   * Setter method for the the property title.
   * @param title The value to set for the property title.
   */
  public void setTitle(String title) {
    this.title = title;
  }

  /**
   * Getter method for the the property x.
   * @return The current value of property x.
   */
  public float getX() {
    return x;
  }
  /**
   * Setter method for the the property x.
   * @param x The value to set for the property x.
   */
  public void setX(float x) {
    this.x = x;
  }

  /**
   * Getter method for the the property y.
   * @return The current value of property y.
   */
  public float getY() {
    return y;
  }
  /**
   * Setter method for the the property y.
   * @param y The value to set for the property y.
   */
  public void setY(float y) {
    this.y = y;
  }

  /**
   * @see java.lang.Object#toString()
   */
  public String toString() {
    return "{name=\"" + name + "\", title=\"" + title + "\", page=" + page + ", x=" + x + ", y=" + y + ", parent=\"" + parent + "\"}";
  }
  
}
