/*
 * Copyright (C) 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print;

/**
 * Name: PagePosition<br>
 * Description: A class holding positions within a document page.<br>
 *   These positions may be negative which means the position will be
 *   calculated by the methods calcX/calcY to place the object 
 *   relative to the right/top edge of the page instead of the 
 *   left/bottom edge.
 * 
 * @author lauerc
 */
public class PagePosition {
  
  /** The horizontal position. */
  private float x = 0.0F; 
  /** Tells whether or not the vertical position is signed. */
  private boolean rightAligned = false;
  
  /** The vertical position. */
  private float y = 0.0F; 
  /** Tells whether or not the horizontal position is signed. */
  private boolean topAligned = false;
  
  /**
   * Constructs a PagePosition instance with specific attributes.
   */
  public PagePosition() {
  }

  /**
   * Constructs a PagePosition instance with specific attributes.
   * @param x The horizontal position.
   * @param y The vertical position.
   */
  public PagePosition(float x, float y) {
    setX(x);
    setY(y);
  }

  /**
   * Getter method for the the property x.
   * @return The current value of property x.
   */
  public float getX() {
    return x;
  }
  /**
   * Setter method for the the property x.
   * @param x The value to set for the property x.
   */
  public void setX(float x) {
    this.x = Math.abs(x);
    this.rightAligned = this.x != x;
  }

  /**
   * Getter method for the the property y.
   * @return The current value of property y.
   */
  public float getY() {
    return y;
  }
  /**
   * Setter method for the the property y.
   * @param y The value to set for the property y.
   */
  public void setY(float y) {
    this.y = Math.abs(y);
    this.topAligned = this.y != y;
  }

  /**
   * Calculates the horizontal position on the page.
   * @param pageWidth The width of the page.
   * @param objectWidth The width of the object to calculate the position for.
   * @return The calculated horizontal position.
   */
  public float calcX(float pageWidth, float objectWidth) {
    if (rightAligned) {
      return pageWidth - x - objectWidth;
    }
    return x;
  }

  /**
   * Calculates the vertical position on the page.
   * @param pageHeight The height of the page.
   * @param objectHeight The height of the object to calculate the position for.
   * @return The calculated vertical position.
   */
  public float calcY(float pageHeight, float objectHeight) {
    if (topAligned) {
      return pageHeight - y - objectHeight;
    }
    return y;
  }

}
