/*
 * Copyright (C) 2003, 2004 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.print;

import org.ujac.util.UjacTypes;

/**
 * Name: ParameterDefinition<br>
 * Description: A class, defining parameters.
 * 
 * @author lauerc
 */
public class ParameterDefinition implements UjacTypes {
  
  /** Constant for font type. */
  public static final int TYPE_FONT = 20;
  /** Constant for Format type. */
  public static final int TYPE_FORMAT = 21;
  /** Constant for Color type. */
  public static final int TYPE_COLOR = 22;

  /** The name attribute. */
  private String name = null;
  /** The parameter type. */
  private int type = TYPE_STRING;
  /** The list flag. */
  private boolean list = false;
  /** The optional flag. */
  private boolean optional = false;
  /** The default value. */
  private Object defaultValue = null;
  /** The parameter description. */
  private String description = null;

  /**
   * Constructs a ParameterDefinition instance with specific attributes.
   * @param name  The parameter name.
   * @param type  The parameter type.
   * @param list  The list flag.
   * @param optional  The optional flag.
   * @param defaultValue  The parameter's default value.
   */
  public ParameterDefinition(String name, int type, boolean list, boolean optional, 
                             Object defaultValue) {
    this.name = name;
    this.type = type;
    this.optional = optional;
    this.list = list;
    this.defaultValue = defaultValue;
  }

  /**
   * Constructs a ParameterDefinition instance with specific attributes.
   * @param name  The parameter name.
   * @param type  The parameter type.
   * @param list  The list flag.
   * @param optional  The optional flag.
   * @param defaultValue  The parameter's default value.
   * @param description  The parameter description.
   */
  public ParameterDefinition(String name, int type, boolean list, boolean optional, 
                             Object defaultValue, String description) {
    this.name = name;
    this.type = type;
    this.optional = optional;
    this.list = list;
    this.defaultValue = defaultValue;
    this.description = description;
  }

  /**
   * Gets the parameter name.
   * @return The parameter name.
   */
  public String getName() {
    return this.name;
  }
  
  /**
   * Gets the parameter type.
   * @return The parameter type.
   */
  public int getType() {
    return this.type;
  }
  
  /**
   * Gets the list flag
   * @return The list flag.
   */
  public boolean isList() {
    return this.list;
  }
  
  /**
   * Gets the optional flag
   * @return The optional flag.
   */
  public boolean isOptional() {
    return this.optional;
  }

  /**
   * Gets the default value.
   * @return The default value.
   */
  public Object getDefaultValue() {
    return this.defaultValue;
  }

  /**
   * Gets the parameter description.
   * @return The parameter description.
   */
  public String getDescription() {
    return this.description;
  }

  /**
   * @see java.lang.Object#toString()
   */
  public String toString() {
    return "{name=" + name + ", type=" + type + ", optional=" + optional + 
        ", list=" + list + ", defaultValue=" + defaultValue + "}";
  }
  
}
