/*
 * Copyright (C) 2003 - 2007 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.print;

import org.ujac.print.tag.CellAttributes;

import com.lowagie.text.pdf.PdfPCell;

/**
 * Name: PdfCellContainer<br>
 * Description: An interface for classes who are capable of containing PDF table cells.<br>
 * 
 * @author lauerc
 */
public interface PdfCellContainer extends CommonAttributesHolder {

  /**
   * Adds a PDF cell to the container.
   * @param item The document item.
   * @param cell The PDF cell to be added.
   * @exception DocumentHandlerException If something went wrong when adding the cell.
   */
  void addCell(BaseDocumentTag item, PdfPCell cell) throws DocumentHandlerException;

  /**
   * Gets the number of remaining columns of the current row.
   * @return The number of remaining column to the end of the current row.
   */
  int getRemainingPdfColumns();

  /**
   * Gets the PDF table holder.
   * @return The component that really holds a PDF table.
   */
  PdfTableHolder getPdfTable();

  /**
   * Gets the cell attributes.
   * @return The cell attributes.
   */
  CellAttributes getCellAttributes();

}