/*
 * Copyright (C) 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print;

import com.lowagie.text.Document;
import com.lowagie.text.DocumentException;
import com.lowagie.text.pdf.ColumnText;
import com.lowagie.text.pdf.PdfContentByte;
import com.lowagie.text.pdf.PdfPTable;
import com.lowagie.text.pdf.PdfWriter;

/**
 * Name: PdfHelper<br>
 * Description: Provides PDF processing related helper methods. 
 * 
 * @author lauerc
 */
public class PdfHelper {

  /**
   * Checks whether or not the given table fits into the current page.
   * @param writer The PDF writer.
   * @param doc The document.
   * @param table The table to place.
   * @return true if the table fits the current page, else false.
   * @throws DocumentException In case the check failed.
   */
  public static final boolean fitsPage(PdfWriter writer, Document doc, PdfPTable table)
    throws DocumentException {
    
    PdfContentByte cb = writer.getDirectContent();
    ColumnText columnText = new ColumnText(cb);
    columnText.go(true);
    float yPos = writer.getVerticalPosition(false);
    columnText.setSimpleColumn(doc.left(), doc.bottom(), doc.right(), yPos);
    columnText.addElement(table);
    return columnText.go(true) == ColumnText.NO_MORE_TEXT;
  }

  /**
   * Gets the current vertical position on the current page.
   * @param writer The PDF writer.
   * @return The current vertical position on the current page.
   * @throws DocumentException In case the check failed.
   */
  public static final float getCurrentVerticalPosition(PdfWriter writer)
    throws DocumentException {
    
    return writer.getVerticalPosition(false);
  }
  
}
