/*
 * Copyright (C) 2003, 2004 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print;

/**
 * Name: PdfTableHolder<br>
 * Description: Interface for tags, holding PDF tables.
 * 
 * @author lauerc
 */
public interface PdfTableHolder extends PdfCellContainer {
  
  /**
   * Gets the number of columns, defined for the table.
   * @return The number of columns that have been defined for the table.
   */
  int getNumColumns();
  
  /**
   * Gets the number of content rows, that have been added to the current table so far.
   * @return The number of content rows, that have been added to the current table so far.
   */
  int getNumContentRows();

  /**
   * Checks whether the table fits the current page or not. 
   * @return true if there's room enough for the table on the current page, else false.
   * @throws DocumentHandlerException In case something went wrong.
   */
  boolean fitsPage()  throws DocumentHandlerException;
  
  /**
   * Splits the table vertically.
   * @param newPage Tells whether to start a new page or not.
   * @param keepHeader Tells whether to keep the old header or not.
   * @return true if a split has been really performed, else false.
   * @exception DocumentHandlerException If something went wrong while splitting the table.
   */
  public boolean splitTable(boolean newPage, boolean keepHeader) throws DocumentHandlerException;
  
  
}
