/*
 * Copyright (C) 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print;

import java.util.Map;
import org.xml.sax.Locator;

/**
 * Name: StyleParser<br>
 * Description: An interface for style attribute parsers.
 * 
 * @author lauerc
 */
public interface StyleParser {

  /**
   * Sets the attribute handler.
   * @param attributeHandler The attribute handler to set.
   */
  void setAttributeHandler(AttributeHandler attributeHandler);

  /**
   * Scans the styles from the given string.
   * @param locator The tag source locator.
   * @param styleDef The style definition
   *   (eg 'background-color:#cccccc; text-align:center; font-size:12px;...')"), 
   * @param supportedAttributeMap The map of supported attributes.
   * @param styleMap The map to fill the styles in.
   * @return The number of detected style attributes
   * @exception DocumentHandlerException In case the parsing failed.
   */
  int parseStyle(Locator locator, String styleDef, Map supportedAttributeMap, Map styleMap)
    throws DocumentHandlerException;
  
}
