/*
 * Copyright (C) 2003 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print;

import java.util.Collection;

/**
 * Name: TagBuilder<br>
 * Description: Interface for document tag builders.
 * 
 * @author lauerc
 */
public interface TagBuilder {
  
  /** Constant for the tagName attribute. */
  String ATTR_TAG_NAME = "tagName";
  
  /**
   * Gets the name of the tags, this builder creates.
   * @return The name of the tags, this builder creates.
   */
  String getName();
  
  /**
   * Creates a new tag.
   * @param documentHandler The document handler for which to create the tag instance.
   * @return The created tag.
   * @exception TagInstantiationException In case the tag instantiation failed.
   */
  BaseDocumentTag createTag(DocumentHandler documentHandler) throws TagInstantiationException;
  
  /**
   * Registers an alias for this tag.
   * @param alias The alias to register.
   */
  void registerAlias(String alias);

  /**
   * Unregisters an alias for this tag.
   * @param alias The alias to unregister.
   */
  void unregisterAlias(String alias);

  /**
   * Gets all registered aliases.
   * @return The registered aliases.
   */
  Collection getAliases();
  
}
