/*
 * Copyright (C) 2003, 2004 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print;

/**
 * Name: TocItem<br>
 * Description: A class holding informations about table of contents entries (chapters or sessions for example).
 * 
 * @author lauerc
 */
public class TocItem {

  /** The toc index. */
  private int index;
  /** The toc level. */
  private int level;
  /** The section number text (1, 1.1 1.1.1, etc.) */
  private String number;
  /** The title */
  private String title;
  /** The page where the item is located. */
  private int page = -1;
  /** The vertical position on the page. */
  private float position = -1.0F;
  /** The referring outline. */
  private OutlineItem outline = null;
  /** The toc relevance. */
  private String tocRelevance = null;

  /**
   * Constructs a TocItem instance with specific attributes.
   * @param level The level of the toc entry.
   * @param number The number of the iten. 
   * @param title The title of the item.
   * @param tocRelevance The relevance definition, 'toc': only for TOC, 'index' only for index, 'all': view in both, index and TOC.
   */
  public TocItem(int level, String number, String title, String tocRelevance) {
    this.level = level;
    this.number = number;
    this.title = title;
    this.tocRelevance = tocRelevance;
  }

  /**
   * Constructs a TocItem instance with specific attributes.
   * @param level The level of the toc entry.
   * @param number The number of the iten. 
   * @param title The title of the item.
   * @param tocRelevance The relevance definition, 'toc': only for TOC, 'index' only for index, 'all': view in both, index and TOC.
   * @param page The page where the item is located.
   * @param position The vertical position of the item.
   */
  public TocItem(int level, String number, String title, String tocRelevance, int page, float position) {
    this(level, number, title, tocRelevance);
    this.page = page;
    this.position = position;
  }

  /**
   * Getter method for the the property level.
   * @return The current value of property level.
   */
  public int getLevel() {
    return level;
  }

  /**
   * Getter method for the the property number.
   * @return The current value of property number.
   */
  public String getNumber() {
    return number;
  }

  /**
   * Getter method for the the property title.
   * @return The current value of property title.
   */
  public String getTitle() {
    return title;
  }

  /**
   * Getter method for the the property page.
   * @return The current value of property page.
   */
  public int getPage() {
    return page;
  }
  /**
   * Setter method for the the property page.
   * @param page The value to set for the property page.
   */
  protected void setPage(int page) {
    this.page = page;
  }

  /**
   * Getter method for the the property position.
   * @return The current value of property position.
   */
  public float getPosition() {
    return position;
  }
  /**
   * Setter method for the the property position.
   * @param position The value to set for the property position.
   */
  public void setPosition(float position) {
    this.position = position;
  }


  /**
   * Getter method for the the property outline.
   * @return The current value of property outline.
   */
  public OutlineItem getOutline() {
    return outline;
  }
  /**
   * Setter method for the the property outline.
   * @param outline The value to set for the property outline.
   */
  public void setOutline(OutlineItem outline) {
    this.outline = outline;
  }

  /**
   * Getter method for the the property tocRelevance.
   * @return The current value of property tocRelevance.
   */
  public String getTocRelevance() {
    return tocRelevance;
  }
  /**
   * Setter method for the the property tocRelevance.
   * @param tocRelevance The value to set for the property tocRelevance.
   */
  public void setTocRelevance(String tocRelevance) {
    this.tocRelevance = tocRelevance;
  }

  /**
   * Getter method for the the property index.
   * @return The current value of property index.
   */
  public int getIndex() {
    return index;
  }
  /**
   * Setter method for the the property index.
   * @param index The value to set for the property index.
   */
  public void setIndex(int index) {
    this.index = index;
  }

  /**
   * @see java.lang.Object#toString()
   */
  public String toString() {
    return number + " " + title + " " + page;
  }

}
