/*
 * Copyright (C) 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print;

import org.xml.sax.Attributes;

/**
 * Name: TraceTagInterceptor<br>
 * Description: Implementation of the DocumentTagInterceptor interface for tracing use.
 * 
 * @author lauerc
 */
public class TraceTagInterceptor implements DocumentTagInterceptor {

  /** The level of tag nesting; 1 -> top level. */
  private int level = 0; 
  
  /**
   * @see org.ujac.print.DocumentTagInterceptor#beforeOpen(org.ujac.print.BaseDocumentTag)
   */
  public boolean beforeOpen(BaseDocumentTag tag)
      throws DocumentHandlerException {

    ++level;
    System.out.print(getIndentation() + "<" + tag.getName());
    Attributes attributes = tag.getAttributes();
    int numAttributes = attributes.getLength();
    for (int i = 0; i < numAttributes; i++) {
      String name = attributes.getLocalName(i);
      String value = attributes.getValue(i);
      System.out.print(" " + name + "\"" + value + "\"");
    }
    System.out.println(">");
    return true;
  }

  /**
   * @see org.ujac.print.DocumentTagInterceptor#afterOpen(org.ujac.print.BaseDocumentTag)
   */
  public void afterOpen(BaseDocumentTag tag) throws DocumentHandlerException {
  }

  /**
   * @see org.ujac.print.DocumentTagInterceptor#beforeClose(org.ujac.print.BaseDocumentTag)
   */
  public boolean beforeClose(BaseDocumentTag tag)
    throws DocumentHandlerException {
    
    return true;
  }
  
  /**
   * @see org.ujac.print.DocumentTagInterceptor#afterClose(org.ujac.print.BaseDocumentTag)
   */
  public void afterClose(BaseDocumentTag tag)
    throws DocumentHandlerException {
    
    System.out.println(getIndentation() + "</" + tag.getName() + ">");
    --level;
  }
  
  /**
   * Gets the indentation for the current level.
   * @return The according indentation.
   */
  private String getIndentation() {
    StringBuffer indentBuf = new StringBuffer();
    for (int i = 1; i < level; i++) {
      indentBuf.append("  ");
    }
    return indentBuf.toString();
  }

}
