/*
 * Copyright (C) 2003 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print;

import java.io.IOException;

import com.lowagie.text.DocumentException;
import com.lowagie.text.pdf.BaseFont;

/**
 * Name: TrueTypeFontHolder<br>
 * Description: A class holding true type fonts for the possible font styles.
 * 
 * @author lauerc
 */
public class TrueTypeFontHolder {

  /** The font name. */
  private String name = null;
  
  //added by Kiran
  /** The font should be embedded. */
  private boolean embedded = false;
  //added by Kiran
  /** The font should be cached. */
  private boolean cached = true;  

  /** The normal font. */
  private BaseFont normalFont = null;
  /** The bold font. */
  private BaseFont boldFont = null;
  /** The italic font. */
  private BaseFont italicFont = null;
  /** The bold+italic font. */
  private BaseFont boldItalicFont = null;

  /**
   * Constructs a TrueTypeFontHolder instance with specific attributes.
   * @param name The font name.
   */
  public TrueTypeFontHolder(String name) {
    this.name = name;
  }

  /**
   * Getter method for the the property name.
   * @return The current value of property name.
   */
  public String getName() {
    return name;
  }
  /**
   * Setter method for the the property name.
   * @param name The value to set for the property name.
   */
  public void setName(String name) {
    this.name = name;
  }

  /**
   * Getter method for the the property embedded.
   * @return The current value of property embedded.
   */
  public boolean getEmbedded() {
    return embedded;
  }
  /**
   * Setter method for the the property embedded.
   * @param embedded The value to set for the property embedded.
   */
  public void setEmbedded(boolean embedded) {
    this.embedded = embedded;
  }

  /**
   * Getter method for the the property cached.
   * @return The current value of property cached.
   */
  public boolean getCached() {
    return cached;
  }
  /**
   * Setter method for the the property cached.
   * @param cached The value to set for the property cached.
   */
  public void setCached(boolean cached) {
    this.cached = cached;
  }

  /**
   * Getter method for the the property normalFont.
   * @return The current value of property normalFont.
   */
  public BaseFont getNormalFont() {
    return normalFont;
  }
  /**
   * Setter method for the the property normalFont.
   * @param ttfAfm The TTF font data.
   * @exception IOException In case the base font creation failed.
   * @exception DocumentException In case the base font creation failed.
   */
  public void setNormalFont(byte[] ttfAfm) throws IOException, DocumentException {
    // creating base font
    // Changed by Kiran
    this.normalFont = BaseFont.createFont(
        name + ".ttf", BaseFont.IDENTITY_H, 
        embedded, cached, ttfAfm, null
    );
  }

  /**
   * Getter method for the the property boldFont.
   * @return The current value of property boldFont.
   */
  public BaseFont getBoldFont() {
    return boldFont;
  }
  /**
   * Setter method for the the property boldFont.
   * @param ttfAfm The TTF font data.
   * @exception IOException In case the base font creation failed.
   * @exception DocumentException In case the base font creation failed.
   */
  public void setBoldFont(byte[] ttfAfm) throws IOException, DocumentException {
    // creating base font
    this.boldFont = BaseFont.createFont(
        name + "-bold.ttf", BaseFont.IDENTITY_H, 
        embedded, cached, ttfAfm, null
    );
  }

  /**
   * Getter method for the the property italicFont.
   * @return The current value of property italicFont.
   */
  public BaseFont getItalicFont() {
    return italicFont;
  }
  /**
   * Setter method for the the property italicFont.
   * @param ttfAfm The TTF font data.
   * @exception IOException In case the base font creation failed.
   * @exception DocumentException In case the base font creation failed.
   */
  public void setItalicFont(byte[] ttfAfm) throws IOException, DocumentException {
    // creating base font
    this.italicFont = BaseFont.createFont(
        name + "-italic.ttf", BaseFont.IDENTITY_H, 
        embedded, cached, ttfAfm, null
    );
  }

  /**
   * Getter method for the the property boldItalicFont.
   * @return The current value of property boldItalicFont.
   */
  public BaseFont getBoldItalicFont() {
    return boldItalicFont;
  }
  /**
   * Setter method for the the property boldItalicFont.
   * @param ttfAfm The TTF font data.
   * @exception IOException In case the base font creation failed.
   * @exception DocumentException In case the base font creation failed.
   */
  public void setBoldItalicFont(byte[] ttfAfm) throws IOException, DocumentException {
    // creating base font
    this.boldItalicFont = BaseFont.createFont(
        name + "-bolditalic.ttf", BaseFont.IDENTITY_H, 
        embedded, cached, ttfAfm, null
    );
  }

}
