/*
 * Copyright (C) 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print;

import org.xml.sax.Locator;

/**
 * Name: TypedAttributeHandler<br>
 * Description: The base class for typed attribute handlers.
 * 
 * @author lauerc
 */
public abstract class TypedAttributeHandler {
  
  /** The attribute handler to use. */
  protected AttributeHandler attributeHandler = null;
  
  /**
   * Constructs a TypedAttributeHandler instance with specific attributes.
   * @param attributeHandler The attribute handler to use.
   */
  public TypedAttributeHandler(AttributeHandler attributeHandler) {
    this.attributeHandler = attributeHandler;
  }
  
  /**
   * Gets the value for the given attribute's name.
   * @param locator The tag source locator.
   * @param attrName The attribute's name.
   * @param attrValue The argument value.
   * @param evaluate If this flag is set to true, the attribute will get evaluated.
   * @return The determined value.
   * @exception TagAttributeException if the item contains an invalid value or an required attribute was not defined.
   */
  public abstract Object parseAttribute(Locator locator, String attrName, Object attrValue, boolean evaluate)
    throws TagAttributeException;

  
}
