/*
 * Copyright (C) 2003 - 2007 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print.tag;

import org.ujac.print.AttributeDefinition;
import org.ujac.print.AttributeDefinitionMap;
import org.ujac.print.BaseDocumentTag;
import org.ujac.print.DocumentHandlerException;

/**
 * Name: AddColumnTag<br>
 * Description: Class handling the &lt;add-column&gt; tag.
 * This tag defines columns for the surrounding &lt;define-table&gt; tag.
 * 
 * @author lauerc
 */
public class AddColumnTag extends BaseDocumentTag {

  /** The item's name. */
  public static final String TAG_NAME = "add-column";

  /** Definition of the 'name' attribute. */
  private static final AttributeDefinition COLUMN_NAME = 
      CommonAttributes.COLUMN_NAME.cloneAttrDef("The name of the column to add.");
  
  /** The surrounding define-table tag. */
  private DefineTableTag defineTable = null;
  
  /** The column  name. */
  private String name = null;
  /** The column type. */
  private String type = null;
  
  /**
   * Constructs a AddColumnTag instance with no specific attributes.
   */
  public AddColumnTag() {
    super(TAG_NAME);
  }

  /**
   * Gets a brief description for the item.
   * @return The item's description.
   */
  public String getDescription() {
    return "Defines a column for the surrounding table." ;
  }

  /**
   * Gets the list of supported attributes.
   * @return The attribute definitions.
   */
  protected AttributeDefinitionMap buildSupportedAttributes() {
    return super.buildSupportedAttributes()
      .addDefinition(COLUMN_NAME)
      .addDefinition(CommonAttributes.COLUMN_TYPE);
  }

  /**
   * Initializes the item. 
   * @exception DocumentHandlerException If something went badly wrong.
   */
  public void initialize() throws DocumentHandlerException {
    super.initialize();
    // getting the surrounding define-table tag.
    this.defineTable = (DefineTableTag) documentHandler.latestOfType(DefineTableTag.class);
  }
  
  /**
   * Opens the item.
   * @exception DocumentHandlerException Thrown in case something went wrong while opening the document item.
   */
  public void openItem() throws DocumentHandlerException {
    super.openItem();

    if (!isValid()) {
      return;
    }

    // getting attributes
    this.name = getStringAttribute(CommonAttributes.COLUMN_NAME, false, null);
    this.type = getStringAttribute(CommonAttributes.COLUMN_TYPE, false, null);
    
    // defines the column for the given table
    defineTable.defineColumn(name, type);
  }
  
}
