/*
 * Copyright (C) 2003 - 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the tems of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print.tag;

import org.ujac.print.AttributeDefinition;
import org.ujac.print.AttributeDefinitionMap;
import org.ujac.print.DocumentHandlerException;
import org.ujac.print.ElementContainer;

import com.lowagie.text.Annotation;

/**
 * Name: AnnotationTag<br>
 * Description: Handler class for the annotation tag.
 * 
 * @author lauerc
 */
public class AnnotationTag extends BaseElementTag {

  /** Definition of the 'title' attribute. */
  private static final AttributeDefinition TITLE = new AttributeDefinition(TagAttributes.ATTR_TITLE, 
      AttributeDefinition.TYPE_STRING, true, "The title of the annotation.");

  /** The item's name. */
  public static final String TAG_NAME = "annotation";
  
  /**
   * Constructs a AnnotationTag instance with no specific attributes.
   */
  public AnnotationTag() {
    super(TAG_NAME);
  }

  /**
   * Gets a brief description for the item.
   * @return The item's description.
   */
  public String getDescription() {
    return "Adds aa annotation to the document.";
  }

  /**
   * Gets the list of supported attributes.
   * @return The attribute definitions.
   */
  protected AttributeDefinitionMap buildSupportedAttributes() {
    return super.buildSupportedAttributes()
      .addDefinition(TITLE);
  }
  
  /**
   * Tells whether textual content is allowed for the tag or not.
   * @return true if the item is allowed to contain textual content, else false.
   */
  public boolean isTextBodyAllowed() {
    return true;
  }

  /**
   * Closes the item.
   * @exception DocumentHandlerException Thrown in case something went wrong while processing the document item.
   */
  public void closeItem() throws DocumentHandlerException {
    if (!isValid()) {
      return;
    }

    Annotation annotation = new Annotation(getTextAttribute(TITLE, true, null), getContent());
    ElementContainer elementContainer = getElementContainer();
    elementContainer.addElement(this, annotation);
  }
 
}
