/*
 * Copyright (C) 2003 - 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print.tag;

import org.ujac.print.AssertionException;
import org.ujac.print.AttributeDefinitionMap;
import org.ujac.print.BaseDocumentTag;
import org.ujac.print.DocumentHandlerException;

import org.ujac.util.exi.ExpressionException;

/**
 * Name: AssertTag<br>
 * Description: Class handling the &lt;assert&gt; tag.
 * 
 * @author lauerc
 */
public class AssertTag extends BaseDocumentTag {

  /** The item's name. */
  public static final String TAG_NAME = "assert";

  /**
   * Constructs a AssertTag instance with no specific attributes.
   */
  public AssertTag() {
    super(TAG_NAME);
  }

  /**
   * Gets a brief description for the item.
   * @return The item's description.
   */
  public String getDescription() {
    return "Tests the given condition and throws an exception in case the result isn't true.";
  }

  /**
   * Gets the list of supported attributes.
   * @return The attribute definitions.
   */
  protected AttributeDefinitionMap buildSupportedAttributes() {
    return super.buildSupportedAttributes()
      .addDefinition(CommonAttributes.CONDITION);
  }

  /**
   * Initializes the item. 
   * @exception DocumentHandlerException If something went badly wrong.
   */
  public void initialize() throws DocumentHandlerException {
    super.initialize();
  }
  
  /**
   * Opens the item.
   * @exception DocumentHandlerException Thrown in case something went wrong while opening the document item.
   */
  public void openItem() throws DocumentHandlerException {
    super.openItem();

    if (!isValid()) {
      return;
    }

    // getting the property value
    String condition = getStringAttribute(CommonAttributes.CONDITION, false, null);
    // testing the condition
    try {
      boolean result = documentHandler.evalBoolean("${" + condition + "}");
      if (!result) {
        throw new AssertionException(locator(), "Assertion failed: " + condition + "!");
      }
    } catch (ExpressionException ex) {
      throw new AssertionException(locator(), "Assertion failed: " + condition + ": " + ex.getMessage(), ex);
    }
  }
   
}
