/*
 * Copyright (C) 2003 - 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.print.tag;

import org.ujac.print.AttributeDefinitionMap;
import org.ujac.print.BaseDocumentTag;
import org.ujac.print.DocumentHandlerException;
import org.ujac.print.ElementContainer;

/**
 * Name: BaseElementTag<br>
 * Description: Base class for items that can be childs of element containers.<br>
 * 
 * @author lauerc
 */
public abstract class BaseElementTag extends BaseDocumentTag {

  /** The element container. */
  private ElementContainer elementContainer = null;
  
  /**
   * Constructs a BaseElementTag instance with specific attributes.
   * @param name The tag name.
   */
  public BaseElementTag(String name) {
    super(name);
  }

  /**
   * Initializes the item. 
   * @exception DocumentHandlerException If something went badly wrong.
   */
  public void initialize() throws DocumentHandlerException {
    super.initialize();
    // setting the element container
    this.elementContainer = documentHandler.latestElementContainer();
  }

  /**
   * Builds the map of supported attributes.
   * @return The attribute definitions.
   */
  protected AttributeDefinitionMap buildSupportedAttributes() {
    return super.buildSupportedAttributes()
      .addDefinition(CommonAttributes.RENDERED);
  }

  /**
   * Opens the item.
   * @exception DocumentHandlerException Thrown in case something went wrong while opening the document item.
   */
  public void openItem() throws DocumentHandlerException {
    super.openItem();

    if (!super.isValid()) {
      return;
    }
    
    // ensure that the document is open here
    documentHandler.getDocument(true);
  }

  /**
   * Gets the element container.
   * In case no element container has been set so far, it 
   * obtains the root element container from the DocumentHandler.
   * @return The current element container.
   */
  public ElementContainer getElementContainer() {
    if (elementContainer == null) {
      elementContainer = documentHandler.latestElementContainer();
    }
    return elementContainer;
  }

}
