/*
 * Copyright (C) 2003 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print.tag;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;

import java.util.zip.GZIPInputStream;

/**
 * Name: BaseImageBuilder<br>
 * Description: Base image builder class.
 * 
 * @author lauerc
 */
public abstract class BaseImageBuilder implements ImageBuilder {
  
  /**
   * Checks whether the image data contains an XML document or not.
   * @param imageData The image data as an byte array.
   * @return true, if the image contains an XML document, else false.
   */
  protected boolean isXml(byte[] imageData) {
    if (imageData.length < 5) {
      return false;
    }

    return ((imageData[0] == '<') && 
            (imageData[1] == '?') && 
            (imageData[2] == 'x') &&
            (imageData[3] == 'm') &&
            (imageData[4] == 'l'));
  }
  
  /**
   * Un-compressing the given image data.
   * @param imageData The image data array.
   * @return The un-compressed data.
   * @throws IOException In case the data was not zip compressed.
   */
  protected byte[] uncompress(byte[] imageData) throws IOException {
    byte[] buffer = new byte[2048];
    GZIPInputStream zis = new GZIPInputStream(new ByteArrayInputStream(imageData));
    ByteArrayOutputStream bos = new ByteArrayOutputStream();
    int numRead = -1;
    while ((numRead = zis.read(buffer, 0, 2048)) != -1) {
      bos.write(buffer, 0, numRead);
    }
    return bos.toByteArray();
  }
  
}
