/*
 * Copyright (C) 2003 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.print.tag;

import org.ujac.print.DocumentHandlerException;

import com.lowagie.text.Font;

/**
 * Name: BoldTag<br>
 * Description: A class handling bold font items.<br>
 * 
 * @author lauerc
 */
public class BoldTag extends BaseFontTag {

  /** The item's name. */
  public static final String TAG_NAME = "b";
  
  /**
   * Constructs a BoldTag instance with no specific attributes.
   */
  public BoldTag() {
    super(TAG_NAME);
  }

  /**
   * Gets a brief description for the item.
   * @return The item's description.
   */
  public String getDescription() {
    return "Changes the document font by adding the 'bold' attribute to the current font.";
  }

  /**
   * Opens the item.
   * @exception DocumentHandlerException Thrown in case something went wrong while opening the document item.
   */
  public void openItem() throws DocumentHandlerException {
    super.openItem();
    
    // manipulating font style
    this.style |= Font.BOLD;
    
    // finally creating font
    createFont();
  }

}
