/*
 * Copyright (C) 2003 - 2007 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.print.tag;

import org.ujac.print.AttributeDefinitionMap;
import org.ujac.print.BaseDocumentTag;
import org.ujac.print.AttributeDefinition;
import org.ujac.print.DocumentHandlerException;

/**
 * Name: CaseTag<br>
 * Description: A class handling 'case' items.<br>
 * 
 * @author lauerc
 */
public class CaseTag extends ConditionTag {

  /** Definition of the 'value' attribute. */
  private static final AttributeDefinition VALUE = new AttributeDefinition(TagAttributes.ATTR_VALUE, AttributeDefinition.TYPE_STRING, false, 
      "The attribute value.");

  /** The item's name. */
  public static final String TAG_NAME = "case";

  /** The surrounding switch item. */
  private SwitchTag switchItem = null;
  /** The value of the case item. */
  private String value = null;

  /**
   * Constructs a CaseTag instance with no specific attributes.
   */
  public CaseTag() {
    super(TAG_NAME);
  }

  /**
   * Gets a brief description for the item.
   * @return The item's description.
   */
  public String getDescription() {
    return "Conditional item, which evalutes its content in case the given value matches the value of the surrounding 'switch' tag.";
  }

  /**
   * Gets the list of supported attributes.
   * @return The attribute definitions.
   */
  protected AttributeDefinitionMap buildSupportedAttributes() {
    return super.buildSupportedAttributes()
      .addDefinition(VALUE);
  }

  /**
   * Initializes the item. 
   * @exception DocumentHandlerException If something went badly wrong.
   */
  public void initialize() throws DocumentHandlerException {
    super.initialize();
    // setting the containers.
    BaseDocumentTag parent = getParentItem();
    if (!(parent instanceof SwitchTag)) {
      throw new DocumentHandlerException(locator(), "The parent of item '" + TAG_NAME + "' must be an '" + SwitchTag.TAG_NAME + "'!");
    }
    this.switchItem = (SwitchTag) parent;
    // setting the attributes
    this.value = getStringAttribute(VALUE, false, null); 
  }

  /**
   * Opens the item.
   * @exception DocumentHandlerException Thrown in case something went wrong while opening the document item.
   */
  public void openItem() throws DocumentHandlerException {
    super.openItem();

    if (!isValid()) {
      result = false;
      return;
    }
    
    super.openItem();
    // evaluating condition
    result = switchItem.equalsValue(value);
  }

}
