/*
 * Copyright (C) 2007 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print.tag;

import org.ujac.print.AttributeDefinition;
import org.ujac.print.BaseDocumentTag;

import com.lowagie.text.pdf.BaseFont;

/**
 * Name: CommonAttributes<br>
 * Description: Defines common tag attributes.
 * 
 * @author lauerc
 */
public interface CommonAttributes extends TagAttributes {
  
  AttributeDefinition ID = new AttributeDefinition(TagAttributes.ATTR_ID, 
      AttributeDefinition.TYPE_NAME, false, "The unique identifier of the item.");
  AttributeDefinition NAME = new AttributeDefinition(TagAttributes.ATTR_NAME, 
      AttributeDefinition.TYPE_NAME, true, "The name of the item.");
  AttributeDefinition STYLE = new AttributeDefinition(TagAttributes.ATTR_STYLE, 
      AttributeDefinition.TYPE_STRING, false, "The attribute style definition to use (eg. " +
      "'border-width:10; border-color: red; padding: 10;...').");
  AttributeDefinition CLASS = new AttributeDefinition(TagAttributes.ATTR_CLASS, 
      AttributeDefinition.TYPE_NAME, false, "The name of the style class to use (see style-def tag).");
  AttributeDefinition RENDERED = new AttributeDefinition(TagAttributes.ATTR_RENDERED, 
      AttributeDefinition.TYPE_BOOLEAN, false, "Rules, whether or not the given element is actually rendered.");

  AttributeDefinition FONT = new AttributeDefinition(TagAttributes.ATTR_FONT, 
      AttributeDefinition.TYPE_NAME, false, "The name of the font definition to use.");
  AttributeDefinition BACKGROUND_COLOR = new AttributeDefinition(TagAttributes.ATTR_BACKGROUND_COLOR, 
      AttributeDefinition.TYPE_COLOR, false, "Defines the background color.");
  AttributeDefinition BORDER_STYLE = new AttributeDefinition(TagAttributes.ATTR_BORDER_STYLE,
      AttributeDefinition.TYPE_BORDER, false, "Defines the border type.");
  AttributeDefinition BORDER_WIDTH = new AttributeDefinition(TagAttributes.ATTR_BORDER_WIDTH, 
      AttributeDefinition.TYPE_DIMENSION, false, "Defines the border width.");
  AttributeDefinition BORDER_COLOR = new AttributeDefinition(TagAttributes.ATTR_BORDER_COLOR, 
      AttributeDefinition.TYPE_COLOR, false, "Defines the border color.");
  AttributeDefinition HORIZONTAL_ALIGNMENT = new AttributeDefinition(TagAttributes.ATTR_HORIZONTAL_ALIGNMENT, 
      AttributeDefinition.TYPE_HORIZONTAL_ALIGNMENT, false, "Defines the horizontal alignment (left|right|center).").addAlias(ATTR_ALIAS_ALIGNMENT);
  AttributeDefinition VERTICAL_ALIGNMENT = new AttributeDefinition(TagAttributes.ATTR_VERTICAL_ALIGNMENT, 
      AttributeDefinition.TYPE_VERTICAL_ALIGNMENT, false, "Defines the vertical alignment (top|bottom|middle).");
  AttributeDefinition CELL_HORIZONTAL_ALIGNMENT = new AttributeDefinition(TagAttributes.ATTR_CELL_HORIZONTAL_ALIGNMENT, 
      AttributeDefinition.TYPE_HORIZONTAL_ALIGNMENT, false, 
      "Defines the horizontal alignment for the nested cells.").addAlias(ATTR_ALIAS_CELL_ALIGNMENT);
  AttributeDefinition CELL_VERTICAL_ALIGNMENT = new AttributeDefinition(TagAttributes.ATTR_CELL_VERTICAL_ALIGNMENT, 
      AttributeDefinition.TYPE_VERTICAL_ALIGNMENT, false, "Defines the vertical alignment for the nested cells.");
  AttributeDefinition TEXT_ALIGNMENT = new AttributeDefinition(TagAttributes.ATTR_TEXT_ALIGNMENT, 
      AttributeDefinition.TYPE_HORIZONTAL_ALIGNMENT, false, "Defines the text alignment.");
  AttributeDefinition PADDING = new AttributeDefinition(TagAttributes.ATTR_PADDING, 
      AttributeDefinition.TYPE_DIMENSION, false, "Defines the padding for all border edges.");
  AttributeDefinition PADDING_LEFT = new AttributeDefinition(TagAttributes.ATTR_PADDING_LEFT, 
      AttributeDefinition.TYPE_DIMENSION, false, "Defines the left padding.");
  AttributeDefinition PADDING_RIGHT = new AttributeDefinition(TagAttributes.ATTR_PADDING_RIGHT, 
      AttributeDefinition.TYPE_DIMENSION, false, "Defines the right padding.");
  AttributeDefinition PADDING_TOP = new AttributeDefinition(TagAttributes.ATTR_PADDING_TOP, 
      AttributeDefinition.TYPE_DIMENSION, false, "Defines the top padding.");
  AttributeDefinition PADDING_BOTTOM = new AttributeDefinition(TagAttributes.ATTR_PADDING_BOTTOM, 
      AttributeDefinition.TYPE_DIMENSION, false, "Defines the bottom padding.");
  AttributeDefinition LINE_SPACING = new AttributeDefinition(TagAttributes.ATTR_LINE_SPACING, 
      AttributeDefinition.TYPE_DIMENSION, false, "The line spacing factor for contents (is " + 
      BaseDocumentTag.DEFAULT_LINE_SPACING + ").");
  AttributeDefinition LEADING = new AttributeDefinition(TagAttributes.ATTR_LEADING, 
      AttributeDefinition.TYPE_DIMENSION, false, "The fixed vertical leading distance.");
  AttributeDefinition SPACING_BEFORE = new AttributeDefinition(TagAttributes.ATTR_SPACING_BEFORE, 
      AttributeDefinition.TYPE_DIMENSION, false, "The vertical spacing before the items.");
  AttributeDefinition SPACING_AFTER = new AttributeDefinition(TagAttributes.ATTR_SPACING_AFTER, 
      AttributeDefinition.TYPE_DIMENSION, false, "The vertical spacing after the items.");
  AttributeDefinition TRIM_BODY = new AttributeDefinition(TagAttributes.ATTR_TRIM_BODY, 
      AttributeDefinition.TYPE_BOOLEAN, false, "Tells whether to trim the body or not, default behaviour is " +
      "not to trim the contents of the tag's body.");
  AttributeDefinition KEEP_TOGETHER = new AttributeDefinition(TagAttributes.ATTR_KEEP_TOGETHER, 
      AttributeDefinition.TYPE_BOOLEAN, false, "Tells whether or not the items's contents should be kept " +
      "together on one page.");

  AttributeDefinition PAGE_SIZE = new AttributeDefinition(TagAttributes.ATTR_SIZE, 
      AttributeDefinition.TYPE_PAGE_SIZE, false, "The page size (LETTER|NOTE|LEGAL|A0|A1|A2|A3|A4|A5|A6|A7|A8|A9|A10|" +
      "B0|B1|B2|B3|B4|B5).");
  AttributeDefinition PAGE_WIDTH = new AttributeDefinition(TagAttributes.ATTR_WIDTH, 
      AttributeDefinition.TYPE_DIMENSION, false, "The page-width can be used alternatively together with page-height " +
      "to define a custom document size.");
  AttributeDefinition PAGE_HEIGHT = new AttributeDefinition(TagAttributes.ATTR_HEIGHT, 
      AttributeDefinition.TYPE_DIMENSION, false, "The page-height can be used alternatively together with page-width " +
      "to define a custom document size.");
  AttributeDefinition PAGE_ROTATE = new AttributeDefinition(TagAttributes.ATTR_ROTATE, 
      AttributeDefinition.TYPE_BOOLEAN, false, "The rotation flag, if true the page gets rotated 90 degrees clockwise.");

  AttributeDefinition COLOR = new AttributeDefinition(TagAttributes.ATTR_COLOR, 
      AttributeDefinition.TYPE_COLOR, false, "The foreground color.");


  AttributeDefinition COLSPAN = new AttributeDefinition(TagAttributes.ATTR_COLSPAN, 
      AttributeDefinition.TYPE_INT, false, "The column span of the cell.");
  AttributeDefinition FILL_ROW = new AttributeDefinition(TagAttributes.ATTR_FILL_ROW, 
      AttributeDefinition.TYPE_BOOLEAN, false, "Tells whether or not to fill up the current table row.");
  AttributeDefinition NO_WRAP = new AttributeDefinition(TagAttributes.ATTR_NO_WRAP, 
      AttributeDefinition.TYPE_BOOLEAN, false, "The no wrap flag.");
  AttributeDefinition ROTATE = new AttributeDefinition(TagAttributes.ATTR_ROTATE, 
      AttributeDefinition.TYPE_FLOAT, false, "The rotation angle.");
  AttributeDefinition ROTATE_FLAG = new AttributeDefinition(TagAttributes.ATTR_ROTATE, 
      AttributeDefinition.TYPE_BOOLEAN, false, "The rotation flag.");
  
  AttributeDefinition INDENTATION = new AttributeDefinition(TagAttributes.ATTR_INDENTATION, 
      AttributeDefinition.TYPE_DIMENSION, false, "The indentation of the content.");

  AttributeDefinition MARGIN_LEFT = new AttributeDefinition(TagAttributes.ATTR_MARGIN_LEFT, 
      AttributeDefinition.TYPE_DIMENSION, false, "The left margin.");
  AttributeDefinition MARGIN_RIGHT = new AttributeDefinition(TagAttributes.ATTR_MARGIN_RIGHT, 
      AttributeDefinition.TYPE_DIMENSION, false, "The right margin.");
  AttributeDefinition MARGIN_TOP = new AttributeDefinition(TagAttributes.ATTR_MARGIN_TOP, 
      AttributeDefinition.TYPE_DIMENSION, false, "The top margin.");
  AttributeDefinition MARGIN_BOTTOM = new AttributeDefinition(TagAttributes.ATTR_MARGIN_BOTTOM, 
      AttributeDefinition.TYPE_DIMENSION, false, "The bottom margin.");
  
  AttributeDefinition FONT_NAME = new AttributeDefinition(TagAttributes.ATTR_NAME, 
      AttributeDefinition.TYPE_NAME, true, "The name of the font definition.");
  AttributeDefinition FONT_COLOR = new AttributeDefinition(TagAttributes.ATTR_COLOR, 
      AttributeDefinition.TYPE_COLOR, false, "The font color.");
  AttributeDefinition FONT_FAMILY = new AttributeDefinition("family", 
      AttributeDefinition.TYPE_FONT_FAMILY, false, "The font family.").addAlias(ATTR_FONT_FAMILY);
  AttributeDefinition FONT_ENCODING = new AttributeDefinition("encoding", 
      new String[] {
          BaseFont.CP1250, BaseFont.CP1252, BaseFont.CP1257, 
          "UniGB-UCS2-H", "UniGB-UCS2-V", 
          "UniCNS-UCS2-H", "UniCNS-UCS2-V", 
          "UniJIS-UCS2-H", "UniJIS-UCS2-V", "UniJIS-UCS2-HW-H", "UniJIS-UCS2-HW-V", 
          "UniKS-UCS2-H", "UniKS-UCS2-V"
      }, false, "The font encoding (default is " + BaseFont.WINANSI + "). For encodings " +
      " different from " + BaseFont.CP1250 + ", " + BaseFont.CP1252 + " and " + 
      BaseFont.CP1257 + " make sure that the asian extensions (iTextAsian.jar) are " +
      "available in your class path.").addAlias(TagAttributes.ATTR_FONT_ENCODING);
  
  AttributeDefinition FONT_SIZE = new AttributeDefinition(TagAttributes.ATTR_SIZE, 
      AttributeDefinition.TYPE_DIMENSION, false, "The font size.").addAlias(ATTR_FONT_SIZE);
  AttributeDefinition FONT_STYLE = new AttributeDefinition(TagAttributes.ATTR_FONT_STYLE, 
      AttributeDefinition.TYPE_FONT_STYLE, false, "For undecorated fonts use 'normal'. Otherwise define one of these, or " +
      "a combination of them: bold|italic|oblique|underline|line-through.");
  AttributeDefinition TEXT_RISE = new AttributeDefinition(TagAttributes.ATTR_TEXT_RISE, 
      AttributeDefinition.TYPE_DIMENSION, false, "The text displacement relative to the baseline. Positive values rise the " +
      "text, negative values lower the text.");

  AttributeDefinition CELL_HEIGHT = new AttributeDefinition(TagAttributes.ATTR_HEIGHT, AttributeDefinition.TYPE_DIMENSION, false, 
      "Defines a fixed height for the nested cells.");
  AttributeDefinition TABLE_WIDTH = new AttributeDefinition(TagAttributes.ATTR_WIDTH, AttributeDefinition.TYPE_FLOAT, false, 
      "The table widths in percent (default is 100.0).");
  AttributeDefinition TABLE_WIDTHS = new AttributeDefinition(TagAttributes.ATTR_WIDTHS, AttributeDefinition.TYPE_STRING, false, 
      "The table widths, a comma separated list of percentual column widths.");
  AttributeDefinition TABLE_COLUMNS = new AttributeDefinition(TagAttributes.ATTR_COLUMNS, AttributeDefinition.TYPE_INT, false, 
      "The number of table columns.");
  AttributeDefinition TABLE_SPLIT_ROWS = new AttributeDefinition(TagAttributes.ATTR_SPLIT_ROWS, AttributeDefinition.TYPE_BOOLEAN, false, 
      "Tells whether to split table rows accross pages or not.");
  AttributeDefinition TABLE_SPLIT_LATE = new AttributeDefinition(TagAttributes.ATTR_SPLIT_LATE, AttributeDefinition.TYPE_BOOLEAN, false, 
      "Tells whether to split rows late or not. If true the row will " +
      "only split if it's the first one in an empty page.");
  AttributeDefinition GROUP_NAME = new AttributeDefinition(TagAttributes.ATTR_GROUP_NAME, AttributeDefinition.TYPE_NAME, false, 
      "The name of the supported group.");
  AttributeDefinition TABLE_HALIGN =  
      CommonAttributes.HORIZONTAL_ALIGNMENT.cloneAttrDef("The horizontal alignment of the table.");
  
  AttributeDefinition IMAGE_X = new AttributeDefinition(TagAttributes.ATTR_X, AttributeDefinition.TYPE_DIMENSION, false,
      "The horizontal position, needed for absolute positioning. In case you've " +
      "specified a negative value, the image will be placed relative to the right " +
      "page border");
  AttributeDefinition IMAGE_Y = new AttributeDefinition(TagAttributes.ATTR_Y, AttributeDefinition.TYPE_DIMENSION, false,
      "The vertical position, needed for absolute positioning. In case you've " +
      "specified a negative value, the image will be placed relative to the top " +
      "page border");
  AttributeDefinition IMAGE_WIDTH = new AttributeDefinition(TagAttributes.ATTR_WIDTH, AttributeDefinition.TYPE_DIMENSION, false,
      "The image width, if no height is given, the image height is " +
      "scaled with the same factor to keep the image proportions.");
  AttributeDefinition IMAGE_HEIGHT = new AttributeDefinition(TagAttributes.ATTR_HEIGHT, AttributeDefinition.TYPE_DIMENSION, false,
      "The image height, if no width is given, the image width is " +
      "scaled with the same factor to keep the image proportions.");
  AttributeDefinition SCALE_TO_FIT = new AttributeDefinition(TagAttributes.ATTR_SCALE_TO_FIT, AttributeDefinition.TYPE_BOOLEAN, false,
      "Tells whether to scale the image to fit the given width and " +
      "height by keeping the original aspect ratio.");
  AttributeDefinition IMAGE_ROTATE = new AttributeDefinition(TagAttributes.ATTR_ROTATE, AttributeDefinition.TYPE_FLOAT, false,
      "The image rotation angle.");
  AttributeDefinition IMAGE_SOURCE = new AttributeDefinition(TagAttributes.ATTR_SOURCE, AttributeDefinition.TYPE_STRING, true,
      "The image source can be the path to the image to load via " +
      "ResourceLoader or an expression that resolves to an java.awt.Image " +
      "or an com.lowagie.text.Image instance.");
  AttributeDefinition IMAGE_PAGE = new AttributeDefinition(TagAttributes.ATTR_PAGE, AttributeDefinition.TYPE_INT, false,
      "The page from the source to use as image, this is currently " +
      "only supported for PDF documents.");
  AttributeDefinition IMAGE_HORIZONTAL_ALIGNMENT = 
    HORIZONTAL_ALIGNMENT.cloneAttrDef("The image's horizontal alignment (left|right|center).");
  AttributeDefinition IMAGE_VERTICAL_ALIGNMENT =
    VERTICAL_ALIGNMENT.cloneAttrDef("The image's vertical alignment (top|bottom|middle).");

  AttributeDefinition IMAGE_TEXTWRAP = new AttributeDefinition(TagAttributes.ATTR_TEXTWRAP, AttributeDefinition.TYPE_BOOLEAN, false,
      "The text wrap flag.");
  AttributeDefinition IMAGE_UNDERLYING = new AttributeDefinition(TagAttributes.ATTR_UNDERLYING, AttributeDefinition.TYPE_BOOLEAN, false,
      "The underlying flag.");
  AttributeDefinition IMAGE_DRAW_FOREGROUND = new AttributeDefinition(ATTR_DRAW_FOREGROUND, AttributeDefinition.TYPE_BOOLEAN, false,
      "Tells whether to draw the image in the foreground " +
      "or in the background.");

  AttributeDefinition BOX_X = new AttributeDefinition(TagAttributes.ATTR_X, AttributeDefinition.TYPE_DIMENSION, true,
      "The horizontal position of the box. In case you've specified a " +
      "negative value, the box will be placed relative to the right " +
      "page border");
  AttributeDefinition BOX_Y = new AttributeDefinition(TagAttributes.ATTR_Y, AttributeDefinition.TYPE_DIMENSION, true,
      "The vertical position of the box. In case you've specified a " +
      "negative value, the box will be placed relative to the top " +
      "page border");
  AttributeDefinition BOX_WIDTH = new AttributeDefinition(TagAttributes.ATTR_WIDTH, AttributeDefinition.TYPE_DIMENSION, true,
      "The width of the box.");
  AttributeDefinition BOX_HEIGHT = new AttributeDefinition(TagAttributes.ATTR_HEIGHT, AttributeDefinition.TYPE_DIMENSION, true,
      "The height of the box.");


  AttributeDefinition ALTER_TABLE = new AttributeDefinition(TagAttributes.ATTR_TABLE, AttributeDefinition.TYPE_NAME, true, 
      "The name of the table to modify.");
  AttributeDefinition ALTER_DISTINCT = new AttributeDefinition(TagAttributes.ATTR_DISTINCT, AttributeDefinition.TYPE_BOOLEAN, false, 
      "Tells whether or not to allow duplicates.");
  
  AttributeDefinition TABLE_NAME = new AttributeDefinition(TagAttributes.ATTR_NAME, AttributeDefinition.TYPE_NAME, true, 
      "The name of the table to define.");


  AttributeDefinition COLUMN_NAME = new AttributeDefinition(TagAttributes.ATTR_NAME, AttributeDefinition.TYPE_NAME, false, 
      "The column name.");
  AttributeDefinition COLUMN_INDEX = new AttributeDefinition(TagAttributes.ATTR_INDEX, AttributeDefinition.TYPE_INT, false, 
      "The column name.");
  AttributeDefinition COLUMN_WIDTH = new AttributeDefinition(TagAttributes.ATTR_WIDTH, AttributeDefinition.TYPE_FLOAT, false, 
      "The column width.");
  AttributeDefinition COLUMN_TITLE = new AttributeDefinition(TagAttributes.ATTR_TITLE, AttributeDefinition.TYPE_STRING, false, 
      "The column title.");
  AttributeDefinition COLUMN_TYPE = new AttributeDefinition(TagAttributes.ATTR_TYPE,
      new String [] {"int", "float", "long", "double", "String", "Date", "Time", "Timestamp", "Object"}, 
      true, "The data type to use for this column.");
  AttributeDefinition COLUMN_REFERENCE = new AttributeDefinition(TagAttributes.ATTR_REFERENCE, AttributeDefinition.TYPE_STRING, true,
      "The reference column at which to insert the new column.");
  AttributeDefinition COLUMN_DIRECTION = new AttributeDefinition(TagAttributes.ATTR_DIRECTION, AttributeDefinition.TYPE_NAME, false, 
      "The insert direction: 'before' | 'after'.");
  
  AttributeDefinition CONDITION = new AttributeDefinition(TagAttributes.ATTR_CONDITION, AttributeDefinition.TYPE_STRING, true, 
      "The condition to test, this may be a boolean constant, but will mostly be an expression.");

  AttributeDefinition LOOP_VARIABLE = new AttributeDefinition(ATTR_LOOP_VARIABLE, 
      AttributeDefinition.TYPE_NAME, true, "The loop variable, holds the current value from the " +
      "specified sequence. Together with the loop variable there will be a property available called variable + 'Idx', " +
      "which holds the index of the current element from the sequence.");
  
  AttributeDefinition SEQUENCE = new AttributeDefinition(ATTR_SEQUENCE, 
      AttributeDefinition.TYPE_STRING, true, "An expression evaluating to a valid sequence. Valid " +
      "sequences are objects of each type that implement a public method called 'iterator()' which serves an " +
      "instance that implements the interface java.util.Iterator.");

  AttributeDefinition CHAPTER_NUMBER = new AttributeDefinition(TagAttributes.ATTR_NUMBER, 
      AttributeDefinition.TYPE_INT, false, "The number of the chapter.");
  AttributeDefinition CHAPTER_TITLE = new AttributeDefinition(TagAttributes.ATTR_TITLE, 
      AttributeDefinition.TYPE_STRING, false, "The title of the chapter.");
  AttributeDefinition CHAPTER_TITLE_FONT = new AttributeDefinition(TagAttributes.ATTR_TITLE_FONT, 
      AttributeDefinition.TYPE_NAME, false, "The font to use for the chapter title output.");

  AttributeDefinition SECTION_NUMBER_DEPTH = new AttributeDefinition(TagAttributes.ATTR_NUMBER_DEPTH, 
      AttributeDefinition.TYPE_INT, false, "The numbering depth.");
  AttributeDefinition SECTION_TITLE = new AttributeDefinition(TagAttributes.ATTR_TITLE, 
      AttributeDefinition.TYPE_STRING, false, "The title of the section.");
  AttributeDefinition SECTION_TITLE_FONT = new AttributeDefinition(TagAttributes.ATTR_TITLE_FONT, 
      AttributeDefinition.TYPE_NAME, false, "The font to use for the section title output.");

  AttributeDefinition TOC_RELEVANCE = new AttributeDefinition("toc-relevance",
      new String[] {"toc", "index", "all"}, false, "Defined the relevance of the item for the table of contents or index of the document.");

  AttributeDefinition CHART_TITLE = new AttributeDefinition(TagAttributes.ATTR_TITLE, 
      AttributeDefinition.TYPE_STRING, false, "The title of the chart.", 
      "Use text-chart-item named 'title' instead.");
  AttributeDefinition CHART_TITLE_FONT = new AttributeDefinition(TagAttributes.ATTR_TITLE_FONT, 
      AttributeDefinition.TYPE_NAME, false, "The font to use for the chart title rendering.",
      "Use text-chart-item named 'title' instead.");
  AttributeDefinition CHART_TYPE = new AttributeDefinition(TagAttributes.ATTR_TYPE, 
      AttributeDefinition.TYPE_NAME, false, 
      "The chart type, currently supported types are 'line-2d', 'bar-2d', 'pie-2d', 'pie-3d' and 'donut-3d'.");
  AttributeDefinition CHART_INSTANCE = new AttributeDefinition(TagAttributes.ATTR_INSTANCE, 
      AttributeDefinition.TYPE_STRING, false, "An expression, resolving to a chart instance.");

  AttributeDefinition PDF_VERSION = new AttributeDefinition(TagAttributes.ATTR_PDF_VERSION, 
      AttributeDefinition.TYPE_INT, false, "The Version of the generated PDF.");
  AttributeDefinition LOGICAL_PAGENUMBERING = new AttributeDefinition(TagAttributes.ATTR_LOGICAL_PAGENUMBERING, 
      AttributeDefinition.TYPE_INT, false, "The Logical Page Numbering style of the generated PDF (" +
      "0: arabic numerals, 1: uppercase roman numerals, 2: lowercase roman numerals" +
      ", 3: uppercase letters, 4: lowercase letters, 5: empty (No logical page " +
      "numbers are generated but fixed text may still exist)).");
  AttributeDefinition LOGICAL_PAGETEXT = new AttributeDefinition(TagAttributes.ATTR_LOGICAL_PAGETEXT, 
      AttributeDefinition.TYPE_STRING, false, "The Logical Page Numbering style text of the generated PDF.");

  AttributeDefinition PARAM_NAME = new AttributeDefinition(TagAttributes.ATTR_NAME, 
      AttributeDefinition.TYPE_NAME, true, "The name of the paremeter.");

  AttributeDefinition PROPERTY_NAME = new AttributeDefinition(TagAttributes.ATTR_NAME, 
      AttributeDefinition.TYPE_NAME, true, "The name of the property to set.");
  AttributeDefinition PROPERTY_TYPE = new AttributeDefinition(TagAttributes.ATTR_TYPE,
      new String [] {"int", "float", "long", "double", "String", "Date", "Time", "Timestamp", "Object"}, 
      true, "The type of the property to set, supported types are: " + 
      "int, long, float, double, String, Date, Time, Timestamp and Object.");
  AttributeDefinition PROPERTY_VALUE = new AttributeDefinition(TagAttributes.ATTR_VALUE, 
      AttributeDefinition.TYPE_STRING, false,  "The value to set for the property. In case of numeric or " +
      "date/time values international format will be used for parsing.");
  AttributeDefinition PROPERTY_A = new AttributeDefinition(TagAttributes.ATTR_A, 
      AttributeDefinition.TYPE_STRING, false,  "The first value to set for the property. In case of numeric or " +
      "date/time values international format will be used for parsing.");
  AttributeDefinition PROPERTY_B = new AttributeDefinition(TagAttributes.ATTR_B, 
      AttributeDefinition.TYPE_STRING, false,  "The second value to set for the property. In case of numeric or " +
      "date/time values international format will be used for parsing.");

  AttributeDefinition FORMAT = new AttributeDefinition(TagAttributes.ATTR_FORMAT, 
      AttributeDefinition.TYPE_STRING, false, "The format to use for output of numeric or date values.");
  
}
