/*
 * Copyright (C) 2007, 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print.tag;

import org.ujac.print.AttributeDefinition;
import org.ujac.print.BaseDocumentTag;

import com.lowagie.text.pdf.BaseFont;

/**
 * Name: CommonStyleAttributes<br>
 * Description: Defines common style attributes.
 * 
 * @author lauerc
 */
public interface CommonStyleAttributes extends TagAttributes {

  AttributeDefinition FONT = new AttributeDefinition(TagAttributes.ATTR_FONT, AttributeDefinition.TYPE_NAME, false,
      "The name of the font definition to use.");
  AttributeDefinition BACKGROUND_COLOR = new AttributeDefinition("background-color", AttributeDefinition.TYPE_COLOR, false, 
      "Defines the background color.");

  AttributeDefinition BORDER_STYLE = new AttributeDefinition(TagAttributes.ATTR_BORDER_STYLE, AttributeDefinition.TYPE_BORDER, false, 
      "Defines the border type.");
  AttributeDefinition BORDER_WIDTH = new AttributeDefinition(TagAttributes.ATTR_BORDER_WIDTH, AttributeDefinition.TYPE_DIMENSION, false, 
      "Defines the border width.");
  AttributeDefinition BORDER_COLOR = new AttributeDefinition(TagAttributes.ATTR_BORDER_COLOR, AttributeDefinition.TYPE_COLOR, false, 
      "Defines the border color.");

  AttributeDefinition BORDER_LEFT = new AttributeDefinition("border-left", AttributeDefinition.TYPE_BORDER, false, 
      "A shorthand property for setting all of the properties for the left border in one declaration.");
  AttributeDefinition BORDER_LEFT_COLOR = new AttributeDefinition("border-left-color", AttributeDefinition.TYPE_COLOR, false, 
      "Sets the color of the left border.");
  AttributeDefinition BORDER_LEFT_WIDTH = new AttributeDefinition("border-left-width", AttributeDefinition.TYPE_DIMENSION, false, 
      "Sets the width of the left border.");
  AttributeDefinition BORDER_RIGHT = new AttributeDefinition("border-right", AttributeDefinition.TYPE_BORDER, false, 
      "A shorthand property for setting all of the properties for the right border in one declaration.");
  AttributeDefinition BORDER_RIGHT_COLOR = new AttributeDefinition("border-right-color", AttributeDefinition.TYPE_COLOR, false, 
      "Sets the color of the right border.");
  AttributeDefinition BORDER_RIGHT_WIDTH = new AttributeDefinition("border-right-width", AttributeDefinition.TYPE_DIMENSION, false, 
      "Sets the width of the right border.");
  AttributeDefinition BORDER_TOP = new AttributeDefinition("border-top", AttributeDefinition.TYPE_BORDER, false, 
      "A shorthand property for setting all of the properties for the top border in one declaration.");
  AttributeDefinition BORDER_TOP_COLOR = new AttributeDefinition("border-top-color", AttributeDefinition.TYPE_COLOR, false, 
      "Sets the color of the top border.");
  AttributeDefinition BORDER_TOP_WIDTH = new AttributeDefinition("border-top-width", AttributeDefinition.TYPE_DIMENSION, false, 
      "Sets the width of the top border.");
  AttributeDefinition BORDER_BOTTOM = new AttributeDefinition("border-bottom", AttributeDefinition.TYPE_BORDER, false, 
      "A shorthand property for setting all of the properties for the right border in one declaration.");
  AttributeDefinition BORDER_BOTTOM_COLOR = new AttributeDefinition("border-bottom-color", AttributeDefinition.TYPE_COLOR, false, 
      "Sets the color of the bottom border.");
  AttributeDefinition BORDER_BOTTOM_WIDTH = new AttributeDefinition("border-bottom-width", AttributeDefinition.TYPE_DIMENSION, false, 
      "Sets the width of the bottom border.");
  
  AttributeDefinition HORIZONTAL_ALIGNMENT = new AttributeDefinition("horizontal-align", AttributeDefinition.TYPE_HORIZONTAL_ALIGNMENT, false, 
      "Defines the horizontal alignment (left|right|center).");
  AttributeDefinition VERTICAL_ALIGNMENT = new AttributeDefinition("vertical-align", AttributeDefinition.TYPE_VERTICAL_ALIGNMENT, false, 
      "Defines the vertical alignment (top|bottom|middle).");
  AttributeDefinition CELL_HORIZONTAL_ALIGNMENT = new AttributeDefinition(TagAttributes.ATTR_CELL_HORIZONTAL_ALIGNMENT, AttributeDefinition.TYPE_HORIZONTAL_ALIGNMENT, false, 
      "Defines the horizontal alignment for the nested cells.").addAlias(ATTR_ALIAS_CELL_ALIGNMENT);
  AttributeDefinition CELL_VERTICAL_ALIGNMENT = new AttributeDefinition(TagAttributes.ATTR_CELL_VERTICAL_ALIGNMENT, AttributeDefinition.TYPE_VERTICAL_ALIGNMENT, false, 
      "Defines the vertical alignment for the nested cells.");
  AttributeDefinition TEXT_ALIGNMENT = new AttributeDefinition(TagAttributes.ATTR_TEXT_ALIGNMENT, AttributeDefinition.TYPE_HORIZONTAL_ALIGNMENT, false, 
    "Defines the text alignment.");
  AttributeDefinition PADDING = new AttributeDefinition(TagAttributes.ATTR_PADDING, AttributeDefinition.TYPE_DIMENSION, false, 
      "Defines the padding for all border edges.");
  AttributeDefinition PADDING_LEFT = new AttributeDefinition(TagAttributes.ATTR_PADDING_LEFT, AttributeDefinition.TYPE_DIMENSION, false, 
      "Defines the left padding.");
  AttributeDefinition PADDING_RIGHT = new AttributeDefinition(TagAttributes.ATTR_PADDING_RIGHT, AttributeDefinition.TYPE_DIMENSION, false, 
      "Defines the right padding.");
  AttributeDefinition PADDING_TOP = new AttributeDefinition(TagAttributes.ATTR_PADDING_TOP, AttributeDefinition.TYPE_DIMENSION, false, 
      "Defines the top padding.");
  AttributeDefinition PADDING_BOTTOM = new AttributeDefinition(TagAttributes.ATTR_PADDING_BOTTOM, AttributeDefinition.TYPE_DIMENSION, false, 
      "Defines the bottom padding.");
  AttributeDefinition LINE_SPACING = new AttributeDefinition(TagAttributes.ATTR_LINE_SPACING, AttributeDefinition.TYPE_DIMENSION, false,
      "The line spacing factor for contents (is " + 
      BaseDocumentTag.DEFAULT_LINE_SPACING + ").");
  AttributeDefinition LEADING = new AttributeDefinition(TagAttributes.ATTR_LEADING, AttributeDefinition.TYPE_DIMENSION, false,
      "The fixed vertical leading distance.");
  AttributeDefinition SPACING_BEFORE = new AttributeDefinition(TagAttributes.ATTR_SPACING_BEFORE, AttributeDefinition.TYPE_DIMENSION, false,
      "The vertical spacing before the items.");
  AttributeDefinition SPACING_AFTER = new AttributeDefinition(TagAttributes.ATTR_SPACING_AFTER, AttributeDefinition.TYPE_DIMENSION, false,
      "The vertical spacing after the items.");
  AttributeDefinition TRIM_BODY = new AttributeDefinition(TagAttributes.ATTR_TRIM_BODY, AttributeDefinition.TYPE_BOOLEAN, false,
      "Tells whether to trim the body or not, default behaviour is " +
      "not to trim the contents of the tag's body.");
  AttributeDefinition KEEP_TOGETHER = new AttributeDefinition(TagAttributes.ATTR_KEEP_TOGETHER, AttributeDefinition.TYPE_BOOLEAN, false,
      "Tells whether or not the items's contents should be kept " +
      "together on one page.");

  AttributeDefinition PAGE_SIZE = new AttributeDefinition(TagAttributes.ATTR_SIZE, AttributeDefinition.TYPE_PAGE_SIZE, false,
      "The page size (LETTER|NOTE|LEGAL|A0|A1|A2|A3|A4|A5|A6|A7|A8|A9|A10|" +
      "B0|B1|B2|B3|B4|B5).");
  AttributeDefinition PAGE_WIDTH = new AttributeDefinition(TagAttributes.ATTR_WIDTH, AttributeDefinition.TYPE_DIMENSION, false,
      "The page-width can be used alternatively together with page-height " +
      "to define a custom document size.");
  AttributeDefinition PAGE_HEIGHT = new AttributeDefinition(TagAttributes.ATTR_HEIGHT, AttributeDefinition.TYPE_DIMENSION, false,
      "The page-height can be used alternatively together with page-width " +
      "to define a custom document size.");
  AttributeDefinition PAGE_ROTATE = new AttributeDefinition(TagAttributes.ATTR_ROTATE, AttributeDefinition.TYPE_BOOLEAN, false,
      "The rotation flag, if true the page gets rotated 90 degrees clockwise.");

  AttributeDefinition COLOR = new AttributeDefinition(TagAttributes.ATTR_COLOR, AttributeDefinition.TYPE_COLOR, false,
      "The foreground color.");


  AttributeDefinition COLSPAN = new AttributeDefinition(TagAttributes.ATTR_COLSPAN, AttributeDefinition.TYPE_INT, false, 
      "The column span of the cell.");
  AttributeDefinition FILL_ROW = new AttributeDefinition(TagAttributes.ATTR_FILL_ROW, AttributeDefinition.TYPE_BOOLEAN, false, 
      "Tells whether or not to fill up the current table row.");
  AttributeDefinition NO_WRAP = new AttributeDefinition(TagAttributes.ATTR_NO_WRAP, AttributeDefinition.TYPE_BOOLEAN, false, 
      "The no wrap flag.");
  AttributeDefinition ROTATE = new AttributeDefinition(TagAttributes.ATTR_ROTATE, AttributeDefinition.TYPE_FLOAT, false,
      "The rotation angle.");
  AttributeDefinition ROTATE_FLAG = new AttributeDefinition(TagAttributes.ATTR_ROTATE, AttributeDefinition.TYPE_BOOLEAN, false,
      "The rotation flag.");
  
  AttributeDefinition INDENTATION = new AttributeDefinition(TagAttributes.ATTR_INDENTATION, AttributeDefinition.TYPE_DIMENSION, false,
      "The indentation of the content.");

  AttributeDefinition MARGIN_LEFT = new AttributeDefinition(TagAttributes.ATTR_MARGIN_LEFT, AttributeDefinition.TYPE_DIMENSION, false,
      "The left margin.");
  AttributeDefinition MARGIN_RIGHT = new AttributeDefinition(TagAttributes.ATTR_MARGIN_RIGHT, AttributeDefinition.TYPE_DIMENSION, false,
      "The right margin.");
  AttributeDefinition MARGIN_TOP = new AttributeDefinition(TagAttributes.ATTR_MARGIN_TOP, AttributeDefinition.TYPE_DIMENSION, false,
      "The top margin.");
  AttributeDefinition MARGIN_BOTTOM = new AttributeDefinition(TagAttributes.ATTR_MARGIN_BOTTOM, AttributeDefinition.TYPE_DIMENSION, false,
      "The bottom margin.");
  
  AttributeDefinition FONT_NAME = new AttributeDefinition(TagAttributes.ATTR_FONT_NAME, AttributeDefinition.TYPE_NAME, true,
      "The name of the font definition.");
  AttributeDefinition FONT_COLOR = new AttributeDefinition(TagAttributes.ATTR_FONT_COLOR, AttributeDefinition.TYPE_COLOR, false,
      "The font color.");
  AttributeDefinition FONT_FAMILY = new AttributeDefinition(TagAttributes.ATTR_FONT_FAMILY, AttributeDefinition.TYPE_FONT_FAMILY, false,
      "The font family.").addAlias("family");
  AttributeDefinition FONT_ENCODING = new AttributeDefinition(TagAttributes.ATTR_FONT_ENCODING, 
      new String[] {
          BaseFont.CP1250, BaseFont.CP1252, BaseFont.CP1257, 
          "UniGB-UCS2-H", "UniGB-UCS2-V", 
          "UniCNS-UCS2-H", "UniCNS-UCS2-V", 
          "UniJIS-UCS2-H", "UniJIS-UCS2-V", "UniJIS-UCS2-HW-H", "UniJIS-UCS2-HW-V", 
          "UniKS-UCS2-H", "UniKS-UCS2-V"
      }, false, "The font encoding (default is " + BaseFont.WINANSI + "). For encodings " +
      " different from " + BaseFont.CP1250 + ", " + BaseFont.CP1252 + " and " + 
      BaseFont.CP1257 + " make sure that the asian extensions (iTextAsian.jar) are " +
      "available in your class path.");
  
  AttributeDefinition FONT_SIZE = new AttributeDefinition(TagAttributes.ATTR_FONT_SIZE, AttributeDefinition.TYPE_DIMENSION, false,
      "The font size.");
  AttributeDefinition FONT_STYLE = new AttributeDefinition(TagAttributes.ATTR_FONT_STYLE, AttributeDefinition.TYPE_FONT_STYLE, false,
      "For undecorated fonts use 'normal'. Otherwise define one of these, or " +
      "a combination of them: bold|italic|oblique|underline|line-through.");
  AttributeDefinition TEXT_RISE = new AttributeDefinition(TagAttributes.ATTR_TEXT_RISE, AttributeDefinition.TYPE_DIMENSION, false,
      "The text displacement relative to the baseline. Positive values rise the " +
      "text, negative values lower the text.");

  AttributeDefinition CELL_HEIGHT = new AttributeDefinition("cell-height", AttributeDefinition.TYPE_DIMENSION, false, 
      "Defines a fixed height for the nested cells.");
  AttributeDefinition TABLE_WIDTH = new AttributeDefinition(TagAttributes.ATTR_WIDTH, AttributeDefinition.TYPE_FLOAT, false, 
      "The table widths in percent (default is 100.0).");
  AttributeDefinition TABLE_SPLIT_ROWS = new AttributeDefinition(TagAttributes.ATTR_SPLIT_ROWS, AttributeDefinition.TYPE_BOOLEAN, false, 
      "Tells whether to split table rows accross pages or not.");
  AttributeDefinition TABLE_SPLIT_LATE = new AttributeDefinition(TagAttributes.ATTR_SPLIT_LATE, AttributeDefinition.TYPE_BOOLEAN, false, 
      "Tells whether to split rows late or not. If true the row will " +
      "only split if it's the first one in an empty page.");

  
  AttributeDefinition IMAGE_X = new AttributeDefinition("image-x", AttributeDefinition.TYPE_DIMENSION, false,
      "The horizontal position, needed for absolute positioning. In case you've " +
      "specified a negative value, the image will be placed relative to the right " +
      "page border");
  AttributeDefinition IMAGE_Y = new AttributeDefinition("image-y", AttributeDefinition.TYPE_DIMENSION, false,
      "The vertical position, needed for absolute positioning. In case you've " +
      "specified a negative value, the image will be placed relative to the top " +
      "page border");
  AttributeDefinition IMAGE_WIDTH = new AttributeDefinition("image-width", AttributeDefinition.TYPE_DIMENSION, false,
      "The image width, if no height is given, the image height is " +
      "scaled with the same factor to keep the image proportions.");
  AttributeDefinition IMAGE_HEIGHT = new AttributeDefinition("image-height", AttributeDefinition.TYPE_DIMENSION, false,
      "The image height, if no width is given, the image width is " +
      "scaled with the same factor to keep the image proportions.");
  AttributeDefinition SCALE_TO_FIT = new AttributeDefinition("image-scale-to-fit", AttributeDefinition.TYPE_BOOLEAN, false,
      "Tells whether to scale the image to fit the given width and " +
      "height by keeping the original aspect ratio.");
  AttributeDefinition IMAGE_ROTATE = new AttributeDefinition(TagAttributes.ATTR_ROTATE, AttributeDefinition.TYPE_FLOAT, false,
      "The image rotation angle.");
  AttributeDefinition IMAGE_SOURCE = new AttributeDefinition(TagAttributes.ATTR_SOURCE, AttributeDefinition.TYPE_STRING, true,
      "The image source can be the path to the image to load via " +
      "ResourceLoader or an expression that resolves to an java.awt.Image " +
      "or an com.lowagie.text.Image instance.");
  AttributeDefinition IMAGE_PAGE = new AttributeDefinition(TagAttributes.ATTR_PAGE, AttributeDefinition.TYPE_INT, false,
      "The page from the source to use as image, this is currently " +
      "only supported for PDF documents.");
  AttributeDefinition IMAGE_HORIZONTAL_ALIGNMENT = new AttributeDefinition("image-horizontal-align", 
      AttributeDefinition.TYPE_HORIZONTAL_ALIGNMENT, false, "The image's horizontal alignment (left|right|center).");
  AttributeDefinition IMAGE_VERTICAL_ALIGNMENT = new AttributeDefinition("image-vertical-align", 
      AttributeDefinition.TYPE_VERTICAL_ALIGNMENT, false, "The image's vertical alignment (top|bottom|middle).");

  AttributeDefinition IMAGE_TEXTWRAP = new AttributeDefinition(TagAttributes.ATTR_TEXTWRAP, AttributeDefinition.TYPE_BOOLEAN, false,
      "The text wrap flag.");
  AttributeDefinition IMAGE_UNDERLYING = new AttributeDefinition(TagAttributes.ATTR_UNDERLYING, AttributeDefinition.TYPE_BOOLEAN, false,
      "The underlying flag.");
  AttributeDefinition IMAGE_DRAW_FOREGROUND = new AttributeDefinition(ATTR_DRAW_FOREGROUND, AttributeDefinition.TYPE_BOOLEAN, false,
      "Tells whether to draw the image in the foreground " +
      "or in the background.");

  AttributeDefinition BOX_X = new AttributeDefinition(TagAttributes.ATTR_X, AttributeDefinition.TYPE_DIMENSION, true,
      "The horizontal position of the box. In case you've specified a " +
      "negative value, the box will be placed relative to the right " +
      "page border");
  AttributeDefinition BOX_Y = new AttributeDefinition(TagAttributes.ATTR_Y, AttributeDefinition.TYPE_DIMENSION, true,
      "The vertical position of the box. In case you've specified a " +
      "negative value, the box will be placed relative to the top " +
      "page border");
  AttributeDefinition BOX_WIDTH = new AttributeDefinition(TagAttributes.ATTR_WIDTH, AttributeDefinition.TYPE_DIMENSION, true,
      "The width of the box.");
  AttributeDefinition BOX_HEIGHT = new AttributeDefinition(TagAttributes.ATTR_HEIGHT, AttributeDefinition.TYPE_DIMENSION, true,
      "The height of the box.");

  AttributeDefinition CHAPTER_TITLE_FONT = new AttributeDefinition(TagAttributes.ATTR_TITLE_FONT, 
      AttributeDefinition.TYPE_NAME, false, "The font to use for the chapter title output.");

  AttributeDefinition SECTION_TITLE_FONT = new AttributeDefinition(TagAttributes.ATTR_TITLE_FONT, 
      AttributeDefinition.TYPE_NAME, false, "The font to use for the section title output.");

  AttributeDefinition TOC_RELEVANCE = new AttributeDefinition("toc-relevance",
      new String[] {"toc", "index", "all"}, false, "Defined the relevance of the item for the table of contents or index of the document.");

  AttributeDefinition CHART_TITLE_FONT = new AttributeDefinition(TagAttributes.ATTR_TITLE_FONT, 
      AttributeDefinition.TYPE_NAME, false, "The font to use for the chart title rendering.");
  AttributeDefinition CHART_TYPE = new AttributeDefinition(TagAttributes.ATTR_TYPE, 
      AttributeDefinition.TYPE_NAME, false, 
      "The chart type, currently supported types are 'line-2d', 'bar-2d', 'pie-2d', 'pie-3d' and 'donut-3d'.");

}
