/*
 * Copyright (C) 2003, 2004 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.print.tag;

import org.ujac.print.BaseDocumentTag;
import org.ujac.print.DocumentHandlerException;

/**
 * Name: DefaultTag<br>
 * Description: A class handling 'default' items.<br>
 * 
 * @author lauerc
 */
public class DefaultTag extends ConditionTag {

  /** The item's name. */
  public static final String TAG_NAME = "default";

  /** The surrounding switch item. */
  private SwitchTag switchItem = null;

  /**
   * Constructs a DefaultTag instance with no specific attributes.
   */
  public DefaultTag() {
    super(TAG_NAME);
  }

  /**
   * Gets a brief description for the item.
   * @return The item's description.
   */
  public String getDescription() {
    return "Conditional item, which evalutes its content in case no occurred 'case' item matched the value of the surrounding 'switch' tag so far.";
  }

  /**
   * Initializes the item. 
   * @exception DocumentHandlerException If something went badly wrong.
   */
  public void initialize() throws DocumentHandlerException {
    super.initialize();
    // setting the containers.
    BaseDocumentTag parent = getParentItem();
    if (!(parent instanceof SwitchTag)) {
      throw new DocumentHandlerException(locator(), "The parent of item '" + TAG_NAME + "' must be an '" + SwitchTag.TAG_NAME + "'!");
    }
    this.switchItem = (SwitchTag) parent;
  }

  /**
   * Opens the item.
   * @exception DocumentHandlerException Thrown in case something went wrong while opening the document item.
   */
  public void openItem() throws DocumentHandlerException {
    super.openItem();
    if (!isValid()) {
      result = false;
      return;
    }

    // evaluating condition
    result = !switchItem.isMatchFound();
  }

}
