/*
 * Copyright (C) 2003 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.print.tag;

import org.ujac.print.Condition;
import org.ujac.print.DocumentHandlerException;

/**
 * Name: ElseTag.java<br>
 * Description: A class handling else items.<br>
 * 
 * @author lauerc
 */
public class ElseTag extends ConditionTag {

  /** The item's name. */
  public static final String TAG_NAME = "else";
  /** The previously defined if item (must be the else item's direct predecessor!). */
  private Condition previousIf;

  /**
   * Constructs a ElseTag instance with no specific attributes.
   */
  public ElseTag() {
    super(TAG_NAME);
  }

  /**
   * Gets a brief description for the item.
   * @return The item's description.
   */
  public String getDescription() {
    return "Conditional item, which evalutes its content in case a previous if tag's condition didn't evaluate to true.";
  }

  /**
   * Initializes the item. 
   * @exception DocumentHandlerException If something went badly wrong.
   */
  public void initialize() throws DocumentHandlerException {
    super.initialize();
    
    if (previousIf == null) {
      // derminining the previous 'if' item
      try {
        previousIf = (Condition) getPreviousItem();
        if (previousIf == null) {
          throw new DocumentHandlerException(locator(), "The 'else' item must follow immediately after a 'if' item.");
        }
      } catch (ClassCastException ex) {
        throw new DocumentHandlerException(locator(), "The 'else' item must follow immediately after a 'if' item.", ex);
      }
    }
  }

  /**
   * Opens the item.
   * @exception DocumentHandlerException Thrown in case something went wrong while opening the document item.
   */
  public void openItem() throws DocumentHandlerException {
    super.openItem();
    if (!isValid()) {
      result = false;
      return;
    }

    // setting the reverse result of the condition.
    result = !previousIf.isTrue();
  }

}
