/*
 * Copyright (C) 2003 - 2007 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print.tag;

import java.io.IOException;

import org.ujac.print.DocumentHandler;

import com.lowagie.text.Image;

/**
 * Name: ImageBuilder<br>
 * Description: An interface for image builders, used by the ImageTag class.
 * 
 * @author lauerc
 */
public interface ImageBuilder {
  
  /**
   * Checks, if the implementation is capable of handling the given image data or not.
   * @param imageData The image data to handle.
   * @return true if this implementation can build a image from the given data, else false.
   */
  boolean checkFormat(byte[] imageData);
  
  /**
   * Builds an image from the given data.
   * @param documentHandler The document handler.
   * @param imageData The image data to handle.
   * @param path The path, where the image is located at the resoure loader.
   * @param width The desired output width for the image (zero if unspecified).
   * @param height The desired output height for the image (zero if unspecified).
   * @param page The number of the page to use as image, useless for the most image builders.
   * @return The generated image.
   * @exception IOException In case the image creation failed.
   */
  Image buildImage(DocumentHandler documentHandler, byte[] imageData, 
                   String path, float width, float height, int page)
    throws IOException;

}
