/*
 * Copyright (C) 2003 - 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.print.tag;

import org.ujac.print.AttributeDefinitionMap;
import org.ujac.print.BaseDocumentTag;
import org.ujac.print.DocumentHandlerException;
import org.ujac.print.ItemHolder;

/**
 * Name: ItemTag<br>
 * Description: A class handling simple list items.
 * 
 * @author lauerc
 */
public class ItemTag extends BaseDocumentTag {

  /** The item's name. */
  public static final String TAG_NAME = "item";

  /** The item holder. */
  private ItemHolder itemHolder = null;

  /**
   * Constructs a ItemTag instance with no specific attributes.
   */
  public ItemTag() {
    super(TAG_NAME);
  }

  /**
   * @see org.ujac.print.BaseDocumentTag#getDescription()
   */
  public String getDescription() {
    return "Adds values to the surrounding item holder. Known item holders tags are: parameter.";
  }

  /**
   * @see org.ujac.print.BaseDocumentTag#buildSupportedAttributes()
   */
  protected AttributeDefinitionMap buildSupportedAttributes() {
    return super.buildSupportedAttributes()
      .addDefinition(CommonAttributes.RENDERED);
  }

  /**
   * Tells whether textual content is allowed for the tag or not.
   * @return true if the item is allowed to contain textual content, else false.
   */
  public boolean isTextBodyAllowed() {
    return true;
  }
  
  /**
   * Initializes the item. 
   * @exception DocumentHandlerException If something went badly wrong.
   */
  public void initialize() throws DocumentHandlerException {
    super.initialize();
    // getting parents
    this.itemHolder = (ItemHolder) documentHandler.latestOfType(ItemHolder.class);
  }

  /**
   * Opens the item.
   * @exception DocumentHandlerException Thrown in case something went wrong while opening the document item.
   */
  public void openItem() throws DocumentHandlerException {
    super.openItem();
  }

  /**
   * Closes the item.
   * @exception DocumentHandlerException Thrown in case something went wrong while processing the document item.
   */
  public void closeItem() throws DocumentHandlerException {
    if (!isValid()) {
      return;
    }

    itemHolder.addItem(itemHolder.parseItem(getContent()));
  }

}
