/*
 * Copyright (C) 2003 - 2007 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print.tag;

import org.ujac.print.AttributeDefinitionMap;
import org.ujac.print.BaseDocumentTag;
import org.ujac.print.ChildDefinition;
import org.ujac.print.ChildDefinitionMap;

/**
 * Name: ModuleTag<br>
 * Description: A tag to use as root tag for imported files.
 * 
 * @author lauerc
 */
public class ModuleTag extends BaseDocumentTag {

  /** The item's name. */
  public static final String TAG_NAME = "module";

  /**
   * Is the item a possible document root tag, such as &lt;document&gt; or &lt;module&gt;.
   * @return true if the item is a possible root tag, else false.
   */
  public boolean isDocumentRoot() {
    return true;
  }

  /**
   * Constructs a ModuleTag instance with no specific attributes.
   */
  public ModuleTag() {
    super(TAG_NAME);
  }

  /**
   * Gets a brief description for the item.
   * @return The item's description.
   */
  public String getDescription() {
    return "This tag is intended as the root element of modules, imported into a " +
        "document using the import tag. It actually does nothing, it's only needed " +
        "to fulfill the prescriptions of the XML specification.";
  }

  /**
   * Gets the list of supported attributes.
   * @return The attribute definitions.
   */
  protected AttributeDefinitionMap buildSupportedAttributes() {
    return null;
  }

  /**
   * Gets the list of supported childs.
   * @return The child definitions.
   */
  public ChildDefinitionMap buildSupportedChilds() {
    return super.buildSupportedChilds()
      .addDefinition(new ChildDefinition(RegisterFontTag.class, 0, ChildDefinition.UNLIMITED))
      .addDefinition(new ChildDefinition(RegisterTagTag.class, 0, ChildDefinition.UNLIMITED))
      .addDefinition(new ChildDefinition(StyleDefTag.class, 0, ChildDefinition.UNLIMITED))
      .addDefinition(new ChildDefinition(ColorDefTag.class, 0, ChildDefinition.UNLIMITED)) 
      .addDefinition(new ChildDefinition(FontDefTag.class, 0, ChildDefinition.UNLIMITED))
      .addDefinition(new ChildDefinition(CustomTagTag.class, 0, ChildDefinition.UNLIMITED)) 
      .addDefinition(new ChildDefinition(MacroDefTag.class, 0, ChildDefinition.UNLIMITED))
      .addDefinition(new ChildDefinition(MacroTag.class, 0, ChildDefinition.UNLIMITED));
  }

  /**
   * Is the item virtual container, such as if, else or foreach.
   * @return true if the item is such a container, else false.
   */
  public boolean isVirtualContainer() {
    return true;
  }

}
