/*
 * Copyright (C) 2003 - 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.print.tag;

import org.ujac.print.AttributeDefinitionMap;
import org.ujac.print.BaseDocumentTag;
import org.ujac.print.DocumentHandlerException;
import org.ujac.print.ElementContainer;

import com.lowagie.text.Phrase;

/**
 * Name: NewLineTag<br>
 * Description: Class handling new-line items.<br>
 * 
 * @author lauerc
 */
public class NewLineTag extends BaseElementTag {

  /** The item's name. */
  public static final String TAG_NAME = "br";

  /**
   * Constructs a NewLineTag instance with no specific attributes.
   */
  public NewLineTag() {
    super(TAG_NAME);
  }

  /**
   * Gets a brief description for the item.
   * @return The item's description.
   */
  public String getDescription() {
    return "Adds a linefeed to its parent item.";
  }

  /**
   * Gets the list of supported attributes.
   * @return The attribute definitions.
   */
  protected AttributeDefinitionMap buildSupportedAttributes() {
    return null;
  }

  /**
   * @see org.ujac.print.tag.BaseElementTag#initialize()
   */
  public void initialize() throws DocumentHandlerException {
    super.initialize();
  }

  /**
   * Closes the item.
   * @exception DocumentHandlerException Thrown in case something went wrong while processing the document item.
   */
  public void closeItem() throws DocumentHandlerException {
    if (!isValid()) {
      return;
    }

    ElementContainer elementContainer = getElementContainer();
    elementContainer.addElement(this, new Phrase("\n", getFont().getFont()));
    ((BaseDocumentTag) elementContainer).setTrimNextHead(true);
  }
}
