/*
 * Copyright (C) 2003 - 2007 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.print.tag;


import org.ujac.print.PdfCellContainer;
import org.ujac.print.DocumentHandlerException;
import com.lowagie.text.pdf.PdfPCell;

/**
 * Name: PdfCellTag<br>
 * Description: A class handling 'cell' items.<br>
 * 
 * @author lauerc
 */
public class PdfCellTag extends BaseCellTag {

  /** The item's name. */
  public static final String TAG_NAME = "cell";
  
  /** The cell container. */
  private PdfCellContainer cellContainer = null;

  /**
   * Constructs a PdfCellTag instance with no specific attributes.
   */
  public PdfCellTag() {
    super(TAG_NAME);
  }

  /**
   * Gets a brief description for the item.
   * @return The item's description.
   */
  public String getDescription() {
    return "Adds a cell to its surrounding table or surrounding cell.";
  }

  /**
   * Initializes the item. 
   * @exception DocumentHandlerException If something went badly wrong.
   */
  public void initialize() throws DocumentHandlerException {
    super.initialize();
    // setting the cell container.
    this.cellContainer = documentHandler.latestPdfCellContainer();
  }

  /**
   * Opens the item.
   * @exception DocumentHandlerException Thrown in case something went wrong while opening the document item.
   */
  public void openItem() throws DocumentHandlerException {
    super.openItem();

    if (!isValid()) {
      return;
    }

    if (fillRow) {
      this.colspan = this.cellContainer.getRemainingPdfColumns();
    }
  }

  /**
   * Gets the parent attributes.
   * @return The parent attributes.
   */
  protected CellAttributes getParentAttributes() {
    return cellContainer.getCellAttributes();
  }

  /**
   * Closes the item.
   * @exception DocumentHandlerException Thrown in case something went wrong while closing the cell tag.
   */
  public void closeItem() throws DocumentHandlerException {
    if (!isValid()) {
      return;
    }
    super.closeItem();

    itemClosed = true;

    PdfPCell cell = getCell();
    if (cell == null) {
      // cell has not been created, building empty cell
      cell = buildCell();
    }
    
    // adding cell to latest cell container
    cellContainer.addCell(this, cell);
  }
  
}
