/*
 * Copyright (C) 2003 - 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print.tag;

import org.ujac.print.AttributeDefinitionMap;
import org.ujac.print.Condition;
import org.ujac.print.FontHolder;
import org.ujac.print.TagAttributeException;

import org.ujac.util.table.GroupRow;
import org.ujac.util.table.Row;
import org.ujac.util.table.TableConstants;

/**
 * Name: PrintHeaderRowTag<br>
 * Description: A class printing group rows.
 * 
 * @author lauerc
 */
public class PrintGroupRowTag 
  extends PrintRowTag
  implements FontHolder, Condition, RowCellContainer {
    
  /** The item's name. */
  public static final String TAG_NAME = "print-group-row";
  
  /**
   * Constructs a PrintGroupRowTag instance with no specific attributes.
   */
  public PrintGroupRowTag() {
    super(TAG_NAME);
  }

  /**
   * Gets a brief description for the item.
   * @return The item's description.
   */
  public String getDescription() {
    return "Prints the contents of group rows.";
  }

  /**
   * Gets the list of supported attributes.
   * @return The attribute definitions.
   */
  protected AttributeDefinitionMap buildSupportedAttributes() {
    return super.buildSupportedAttributes()
      .addDefinition(CommonAttributes.CLASS)
      .addDefinition(CommonAttributes.STYLE)
      .addDefinition(CommonAttributes.GROUP_NAME)
      .addDefinition(CommonAttributes.FONT)
      .addDefinition(CommonAttributes.LEADING)
      .addDefinition(CommonAttributes.LINE_SPACING)
      .addDefinition(CommonAttributes.BACKGROUND_COLOR)
      .addDefinition(CommonAttributes.BORDER_STYLE)
      .addDefinition(CommonAttributes.BORDER_WIDTH)
      .addDefinition(CommonAttributes.BORDER_COLOR)
      .addDefinition(CommonAttributes.HORIZONTAL_ALIGNMENT)
      .addDefinition(CommonAttributes.VERTICAL_ALIGNMENT)
      .addDefinition(CommonAttributes.PADDING)
      .addDefinition(CommonAttributes.PADDING_LEFT)
      .addDefinition(CommonAttributes.PADDING_RIGHT)
      .addDefinition(CommonAttributes.PADDING_TOP)
      .addDefinition(CommonAttributes.PADDING_BOTTOM)
      .addDefinition(CommonAttributes.CELL_HEIGHT)
      .addDefinition(CommonAttributes.ROTATE)
      .addDefinition(CommonAttributes.NO_WRAP);
  }

  /**
   * Gets the list of supported style attributes.
   * @return The attribute style definitions.
   */
  protected AttributeDefinitionMap buildSupportedStyleAttributes() {
    return super.buildSupportedStyleAttributes()
      .addDefinition(CommonStyleAttributes.FONT_NAME)
      .addDefinition(CommonStyleAttributes.LEADING)
      .addDefinition(CommonStyleAttributes.LINE_SPACING)
      .addDefinition(CommonStyleAttributes.BACKGROUND_COLOR)
      .addDefinition(CommonStyleAttributes.BORDER_STYLE)
      .addDefinition(CommonStyleAttributes.BORDER_WIDTH)
      .addDefinition(CommonStyleAttributes.BORDER_LEFT_WIDTH)
      .addDefinition(CommonStyleAttributes.BORDER_RIGHT_WIDTH)
      .addDefinition(CommonStyleAttributes.BORDER_TOP_WIDTH)
      .addDefinition(CommonStyleAttributes.BORDER_BOTTOM_WIDTH)
      .addDefinition(CommonStyleAttributes.BORDER_COLOR)
      .addDefinition(CommonStyleAttributes.BORDER_LEFT_COLOR)
      .addDefinition(CommonStyleAttributes.BORDER_RIGHT_COLOR)
      .addDefinition(CommonStyleAttributes.BORDER_TOP_COLOR)
      .addDefinition(CommonStyleAttributes.BORDER_BOTTOM_COLOR)
      .addDefinition(CommonStyleAttributes.HORIZONTAL_ALIGNMENT)
      .addDefinition(CommonStyleAttributes.VERTICAL_ALIGNMENT)
      .addDefinition(CommonStyleAttributes.PADDING)
      .addDefinition(CommonStyleAttributes.PADDING_LEFT)
      .addDefinition(CommonStyleAttributes.PADDING_RIGHT)
      .addDefinition(CommonStyleAttributes.PADDING_TOP)
      .addDefinition(CommonStyleAttributes.PADDING_BOTTOM)
      .addDefinition(CommonStyleAttributes.CELL_HEIGHT)
      .addDefinition(CommonStyleAttributes.ROTATE)
      .addDefinition(CommonStyleAttributes.NO_WRAP);
  }
  
  /**
   * @see org.ujac.print.Condition#isTrue()
   */
  public boolean isTrue() {
    Row currentRow = (Row) rowContainer.getCurrentValue();
    try {
      if ((currentRow != null) && TableConstants.ROW_TYPE_GROUP.equals(currentRow.getType())) {
        String groupName = getStringAttribute(CommonAttributes.GROUP_NAME, true, null);
        GroupRow groupRow = (GroupRow) currentRow;
        if ((groupName != null) && !groupName.equals(groupRow.getGroupName())) {
          return false;
        }
        return true;
      }
      return false;
    } catch (TagAttributeException ex) {
      throw new RuntimeException(ex.getMessage());
    }
  }
  
}
