/*
 * Copyright (C) 2003 - 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print.tag;

import org.ujac.print.Condition;
import org.ujac.print.DocumentHandlerException;
import org.ujac.print.FontHolder;

import org.ujac.util.table.Row;
import org.ujac.util.table.TableConstants;

import com.lowagie.text.pdf.PdfPTable;

/**
 * Name: PrintHeaderRowTag<br>
 * Description: A class printing header rows.
 * 
 * @author lauerc
 */
public class PrintHeaderRowTag 
  extends PrintRowTag
  implements FontHolder, Condition, RowCellContainer {
    
  /** The item's name. */
  public static final String TAG_NAME = "print-header-row";
  
  /**
   * Constructs a PrintHeaderRowTag instance with no specific attributes.
   */
  public PrintHeaderRowTag() {
    super(TAG_NAME);
  }

  /**
   * Gets a brief description for the item.
   * @return The item's description.
   */
  public String getDescription() {
    return "Prints the contents of table header rows.";
  }

  /**
   * Opens the item.
   * @exception DocumentHandlerException Thrown in case something went wrong while opening the foreach item.
   */
  public void openItem() throws DocumentHandlerException {
    super.openItem();

    if (!isValid()) {
      return;
    }
    
    if (isTrue()) {
      this.rowContainer.splitTable(false, false);
    }
  }

  /**
   * Closes the item.
   * @exception DocumentHandlerException Thrown in case something went wrong while closing the foreach item.
   */
  public void closeItem() throws DocumentHandlerException {
    super.closeItem();
    
    if (!isValid()) {
      return;
    }
    if (isTrue()) {
      PdfPTable table = this.rowContainer.getTable();
      if (table != null) {
        table.setHeaderRows(rowContainer.getNumRows());
      }
    }
  }

  /**
   * @see org.ujac.print.Condition#isTrue()
   */
  public boolean isTrue() {
    Row currentRow = (Row) rowContainer.getCurrentValue();
    return (currentRow != null) && TableConstants.ROW_TYPE_HEADER.equals(currentRow.getType());
  }
  
  /**
   * Tells whether the row is a header row or not.
   * @return true in case the row is a header row, else false.
   */
  protected boolean isHeaderRow() {
    return true;
  }

}
