/*
 * Copyright (C) 2003 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print.tag;

import java.io.IOException;

import org.ujac.print.DocumentHandler;

import com.lowagie.text.BadElementException;
import com.lowagie.text.Image;

/**
 * Name: RasterImageBuilder<br>
 * Description: ImageBuilder implementation for raster image formats.
 * 
 * @author lauerc
 */
public class RasterImageBuilder extends BaseImageBuilder {

  /**
   * Checks, if the implementation is capable of handling the given image data or not.
   * @param imageData The image data to handle.
   * @return true if this implementation can build a image from the given data, else false.
   */
  public boolean checkFormat(byte[] imageData) {
    return !isXml(imageData);
  }
  
  /**
   * Builds an image from the given data.
   * @param documentHandler The document handler.
   * @param imageData The image data to handle.
   * @param path The path, where the image is located at the resoure loader.
   * @param width The desired output width for the image (zero if unspecified).
   * @param height The desired output height for the image (zero if unspecified).
   * @param page The number of the page to use as image, useless for this image builder.
   * @return The generated image.
   * @exception IOException In case the image creation failed.
   */
  public Image buildImage(DocumentHandler documentHandler, byte[] imageData, 
                          String path, float width, float height, int page) 
    throws IOException {
    
    try {
      // creating image from raster data.
      return Image.getInstance(imageData);
    } catch (BadElementException ex) {
      throw new IOException("Unable to create raster image: " + ex.getMessage());
    }
  }

}
