/*
 * Copyright (C) 2003 - 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print.tag;

import org.ujac.print.AttributeDefinition;
import org.ujac.print.AttributeDefinitionMap;
import org.ujac.print.BaseDocumentTag;
import org.ujac.print.DocumentHandlerException;

/**
 * Name: RemveColumnTag<br>
 * Description: A tag implementation removing columns from surrounding print-table tags.
 * 
 * @author lauerc
 */
public class RemoveColumnTag extends BaseDocumentTag {

  /** The item's name. */
  public static final String TAG_NAME = "remove-column";
  
  /** Definition of the 'NAME' attribute. */
  private static final AttributeDefinition COLUMN_NAME = 
      CommonAttributes.COLUMN_NAME.cloneAttrDef("The name of the column to remove.");
  
  /** The surrounding print-table tag. */
  private PrintTableTag printTableTag = null;
  
  /**
   * Constructs a RemoveColumnTag instance with no specific attributes.
   */
  public RemoveColumnTag() {
    super(TAG_NAME);
  }

  /**
   * Gets a brief description for the item.
   * @return The item's description.
   */
  public String getDescription() {
    return "Removes a column from the surrounding &lt;print-table&gt; tag.";
  }

  /**
   * Gets the list of supported attributes.
   * @return The attribute definitions.
   */
  protected AttributeDefinitionMap buildSupportedAttributes() {
    return super.buildSupportedAttributes()
      .addDefinition(COLUMN_NAME);
  }

  /**
   * @see org.ujac.print.BaseDocumentTag#initialize()
   */
  public void initialize() throws DocumentHandlerException {
    super.initialize();
    printTableTag = (PrintTableTag) documentHandler.latestOfType(PrintTableTag.class);
  }
  
  /**
   * Opens the item.
   * @exception DocumentHandlerException Thrown in case something went wrong while processing the document item.
   */
  public void openItem() throws DocumentHandlerException {
    if (!isValid()) {
      return;
    }
    
    if (!printTableTag.isFirstLoop()) {
      // output has already been started, skipping insertion
      return;
    }
    
    String name = getStringAttribute(CommonAttributes.COLUMN_NAME, true, null);
    
    // removing column from table
    printTableTag.removeColumn(name);
  }
  
}
