/*
 * Copyright (C) 2003 - 2007 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print.tag;

import org.ujac.print.AttributeDefinition;
import org.ujac.print.AttributeDefinitionMap;
import org.ujac.print.BaseDocumentTag;
import org.ujac.print.DocumentHandlerException;

/**
 * Name: SetFieldTag<br>
 * Description: Class handling the &lt;set-field&gt; tag.
 * 
 * @author lauerc
 */
public class SetFieldTag extends BaseDocumentTag {

  /** Definition of the 'name' attribute. */
  private static final AttributeDefinition FIELD_NAME =  
      CommonAttributes.NAME.cloneAttrDef("The name of the field to set.");
  /** Definition of the 'value' attribute. */
  private static final AttributeDefinition FIELD_VALUE = new AttributeDefinition(TagAttributes.ATTR_VALUE, 
      AttributeDefinition.TYPE_STRING, true, "The value to set for the field.");
  
  /** The item's name. */
  public static final String TAG_NAME = "set-field";

  /** The surrounding add-row tag. */
  private AddRowTag addRow = null;
  
  /** The column  name. */
  private String name = null;
  /** The field value. */
  private String value = null;
  
  /**
   * Constructs a SetFieldTag instance with no specific attributes.
   */
  public SetFieldTag() {
    super(TAG_NAME);
  }

  /**
   * Gets a brief description for the item.
   * @return The item's description.
   */
  public String getDescription() {
    return "Sets a field value at the surrounding table row." ;
  }

  /**
   * Gets the list of supported attributes.
   * @return The attribute definitions.
   */
  protected AttributeDefinitionMap buildSupportedAttributes() {
    return super.buildSupportedAttributes()
      .addDefinition(FIELD_NAME)
      .addDefinition(FIELD_VALUE);
  }

  /**
   * Initializes the item. 
   * @exception DocumentHandlerException If something went badly wrong.
   */
  public void initialize() throws DocumentHandlerException {
    super.initialize();
    // getting the surrounding add-row tag.
    this.addRow = (AddRowTag) documentHandler.latestOfType(AddRowTag.class);
  }
  
  /**
   * Opens the item.
   * @exception DocumentHandlerException Thrown in case something went wrong while opening the document item.
   */
  public void openItem() throws DocumentHandlerException {
    super.openItem();

    if (!isValid()) {
      return;
    }

    // getting attributes
    this.name = getStringAttribute(CommonAttributes.NAME, false, null);
    this.value = getStringAttribute(FIELD_VALUE, false, null);
    
    // defines the column for the given table
    addRow.setFieldValue(name, value);
  }
  
}
