/*
 * Copyright (C) 2003 - 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print.tag;

import org.ujac.print.AttributeDefinitionMap;
import org.ujac.print.BaseDocumentTag;
import org.ujac.print.DocumentHandlerException;

/**
 * Name: SetPropertyTag<br>
 * Description: Class handling the set-property tag.
 * 
 * @author lauerc
 */
public class SetPropertyTag extends BaseDocumentTag {

  /** The item's name. */
  public static final String TAG_NAME = "set-property";

  /** The property name. */
  private String name = null;
  /** The property type. */
  private String type = null;
    
  /**
   * Constructs a SetPropertyTag instance with no specific attributes.
   */
  public SetPropertyTag() {
    super(TAG_NAME);
  }


  /**
   * Gets a brief description for the item.
   * @return The item's description.
   */
  public String getDescription() {
    return "Defines the value for a specific property." ;
  }

  /**
   * Gets the list of supported attributes.
   * @return The attribute definitions.
   */
  protected AttributeDefinitionMap buildSupportedAttributes() {
    return super.buildSupportedAttributes()
      .addDefinition(CommonAttributes.PROPERTY_NAME)    
      .addDefinition(CommonAttributes.PROPERTY_TYPE)    
      .addDefinition(CommonAttributes.PROPERTY_VALUE);
  }

  /**
   * Initializes the item. 
   * @exception DocumentHandlerException If something went badly wrong.
   */
  public void initialize() throws DocumentHandlerException {
    super.initialize();
    // getting attributes
    name = getStringAttribute(CommonAttributes.PROPERTY_NAME, false, null);
    type = getStringAttribute(CommonAttributes.PROPERTY_TYPE, false, null);
  }
  
  /**
   * Opens the item.
   * @exception DocumentHandlerException Thrown in case something went wrong while opening the document item.
   */
  public void openItem() throws DocumentHandlerException {
    super.openItem();

    if (!isValid()) {
      return;
    }

    // getting the property value
    String valueAttr = getStringAttribute(CommonAttributes.PROPERTY_VALUE, false, null);
    Object value = typeCastValue(valueAttr, type);
    // setting the document property
    documentHandler.getTemplateContext().setProperty(name, value);
  }

  /**
   * @see org.ujac.print.BaseDocumentTag#isStructureChecksDisabled()
   */
  public boolean isStructureChecksDisabled() {
    return true;
  }

}
