/*
 * Copyright (C) 2003 - 2008 Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.print.tag;

import org.ujac.print.AttributeDefinition;
import org.ujac.print.AttributeDefinitionMap;
import org.ujac.print.DocumentHandlerException;
import org.ujac.print.ElementContainer;

import com.lowagie.text.Phrase;

/**
 * Name: SpaceTag<br>
 * Description: A class handling the 'space' item.<br>
 * 
 * @author lauerc
 */
public class SpaceTag extends BaseElementTag {

  /** Definition of the 'count' attribute. */
  private static final AttributeDefinition COUNT = new AttributeDefinition(TagAttributes.ATTR_COUNT, 
      AttributeDefinition.TYPE_INT, false, "The amount of spaces to insert, default is 1.");

  /** The item's name. */
  public static final String TAG_NAME = "space";

  /** The count value. */
  private int count = 1;
 
  /**
   * Constructs a SpaceTag instance with no specific attributes.
   */
  public SpaceTag() {
    super(TAG_NAME);
  }


  /**
   * Gets a brief description for the item.
   * @return The item's description.
   */
  public String getDescription() {
    return "Leading and trailing spaces are mostly killed by trimming the content, so if you like " +
      "to explicitely print a certain amount of spaces into the document, you can do this by using " +
      "this item.";
  }

  /**
   * Gets the list of supported attributes.
   * @return The attribute definitions.
   */
  protected AttributeDefinitionMap buildSupportedAttributes() {
    return super.buildSupportedAttributes()
      .addDefinition(COUNT);
  }

  /**
   * Initializes the item. 
   * @exception DocumentHandlerException If something went badly wrong.
   */
  public void initialize() throws DocumentHandlerException {
    super.initialize();
  }

  /**
   * Opens the item.
   * @exception DocumentHandlerException Thrown in case something went wrong while opening the document item.
   */
  public void openItem() throws DocumentHandlerException {
    super.openItem();

    if (!isValid()) {
      return;
    }
    
    if (isAttributeDefined(COUNT)) {
      // evaluating condition
      this.count = getIntegerAttribute(COUNT, true, null);
    }
  }

  /**
   * Processes the item.
   * @exception DocumentHandlerException Thrown in case something went wrong while processing the document item.
   */
  public void closeItem() throws DocumentHandlerException {
    if (!isValid()) {
      return;
    }

    int count = this.count;
    char[] buf = new char[count];
    for (int i = 0; i < count; i++) {
      buf[i] = ' ';
    }
    ElementContainer elementContainer = getElementContainer();
    elementContainer.addElement(this, new Phrase(new String(buf)));
 }

}
