/*
 * Copyright (C) 2003, 2004 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print.tag;

import org.ujac.print.DocumentHandlerException;

/**
 * Name: SuperscriptTag<br>
 * Description: A class, printing the nested text as super script.
 * 
 * @author lauerc
 */
public class SuperscriptTag extends BaseFontTag {

  /** The item's name. */
  public static final String TAG_NAME = "super";
  
  /**
   * Constructs a SuperscriptTag instance with no specific attributes.
   */
  public SuperscriptTag() {
    super(TAG_NAME);
  }

  /**
   * Gets a brief description for the item.
   * @return The item's description.
   */
  public String getDescription() {
    return "Performs the output of the nested text above the baseline.";
  }

  /**
   * Opens the item.
   * @exception DocumentHandlerException Thrown in case something went wrong while opening the document item.
   */
  public void openItem() throws DocumentHandlerException {
    super.openItem();

    // altering font attributes
    this.textRise = this.size * 0.33F;
    this.size *= 0.8F;
    
    // finally creating font
    createFont();
  }
  
}
