/*
 * Copyright (C) 2003 - 2006 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.print.tag;

/**
 * Name: TagAttributes<br>
 * Description: Holds the attribute name constants of all print items.<br>
 * 
 * @author lauerc
 */
public interface TagAttributes {

  /** Constant for attribute 'size' used at items: document, font */ 
  String ATTR_SIZE = "size";
  /** Constant for attribute 'x' used at items: image */ 
  String ATTR_X = "x";
  /** Constant for attribute 'y' used at items: image */ 
  String ATTR_Y = "y";
  /** Constant for attribute 'width' used at items: document, table, image */ 
  String ATTR_WIDTH = "width";
  /** Constant for attribute 'height' used at items: document, image */ 
  String ATTR_HEIGHT = "height";
  /** Constant for attribute 'scale-to-fit' used at items: image */ 
  String ATTR_SCALE_TO_FIT = "scale-to-fit";
  /** Constant for attribute 'rotate' used at items: document, image */ 
  String ATTR_ROTATE = "rotate";
  
  /** Constant for attribute 'margin-left' used at items: document */ 
  String ATTR_MARGIN_LEFT = "margin-left";
  /** Constant for attribute 'margin-right' used at items: document */ 
  String ATTR_MARGIN_RIGHT = "margin-right";
  /** Constant for attribute 'margin-top' used at items: document */ 
  String ATTR_MARGIN_TOP = "margin-top";
  /** Constant for attribute 'margin-bottom' used at items: document */ 
  String ATTR_MARGIN_BOTTOM = "margin-bottom";
  /** Constant for attribute 'pdfversion' used at document attribute */ 
  String ATTR_PDF_VERSION = "pdfversion";
  /** Constant for attribute 'logicalpagestyle' used at document attribute */ 
  String  ATTR_LOGICAL_PAGENUMBERING = "logical-pagestyle";
  /** Constant for attribute 'pdfversion' used at document attribute */ 
  String  ATTR_LOGICAL_PAGETEXT = "logical-pagetext";  

  /** Constant for attribute 'widths' used at items: table */ 
  String ATTR_WIDTHS = "widths";
  /** Constant for attribute 'columns' used at items: table */ 
  String ATTR_COLUMNS = "columns";
  /** Constant for attribute 'background-color' used at items: document, cell */ 
  String ATTR_BACKGROUND_COLOR = "bgcolor";
  /** Constant for attribute 'border-style' used at items: document, table*/ 
  String ATTR_BORDER_STYLE = "border-style";
  /** Constant for attribute 'border-type' used at acrofield items*/ 
  String ATTR_BORDER_TYPE = "border-type";
  /** Constant for attribute 'border-color' used at items: cell */ 
  String ATTR_BORDER_COLOR = "border-color";
  /** Constant for attribute 'border-width' used at items: cell */ 
  String ATTR_BORDER_WIDTH = "border-width";
  /** Constant for attribute 'colspan' used at items: cell */ 
  String ATTR_COLSPAN = "colspan";
  /** Constant for attribute 'fill-row' used at items: cell */ 
  String ATTR_FILL_ROW = "fill-row";
  /** Constant for attribute 'text-align' used at items: text-chart-item */ 
  String ATTR_HORIZONTAL_ALIGNMENT = "halign";
  /** Constant for attribute 'halign' used at items: cell, header, footer */ 
  String ATTR_TEXT_ALIGNMENT = "text-align";
  /** Constant for attribute 'align' used at items: cell, header, footer */ 
  String ATTR_ALIAS_ALIGNMENT = "align";
  /** Constant for attribute 'valign' used at items: cell */ 
  String ATTR_VERTICAL_ALIGNMENT = "valign";
  /** Constant for attribute 'cell-halign' used at items: table, print-table */ 
  String ATTR_CELL_HORIZONTAL_ALIGNMENT = "cell-halign";
  /** Constant for attribute 'align' used at items: table, print-table. */ 
  String ATTR_ALIAS_CELL_ALIGNMENT = "cell-align";
  /** Constant for attribute 'cell-valign' used at items: table, print-table */ 
  String ATTR_CELL_VERTICAL_ALIGNMENT = "cell-valign";
  /** Constant for attribute 'padding' used at items: cell */ 
  String ATTR_PADDING = "padding";
  /** Constant for attribute 'padding' used at items: cell */ 
  String ATTR_PADDING_LEFT = "padding-left";
  /** Constant for attribute 'padding' used at items: cell */ 
  String ATTR_PADDING_RIGHT = "padding-right";
  /** Constant for attribute 'padding' used at items: cell */ 
  String ATTR_PADDING_TOP = "padding-top";
  /** Constant for attribute 'padding' used at items: cell */ 
  String ATTR_PADDING_BOTTOM = "padding-bottom";
  /** Constant for attribute 'no-wrap' used at items: cell */ 
  String ATTR_NO_WRAP = "no-wrap";
  /** Constant for attribute 'split-rows' used at items: table, print-table */ 
  String ATTR_SPLIT_ROWS = "split-rows";
  /** Constant for attribute 'split-late' used at items: table, print-table */ 
  String ATTR_SPLIT_LATE = "split-late";
  
  /** Constant for attribute 'id' applicable for all items, ... */ 
  String ATTR_ID = "id";
  /** Constant for attribute 'name' used at items: font-def, row-cell, property, ... */ 
  String ATTR_NAME = "name";
  /** Constant for attribute 'index' used at items: row-cell, ... */ 
  String ATTR_INDEX = "index";

  /** Constant for attribute 'rendered', applicable for almost all items. */
  String ATTR_RENDERED = "rendered";
  
  /** Constant for attribute 'color-space' used at items: color-def */ 
  String ATTR_COLOR_SPACE = "color-space";
  /** Constant for attribute 'spot-color' used at items: color-def */ 
  String ATTR_SPOT_COLOR = "spot-color";
  /** Constant for attribute 'color' used at items: set-fill-color */ 
  String ATTR_COLOR = "color";
  
  /** Constant for attribute 'font-def' used at items: font */ 
  String ATTR_FONT_DEF = "font-def";
  /** Constant for attribute 'font-name' used at items: font, font-def */ 
  String ATTR_FONT_NAME = "font-name";
  /** Constant for attribute 'color' used at items: font, font-def */ 
  String ATTR_FONT_COLOR = "font-color";
  /** Constant for attribute 'font-family' used at items: font, font-def */ 
  String ATTR_FONT_FAMILY = "font-family";
  /** Constant for attribute 'font-size' used at items: font, font-def */ 
  String ATTR_FONT_SIZE = "font-size";
  /** Constant for attribute 'encoding' used at items: font, font-def */ 
  String ATTR_FONT_ENCODING = "font-encoding";
  /** Constant for attribute 'font-style' used at items: font, font-def */ 
  String ATTR_FONT_STYLE = "font-style";
  /** Constant for attribute 'style' used at items: font, font-def */ 
  String ATTR_STYLE = "style";
  /** Constant for attribute 'trim-body' used at items: base-font, condition */ 
  String ATTR_TRIM_BODY = "trim-body";
  /** Constant for attribute 'text-rise' used at items: font, font-def */ 
  String ATTR_TEXT_RISE = "text-rise";

  /** Constant for attribute 'cond' used at items: if */ 
  String ATTR_CONDITION = "cond";

  /** Constant for attribute 'loop-variable' used at items: foreach */ 
  String ATTR_LOOP_VARIABLE = "loop-variable";
  /** Constant for attribute 'sequence' used at items: foreach */ 
  String ATTR_SEQUENCE = "sequence";
  
  /** Constant for attribute 'spacing-before' used at items: paragraph */ 
  String ATTR_SPACING_BEFORE = "spacing-before";
  /** Constant for attribute 'spacing-after' used at items: paragraph */ 
  String ATTR_SPACING_AFTER = "spacing-after";
  /** Constant for attribute 'keep-together' used at items: paragraph */ 
  String ATTR_KEEP_TOGETHER = "keep-together";
  /** Constant for attribute 'leading' used at items: paragraph, phrase, box, list-item */ 
  String ATTR_LEADING = "leading";
  /** Constant for attribute 'line-spacing' used at items: paragraph, box, list */ 
  String ATTR_LINE_SPACING = "line-spacing";
  /** Constant for attribute 'source' used at items: image */ 
  String ATTR_SOURCE = "source";

  /** Constant for attribute 'value' used at items: switch, case */ 
  String ATTR_VALUE = "value";
  /** Constant for attribute 'values' used at items: chart */ 
  String ATTR_VALUES = "values";
  /** Constant for attribute 'count' used at items: space */ 
  String ATTR_COUNT = "count";

  /** Constant for attribute 'new-page' used at items: table-split */ 
  String ATTR_NEW_PAGE = "new-page";
  /** Constant for attribute 'keep-header' used at items: table-split */ 
  String ATTR_KEEP_HEADER = "keep-header";

  /** Constant for attribute 'format' used at items: number-format */ 
  String ATTR_FORMAT = "format";
  /** Constant for attribute 'title' used at items: chart */ 
  String ATTR_TITLE = "title";
  /** Constant for attribute 'title-font' used at items: chart */ 
  String ATTR_TITLE_FONT = "title-font";
  /** Constant for attribute 'type' used at items: chart */ 
  String ATTR_TYPE = "type";
  /** Constant for attribute 'instance' used at items: chart */ 
  String ATTR_INSTANCE = "instance";
  /** Constant for attribute 'descriptions' used at item: chart */ 
  String ATTR_DESCRIPTIONS = "descriptions";
  /** Constant for attribute 'description-font' used at item: chart */ 
  String ATTR_DESCRIPTION_FONT = "description-font";
  /** Constant for the attribute 'description-pattern' used at item: chart */
  String ATTR_DESCRIPTION_PATTERN = "description-pattern";
  /** Constant for the attribute 'value-format' used at item: chart */
  String ATTR_VALUE_FORMAT = "value-format";
  /** Constant for the attribute 'value-format' used at item: chart */
  String ATTR_PERCENT_FORMAT = "percent-format";
  
  /** Constant for attribute 'bar-width' used at items: barcode */ 
  String ATTR_BAR_WIDTH = "bar-width";
  /** Constant for attribute 'bar-height' used at items: barcode */ 
  String ATTR_BAR_HEIGHT = "bar-height";
  /** Constant for attribute 'bar-color' used at items: barcode */ 
  String ATTR_BAR_COLOR = "bar-color";
  /** Constant for attribute 'text-color' used at items: barcode */ 
  String ATTR_TEXT_COLOR = "text-color";
  /** Constant for attribute 'start-stop-text' used at items: barcode */ 
  String ATTR_START_STOP_TEXT = "start-stop-text";
  /** Constant for attribute 'generate-checksum' used at items: barcode */ 
  String ATTR_GENERATE_CHECKSUM = "generate-checksum";
  /** Constant for attribute 'baseline' used at items: barcode */ 
  String ATTR_BASELINE= "baseline";

  /** Constant for attribute 'list' used at items: parameter-def */ 
  String ATTR_LIST = "list";
  /** Constant for attribute 'optional' used at items: parameter-def */ 
  String ATTR_OPTIONAL = "optional";
  /** Constant for attribute 'default-value' used at items: parameter-def */ 
  String ATTR_DEFAULT_VALUE = "default-value";
  /** Constant for the attribute 'description' used at item: parameter-def */
  String ATTR_DESCRIPTION = "description";

  /** Constant for attribute 'print-header' used at items: print-table */ 
  String ATTR_PRINT_HEADER = "print-header";
  /** Constant for attribute 'level-filter' used at items: print-table */ 
  String ATTR_LEVEL_FILTER = "level-filter";
  
  /** Constant for attribute 'textwrap' used at items: image, chart */ 
  String ATTR_TEXTWRAP = "textwrap";
  /** Constant for attribute 'underlying' used at items: image, chart */ 
  String ATTR_UNDERLYING = "underlying";
  /** Constant for attribute 'underlying' used at items: image, chart */ 
  String ATTR_DRAW_FOREGROUND = "draw-foreground";
  /** Constant for attribute 'number' used at items: chapter */ 
  String ATTR_NUMBER = "number";
  /** Constant for attribute 'number-depth' used at items: section */ 
  String ATTR_NUMBER_DEPTH = "number-depth";
  /** Constant for attribute 'number-style' used at items: chapter */ 
  String ATTR_NUMBER_STYLE = "number-style"; 
  /** Constant for attribute 'indentation' used at items: section */ 
  String ATTR_INDENTATION = "indentation";
 
  /** Constant for attribute 'numbered' used at items: list */ 
  String ATTR_NUMBERED = "numbered";
  /** Constant for attribute 'numbered' used at items: list */ 
  String ATTR_LETTERED = "lettered";
  /** Constant for attribute 'symbol-indent' used at items: list */ 
  String ATTR_SYMBOL_INDENT = "symbol-indent";
  // Added by Kiran
  /** Constant for attribute 'listtype' used at list attribute */
  String ATTR_LIST_TYPE = "listtype";
  /** Constant for attribute 'start' used at list attribute */
  String ATTR_LIST_ITEMSTART = "start";

  /** Constant for attribute 'subject' used at items: meta */ 
  String ATTR_SUBJECT = "subject";
  /** Constant for attribute 'keywords' used at items: meta */ 
  String ATTR_KEYWORDS = "keywords";
  /** Constant for attribute 'author' used at items: meta */ 
  String ATTR_AUTHOR = "author";
  /** Constant for attribute 'creator' used at items: meta */ 
  String ATTR_CREATOR = "creator";
  /** Constant for attribute 'creation-date' used at items: meta */ 
  String ATTR_CREATION_DATE = "creation-date";
  
  /** Constant for attribute 'refernce' used at items: anchor */ 
  String ATTR_REFERENCE = "reference";

  /** Constant for attribute 'group-name' used at items: print-group-row, print-group-title-row */ 
  String ATTR_GROUP_NAME = "group-name";

  /** Constant for attribute 'direction' used at items: insert-column, extra-row, viewer-preferences */ 
  String ATTR_DIRECTION = "direction";
  /** Constant for attribute 'direction' used at items: viewer-preferences */ 
  String ATTR_ZOOM = "zoom";

  /** Constant for attribute 'tag' used at items: custom-tag */ 
  String ATTR_TAG = "tag";
  /** Constant for attribute 'alias' used at items: custom-tag */ 
  String ATTR_ALIAS = "alias";
  
  /** Constant for attribute 'font' used at items: phrase, paragraph, cell, etc. */ 
  String ATTR_FONT = "font";

  /** Constant for attribute 'page' used at items: overlay. */ 
  String ATTR_PAGE = "page";

  /** Constant for attribute 'parent' used at items: outline */ 
  String ATTR_PARENT = "parent";

  /** Constant for attribute 'a' used at items: toggle-values */ 
  String ATTR_A = "a";
  /** Constant for attribute 'b' used at items: toggle-values */ 
  String ATTR_B = "b";

  /** Constant for attribute 'from' used at items: insert-document */ 
  String ATTR_FROM = "a";
  /** Constant for attribute 'to' used at items: insert-document */ 
  String ATTR_TO = "to";

  /** Constant for attribute 'status' used at items: check-box */ 
  String ATTR_STATUS = "status";
  /** Constant for attribute 'editable' used at items: combo-box */ 
  String ATTR_EDITABLE = "editable";

  /** Constant for attribute 'status' used at items: post-button */ 
  String ATTR_URL = "url";

  /** Constant for attribute 'stroke-color' used at items: graphics */ 
  String ATTR_STROKE_COLOR = "stroke-color";
  /** Constant for attribute 'fill-color' used at items: graphics */ 
  String ATTR_FILL_COLOR = "fill-color";
  /** Constant for attribute 'line-width' used at items: graphics */ 
  String ATTR_LINE_WIDTH = "line-width";
  
  /** Constant for attribute 'phase' used at items: set-line-dash */ 
  String ATTR_PHASE = "phase";
  /** Constant for attribute 'units-on' used at items: set-line-dash */ 
  String ATTR_UNITS_ON = "units-on";
  /** Constant for attribute 'units-off' used at items: set-line-dash */ 
  String ATTR_UNITS_OFF = "units-off";

  /** Constant for attribute 'x1' used at items: draw-line, draw-curve, draw-ellipse */ 
  String ATTR_X1 = "x1";
  /** Constant for attribute 'y1' used at items: draw-line, draw-curve, draw-ellipse */ 
  String ATTR_Y1 = "y1";
  /** Constant for attribute 'x2' used at items: draw-line, draw-curve, draw-ellipse */ 
  String ATTR_X2 = "x2";
  /** Constant for attribute 'y2' used at items: draw-line, draw-curve, draw-ellipse */ 
  String ATTR_Y2 = "y2";
  /** Constant for attribute 'x3' used at items: draw-curve */ 
  String ATTR_X3 = "x3";
  /** Constant for attribute 'y3' used at items: draw-curve */ 
  String ATTR_Y3 = "y3";
  /** Constant for attribute 'x4' used at items: draw-curve */ 
  String ATTR_X4 = "x4";
  /** Constant for attribute 'y2' used at items: draw-curve */ 
  String ATTR_Y4 = "y4";

  /** Constant for attribute 'radius' used at items: draw-circle */ 
  String ATTR_RADIUS = "radius";
  /** Constant for attribute 'fill' used at items: polygon */ 
  String ATTR_FILL = "fill";
  /** Constant for attribute 'line-cap' used at items: polygon, set-line-cap */ 
  String ATTR_LINE_CAP = "line-cap";
  /** Constant for attribute 'line-join' used at items: graphics, set-line-join */ 
  String ATTR_LINE_JOIN = "line-join";

  /** Constant for attribute 'rule-width' used at items: header, footer. */ 
  String ATTR_RULE_WIDTH = "rule-width";
  /** Constant for attribute 'rule-color' used at items: header, footer. */ 
  String ATTR_RULE_COLOR = "rule-color";

  /** Constant for attribute 'toc-number' used at items: outline, ... */ 
  String ATTR_TOC_NUMBER = "toc-number";

  /** Constant for attribute 'page-layout' used at items: viewer-preferences */ 
  String ATTR_PAGE_LAYOUT = "page-layout";
  /** Constant for attribute 'page-mode' used at items: viewer-preferences */ 
  String ATTR_PAGE_MODE = "page-mode";
  /** Constant for attribute 'non-full-screen-page-mode' used at items: viewer-preferences */ 
  String ATTR_NON_FULL_SCREEN_PAGE_MODE = "non-full-screen-page-mode";

  /** Constant for attribute 'full-screen' used at items: viewer-preferences */ 
  String ATTR_FULL_SCREEN = "full-screen";

  /** Constant for attribute 'hide-toolbar' used at items: viewer-preferences */ 
  String ATTR_HIDE_TOOLBAR = "hide-toolbar";
  /** Constant for attribute 'hide-menubar' used at items: viewer-preferences */ 
  String ATTR_HIDE_MENUBAR = "hide-menubar";
  /** Constant for attribute 'hide-window-ui' used at items: viewer-preferences */ 
  String ATTR_HIDE_WINDOW_UI = "hide-window-ui";

  /** Constant for attribute 'fit-window' used at items: viewer-preferences */ 
  String ATTR_FIT_WINDOW = "fit-window";
  /** Constant for attribute 'center-window' used at items: viewer-preferences */ 
  String ATTR_CENTER_WINDOW = "center-window";

  /** Constant for attribute 'display-doc-title' used at items: viewer-preferences */ 
  String ATTR_DISPLAY_DOC_TITLE = "display-doc-title";

  /** Constant for attribute 'encryption-type' used at items: encryption */ 
  String ATTR_ENCRYPTION_TYPE = "encryption-type";
  /** Constant for attribute 'user-password' used at items: encryption */ 
  String ATTR_USER_PASSWORD = "user-password";
  /** Constant for attribute 'owner-password' used at items: encryption */ 
  String ATTR_OWNER_PASSWORD = "owner-password";
  /** Constant for attribute 'allow-printing' used at items: encryption */ 
  String ATTR_ALLOW_PRINTING = "allow-printing";
  /** Constant for attribute 'allow-modify-contents' used at items: encryption */ 
  String ATTR_ALLOW_MODIFY_CONTENTS = "allow-modify-contents";
  /** Constant for attribute 'allow-copy' used at items: encryption */ 
  String ATTR_ALLOW_COPY = "allow-copy";
  /** Constant for attribute 'allow-modify-annotations' used at items: encryption */ 
  String ATTR_ALLOW_MODIFY_ANNOTATIONS = "allow-modify-annotations";
  /** Constant for attribute 'allow-fillin' used at items: encryption */ 
  String ATTR_ALLOW_FILLIN = "allow-fillin";
  /** Constant for attribute 'allow-screen-readers' used at items: encryption */ 
  String ATTR_ALLOW_SCREEN_READERS = "allow-screen-readers";
  /** Constant for attribute 'allow-assembly' used at items: encryption */ 
  String ATTR_ALLOW_ASSEMBLY = "allow-assembly";
  /** Constant for attribute 'allow-degraded-printing' used at items: encryption */ 
  String ATTR_ALLOW_DEGRADED_PRINTING = "allow-degraded-printing";

  /** Constant for attribute 'level' used at tags: log */ 
  String ATTR_LEVEL = "level";

  /** Constant for attribute 'table' used at items: add-row */ 
  String ATTR_TABLE = "table";
  /** Constant for attribute 'distinct' used at items: add-row */ 
  String ATTR_DISTINCT = "distinct";

  /** Constant for attribute 'classe' used at various tags. */ 
  String ATTR_CLASS = "class";
  
}
