/*
 * Copyright (C) 2003 - 2007 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print.tag.graphics;

import org.ujac.print.AttributeDefinition;
import org.ujac.print.AttributeDefinitionMap;
import org.ujac.print.BaseDocumentTag;
import org.ujac.print.DocumentHandlerException;

import org.ujac.print.tag.CommonAttributes;
import org.ujac.print.tag.TagAttributes;

/**
 * Name: BaseGraphicsTag<br>
 * Description: Base implementation of tags for graphical operations.
 * 
 * @author lauerc
 */
public abstract class BaseGraphicsTag extends BaseDocumentTag {

  /** Definition of the 'fill' attribute. */
  protected static final AttributeDefinition FILL = new AttributeDefinition(TagAttributes.ATTR_FILL, 
      AttributeDefinition.TYPE_BOOLEAN, false, "Tells whether or not to fill the object, default is false.");
  /** Definition of the 'x' attribute. */
  protected static final AttributeDefinition X = new AttributeDefinition(TagAttributes.ATTR_X, 
      AttributeDefinition.TYPE_DIMENSION, true, "The horizontal position.");
  /** Definition of the 'y' attribute. */
  protected static final AttributeDefinition Y = new AttributeDefinition(TagAttributes.ATTR_Y, 
      AttributeDefinition.TYPE_DIMENSION, true, "The vertical position.");

  /** Definition of the 'x1' attribute. */
  protected static final AttributeDefinition X1 = new AttributeDefinition(TagAttributes.ATTR_X1, 
      AttributeDefinition.TYPE_DIMENSION, true, "The horizontal position of the start point.");
  /** Definition of the 'y1' attribute. */
  protected static final AttributeDefinition Y1 = new AttributeDefinition(TagAttributes.ATTR_Y1, 
      AttributeDefinition.TYPE_DIMENSION, true, "The vertical position of the start point.");
  /** Definition of the 'x2' attribute. */
  protected static final AttributeDefinition X2 = new AttributeDefinition(TagAttributes.ATTR_X2, 
      AttributeDefinition.TYPE_DIMENSION, false, "The horizontal position of the first control point.");
  /** Definition of the 'y2' attribute. */
  protected static final AttributeDefinition Y2 = new AttributeDefinition(TagAttributes.ATTR_Y2, 
      AttributeDefinition.TYPE_DIMENSION, false, "The vertical position of the first control point.");
  /** Definition of the 'x3' attribute. */
  protected static final AttributeDefinition X3 = new AttributeDefinition(TagAttributes.ATTR_X3, 
      AttributeDefinition.TYPE_DIMENSION, false, "The horizontal position of the second control point.");
  /** Definition of the 'y3' attribute. */
  protected static final AttributeDefinition Y3 = new AttributeDefinition(TagAttributes.ATTR_Y3, 
      AttributeDefinition.TYPE_DIMENSION, false, "The vertical position of the second control point.");
  /** Definition of the 'x4' attribute. */
  protected static final AttributeDefinition X4 = new AttributeDefinition(TagAttributes.ATTR_X4, 
      AttributeDefinition.TYPE_DIMENSION, true, "The horizontal position of the ebd point.");
  /** Definition of the 'y4' attribute. */
  protected static final AttributeDefinition Y4 = new AttributeDefinition(TagAttributes.ATTR_Y4, 
      AttributeDefinition.TYPE_DIMENSION, true, "The vertical position of the end point.");

  /** The surrounding &lt;graphics&gt; tag. */
  protected GraphicsTag graphicsTag = null;
  
  /**
   * Constructs a BaseGraphicsTag instance with specific attributes.
   * @param name The tag name.
   */
  public BaseGraphicsTag(String name) {
    super(name);
  }
  
  /**
   * Gets the list of supported attributes.
   * @return The attribute definitions.
   */
  protected AttributeDefinitionMap buildSupportedAttributes() {
    return super.buildSupportedAttributes()
      .addDefinition(CommonAttributes.RENDERED);
  }
  
  /**
   * Tells whether textual content is allowed for the tag or not.
   * @return true if the item is allowed to contain textual content, else false.
   */
  public boolean isTextBodyAllowed() {
    return false;
  }

  /**
   * Initializes the item. 
   * @exception DocumentHandlerException If something went badly wrong.
   */
  public void initialize() throws DocumentHandlerException {
    super.initialize();

    this.graphicsTag = (GraphicsTag) documentHandler.latestOfType(GraphicsTag.class);
    if (this.graphicsTag == null) {
      throw new DocumentHandlerException(locator(), "No surrounding <graphics> tag found.");
    }
  }

}
