/*
 * Copyright (C) 2003 - 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print.tag.graphics;

import org.ujac.print.ChildDefinition;
import org.ujac.print.ChildDefinitionMap;
import org.ujac.print.DocumentHandlerException;
import org.ujac.print.TagAttributeException;

import com.lowagie.text.pdf.PdfContentByte;

/**
 * Name: DrawPolyLineTag<br>
 * Description: Implementation of the &lt;draw-poly-line&gt; tag.
 * 
 * @author lauerc
 */
public class DrawPolyLineTag extends BaseGraphicsTag implements PointHolder {

  /** The item's name. */
  public static final String TAG_NAME = "draw-poly-line";

  /** The number of points of the polygon to draw. */
  private int numPoints = 0;
  
  /**
   * Constructs a DrawPolyLineTag instance with no specific attributes.
   */
  public DrawPolyLineTag() {
    super(TAG_NAME);
  }


  /**
   * Gets a brief description for the item.
   * @return The item's description.
   */
  public String getDescription() {
    return "Draws a poly line.";
  }

  /**
   * Gets the list of supported childs.
   * @return The child definitions.
   */
  public ChildDefinitionMap buildSupportedChilds() {
    return super.buildSupportedChilds()
      .addDefinition(new ChildDefinition(PointTag.class, 0, ChildDefinition.UNLIMITED));
  }

  /**
   * Opens the item.
   * @exception DocumentHandlerException Thrown in case something went wrong while opening the document item.
   */
  public void openItem() throws DocumentHandlerException {
    super.openItem();
    
    // resetting the point counter
    this.numPoints = 0;
    
    if (!isValid()) {
      return;
    }

  }

  /**
   * Closes the item.
   * @exception DocumentHandlerException Thrown in case something went wrong while processing the document item.
   */
  public void closeItem() throws DocumentHandlerException {
    if (!isValid()) {
      return;
    }

    // closing the polyline
    PdfContentByte cb = this.graphicsTag.getContentByte();
    cb.stroke();
  }

  /**
   * Adds the given point to the point holder's container.
   * @param x The horizontal position of the point.
   * @param y The vertical position of the point.
   * @exception TagAttributeException In case the adding of the option has been failed.
   */
  public void addPoint(float x, float y) throws TagAttributeException {
    PdfContentByte cb = this.graphicsTag.getContentByte();
    if (numPoints == 0) {
      cb.moveTo(x, y);
    } else {
      cb.lineTo(x, y);
    }
    ++numPoints;
  }

}
