/*
 * Copyright (C) 2003 - 2007 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print.tag.graphics;

import org.ujac.print.AttributeDefinitionMap;
import org.ujac.print.DocumentHandlerException;

/**
 * Name: PointTag<br>
 * Description: Implementation of the &lt;point&gt; tag.
 * 
 * @author lauerc
 */
public class PointTag extends BaseGraphicsTag {

  /** The item's name. */
  public static final String TAG_NAME = "point";
  
  /** The point holder. */
  private PointHolder pointHolder = null;

  /**
   * Constructs a PointTag instance with no specific attributes.
   */
  public PointTag() {
    super(TAG_NAME);
  }


  /**
   * Gets a brief description for the item.
   * @return The item's description.
   */
  public String getDescription() {
    return "Defines a single point for a polygon or poly line.";
  }

  /**
   * Gets the list of supported attributes.
   * @return The attribute definitions.
   */
  protected AttributeDefinitionMap buildSupportedAttributes() {
    return super.buildSupportedAttributes()
      .addDefinition(X)
      .addDefinition(Y);
  }

  /**
   * Initializes the item. 
   * @exception DocumentHandlerException If something went badly wrong.
   */
  public void initialize() throws DocumentHandlerException {
    super.initialize();
    // getting parents
    this.pointHolder = (PointHolder) documentHandler.latestOfType(PointHolder.class);
  }

  /**
   * Opens the item.
   * @exception DocumentHandlerException Thrown in case something went wrong while opening the document item.
   */
  public void openItem() throws DocumentHandlerException {
    super.openItem();
    
    if (!isValid()) {
      return;
    }

    // getting the coordinates
    float x = getDimensionAttribute(X, true, X);
    float y = getDimensionAttribute(Y, true, Y);

    // adding point to parent 
    pointHolder.addPoint(x, y);
  }

  /**
   * Closes the item.
   * @exception DocumentHandlerException Thrown in case something went wrong while processing the document item.
   */
  public void closeItem() throws DocumentHandlerException {
    if (!isValid()) {
      return;
    }
  }

}
