/*
 * Copyright (C) 2003 - 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print.tag.graphics;

import org.ujac.print.AttributeDefinition;
import org.ujac.print.AttributeDefinitionMap;
import org.ujac.print.DocumentHandlerException;

import org.ujac.print.tag.TagAttributes;

/**
 * Name: SetLineJoinTag<br>
 * Description: Implementation of the &lt;set-line-join&gt; tag.
 * 
 * @author lauerc
 */
public class SetLineJoinTag extends BaseGraphicsTag {

  /** Definition of the 'line-join' attribute. */
  protected static final AttributeDefinition LINE_JOIN = new AttributeDefinition(TagAttributes.ATTR_LINE_JOIN, 
      new String[] {"miter", "round", "bevel"}, true, "The line join to set.");

  /** The item's name. */
  public static final String TAG_NAME = "set-line-join";

  /**
   * Constructs a SetLineJoinTag instance with no specific attributes.
   */
  public SetLineJoinTag() {
    super(TAG_NAME);
  }

  /**
   * Gets a brief description for the item.
   * @return The item's description.
   */
  public String getDescription() {
    return "Defines the current line dash for the surrounding graphics area.";
  }

  /**
   * Gets the list of supported attributes.
   * @return The attribute definitions.
   */
  protected AttributeDefinitionMap buildSupportedAttributes() {
    return super.buildSupportedAttributes()
      .addDefinition(LINE_JOIN);
  }

  /**
   * Opens the item.
   * @exception DocumentHandlerException Thrown in case something went wrong while opening the document item.
   */
  public void openItem() throws DocumentHandlerException {
    super.openItem();
    
    if (!isValid()) {
      return;
    }

    // getting the attributes
    String strLineJoin = getStringAttribute(LINE_JOIN, "miter", true, null).toLowerCase();
    int lineJoin = 0;
    if ("miter".equals(strLineJoin)) {
      lineJoin = 0;
    } else if ("round".equals(strLineJoin)) {
      lineJoin = 1;
    } else if ("bevel".equals(strLineJoin)) {
      lineJoin = 2;
    }
    // manipulating the surrounding <graphics> area. 
    this.graphicsTag.setLineJoin(lineJoin);
  }

  /**
   * Closes the item.
   * @exception DocumentHandlerException Thrown in case something went wrong while processing the document item.
   */
  public void closeItem() throws DocumentHandlerException {
    if (!isValid()) {
      return;
    }
  }

}
