/*
 * Copyright (C) 2003 - 2007 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print.tag.graphics;

import java.awt.Color;

import org.ujac.print.AttributeDefinition;
import org.ujac.print.AttributeDefinitionMap;
import org.ujac.print.DocumentHandlerException;
import org.ujac.print.tag.CommonAttributes;

/**
 * Name: SetStrokeColorTag<br>
 * Description: Implementation of the &lt;set-stroke-color&gt; tag.
 * 
 * @author lauerc
 */
public class SetStrokeColorTag extends BaseGraphicsTag {

  /** The item's name. */
  public static final String TAG_NAME = "set-stroke-color";
  
  /** Definition of the 'color' attribute. */
  private static final AttributeDefinition STROKE_COLOR = 
      CommonAttributes.COLOR.cloneAttrDef("The stroke color to set.").setRequired(true);
  
  /**
   * Constructs a SetStrokeColorTag instance with no specific attributes.
   */
  public SetStrokeColorTag() {
    super(TAG_NAME);
  }


  /**
   * Gets a brief description for the item.
   * @return The item's description.
   */
  public String getDescription() {
    return "Defines the current stroke color for the surrounding graphics area.";
  }

  /**
   * Gets the list of supported attributes.
   * @return The attribute definitions.
   */
  protected AttributeDefinitionMap buildSupportedAttributes() {
    return super.buildSupportedAttributes()
      .addDefinition(STROKE_COLOR);
  }

  /**
   * Opens the item.
   * @exception DocumentHandlerException Thrown in case something went wrong while opening the document item.
   */
  public void openItem() throws DocumentHandlerException {
    super.openItem();
    
    if (!isValid()) {
      return;
    }

    // getting the attributes
    Color color = getColorAttribute(CommonAttributes.COLOR, true, null);

    // manipulating the surrounding <graphics> area. 
    this.graphicsTag.setStrokeColor(color);
  }

  /**
   * Closes the item.
   * @exception DocumentHandlerException Thrown in case something went wrong while processing the document item.
   */
  public void closeItem() throws DocumentHandlerException {
    if (!isValid()) {
      return;
    }
  }

}
