/*
 * Copyright (C) 2003 - 2007 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print.test;

import org.ujac.print.AttributeDefinitionMap;
import org.ujac.print.BaseCustomTag;
import org.ujac.print.DocumentHandlerException;
import org.ujac.print.ElementContainer;

import com.lowagie.text.Paragraph;

/**
 * Name: ExampleTag<br>
 * Description: An example custom tag implementation.
 * 
 * @author lauerc
 */
public class ExampleTag extends BaseCustomTag {

  /** The item's name. */
  public static final String TAG_NAME = "example";
  
  /** The surrounding element container. */
  public ElementContainer elementContainer = null;
  
  /**
   * Gets the item's name.
   * @return The item's name.
   */
  public String getName() {
    return TAG_NAME;
  }

  /**
   * Gets a brief description for the item.
   * @return The item's description.
   */
  public String getDescription() {
    return "Adds the nested contents to its parent item.";
  }

  /**
   * Gets the list of supported attributes.
   * @return The attribute definitions.
   */
  protected AttributeDefinitionMap buildSupportedAttributes() {
    return null;
  }

  /**
   * Tells whether textual content is allowed for the tag or not.
   * @return true if the item is allowed to contain textual content, else false.
   */
  public boolean isTextBodyAllowed() {
    return true;
  }

  /**
   * Initializes the item. 
   * @exception DocumentHandlerException If something went badly wrong.
   */
  public void initialize() throws DocumentHandlerException {
    super.initialize();

    this.elementContainer = documentHandler.latestElementContainer(); 
  }

  /**
   * Opens the item.
   * @exception DocumentHandlerException Thrown in case something went wrong while opening the document item.
   */
  public void openItem() throws DocumentHandlerException {
    super.openItem();

    if (!isValid()) {
      return;
    }
  }

  /**
   * Processes the item.
   * @exception DocumentHandlerException Thrown in case something went wrong while processing the document item.
   */
  public void closeItem() throws DocumentHandlerException {
    if (!isValid()) {
      return;
    }
    this.elementContainer.addElement(this, new Paragraph("Test: " + getContent()));
  }
  
}
