/*
 * Copyright (C) 2003, 2004 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print.test;

import java.io.IOException;

import org.ujac.print.DocumentHandlerException;

import org.ujac.util.UjacTypes;

import org.ujac.util.table.Column;
import org.ujac.util.table.CountFunctionExecutor;
import org.ujac.util.table.LayoutHints;
import org.ujac.util.table.ReportFunction;
import org.ujac.util.table.ReportGroup;
import org.ujac.util.table.ReportTable;
import org.ujac.util.table.Row;
import org.ujac.util.table.SumFunctionExecutor;
import org.ujac.util.table.DataTable;
import org.ujac.util.table.Table;
import org.ujac.util.table.TableException;

/**
 * Name: ReportTest<br>
 * Description: A class testing report table output.
 * 
 * @author lauerc
 */
public class ReportTest extends BasePrintTest {

  /** The data table to use. */
  private Table dataTable = null;
  /** The output folder location. */
  private String outputFolder = "test/";
  
  /**
   * Sets up the test data.
   * @exception Exception In case a problem occured during the set up.
   */
  protected void setUp() throws Exception {
    super.setUp();

    // setting up data table
    this.dataTable = new DataTable();
    Column idCol = dataTable.addColumn("ID", UjacTypes.TYPE_INT);
    idCol.setLayoutHints(new LayoutHints(10, "ID", LayoutHints.LEFT));
    int idID = idCol.getIndex();
    Column depotCol = dataTable.addColumn("DEPOT", UjacTypes.TYPE_STRING);
    depotCol.setLayoutHints(new LayoutHints(12, "Depot", LayoutHints.LEFT));
    int depotID = depotCol.getIndex();
    Column typeCol = dataTable.addColumn("TYPE", UjacTypes.TYPE_STRING);
    typeCol.setLayoutHints(new LayoutHints(12, "Type", LayoutHints.LEFT));
    int typeID = typeCol.getIndex();
    Column nameCol = dataTable.addColumn("NAME", UjacTypes.TYPE_STRING);
    nameCol.setLayoutHints(new LayoutHints(40, "Name", LayoutHints.LEFT));
    int nameID = nameCol.getIndex();
    Column valueCol = dataTable.addColumn("VALUE", UjacTypes.TYPE_DOUBLE);
    valueCol.setLayoutHints(new LayoutHints(25, "Value", LayoutHints.RIGHT).setHeaderAlign(LayoutHints.LEFT));
    int valueID = valueCol.getIndex();
    
    // filling data table
    Row row = dataTable.addRow();
    row.setInt(idID, 1);
    row.setString(depotID, "Depot 1");
    row.setString(typeID, "S");
    row.setString(nameID, "SAP");
    row.setDouble(valueID, 2725.80);

    row = dataTable.addRow();
    row.setInt(idID, 2);
    row.setString(depotID, "Depot 1");
    row.setString(typeID, "S");
    row.setString(nameID, "ZOOM TECHNLGIES");
    row.setDouble(valueID, 1235.65);

    row = dataTable.addRow();
    row.setInt(idID, 3);
    row.setString(depotID, "Depot 1");
    row.setString(typeID, "S");
    row.setString(nameID, "MICRO$OFT");
    row.setDouble(valueID, 455.33);

    row = dataTable.addRow();
    row.setInt(idID, 4);
    row.setString(depotID, "Depot 1");
    row.setString(typeID, "S");
    row.setString(nameID, "COMTECH TELCOM");
    row.setDouble(valueID, 5465.56);

    row = dataTable.addRow();
    row.setInt(idID, 5);
    row.setString(depotID, "Depot 1");
    row.setString(typeID, "S");
    row.setString(nameID, "DAIMLER CRYSLER");
    row.setDouble(valueID, 7655.23);

    row = dataTable.addRow();
    row.setInt(idID, 6);
    row.setString(depotID, "Depot 1");
    row.setString(typeID, "F");
    row.setString(nameID, "NASDAQ 100 TRUST");
    row.setDouble(valueID, 135.50);
    
    row = dataTable.addRow();
    row.setInt(idID, 7);
    row.setString(depotID, "Depot 1");
    row.setString(typeID, "F");
    row.setString(nameID, "NORDASIA.COM");
    row.setDouble(valueID, 435.23);

    row = dataTable.addRow();
    row.setInt(idID, 8);
    row.setString(depotID, "Depot 1");
    row.setString(typeID, "F");
    row.setString(nameID, "MERRILL LIIF WLD MINING A");
    row.setDouble(valueID, 1567.54);

    row = dataTable.addRow();
    row.setInt(idID, 9);
    row.setString(depotID, "Depot 1");
    row.setString(typeID, "F");
    row.setString(nameID, "SPAENGLER LIFE SCIENCE TRUST");
    row.setDouble(valueID, 545.45);
    
    row = dataTable.addRow();
    row.setInt(idID, 10);
    row.setString(depotID, "Depot 2");
    row.setString(typeID, "F");
    row.setString(nameID, "MMF (Most Miserable Fund)");
    row.setDouble(valueID, 12326.74);
   
    row = dataTable.addRow();
    row.setInt(idID, 10);
    row.setString(depotID, "Depot 3");
    row.setString(typeID, "S");
    row.setString(nameID, "CISCO SYSTEMS");
    row.setDouble(valueID, 5546.74);

    row = dataTable.addRow();
    row.setInt(idID, 11);
    row.setString(depotID, "Depot 3");
    row.setString(typeID, "S");
    row.setString(nameID, "WHEELING PITTS");
    row.setDouble(valueID, 2835.21);

    row = dataTable.addRow();
    row.setInt(idID, 12);
    row.setString(depotID, "Depot 3");
    row.setString(typeID, "S");
    row.setString(nameID, "NATIONAL VISION");
    row.setDouble(valueID, 7675.12);

    row = dataTable.addRow();
    row.setInt(idID, 13);
    row.setString(depotID, "Depot 3");
    row.setString(typeID, "S");
    row.setString(nameID, "COMTECH TELCOM");
    row.setDouble(valueID, 865.23);

    row = dataTable.addRow();
    row.setInt(idID, 14);
    row.setString(depotID, "Depot 3");
    row.setString(typeID, "S");
    row.setString(nameID, "IMMUNOMEDICS");
    row.setDouble(valueID, 876.21);

    row = dataTable.addRow();
    row.setInt(idID, 15);
    row.setString(depotID, "Depot 3");
    row.setString(typeID, "S");
    row.setString(nameID, "INTEL CORP");
    row.setDouble(valueID, 673.45);
    
    row = dataTable.addRow();
    row.setInt(idID, 16);
    row.setString(depotID, "Depot 3");
    row.setString(typeID, "F");
    row.setString(nameID, "Wasatch Ultra Growth");
    row.setDouble(valueID, 435.23);

    row = dataTable.addRow();
    row.setInt(idID, 17);
    row.setString(depotID, "Depot 3");
    row.setString(typeID, "F");
    row.setString(nameID, "Mutual Discovery A");
    row.setDouble(valueID, 1567.54);

    row = dataTable.addRow();
    row.setInt(idID, 18);
    row.setString(depotID, "Depot 3");
    row.setString(typeID, "F");
    row.setString(nameID, "Vanguard Global Equity");
    row.setDouble(valueID, 425.53);

    row = dataTable.addRow();
    row.setInt(idID, 1);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "S");
    row.setString(nameID, "QUIRKS");
    row.setDouble(valueID, 3456.54);

    row = dataTable.addRow();
    row.setInt(idID, 2);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "S");
    row.setString(nameID, "ZOORO");
    row.setDouble(valueID, 455.25);

    row = dataTable.addRow();
    row.setInt(idID, 3);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "S");
    row.setString(nameID, "ROBOTRON");
    row.setDouble(valueID, 3545.37);

    row = dataTable.addRow();
    row.setInt(idID, 4);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "S");
    row.setString(nameID, "PARODENTRON");
    row.setDouble(valueID, 7567.76);

    row = dataTable.addRow();
    row.setInt(idID, 5);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "S");
    row.setString(nameID, "FORZA");
    row.setDouble(valueID, 3621.21);

    row = dataTable.addRow();
    row.setInt(idID, 5);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "S");
    row.setString(nameID, "CUPTEC");
    row.setDouble(valueID, 541.34);

    row = dataTable.addRow();
    row.setInt(idID, 6);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "ZOCKER.COM");
    row.setDouble(valueID, 521.12);
    
    row = dataTable.addRow();
    row.setInt(idID, 7);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "GAAGLI");
    row.setDouble(valueID, 5464.12);

    row = dataTable.addRow();
    row.setInt(idID, 8);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "HANSO INC");
    row.setDouble(valueID, 554.34);

    row = dataTable.addRow();
    row.setInt(idID, 9);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "LOCKER");
    row.setDouble(valueID, 145.32);

    row = dataTable.addRow();
    row.setInt(idID, 1);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "KOCKEL");
    row.setDouble(valueID, 654.24);

    row = dataTable.addRow();
    row.setInt(idID, 1);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "FARBIC");
    row.setDouble(valueID, 4564.34);

    row = dataTable.addRow();
    row.setInt(idID, 1);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "HEGON");
    row.setDouble(valueID, 235.31);

    row = dataTable.addRow();
    row.setInt(idID, 1);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "REHAKLES");
    row.setDouble(valueID, 1432.32);

    row = dataTable.addRow();
    row.setInt(idID, 1);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "PATZIKI");
    row.setDouble(valueID, 324.12);

    row = dataTable.addRow();
    row.setInt(idID, 1);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "GRINSO");
    row.setDouble(valueID, 228.53);

    row = dataTable.addRow();
    row.setInt(idID, 1);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "GONZOLES");
    row.setDouble(valueID, 458.33);

    row = dataTable.addRow();
    row.setInt(idID, 1);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "HASTENIX");
    row.setDouble(valueID, 4528.33);

    row = dataTable.addRow();
    row.setInt(idID, 1);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "ALLESKAPUTT");
    row.setDouble(valueID, 556.54);

    row = dataTable.addRow();
    row.setInt(idID, 1);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "MIES");
    row.setDouble(valueID, 764.45);

    row = dataTable.addRow();
    row.setInt(idID, 1);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "MIESER SPEZIAL");
    row.setDouble(valueID, 438.26);

    row = dataTable.addRow();
    row.setInt(idID, 1);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "AMMIESESTEN");
    row.setDouble(valueID, 342.31);
  }

  /**
   * Tests the report output.
   * @throws DocumentHandlerException In case a document handler problem occured.
   * @throws TableException In case a table access problem occured.
   * @throws IOException In case an I/O problem occured.
   */
  public void testReport() throws DocumentHandlerException, TableException, IOException {
    // creating report table
    ReportTable reportTable = new ReportTable(dataTable);
    ReportFunction f = new ReportFunction("NAME", new CountFunctionExecutor(), true, new String[] {"DEPOT", "TYPE"});
    f.setAlign(LayoutHints.RIGHT);
    reportTable.addFunction(f);
    reportTable.addFunction(new ReportFunction("VALUE", new SumFunctionExecutor(), true, new String[] {"DEPOT", "TYPE"}));
    reportTable.addGroup(new ReportGroup("DEPOT", true, true, true, false, true));
    reportTable.addGroup(new ReportGroup("TYPE", false, false, true, false));
    reportTable.orderColumns(new String[] {"DEPOT", "TYPE", "ID", "NAME", "VALUE"});
    
    // printing report to PDF
    docProperties.put("table", reportTable);
    setTemplateSource("test/print/report-test.xml");
    printDocument(outputFolder + "report-test.pdf");
  }

  /**
   * Tests enforceResultRow flag.
   * @throws DocumentHandlerException In case a document handler problem occured.
   * @throws TableException In case a table access problem occured.
   * @throws IOException In case an I/O problem occured.
   */
  public void testEnforceResultRow() throws DocumentHandlerException, TableException, IOException {
    // creating report table
    ReportTable reportTable = new ReportTable(dataTable);
    ReportFunction f = new ReportFunction("NAME", new CountFunctionExecutor(), true, new String[] {"DEPOT"});
    f.setAlign(LayoutHints.RIGHT);
    reportTable.addFunction(f);
    reportTable.addFunction(new ReportFunction("VALUE", new SumFunctionExecutor(), true, new String[] {"DEPOT"}));
    reportTable.addGroup(new ReportGroup("DEPOT", true, true, true, false, true).setEnforceResultRow(true));
    reportTable.addGroup(new ReportGroup("TYPE", false, false, true, false).setEnforceResultRow(true));
    reportTable.orderColumns(new String[] {"DEPOT", "TYPE", "ID", "NAME", "VALUE"});
    
    // printing report to PDF
    docProperties.put("table", reportTable);
    setTemplateSource("test/print/report-test2.xml");
    printDocument(outputFolder + "report-test2.pdf");
  }

  /**
   * The main method for testing purposal.
   * @param args The command line argumants.
   */
  public static void main(String[] args) {
    
    if (args.length < 1) {
      System.err.println("Usage: java org.ujac.print.test.ReportTest <output folder>");
      System.exit(1);
    }
    
    try {
      ReportTest test = new ReportTest();
      test.setUp();
      test.outputFolder = args[0];
      test.testReport();
      test.testEnforceResultRow();
    } catch (Exception ex) {
      ex.printStackTrace();
    }
  }

}
