/*
 * Copyright (C) 2005 - 2007 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.print.test;

import java.util.HashMap;
import java.util.Map;

import org.ujac.print.BaseDocumentTag;
import org.ujac.print.DefaultDocumentTagFactory;
import org.ujac.print.DocumentHandler;
import org.ujac.print.StyleParser;

import org.ujac.util.template.TemplateContext;

import com.lowagie.text.Element;

/**
 * Name: StyleParserTest<br>
 * Description: Tests for the style parser.
 * 
 * @author lauerc
 */
public class StyleParserTest extends BasePrintTest {

  /** The document handler. */
  private DocumentHandler documentHandler = null;
  /** The style parser. */
  private StyleParser styleParser = null;
  /** The map of supported attributes. */
  private Map supportedStyleAttributeMap = null;
  
  /**
   * @see junit.framework.TestCase#setUp()
   */
  protected void setUp() throws Exception {
    super.setUp();
    
    Map properties = new HashMap();
    TemplateContext tcx = new TemplateContext(properties);
    this.documentHandler = new DocumentHandler(null, tcx, DefaultDocumentTagFactory.getInstance());
    this.styleParser = documentHandler.getStyleParser();
    BaseDocumentTag cell = documentHandler.getTagFactory().createTagInstance(documentHandler, "cell");
    this.supportedStyleAttributeMap =  cell.getSupportedAttributes();
  }

  /**
   * Testing text style attribute parsing. 
   * @throws Exception In case something went wrong.
   */
  public void testTextStyleAttributes() throws Exception {
    Map styleMap = new HashMap();
    assertEquals(1, styleParser.parseStyle(documentHandler.locator(), "font: large", supportedStyleAttributeMap, styleMap));
    assertEquals("large", styleMap.get("font"));
  }

  /**
   * Testing float style attribute parsing. 
   * @throws Exception In case something went wrong.
   */
  public void testFloatStyleAttributes() throws Exception {
    Map styleMap = new HashMap();
    assertEquals(3, styleParser.parseStyle(documentHandler.locator(), "padding: 15;line-spacing:20;leading:2", supportedStyleAttributeMap, styleMap));
    assertEquals(new Float(15.0F), styleMap.get("padding"));
    assertEquals(new Float(20.0F), styleMap.get("line-spacing"));
    assertEquals(new Float(2.0F), styleMap.get("leading"));
  }

  /**
   * Testing float style attribute parsing. 
   * @throws Exception In case something went wrong.
   */
  public void testAlignmentAttributes() throws Exception {
    Map styleMap = new HashMap();
    assertEquals(2, styleParser.parseStyle(documentHandler.locator(), "halign:left; valign:middle", supportedStyleAttributeMap, styleMap));
    assertEquals(new Integer(Element.ALIGN_LEFT), styleMap.get("halign"));
    assertEquals(new Integer(Element.ALIGN_MIDDLE), styleMap.get("valign"));
  }

  /**
   * Testing global attribute alias support. 
   * @throws Exception In case something went wrong.
   */
  public void testGlobalAttributeAliases() throws Exception {
    Map styleMap = new HashMap();
    assertEquals(1, styleParser.parseStyle(documentHandler.locator(), "align:center", supportedStyleAttributeMap, styleMap));
    assertEquals(new Integer(Element.ALIGN_CENTER), styleMap.get("halign"));
  }

}