/*
 * Copyright (C) 2005-2007 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util;

import java.util.Comparator;

/**
 * Name: BeanComparator<br>
 * Description: Generic comparator for java beans.
 * 
 * @author lauerc
 */
public class BeanComparator implements Comparator {

  /** The names of the fields by which to sort. */ 
  private CompareTuple[] compareTuples = null;
  
  /**
   * Constructs a BeanComparator instance with specific attributes.
   * @param fieldName The name of the field by which to sort. 
   */
  public BeanComparator(String fieldName) {
    this.compareTuples = new CompareTuple[] { new CompareTuple(fieldName) };
  }
  /**
   * Constructs a BeanComparator instance with specific attributes.
   * @param compareTuple The name of the field plus the direction by which to sort. 
   */
  public BeanComparator(CompareTuple compareTuple) {
    this.compareTuples = new CompareTuple[] { compareTuple };
  }
  /**
   * Constructs a BeanComparator instance with specific attributes.
   * @param fieldNames The names of the fields by which to sort. 
   */
  public BeanComparator(String[] fieldNames) {
    if (fieldNames != null) {
      this.compareTuples = new CompareTuple[fieldNames.length];
      for (int i = 0; i < fieldNames.length; i++) {
        compareTuples[i] = new CompareTuple(fieldNames[i]);
      }
    }
  }
  /**
   * Constructs a BeanComparator instance with specific attributes.
   * @param compareTuples The names of the field plus the directions by which to sort. 
   */
  public BeanComparator(CompareTuple[] compareTuples) {
    this.compareTuples = compareTuples;
  }
  
  /**
   * @see java.util.Comparator#compare(java.lang.Object, java.lang.Object)
   */
  public int compare(Object o1, Object o2) {
    Comparable c1 = null;
    Comparable c2 = null;
    CompareTuple[] compareTuples = this.compareTuples;
    if (compareTuples != null) {
      for (int i = 0; i < compareTuples.length; i++) {
        CompareTuple compareTuple = compareTuples[i];
        String fieldName = compareTuple.getFieldName();
        try {
          c1 = (Comparable) BeanUtils.getProperty(o1, fieldName);
          c2 = (Comparable) BeanUtils.getProperty(o2, fieldName);
        } catch (BeanException ex) {
          throw new RuntimeException(ex.getMessage(), ex);
        }
        int result = c1.compareTo(c2);
        if (result != 0) {
          if (compareTuple.getDirection() == CompareTuple.DESCENDING) {
            return result * -1;
          }
          return result;
        }
      }
      return 0;
    }
    
    // no fields defined, comparing the elements
    c1 = (Comparable) o1;
    c2 = (Comparable) o2;
    return c1.compareTo(c2);
  }
  
}
