package org.ujac.util;

/**
 * Title:       CompareTuple<br>
 * Description: Holds tuples of field names and directions to sort by.<br>
 *
 * @author christian.lauer@dekabank.lu
 */
public class CompareTuple {

  /** Constant for ascending sort direction. */
  public static final int ASCENDING = 1;
  /** Constant for descending sort direction. */
  public static final int DESCENDING = 2;
  
  /** The field name. */
  private String fieldName = null;
  /** The sort direction. */
  private int direction = ASCENDING;
  
  /**
   * Constructs a CompareTuple instance with specific attributes.
   * @param fieldName The initial field name.
   */
  public CompareTuple(String fieldName) {
    this(fieldName, ASCENDING);
  }
  
  /**
   * Constructs a CompareTuple instance with specific attributes.
   * @param fieldName The initial field name.
   * @param direction The initial sort direction.
   */
  public CompareTuple(String fieldName, int direction) {
    this.fieldName = fieldName;
    this.direction = direction;
  }

  /**
   * Getter method for the the property fieldName.
   * @return The current value of property fieldName.
   */
  public String getFieldName() {
    return fieldName;
  }
  /**
   * Setter method for the the property fieldName.
   * @param fieldName The value to set for the property fieldName.
   */
  public void setFieldName(String fieldName) {
    this.fieldName = fieldName;
  }
  
  /**
   * Getter method for the the property direction.
   * @return The current value of property direction.
   */
  public int getDirection() {
    return direction;
  }
  /**
   * Gets the sort direction name.
   * @return The sort direction name.
   */
  public String getDirectionName() {
    switch (direction) {
      case DESCENDING:
        return "DESC";
      
      default:
        return "ASC";
    }
  }
  /**
   * Setter method for the the property direction.
   * @param direction The value to set for the property direction.
   */
  public void setDirection(int direction) {
    this.direction = direction;
  }

  /**
   * @see java.lang.Object#toString()
   */
  public String toString() {
    return "{fieldName: " + fieldName + ", direction: " + getDirectionName() + "}";
  }
}
