/*
 * Copyright (C) 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util;

/**
 * Name: StopWatch<br>
 * Description: A class for time measurements.
 * 
 * @author lauerc
 */
public class StopWatch {

  /** The start time. */
  private long startTime = 0L;
  /** The stop time. */
  private long stopTime = 0L;
  
  /**
   * Constructs a StopWatch instance with no specific attributes.
   */
  public StopWatch() {
    this.startTime = System.currentTimeMillis();
  }

  /**
   * Stops the time measuring.
   * @return The passed milli seconds since the stop watch has been started.
   */
  public long stop() {
    this.stopTime = System.currentTimeMillis();
    return stopTime - startTime;
  }

  /**
   * Gets the current mean time that has been passed since the latest start time.
   * @return The passed milli seconds since the stop watch has been started.
   */
  public long meantime() {
    long meantime = System.currentTimeMillis();
    return meantime - startTime;
  }
  
  /**
   * Resets the stop watch.
   * @return The new start time.
   */
  public long reset() {
    this.stopTime = 0L;
    this.startTime = System.currentTimeMillis();
    return startTime;
  }

  /**
   * Gets the start time.
   * @return The time when the stop watch has been started.
   */
  public long getStartTime() {
    return startTime;
  }

  /**
   * Gets the stop time.
   * @return The time when the stop watch has been stop.
   */
  public long getStopTime() {
    return stopTime;
  }

  /**
   * Gets the time duration.
   * @return The passed time between starting and stopping the stop watch.
   */
  public long getDuration() {
    return stopTime - startTime;
  }

}
