/*
 * Copyright (C) 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util;

import org.ujac.util.types.DataType;

/**
 * Name: TypeConverter<br>
 * Description: An interface for type converters.
 * 
 * @author lauerc
 */
public interface TypeConverter {
  
  /**
   * Registers the data type.
   * @param clazz The type to handle.
   * @param typeHandler The type handler.
   */
  void registerDataType(Class clazz, DataType typeHandler);

  /**
   * Gets the data type for the given class.
   * @param clazz The type to handle.
   * @return The registered type handler.
   */
  DataType getDataType(Class clazz);
  /**
   * Gets the data type for the given type ID.
   * @param typeId The ID of the type to get the handler for.
   * @return The registered type handler.
   */
  DataType getDataType(int typeId);

  /**
   * Converts the given value into an instance of this type.
   * @param clazz The class value.
   * @param value The value to convert.
   * @return The according instance.
   * @exception TypeConverterException In case the conversion failed.
   */
  Object convertObject(Class clazz, Object value)
    throws TypeConverterException;
  /**
   * Converts the given value into an instance of this type.
   * @param typeId The type ID.
   * @param value The value to convert.
   * @return The according instance.
   * @exception TypeConverterException In case the conversion failed.
   */
  Object convertObject(int typeId, Object value)
    throws TypeConverterException;

  /**
   * FormatsConverts the given value into an instance of this type.
   * @param clazz The class value.
   * @param value The value to convert. 
   * @return The formatted value.
   * @exception TypeConverterException In case the conversion failed.
   */
  String formatValue(Class clazz, Object value)
    throws TypeConverterException;
  /**
   * FormatsConverts the given value into an instance of this type.
   * @param typeId The type ID.
   * @param value The value to convert. 
   * @return The formatted value.
   * @exception TypeConverterException In case the conversion failed.
   */
  String formatValue(int typeId, Object value)
    throws TypeConverterException;

}
