/*
 * Copyright (C) 2003, 2004, 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util;

import java.io.PrintStream;
import java.io.PrintWriter;

/**
 * Name: UjacException<br>
 * Description: The base UJAC exception class.
 * 
 * @author lauerc
 */
public class UjacException extends Exception {

  /** The serial version UID. */
  static final long serialVersionUID = 6371898282973694816L;

  /** The original exception that caused this exception. */
  private Throwable originalCause;

  /**
   * Creates an instance with no specific arguments.
   */
  public UjacException() {
  }
  
  /**
   * Creates an instance with specific arguments.
   * @param msg The error message.
   */
  public UjacException(String msg) {
    super(msg);
  }
  
  /**
   * Constructs a UjacException instance with no specific arguments.
   * @param msg The error message.
   * @param cause The cause of the error. 
   */
  public UjacException(String msg, Throwable cause) {
    this(msg);
    this.originalCause = cause;
  }
  
  /**
   * Gets the exception that causet this one.
   * @return The exception that causet this one.
   */
  public Throwable getOriginalCause() {
    return originalCause;
  }
  
  /**
   * @see java.lang.Throwable#printStackTrace(java.io.PrintStream)
   */
  public void printStackTrace(PrintStream stream) {
    super.printStackTrace(stream);
    if (originalCause != null) {
      stream.println("Caused by:" + originalCause.getMessage());
      originalCause.printStackTrace(stream);
    }
  }

  /**
   * @see java.lang.Throwable#printStackTrace(java.io.PrintWriter)
   */
  public void printStackTrace(PrintWriter writer) {
    super.printStackTrace(writer);
    if (originalCause != null) {
      writer.println("Caused by:" + originalCause.getMessage());
      originalCause.printStackTrace(writer);
    }
  }

}
