/*
 * Copyright (C) 2005 - 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util;

import java.util.HashMap;
import java.util.Map;

/**
 * Name: UjacTypes<br>
 * Description: Provides helper methods for string to type conversion and back.
 * 
 * @author lauerc
 */
public class UjacTypeHelper implements UjacTypes {

  /** The type name map. */
  private static final Map TYPE_NAME_MAP = new HashMap();
  /** The type name list. */
  private static final String[] TYPE_NAMES = new String[] {
    TYPE_NAME_BOOLEAN,
    TYPE_NAME_DATE,
    TYPE_NAME_DOUBLE,
    TYPE_NAME_FLOAT,
    TYPE_NAME_INT,
    TYPE_NAME_LONG,
    TYPE_NAME_OBJECT,
    TYPE_NAME_SHORT,
    TYPE_NAME_STRING,
    TYPE_NAME_TABLE,
    TYPE_NAME_TIME,
    TYPE_NAME_TIMESTAMP
  };
  /** The type ID list. */
  private static final int[] TYPE_IDS = new int[] {
    TYPE_STRING,
    TYPE_INT,
    TYPE_SHORT,
    TYPE_LONG,
    TYPE_FLOAT,
    TYPE_DOUBLE,
    TYPE_BOOLEAN,
    TYPE_DATE,
    TYPE_TIME,
    TYPE_TIMESTAMP,
    TYPE_OBJECT,
    TYPE_TABLE
  };
  
  static {
    TYPE_NAME_MAP.put(TYPE_NAME_STRING, new Integer(TYPE_STRING));
    TYPE_NAME_MAP.put(TYPE_NAME_INT, new Integer(TYPE_INT));
    TYPE_NAME_MAP.put(TYPE_NAME_SHORT, new Integer(TYPE_SHORT));
    TYPE_NAME_MAP.put(TYPE_NAME_LONG, new Integer(TYPE_LONG));
    TYPE_NAME_MAP.put(TYPE_NAME_FLOAT, new Integer(TYPE_FLOAT));
    TYPE_NAME_MAP.put(TYPE_NAME_DOUBLE, new Integer(TYPE_DOUBLE));
    TYPE_NAME_MAP.put(TYPE_NAME_BOOLEAN, new Integer(TYPE_BOOLEAN));
    TYPE_NAME_MAP.put(TYPE_NAME_DATE, new Integer(TYPE_DATE));
    TYPE_NAME_MAP.put(TYPE_NAME_TIME, new Integer(TYPE_TIME));
    TYPE_NAME_MAP.put(TYPE_NAME_TIMESTAMP, new Integer(TYPE_TIMESTAMP));
    TYPE_NAME_MAP.put(TYPE_NAME_OBJECT, new Integer(TYPE_OBJECT));
    TYPE_NAME_MAP.put(TYPE_NAME_TABLE, new Integer(TYPE_TABLE));
  }
  
  /**
   * Gets the type ID from the given String.
   * @param name The name of the type to determine.
   * @return The according type ID or -1 in case the type name is unknown.
   */
  public static final int getTypeId(String name) {
    if (name == null) {
      return -1;
    }
    Integer typeId = (Integer) TYPE_NAME_MAP.get(name.toLowerCase());
    if (typeId == null) {
      return -1;
    }
    return typeId.intValue();
  }

  /**
   * Gets the type name from the given ID.
   * @param id The ID of the type to get the name for.
   * @return The according type name or null in case the type ID is unknown.
   */
  public static final String getTypeName(int id) {
    switch (id) {
      case TYPE_STRING:
        return TYPE_NAME_STRING;
      case TYPE_INT:
        return TYPE_NAME_INT;
      case TYPE_LONG:
        return TYPE_NAME_LONG;
      case TYPE_FLOAT:
        return TYPE_NAME_FLOAT;
      case TYPE_DOUBLE:
        return TYPE_NAME_DOUBLE;
      case TYPE_BOOLEAN:
        return TYPE_NAME_BOOLEAN;
      case TYPE_DATE:
        return TYPE_NAME_DATE;
      case TYPE_TIME:
        return TYPE_NAME_TIME;
      case TYPE_TIMESTAMP:
        return TYPE_NAME_TIMESTAMP;
      case TYPE_OBJECT:
        return TYPE_NAME_OBJECT;
      case TYPE_TABLE:
        return TYPE_NAME_TABLE;
      default:
        return null;
    }
  }

  /**
   * Gets an array of all type names.
   * @return An array with all type names.
   */
  public static final String[] getTypeNames() {
    return TYPE_NAMES;
  }

  /**
   * Gets an array of all type IDs.
   * @return An array of all type IDs.
   */
  public static final int[] getTypeIds() {
    return TYPE_IDS;
  }
  
}