/*
 * Copyright (C) 2003 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.util.console;

import java.util.Map;

/**
 * Name: CommandLineHelper<br>
 * Description: A class providing useful utilities for command line handling.
 * 
 * @author lauerc
 */
public class CommandLineHelper {

  /**
   * Parses the command line argument list for options.
   * @param args The command line argument list.
   * @param options The option map to fill.
   * @return The index of the first non option argument.
   */
  public static final int parseOptions(String[] args, Map options) {
    for (int i = 0; i < args.length; i++) {
      String arg = args[i];
      if (arg.charAt(0) == '-') {
        int assignIdx = arg.indexOf('=');
        String option = null;
        String value = null;
        if (assignIdx > 0) {
          option = arg.substring(1, assignIdx);
          value = arg.substring(assignIdx + 1);
        } else {
          option = arg.substring(1);
        }
        options.put(option, value);
      } else {
        // non option argument detected
        return i;
      }
    }
    // no non option argument detected
    return -1;
  }

}
