/*
 * Copyright (C) 2003, 2004, 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.util.console;

import java.io.IOException;

/**
 * Name: PasswordReader<br>
 * Description: Reads a password from console input and tries to hide the typed characters.<br>
 * 
 * @author lauerc
 */
public class PasswordReader implements Runnable {

  /** Tells the masking thread to quit his job. */ 
  private boolean passwordEntered = false;
  /** The command line prompt. */
  private String prompt;
	
  /**
   * Constructs a PasswordReader with no specific attributes.
   * @param prompt The command line prompt.
   */
  public PasswordReader(String prompt) {
    this.prompt = prompt;
  }

  /**
   * Begins masking until asked to stop.
   */
  public void run() {
    while (!passwordEntered) {
      try {
        // attempt masking at this rate
        Thread.sleep(1);
      } catch (InterruptedException iex) {
        iex.printStackTrace();
      }
      if (!passwordEntered) {
        System.out.print("\r" + prompt + " \r" + prompt);
      }
      System.out.flush();
    }
  }

  /**
   * Instructs the thread to stop masking.
   */
  public void stopMasking() {
    this.passwordEntered = true;
  }

  /**
   * Reads the password from the command line.
   * @return The password as entered by the user.
   * @exception IOException In case the console input failed.
   */
  public String readPassword() throws IOException {
    // password buffer
    StringBuffer passwdBuf = new StringBuffer();
    Thread maskingthread = new Thread(this);
    Thread thread = new Thread(maskingthread);
    thread.start();
    
    // block until enter is pressed
    while (true) {
      char c = (char) System.in.read();
      // assume enter pressed, stop masking
      stopMasking();

      if (c == '\r') {
        c = (char) System.in.read();
        if (c == '\n') {
          break;
        }
        continue;
      } else if (c == '\n') {
        break;
      } else {
        // appending entered character to the password
        passwdBuf.append(c);
      }
    }
    return passwdBuf.toString();
  }

  /**
   * The main method for testing purposes.
   * @param args The command line arguments.
   */
  public static void main(String[] args) {
    try {
      String passwd = new PasswordReader("password: ").readPassword();
      System.out.println("Password is: " + passwd);
    } catch (IOException e) {
      e.printStackTrace();
    }    
  }
}
