/*
 * Copyright (C) 2003 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util.db;

import org.ujac.util.UjacTypes;

/**
 * Name: DataTypeMapper<br>
 * Description: A interface intended to make the type conversion from 
 *   database types to java types more customizable.
 * 
 * @author lauerc
 */
public interface DataTypeMapper {

  /** Constant for the java type Object. */
  int JAVA_TYPE_OBJECT = UjacTypes.TYPE_OBJECT;
  /** Constant for the java type int. */
  int JAVA_TYPE_INT = UjacTypes.TYPE_INT;
  /** Constant for the java type long. */
  int JAVA_TYPE_LONG = UjacTypes.TYPE_LONG;
  /** Constant for the java type float. */
  int JAVA_TYPE_FLOAT = UjacTypes.TYPE_FLOAT;
  /** Constant for the java type double. */
  int JAVA_TYPE_DOUBLE = UjacTypes.TYPE_DOUBLE;
  /** Constant for the java type boolean. */
  int JAVA_TYPE_BOOLEAN = UjacTypes.TYPE_BOOLEAN;
  /** Constant for the java type String. */
  int JAVA_TYPE_STRING = UjacTypes.TYPE_STRING;
  /** Constant for the java type Date. */
  int JAVA_TYPE_DATE = UjacTypes.TYPE_DATE;
  /** Constant for the java type Time. */
  int JAVA_TYPE_TIME = UjacTypes.TYPE_TIME;
  /** Constant for the java type Timestamp. */
  int JAVA_TYPE_TIMESTAMP = UjacTypes.TYPE_TIMESTAMP;
  
  /**
   * Gets the JAVA type of the given SQL type.
   * @param sqlType The SQL type ID from java.sql.Types.
   * @param columnSize The size of the SQL type.
   * @param decimalDigits The number of decimal digits.
   * @return The SQL type name.
   * @see #JAVA_TYPE_OBJECT
   * @see #JAVA_TYPE_INT
   * @see #JAVA_TYPE_LONG
   * @see #JAVA_TYPE_FLOAT
   * @see #JAVA_TYPE_DOUBLE
   * @see #JAVA_TYPE_BOOLEAN
   * @see #JAVA_TYPE_STRING
   * @see #JAVA_TYPE_DATE
   * @see #JAVA_TYPE_TIME
   * @see #JAVA_TYPE_TIMESTAMP
   */
  int getJavaType(int sqlType, int columnSize, int decimalDigits);

  /**
   * Gets the name of the given SQL type
   * @param sqlType The SQL type ID from java.sql.Types.
   * @param columnSize The size of the SQL type.
   * @param decimalDigits The number of decimal digits.
   * @param allowPrimitive If true, uses the simple types (int, long, float, double, ...) for
   *   numeric values, otherwise returns the wrapper classed for these types.
   * @param fullyQualified If true, returns the fully qualified class names for system classes, 
   *   else returns the system class names without java.lang package prefix. 
   * @return The JAVA type name.
   */
  String getJavaTypeName(int sqlType, int columnSize, int decimalDigits, 
                         boolean allowPrimitive, boolean fullyQualified);

  /**
   * Gets the name of the given SQL type
   * @param sqlType The SQL type ID from java.sql.Types.
   * @return The SQL type name.
   */
  String getSqlTypeName(int sqlType);
    
}
