/*
 * Copyright (C) 2003 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.util.exi;

/**
 * Title: AncestorDefinition<br>
 * Description: Helper class for definitions of ancestors.<br>
 * @author lauerc
 */
public class AncestorDefinition {

  /** The statement type. */
  private Integer type;
  /** The optional flag. */
  private boolean optional;
  /** The mutiple flag. */
  private boolean multiple;

  /**
   * Constructs a AncestorDefinition instance with specific attributes.
   * @param type The statement type. 
   */
  public AncestorDefinition(Integer type) {
    this(type, false, false);
  }

  /**
   * Constructs a AncestorDefinition instance with specific attributes.
   * @param type The statement type. 
   * @param optional The optional flag. 
   */
  public AncestorDefinition(Integer type, boolean optional) {
    this(type, optional, false);
  }

  /**
   * Constructs a AncestorDefinition instance with specific attributes.
   * @param type The statement type. 
   * @param optional The optional flag. 
   * @param multiple The multiple flag. 
   */
  public AncestorDefinition(Integer type, boolean optional, boolean
multiple) {
    this.type = type;
    this.optional = optional;
    this.multiple = multiple;
  }

  /**
   * Gets the ancestor type.
   * @return The ancestor type.
   */
  public Integer getType() {
    return type;
  }

  /**
   * Gets the optional flag.
   * @return The optional flag.
   */
  public boolean isOptional() {
    return optional;
  }

  /**
   * Gets the multiple flag.
   * @return The multiple flag.
   */
  public boolean isMultiple() {
    return multiple;
  }

}
