/*
 * Copyright (C) 2003 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.util.exi;

/**
 * Name: ConstantOperand<br>
 * Description: A class implementing operands holding constant values.<br>
 * 
 * @author lauerc
 */
public class ConstantOperand extends Operand {

  /** The serial version UID. */
  private static final long serialVersionUID = 3618420436409857330L;
  
  /** The constant object. */
  private Object object;

  /**
   * Constructs a ConstantOperand instance with specific attributes.
   */
  public ConstantOperand() {
    super();
  }

  /**
   * Constructs a ConstantOperand instance with specific attributes.
   * @param source The textual source for the expression.
   * @param absolutePosition The absolute start position of the expression within the source.
   * @param relativePosition The relative start position of the expression within the source.
   * @param length The length of the expression.
   */
  public ConstantOperand(char[] source, int absolutePosition, int relativePosition, int length) {
    super(source, absolutePosition, relativePosition, length);
    this.object = new String(source, absolutePosition, length);
  }

  /**
   * Constructs a ConstantOperand instance with specific attributes.
   * @param outer The outer expression.
   */
  public ConstantOperand(Operand outer) {
    super(outer);
  }

  /**
   * @see org.ujac.util.exi.Operand#isSimple()
   */
  public boolean isSimple() {
    return true;
  }

  /**
   * Returns the constant object.
   * @return The object's value.
   */
  public Object getObject() {
    return object;
  }
  /**
   * Sets the constant object.
   * @param object The object to set
   */
  public void setObject(Object object) {
    this.object = object;
  }

  /**
   * Gets the operand value.
   * @return the value of the operand.
   */
  public Object getValue() {
    return object;
  }

  /**
   * @see java.lang.Object#toString()
   */
  public String toString() {
    if (object == null) {
      return "null";
    }
    return object.toString();
  }

  /**
   * @see java.lang.Object#clone()
   */
  public Object clone() {
    ConstantOperand clone = (ConstantOperand) super.clone();
    return clone;
  }

}
