/*
 * Copyright (C) 2003, 2004, 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.util.exi;

/**
 * Name: ExpressionOperation<br>
 * Description: The interface for expression operations.<br>
 * 
 * @author lauerc
 */
public interface ExpressionOperation {

  /**
   * Evaluates the given values.
   * @param expr The expression tuple to evaluate. 
   * @param ctx The expression context.
   * @return The result of the tuple evaluation.
   * @exception ExpressionException If the evaluation failed.
   */
  Object evaluate(ExpressionTuple expr, ExpressionContext ctx)
  	throws ExpressionException;
  
  /**
   * Gets a description for the operation.
   * @return The item's description.
   */
  String getDescription();

  /**
   * Gets examples for the item.
   * @return one ore more examples for the item's usage..
   */
  String getExamples();
  
}
