/*
 * Copyright (C) 2003, 2004, 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.util.exi;

import java.util.Map;
import java.util.Set;

/**
 * Name: ExpressionType<br>
 * Description: The interface for expression types.<br>
 * 
 * @author lauerc
 */
public interface ExpressionType {

  /**
   * Gets the class of the expression type.
   * @return The class the expression type is valid for.
   */
  Class getType();

  /**
   * Gets the type name of the expression type.
   * @return The name of the class the expression type is valid for.
   */
  String getTypeName();

  /**
   * Gets the alias of the expression type.
   * @return The type alias.
   */
  String getAlias();

  /**
   * Gets the operation implementation that matches the given operation.
   * @param operation gets the expression operation for the given operation definition.
   * @return The operation object if a operation for this name is defined else null.
   */
  ExpressionOperation getOperation(Operation operation);
  
  /**
   * Gets all registered operation names.
   * @return The names of the operations, registerd with this type handler.
   */
  Set getOperationNames();

  /**
   * Gets all registered operations.
   * @return The operations, registerd with this type handler.
   */
  Map getOperations();

  /**
   * Evaluates the given expression tuple.
   * @param expr The expression tuple to evaluate. 
   * @param ctx The expression context.
   * @return The result of the tuple evaluation.
   * @exception ExpressionException If the evaluation failed.
   */
  Object evalTuple(ExpressionTuple expr, ExpressionContext ctx)
    throws ExpressionException;

  /**
   * Gets a description for the operation.
   * @return The item's description.
   */
  String getDescription();

  /**
   * Casts the given value into the handler-specific type.
   * @param value The value to cast.
   * @return The transformed value.
   * @exception TypeCastException In case the type cast failed.
   */
  Object typeCast(Object value) throws TypeCastException;

}
