/*
 * Copyright (C) 2003 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.util.exi;

/**
 * Name: Operation<br>
 * Description: A class specifying expression operations.
 * 
 * @author lauerc
 */
public class Operation {

  /** The operation name. */
  private String name;
  /** The operation priotity. */
  private int priority;
  

  /**
   * Constructs a Operation instance with specific attributes.
   * @param name The name of the operation.
   */
  public Operation(String name) {
    this.name = name;
    this.priority = 0;
  }

  /**
   * Constructs a Operation instance with specific attributes.
   * @param name The name of the operation.
   * @param priority The priority for the operation.
   */
  public Operation(String name, int priority) {
    this.name = name;
    this.priority = priority;
  }

  /**
   * Gets the operation name.
   * @return The operation name.
   */
  public String getName() {
    return name;
  }

  /**
   * Gets the operation's priority.
   * @return The operation's priority.
   */
  public int getPriority() {
    return priority;
  }
  
  /**
   * @see java.lang.Object#toString()
   */
  public String toString() {
    return name;
  }
}
