/*
 * Copyright (C) 2003, 2004, 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.util.exi;

import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;

/**
 * Title: SequenceIndex<br>
 * Description: A class implementing a mutable number number used for sequence indices.<br>
 * 
 * @author lauerc
 */
public class SequenceIndex extends Number {

  /** The serial version UID. */
  static final long serialVersionUID = 2800414953792000585L;

  /** The value. */
  private int value = 0;

  /**
   * Constructs a SequenceIndex instance with no specific attributes.
   * This sequence starts with index 0.
   */
  public SequenceIndex() {
  }

  /**
   * Constructs a SequenceIndex instance with specific attributes.
   * @param value The initial index.
   */
  public SequenceIndex(int value) {
    this.value = value; 
  }
  
  /**
   * Sets the new value.
   * @param value The value to set.
   */
  public void setValue(int value) {
    this.value = value;
  }

  /**
   * Increments the index by one.
   */
  public void increment() {
    ++value;
  }

  /**
   * Increments the index by the given value.
   * @param value The value, by which to increment the index.
   */
  public void increment(int value) {
    this.value += value;
  }

  /**
   * @see java.lang.Number#intValue()
   */
  public int intValue() {
    return value;
  }

  /**
   * @see java.lang.Number#longValue()
   */
  public long longValue() {
    return value;
  }

  /**
   * @see java.lang.Number#floatValue()
   */
  public float floatValue() {
    return value;
  }

  /**
   * @see java.lang.Number#doubleValue()
   */
  public double doubleValue() {
    return value;
  }

  /**
   * @see java.lang.Object#toString()
   */
  public String toString() {
    return Integer.toString(value);
  }

  /**
   * Writes the object's data to the given stream.
   * @param s The stream to write to
   * @exception IOException In case the data output failed.
   */
  private void writeObject(ObjectOutputStream s) throws IOException {
    s.writeInt(value);
  }
  /**
   * Reads the object's data from the given stream.
   * @param s The stream to read from.
   * @exception IOException In case the data reading failed.
   */
  private void readObject(ObjectInputStream s) throws IOException {
    value = s.readInt();
  }

}
