/*
 * Copyright (C) 2003 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.util.exi;

/**
 * Name: VariableOperand<br>
 * Description: A class implementing operands holding variables.<br>
 * 
 * @author lauerc
 */
public class VariableOperand extends Operand {

  /** The serial version UID. */
  private static final long serialVersionUID = 3545233613814576432L;
  
  /** The variable which holds the object. */
  private String variable;
  /** The object connected to the variable. */
  private Object object;
  /** Tells whether or not the variable is signed negative. */
  private boolean negative = false;
  
  /**
   * Constructs a VariableOperand instance with specific attributes.
   */
  public VariableOperand() {
    super();
  }

  /**
   * Constructs an VariableOperand instance with specific arguments.
   * @param source The textual source for the expression.
   * @param absolutePosition The absolute start position of the expression within the source.
   * @param relativePosition The relative start position of the expression within the source.
   * @param length The length of the expression.
   */
  public VariableOperand(char[] source, int absolutePosition, int relativePosition, int length) {
    super(source, absolutePosition, relativePosition, length);
  }
  
  /**
   * Constructs an VariableOperand instance with specific arguments.
   * Copies the source, totalPosition and totalLength from the outer expression.
   * @param outer The outer expression.
   */
  public VariableOperand(Operand outer) {
    super(outer);
  }

  /**
   * @see org.ujac.util.exi.Operand#isSimple()
   */
  public boolean isSimple() {
    return true;
  }

  /**
   * Returns the variable.
   * @return The variable name.
   */
  public String getVariable() {
    return variable;
  }
  /**
   * Sets the variable.
   * @param variable The variable to set
   */
  public void setVariable(String variable) {
    this.variable = variable;
  }

  /**
   * Returns the object, connected to the variable.
   * @return The object's value.
   */
  public Object getObject() {
    return object;
  }
  /**
   * Sets the object, connected to the variable.
   * @param object The object to set
   */
  public void setObject(Object object) {
    this.object = object;
  }

  /**
   * Tells whether the variable is signed negative or not.
   * @return true if the variable is signed negative, else false.
   */
  public boolean isNegative() {
    return negative;
  }
  /**
   * Sets the negative flag for the variable.
   * @param negative true if the variable shall be signed negative, else false.
   */
  public void setNegative(boolean negative) {
    this.negative = negative;
  }

  /**
   * Gets the operand value.
   * @return the value of the operand.
   */
  public Object getValue() {
    return object;
  }
  
  /**
   * @see java.lang.Object#toString()
   */
  public String toString() {
    return variable;
  }

  /**
   * @see java.lang.Object#clone()
   */
  public Object clone() {
    VariableOperand clone = (VariableOperand) super.clone();
    return clone;
  }

}
