/*
 * Copyright (C) 2003, 2004, 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.util.exi.test;

import java.util.Date;

import org.ujac.util.exi.ExpressionException;

/**
 * Name: ArrayTypeTest<br>
 * Description: A class testing the XyzArrayType classes.
 * 
 * @author lauerc
 */
public class ArrayTypeTest extends BaseExpressionTest {

  /**
   * @see junit.framework.TestCase#setUp()
   */
  protected void setUp() throws Exception {
    super.setUp();

    Object[] emptyArray = new Object[0];
    properties.put("nothing", emptyArray);

    Object[] objArray = new Object[10];
    objArray[0] = new Integer(1);
    objArray[1] = new Long(2);
    objArray[2] = new Short((short) 3);
    objArray[3] = new Double(4);
    objArray[4] = new Float(5);
    objArray[5] = null;
    objArray[6] = new Date();
    objArray[7] = new Character('A');
    objArray[8] = new Boolean(false);
    objArray[9] = "FIN";
    properties.put("objects", objArray);
    
    int[] intArray = new int[] {
      1, 6, 7, 12, 43, 42, 33, 45, 90, 121, 18, 27
    };
    properties.put("integers", intArray);

    short[] shortArray = new short[] {
      1, 6, 7, 12, 43, 42, 33, 45, 90, 121, 18, 27
    };
    properties.put("shorts", shortArray);

    long[] longArray = new long[] {
      14, 36, 23, 43, 43, 42, 33, 45, 90, 121, 18, 27
    };
    properties.put("longs", longArray);

    double[] doubleArray = new double[] {
      14.12, 36.12, 23.34, 43.34, 43.23, 42.67, 33.42, 45.44, 90.54, 121.12, 18.32, 27.43
    };
    properties.put("doubles", doubleArray);

    float[] floatArray = new float[] {
      1.12F, 6.12F, 2.34F, 2.34F, 4.23F, 2.67F, 3.42F, 4.44F, 0.54F, 1.12F, 1.32F, 2.43F
    };
    properties.put("floats", floatArray);

    char[] charArray = new char[] {
      'U', 'J', 'A', 'C', '!'
    };
    properties.put("chars", charArray);

    String[] stringArray = new String[] {
      "lorem", "ipsum", "dolor"
    };
    properties.put("strings", stringArray);
  
    Object[][] arrayOfArrays = new Object[][] {
      new String[] {"Meier", "Karl"},
      new String[] {"Huber", "Horst"},
      new String[] {"Linz", "Paul"},
      new String[] {"Keller", "Axel"},
      new String[] {"Kevric", "Adnan"},
      new String[] {"Klose", "Miroslav"},
      new String[] {"M�ller", "Peter"}
    };
    properties.put("arrayOfArrays", arrayOfArrays);
  }
  
  /**
   * Tests the isEmpty operation for various types.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testIsEmpty() throws ExpressionException {
    assertTrue(exi.evalBoolean("${nothing isEmpty}", properties, formatHelper));
    assertTrue(exi.evalBoolean("${objects notEmpty}", properties, formatHelper));
    assertFalse(exi.evalBoolean("${integers isEmpty}", properties, formatHelper));
    assertTrue(exi.evalBoolean("${shorts notEmpty}", properties, formatHelper));
    assertFalse(exi.evalBoolean("${longs isEmpty}", properties, formatHelper));
    assertTrue(exi.evalBoolean("${doubles notEmpty}", properties, formatHelper));
    assertFalse(exi.evalBoolean("${floats isEmpty}", properties, formatHelper));
    assertTrue(exi.evalBoolean("${chars notEmpty}", properties, formatHelper));
  }

  /**
   * Tests the size operation for various types.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testSize() throws ExpressionException {
    assertTrue(exi.evalInt("${nothing size}", properties, formatHelper) == 0);
    assertTrue(exi.evalInt("${integers size}", properties, formatHelper) == 12);
    assertTrue(exi.evalInt("${shorts size}", properties, formatHelper) == 12);
    assertTrue(exi.evalInt("${longs size}", properties, formatHelper) == 12);
    assertTrue(exi.evalInt("${doubles size}", properties, formatHelper) == 12);
    assertTrue(exi.evalInt("${floats size}", properties, formatHelper) == 12);
    assertTrue(exi.evalInt("${chars size}", properties, formatHelper) == 5);
  }

  /**
   * Tests the access of elements of collections or arrays.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testAccess() throws ExpressionException {
    //assertEquals(exi.evalObject("${nothing.0}", properties, formatHelper), null);
    assertEquals(exi.evalObject("${integers.3}", properties, formatHelper), new Integer(12));
    assertEquals(exi.evalObject("${shorts.0}", properties, formatHelper), new Short((short) 1));
    assertEquals(exi.evalObject("${longs.0}", properties, formatHelper), new Long(14));
    assertEquals(exi.evalObject("${doubles.0}", properties, formatHelper), new Double(14.12));
    assertEquals(exi.evalObject("${floats.0}", properties, formatHelper), new Float(1.12F));
    assertEquals(exi.evalObject("${chars.1}", properties, formatHelper), new Character('J'));

    assertEquals(exi.evalObject("${integers[1]}", properties, formatHelper), new Integer(6));
    assertEquals(exi.evalObject("${shorts[5]}", properties, formatHelper), new Short((short) 42));
    assertEquals(exi.evalObject("${longs[6]}", properties, formatHelper), new Long(33));
    assertEquals(exi.evalObject("${doubles[5]}", properties, formatHelper), new Double(42.67));
    assertEquals(exi.evalObject("${floats[4]}", properties, formatHelper), new Float(4.23F));
    assertEquals(exi.evalObject("${chars[2]}", properties, formatHelper), new Character('A'));
  }

}
