/*
 * Copyright (C) 2003, 2004, 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.util.exi.test;

import org.ujac.util.exi.ExpressionException;

/**
 * Name: BeanAccessTest<br>
 * Description: Tests expressions, which access bean properties.
 * 
 * @author lauerc
 */
public class BeanAccessTest extends BaseExpressionTest {

  /** The bean to test. */
  private TestBean bean;
  
  /**
   * A class for testing purposes.
   */
  public class TestBean {
    /**
     * Always returns true.
     * @return true
     */
    public boolean isTrueProp() {
      return true;
    }
    /**
     * Always returns false.
     * @return false
     */
    public boolean isFalseProp() {
      return false;
    }
    /**
     * Always returns null.
     * @return null
     */
    public Object getNullValue() {
      return null;
    }
    /**
     * Always returns "test".
     * @return "test"
     */
    public String getStringValue() {
      return "test";
    }
    /**
     * Always returns 10.
     * @return 10
     */
    public int getIntValue() {
      return 10;
    }
    /**
     * Always returns 133.333333.
     * @return 33.333333
     */
    public double getDoubleValue() {
      return 300.5;
    }
    /**
     * Always returns 12.5.
     * @return 12.5
     */
    public float getFloatValue() {
      return 12.5F;
    }
  }
  
  /**
   * @see junit.framework.TestCase#setUp()
   */
  protected void setUp() throws Exception {
    super.setUp();

    bean = new TestBean();
    properties.put("bean", bean);
  }

  /**
   * Tests the 'and' operation.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testAnd() throws ExpressionException {
    assertTrue(exi.evalBoolean("${trueProp==true and trueProp==true}", properties, bean, formatHelper));
    assertFalse(exi.evalBoolean("${trueProp==true and falseProp==true}", properties, bean, formatHelper));
    assertFalse(exi.evalBoolean("${trueProp==false and falseProp==false}", properties, bean, formatHelper));
  }

  /**
   * Tests the 'or' operation.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testOr() throws ExpressionException {
    assertTrue(exi.evalBoolean("${trueProp==true or trueProp==true}", properties, bean, formatHelper));
    assertTrue(exi.evalBoolean("${trueProp==false or trueProp==true}", properties, bean, formatHelper));
    assertTrue(exi.evalBoolean("${trueProp==true or falseProp==true}", properties, bean, formatHelper));
    assertFalse(exi.evalBoolean("${trueProp==false or falseProp==true}", properties, bean, formatHelper));
  }

  /**
   * Tests the '.' operation.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testPropertyAccess() throws ExpressionException {
    assertEquals(exi.evalObject("${bean.stringValue}", properties, formatHelper), "test");
    assertEquals(exi.evalObject("${bean[ 'stringValue']}", properties, formatHelper), "test");
    assertEquals(exi.evalDouble("${bean.doubleValue-bean.intValue*bean.floatValue}", properties, formatHelper), 180.5, 0.0);
  }
 
}
