/*
 * Copyright (C) 2003, 2004, 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.util.exi.test;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.ujac.util.exi.ExpressionException;

/**
 * Name: CollectionTypeTest<br>
 * Description: A class testing the CollectionType class.
 * 
 * @author lauerc
 */
public class CollectionTypeTest extends BaseExpressionTest {

  /**
   * A class for person data.
   */
  public class Person {
    
    /** The name. */
    private String name;
    /** The first name. */
    private String firstName;
    
    /**
     * Constructs a Person instance with specific attributes.
     * @param name The name.
     * @param firstName The first name.
     */
    public Person(String name, String firstName) {
      this.name = name;
      this.firstName = firstName;
    }
    
    /**
     * Getter method for the the property name.
     * @return The current value of property name.
     */
    public String getName() {
      return name;
    }
  
    /**
     * Getter method for the the property firstName.
     * @return The current value of property firstName.
     */
    public String getFirstName() {
      return firstName;
    }

    /**
     * @see java.lang.Object#toString()
     */
    public String toString() {
      return "{" + name + ", " + firstName + "}";
    }
    
  }
  
  /**
   * @see junit.framework.TestCase#setUp()
   */
  protected void setUp() throws Exception {
    super.setUp();

    Map numbers = new HashMap();
    numbers.put("one", new Integer(1));
    numbers.put("two", new Integer(2));
    numbers.put("three", new Integer(3));
    numbers.put("four", new Integer(4));
    numbers.put("five", new Integer(5));
    numbers.put("six", new Integer(6));
    numbers.put("seven", new Integer(7));
    numbers.put("eight", new Integer(8));
    numbers.put("nine", new Integer(9));
    numbers.put("ten", new Integer(10));
    numbers.put("ten and a half", new Double(10.5));
    properties.put("numbers", numbers);
  
    List list = new ArrayList();
    list.add("Meier");
    list.add("M�ller");
    list.add("Huber");
    list.add("Linz");
    list.add("Keller");
    list.add("Kevric");
    properties.put("list", list);
  
    List persons = new ArrayList();
    persons.add(new Person("Meier", "Kurt"));
    persons.add(new Person("M�ller", "Peter"));
    persons.add(new Person("Huber", "Horst"));
    persons.add(new Person("Linz", "Paul"));
    persons.add(new Person("Keller", "Axel"));
    persons.add(new Person("Kevric", "Adnan"));
    persons.add(new Person("Klose", "Miroslav"));
    properties.put("persons", persons);

    List listOfLists = new ArrayList();
    listOfLists.add(new String[] {"Meier", "Karl"});
    listOfLists.add(new String[] {"M�ller", "Peter"});
    listOfLists.add(new String[] {"Huber", "Horst"});
    listOfLists.add(new String[] {"Linz", "Paul"});
    listOfLists.add(new String[] {"Keller", "Axel"});
    listOfLists.add(new String[] {"Kevric", "Adnan"});
    listOfLists.add(new String[] {"Klose", "Miroslav"});
    properties.put("listOfLists", listOfLists);
  
    properties.put("userList", new ArrayList());

    properties.put("index", new Integer(1));
  }
  
  /**
   * Tests the 'contains' operation.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testContains() throws ExpressionException {
    assertTrue(exi.evalBoolean("${list contains 'Meier'}", properties, formatHelper));
    assertFalse(exi.evalBoolean("${list contains 'Smith'}", properties, formatHelper));
    assertTrue(exi.evalBoolean("${numbers containsKey 'one'}", properties, formatHelper));
    assertFalse(exi.evalBoolean("${numbers containsKey 'thirteen'}", properties, formatHelper));
  }

  /**
   * Tests the 'notContains' operation.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testNotContains() throws ExpressionException {
    assertFalse(exi.evalBoolean("${list notContains 'Meier'}", properties, formatHelper));
    assertTrue(exi.evalBoolean("${list notContains 'Smith'}", properties, formatHelper));
    assertFalse(exi.evalBoolean("${numbers notContainsKey 'one'}", properties, formatHelper));
    assertTrue(exi.evalBoolean("${numbers notContainsKey 'thirteen'}", properties, formatHelper));
  }

  /**
   * Tests the 'isEmpty' operation.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testIsEmpty() throws ExpressionException {
    assertFalse(exi.evalBoolean("${list isEmpty}", properties, formatHelper));
    assertTrue(exi.evalBoolean("${list notEmpty}", properties, formatHelper));
    assertFalse(exi.evalBoolean("${numbers isEmpty}", properties, formatHelper));
    assertTrue(exi.evalBoolean("${numbers notEmpty}", properties, formatHelper));
  }

  /**
   * Tests the 'size' operation.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testSize() throws ExpressionException {
    assertTrue(exi.evalInt("${list size}", properties, formatHelper) == 6);
    assertTrue(exi.evalInt("${numbers size}", properties, formatHelper) == 11);
  }

  /**
   * Tests the '.' operation.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testAccess() throws ExpressionException {
    assertEquals(exi.evalObject("${list.3}", properties, formatHelper), "Linz");
    assertEquals(exi.evalObject("${numbers.one}", properties, formatHelper), new Integer(1));
    assertEquals(exi.evalObject("${numbers.'ten'}", properties, formatHelper), new Integer(10));
    
    assertEquals(exi.evalObject("${list[index]}", properties, formatHelper), "M�ller");
    assertEquals(exi.evalObject("${ list[ ${index} ] }", properties, formatHelper), "M�ller");
    assertEquals(exi.evalObject("${list[ 4 ]}", properties, formatHelper), "Keller");
    assertEquals(exi.evalObject("${list[2 ]}", properties, formatHelper), "Huber");
    assertEquals(exi.evalObject("${list[ 3]}", properties, formatHelper), "Linz");
    assertEquals(exi.evalObject("${list[5]}", properties, formatHelper), "Kevric");
    assertEquals(exi.evalObject("${numbers['seven']}", properties, formatHelper), new Integer(7));
    assertEquals(exi.evalObject("${numbers[ \"eight\" ]}", properties, formatHelper), new Integer(8));
  }
 
  /**
   * Tests the 'sort' operation.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testSort() throws ExpressionException {
    assertEquals(exi.evalString("${list sort}", properties, formatHelper), "[Huber, Keller, Kevric, Linz, Meier, M�ller]");
    assertEquals(exi.evalString("${persons sort 'name'}", properties, formatHelper), "[{Huber, Horst}, {Keller, Axel}, {Kevric, Adnan}, {Klose, Miroslav}, {Linz, Paul}, {Meier, Kurt}, {M�ller, Peter}]");
  }

}
