/*
 * Copyright (C) 2007 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util.exi.test;

import org.ujac.util.exi.ExpressionException;


/**
 * Name: ConditionTest<br>
 * Description: A class testing conditional execution.
 * 
 * Example:
 * <code>
 *  ${${a isDefined} ? a : ''}
 * </code>
 * 
 * @author lauerc
 */
public class ConditionTest extends BaseExpressionTest {

  /**
   * @see junit.framework.TestCase#setUp()
   */
  protected void setUp() throws Exception {
    super.setUp();

    properties.put("NULL", null);  
    properties.put("negativeInt", new Integer(-13));  
    properties.put("negativeFloat", new Float(-13.0F));  
    properties.put("negativeDouble", new Double(-13.0));

    properties.put("byte1", new Byte((byte) 8));
    properties.put("byte2", new Byte((byte) 15));
  }

  /**
   * Tests type casts.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testCondition() throws ExpressionException {
    assertEquals(exi.evalInt("${${negativeInt < 0} ? negativeInt : ${negativeInt * -1}}", properties, formatHelper), -13);
    assertEquals(exi.evalInt("${negativeInt < 0 ? negativeInt : negativeInt * -1}", properties, formatHelper), -13);

    assertEquals(exi.evalInt("${${NULL isDefined}?1:0}", properties, formatHelper), 0);
    assertEquals(exi.evalInt("${${NULL notDefined}?0:1}", properties, formatHelper), 0);
  }

}
