/*
 * Copyright (C) 2004, 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.util.exi.test;

import org.ujac.util.exi.ExpressionException;

/**
 * Name: NullTypeTest<br>
 * Description: A class testing operations on null values.
 * 
 * @author lauerc
 */
public class NullTypeTest extends BaseExpressionTest {

  /**
   * @see junit.framework.TestCase#setUp()
   */
  protected void setUp() throws Exception {
    super.setUp();

    properties.put("NULL", null);  
    properties.put("negativeInt", new Integer(-13));  
    properties.put("negativeFloat", new Float(-13.0F));  
    properties.put("negativeDouble", new Double(-13.0));

    properties.put("byte1", new Byte((byte) 8));
    properties.put("byte2", new Byte((byte) 15));
  }

  /**
   * Tests type casts.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testTypeCast() throws ExpressionException {
    assertEquals(exi.evalInt("${(int) NULL}", properties, formatHelper), 0);
    assertEquals(exi.evalLong("${(long) NULL}", properties, formatHelper), 0L);
    assertEquals(exi.evalDouble("${(double) NULL}", properties, formatHelper), 0.0, 0.0);
    assertEquals(exi.evalFloat("${(float) NULL}", properties, formatHelper), 0.0F, 0.0F);
    assertEquals(exi.evalDouble("${(double) NULL + 2.5 + 3.5}", properties, formatHelper), 6.0, 0.0);
  }

  /**
   * Tests the '+' operation.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testPlus() throws ExpressionException {
    assertEquals(exi.evalInt("${1 + 2 + NULL}", properties, formatHelper), 3);
    assertEquals(exi.evalDouble("${1.0 + NULL + 3.5}", properties, formatHelper), 4.5, 0.0);
  }

  /**
   * Tests the '-' operation.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testMinus() throws ExpressionException {
    assertEquals(exi.evalInt("${NULL - 2 - 3}", properties, formatHelper), -5);
    assertEquals(exi.evalDouble("${5.7 - NULL - 3.2}", properties, formatHelper), 2.5, 0.0);
  }

  /**
   * Tests the '*' operation.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testMmul() throws ExpressionException {
    assertEquals(exi.evalInt("${5 * NULL * 3}", properties, formatHelper), 0);
    assertEquals(exi.evalDouble("${NULL * 3.5 * 1.5}", properties, formatHelper), 0.0, 0.0);
  }

  /**
   * Tests the '/' operation.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testDiv() throws ExpressionException {
    assertEquals(exi.evalInt("${NULL / 2 / 5}", properties, formatHelper), 0);
    assertEquals(exi.evalDouble("${20.0 / 5.0 / NULL}", properties, formatHelper), Double.POSITIVE_INFINITY, 0.0);
  }

  /**
   * Tests comparison operators for numeric values.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testComparisonOperators() throws ExpressionException {
    assertFalse(exi.evalBoolean("${NULL==10}", properties, formatHelper));
    assertTrue(exi.evalBoolean("${NULL<=10}", properties, formatHelper));
    assertFalse(exi.evalBoolean("${NULL>=10}", properties, formatHelper));
    assertTrue(exi.evalBoolean("${11>NULL}", properties, formatHelper));
    assertFalse(exi.evalBoolean("${NULL>10}", properties, formatHelper));
    
    assertTrue(exi.evalBoolean("${NULL == 0}", properties, formatHelper));
    assertTrue(exi.evalBoolean("${NULL <= 10}", properties, formatHelper));
    assertFalse(exi.evalBoolean("${NULL >= 10}", properties, formatHelper));
    assertTrue(exi.evalBoolean("${NULL < 11}", properties, formatHelper));
    assertFalse(exi.evalBoolean("${NULL > 10}", properties, formatHelper));
  }

}
