/*
 * Copyright (C) 2003 - 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.util.exi.test;

import org.ujac.util.exi.ExpressionException;

/**
 * Name: StringTypeTest<br>
 * Description: A class testing the StringType class.
 * 
 * @author lauerc
 */
public class StringTypeTest extends BaseExpressionTest {

  /**
   * @see junit.framework.TestCase#setUp()
   */
  protected void setUp() throws Exception {
    super.setUp();

    properties.put("name", "UJAC");  
    properties.put("string", "This is a test");
    properties.put("number", new Integer(10));
    properties.put("nullString", null);
    properties.put("emptyString", "");
    properties.put("ten", new Integer(10));  
  }

  /**
   * Tests the 'concat' operation.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testConcat() throws ExpressionException {
    assertEquals("This is a test 123", exi.evalString("${string + ' 123'}", properties, formatHelper));
    assertEquals("UJAC-11", exi.evalString("${${name} + '-' + ${ten + 1}}", properties, formatHelper));
  }

  /**
   * Tests the '==' operation.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testEqual() throws ExpressionException {
    assertTrue(exi.evalBoolean("${string == 'This is a test'}", properties, formatHelper));
    assertFalse(exi.evalBoolean("${string == 'This is A test'}", properties, formatHelper));
  }

  /**
   * Tests the '!=' operation.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testNotEqual() throws ExpressionException {
    assertTrue(exi.evalBoolean("${string != 'This is A test'}", properties, formatHelper));
    assertFalse(exi.evalBoolean("${string != 'This is a test'}", properties, formatHelper));
  }

  /**
   * Tests the 'like' operation.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testLike() throws ExpressionException {
    assertTrue(exi.evalBoolean("${string like 'This is a test'}", properties, formatHelper));
    assertTrue(exi.evalBoolean("${string like '%is a%'}", properties, formatHelper));
    assertTrue(exi.evalBoolean("${string like '%is a test'}", properties, formatHelper));
    assertTrue(exi.evalBoolean("${string like 'This is%'}", properties, formatHelper));
    assertFalse(exi.evalBoolean("${string like 'This is A test'}", properties, formatHelper));
    assertFalse(exi.evalBoolean("${string like '%is A%'}", properties, formatHelper));
    assertFalse(exi.evalBoolean("${string like '%is A'}", properties, formatHelper));
    assertFalse(exi.evalBoolean("${string like '%is A test'}", properties, formatHelper));
    assertFalse(exi.evalBoolean("${string like 'This is A'}", properties, formatHelper));
  }

  /**
   * Tests the 'notLike' operation.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testNotLike() throws ExpressionException {
    assertFalse(exi.evalBoolean("${string notLike 'This is a test'}", properties, formatHelper));
    assertFalse(exi.evalBoolean("${string notLike '%is a%'}", properties, formatHelper));
    assertFalse(exi.evalBoolean("${string notLike '%is a test'}", properties, formatHelper));
    assertFalse(exi.evalBoolean("${string notLike 'This is%'}", properties, formatHelper));
    assertTrue(exi.evalBoolean("${string notLike 'This is A test'}", properties, formatHelper));
    assertTrue(exi.evalBoolean("${string notLike '%is A%'}", properties, formatHelper));
    assertTrue(exi.evalBoolean("${string notLike '%is A'}", properties, formatHelper));
    assertTrue(exi.evalBoolean("${string notLike '%is A test'}", properties, formatHelper));
    assertTrue(exi.evalBoolean("${string notLike 'This is A'}", properties, formatHelper));
  }

  /**
   * Tests the 'length' operation.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testLength() throws ExpressionException {
    assertTrue(exi.evalInt("${string length}", properties, formatHelper) == 14);
    assertTrue(exi.evalInt("${string  + ' 123' length}", properties, formatHelper) == 18);
  }

  /**
   * Tests the 'lowerCase' operation.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testLowerCase() throws ExpressionException {
    assertEquals("this is a test", exi.evalString("${string lowerCase}", properties, formatHelper));
    assertEquals("this is a test abc", exi.evalString("${string  + ' ABC' lowerCase}", properties, formatHelper));
  }
  
  /**
   * Tests the 'upperCase' operation.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testUpperCase() throws ExpressionException {
    assertEquals("THIS IS A TEST", exi.evalString("${string upperCase}", properties, formatHelper));
    assertEquals("THIS IS A TEST ABC", exi.evalString("${string  + ' abc' upperCase}", properties, formatHelper));
  }

  /**
   * Tests the 'isEmpty' operation.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testIsEmpty() throws ExpressionException {
    assertTrue(exi.evalBoolean("${string notEmpty}", properties, formatHelper));
    assertFalse(exi.evalBoolean("${string isEmpty}", properties, formatHelper));

    assertFalse(exi.evalBoolean("${emptyString notEmpty}", properties, formatHelper));
    assertTrue(exi.evalBoolean("${emptyString isEmpty}", properties, formatHelper));

    assertFalse(exi.evalBoolean("${nullString notEmpty}", properties, formatHelper));
    assertTrue(exi.evalBoolean("${nullString isEmpty}", properties, formatHelper));
  }

  /**
   * Tests the 'substring' operation.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testSubstring() throws ExpressionException {
    assertEquals("is is a test", exi.evalString("${string substring 2}", properties, formatHelper));
    assertNotSame("This is a test", exi.evalString("${string substring 2}", properties, formatHelper));
    assertEquals("This", exi.evalString("${string substring ':4'}", properties, formatHelper));
    assertEquals("is a", exi.evalString("${string substring '5:9'}", properties, formatHelper));
  }

}
