/*
 * Copyright (C) 2003 - 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.util.exi.test;

import org.ujac.util.UjacTypes;
import org.ujac.util.exi.ExpressionException;

import org.ujac.util.table.LayoutHints;
import org.ujac.util.table.Row;
import org.ujac.util.table.DataTable;

/**
 * Name: TableTypeTest<br>
 * Description: A class testing the TableType class.
 * 
 * @author lauerc
 */
public class TableTypeTest extends BaseExpressionTest {

  /**
   * @see junit.framework.TestCase#setUp()
   */
  protected void setUp() throws Exception {
    super.setUp();

    DataTable table = new DataTable();
    int nameID = table.addColumn("name", UjacTypes.TYPE_STRING).setLayoutHints(new LayoutHints(10, "Name")).getIndex();
    int firstNameID = table.addColumn("firstName", UjacTypes.TYPE_STRING).setLayoutHints(new LayoutHints(10, "First Name")).getIndex();
    int addressID = table.addColumn("address", UjacTypes.TYPE_STRING).setLayoutHints(new LayoutHints(10, "Address")).getIndex();
    int zipCodeID = table.addColumn("zipCode", UjacTypes.TYPE_INT).setLayoutHints(new LayoutHints(10, "Zip Code")).getIndex();
    int cityID = table.addColumn("city", UjacTypes.TYPE_STRING).setLayoutHints(new LayoutHints(10, "City")).getIndex();
        
    Row row = table.addRow();
    row.setString(nameID, "Pan");
    row.setString(firstNameID, "Peter");
    row.setString(addressID, "Zwiebelgasse 12");
    row.setInt(zipCodeID, 12345);
    row.setString(cityID, "Wichtelhausen");
  
    int ageID = table.addColumn("age", UjacTypes.TYPE_INT).setLayoutHints(new LayoutHints(10, "Age")).getIndex();
  
    row = table.addRow();
    row.setString(nameID, "Kunz");
    row.setString(firstNameID, "Heiner");
    row.setString(addressID, "Wurstweg 23");
    row.setInt(zipCodeID, 12345);
    row.setString(cityID, "Wichtelhausen");
    row.setInt(ageID, 39);
  
    row = table.addRow();
    row.setString(nameID, "Meier");
    row.setString(firstNameID, "Paul");
    row.setString(addressID, "K�belweg 34");
    row.setInt(zipCodeID, 12345);
    row.setString(cityID, "Wichtelhausen");
    row.setInt(ageID, 39);
  
    properties.put("customers", table);
  }

  /**
   * Tests the 'hasRows' operation.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testHasRows() throws ExpressionException {
    assertTrue(exi.evalBoolean("${customers hasRows}", properties, formatHelper));
    assertTrue(exi.evalBoolean("${customers notEmpty}", properties, formatHelper));
    assertFalse(exi.evalBoolean("${cstomers hasRows}", properties, formatHelper));
    assertFalse(exi.evalBoolean("${cstomers notEmpty}", properties, formatHelper));
  }

  /**
   * Tests the 'noRows' operation.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testNoRows() throws ExpressionException {
    assertFalse(exi.evalBoolean("${customers noRows}", properties, formatHelper));
    assertFalse(exi.evalBoolean("${customers isEmpty}", properties, formatHelper));
    assertTrue(exi.evalBoolean("${cstomers noRows}", properties, formatHelper));
    assertTrue(exi.evalBoolean("${cstomers isEmpty}", properties, formatHelper));
  }

  /**
   * Tests the 'rowCount' operation.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testRowCount() throws ExpressionException {
    assertTrue(exi.evalInt("${customers rowCount}", properties, formatHelper) == 3);
    assertTrue(exi.evalInt("${customers size}", properties, formatHelper) == 3);
  }

  /**
   * Tests the 'columnCount' operation.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testColumnCount() throws ExpressionException {
    assertTrue(exi.evalInt("${customers columnCount}", properties, formatHelper) == 6);
  }
  
  /**
   * Tests the 'hasColumn' operation.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testHasColumn() throws ExpressionException {
    assertTrue(exi.evalBoolean("${customers hasColumn 'age'}", properties, formatHelper));
  }

  /**
   * Tests the 'rotate' operation.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testRotate() throws ExpressionException {
    System.out.println("Original: " + exi.evalString("${customers}", properties, formatHelper));
    System.out.println("Rotated: " + exi.evalString("${customers rotate}", properties, formatHelper));
  }
  
  /**
   * Added performance test.
   * @throws ExpressionException In case an expression evaluation fails.
   */
  public void testPerformance() throws ExpressionException {
    long start = System.currentTimeMillis(); 
    
    for (int i = 0; i < 50000; i++) {
      assertTrue(exi.evalBoolean(
          "${${customers getRow 0}.name=='Pan' && ${customers getRow 0}.firstName=='Peter' &&" +
          "${customers getRow 0}.address=='Zwiebelgasse 12' && ${customers getRow 0}.zipCode==12345 &&" +
          "${customers getRow 0}.city=='Wichtelhausen'}", 
          properties, formatHelper
      ));
    }
    
    long end = System.currentTimeMillis();
    long elapsed = end - start;
    System.out.println("ExpressionInterpreter needed " + elapsed + " ms for performance test.");
  }

}
