/*
 * Copyright (C) 2004 - 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util.exi.type;

import java.text.Format;

import org.ujac.util.exi.BaseExpressionOperation;
import org.ujac.util.exi.ExpressionContext;
import org.ujac.util.exi.ExpressionException;
import org.ujac.util.exi.ExpressionInterpreter;
import org.ujac.util.exi.ExpressionTuple;
import org.ujac.util.exi.NoOperandException;
import org.ujac.util.exi.Operand;

import org.ujac.util.text.FormatHelper;

/**
 * Name: BaseNumberType<br>
 * Description: A base type handler class for numeric values.
 * 
 * @author lauerc
 */
public abstract class BaseNumberType extends BaseType {

  /**
   * The 'format' operation for Numbers.
   */
  public class FormatOperation extends BaseExpressionOperation {
    /**
     * Evaluates the given values.
     * @param expr The expression tuple to process. 
     * @param ctx The expression context.
     * @return The result of the tuple evaluation.
     * @exception ExpressionException If the evaluation failed.
     */
    public Object evaluate(ExpressionTuple expr, ExpressionContext ctx)
      throws ExpressionException {
        
      Operand operand = expr.getOperand();
      if (operand == null) {
        throw new NoOperandException("No operand given for operation: " + expr.getOperation() + " on object " + expr.getObject() + "!");         
      }
      Object operandValue = operand.getValue();
      // determining format
      Format format = null;
      FormatHelper formatHelper = ctx.getFormatHelper();
      if (operandValue instanceof String) {
        String formatName = (String) operandValue;
        format = formatHelper.lookupFormat(formatName);
        if (format == null) {
          format = formatHelper.createNumberFormat(formatName);
          formatHelper.registerFormat(formatName, format);
        }
      }
      return format.format(expr.getObject().getValue());
    }

    
    /**
     * Gets a description for the operation.
     * @return The item's description.
     */
    public String getDescription() {
      return "Formats the object using the format, specified by the operand.";
    }
  }

  /**
   * Constructs a BaseNumberType instance with specific attributes.
   * @param interpreter The expression interpreter
   */
  public BaseNumberType(ExpressionInterpreter interpreter) {
    super(interpreter);
    addOperation("format", new FormatOperation());
  }
  
  /**
   * Gets the negative value for the given number.
   * @param number The number to negate.
   * @return The negated value of the given number.
   */
  public abstract Number getNegative(Number number);
  
}
