/*
 * Copyright (C) 2007 - 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util.exi.type;

import org.ujac.util.exi.BaseExpressionOperation;
import org.ujac.util.exi.ConditionResultHolder;
import org.ujac.util.exi.ExpressionContext;
import org.ujac.util.exi.ExpressionException;
import org.ujac.util.exi.ExpressionInterpreter;
import org.ujac.util.exi.ExpressionOperation;
import org.ujac.util.exi.ExpressionTuple;
import org.ujac.util.exi.NoOperandException;
import org.ujac.util.exi.Operand;


/**
 * Name: ConditionResultHolderType<br>
 * Description: An expression type handler for results of conditional evaluations.<br>
 * 
 * @author lauerc
 */
public class ConditionResultHolderType extends BaseType {

  /**
   * Evaluates the else branch of the expression.
   */
  public class ElseOperation extends BaseExpressionOperation {
    /**
     * Evaluates the given values.
     * @param expr The expression tuple to process. 
     * @param ctx The expression context.
     * @return The result of the tuple evaluation.
     * @exception ExpressionException If the evaluation failed.
     */
    public Object evaluate(ExpressionTuple expr, ExpressionContext ctx)
      throws ExpressionException {

      Operand operand = expr.getOperand();
      if (operand == null) {
        throw new NoOperandException("No operand given for operation: " + 
                                     expr.getOperation() + 
                                     " on object " + 
                                     expr.getObject() + "!");         
      }

      ConditionResultHolder conditionResult = (ConditionResultHolder) expr.getObject().getValue();
      if (conditionResult.isStatus()) {
        // keeping result
        return conditionResult.getResult();
      }
      // returning result of else branch
      return interpreter.evalOperand(operand, ctx);
    }

    /**
     * Gets a description for the operation.
     * @return The item's description.
     */
    public String getDescription() {
      return "Tells whether the object is defined or not.";
    }
  }

  /**
   * Constructs a ConditionResultHolderType instance with no specific arguments.
   * @param interpreter
   */
  public ConditionResultHolderType(ExpressionInterpreter interpreter) {
    super(interpreter);
    // adding operations for this type.
    ExpressionOperation op = new ElseOperation();
    addOperation(":", op);
  }

  /**
   * @see org.ujac.util.exi.ExpressionType#getType()
   */
  public Class getType() {
    return ConditionResultHolder.class;
  }


}
