/*
 * Copyright (C) 2005 - 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util.exi.type;

import java.util.Map;

import org.ujac.util.BeanUtils;

import org.ujac.util.exi.BaseExpressionOperation;
import org.ujac.util.exi.ExpressionContext;
import org.ujac.util.exi.ExpressionException;
import org.ujac.util.exi.ExpressionInterpreter;
import org.ujac.util.exi.ExpressionOperation;
import org.ujac.util.exi.ExpressionTuple;
import org.ujac.util.exi.NoOperandException;
import org.ujac.util.exi.Operand;
import org.ujac.util.exi.OperandException;

/**
 * Name: MapEntryType<br>
 * Description: An expression type handler for Map.Entry values.
 * 
 * @author lauerc
 */
public class MapEntryType extends BaseType {

  /**
   * The reference operation for beans.
   */
  public class ReferenceOperation extends BaseExpressionOperation {
    /**
     * Evaluates the given values.
     * @param expr The expression tuple to process. 
     * @param ctx The expression context.
     * @return The result of the tuple evaluation.
     * @exception ExpressionException If the evaluation failed.
     */
    public Object evaluate(ExpressionTuple expr, ExpressionContext ctx)
      throws ExpressionException {

      Operand operand = expr.getOperand();
      if (operand == null) {
        throw new NoOperandException("No operand given for operation: " + expr.getOperation() + " on object " + expr.getObject() + "!");         
      }
      // getting the property name.
      String operandValue = interpreter.evalStringOperand(operand, ctx);
      
      Operand object = expr.getObject();
      Map.Entry objectValue = (Map.Entry) object.getValue();
      if (objectValue == null) {
        // Avoiding NullPointerException
        throw new OperandException("Unable to resolve reference " + expr.getObject() + " for null value at expression " + expr.toString() + "!");         
      } 

      if (BeanUtils.equals(operandValue, "key")) {
        return objectValue.getKey();
      }

      if (BeanUtils.equals(operandValue, "value")) {
        return objectValue.getValue();
      }
      
      throw new OperandException("Invalid property '" + operandValue + "' requested for Map Entry " + expr.getObject() + " at expression '" + expr.getCode() + "'.");
    }

    /**
     * Gets a description for the operation.
     * @return The item's description.
     */
    public String getDescription() {
      return "Accesses the object's key/value properties.";
    }
  }

  /**
   * Constructs a MapEntryType instance with specific attributes.
   * @param interpreter
   */
  public MapEntryType(ExpressionInterpreter interpreter) {
    super(interpreter);
    ExpressionOperation op = new ReferenceOperation();
    addOperation(".", op);
    addOperation("[]", op);
    addOperation("get", op);
  }

  /**
   * @see org.ujac.util.exi.ExpressionType#getType()
   */
  public Class getType() {
    return Map.Entry.class;
  }

}
