/*
 * Copyright (C) 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util.io.test;

import java.io.File;
import java.io.IOException;

import org.ujac.util.io.ClassPathResourceLoader;
import org.ujac.util.io.FileResourceLoader;
import org.ujac.util.io.MultiResourceLoader;

import junit.framework.TestCase;

/**
 * 
 * Name: MultiResourceLoaderTest<br>
 * Description: Test cases for the MultiResourceLoader class.
 * 
 * @author lauerc
 */
public class MultiResourceLoaderTest extends TestCase {
  
  /** The resource loader to test. */  
  private MultiResourceLoader rl = null;
  
  /**
   * @see junit.framework.TestCase#setUp()
   */
  protected void setUp() throws Exception {
    super.setUp();
    rl = new MultiResourceLoader();
    rl.addResourceLoader(new ClassPathResourceLoader(this.getClass().getClassLoader()));
    rl.addResourceLoader(new FileResourceLoader("./test"));
  }
  
  /**
   * Tests attribute name conversion.
   */
  public void testResourceExists() {
    assertTrue(rl.resourceExists("print/bullit.gif"));
    assertFalse(rl.resourceExists("print/bullit.jpg"));
    assertTrue(rl.resourceExists("org/ujac/print/documentation-template.xml"));
    assertFalse(rl.resourceExists("org/ujac/print/documentation-templates.xml"));
  }

  /**
   * Tests attribute name conversion.
   * @exception IOException In case the resource could not be loaded.
   */
  public void testLoadResource() throws IOException {
    assertEquals(1556, rl.loadResource("print/bullit.gif").length);
    File file = new File("classes/org/ujac/print/documentation-template.xml");
    assertEquals(file.length(), rl.loadResource("org/ujac/print/documentation-template.xml").length);
  }

  /**
   * Runs all test cases.
   * @param args The command line arguments.
   */
  public static void main(String[] args) {
    new MultiResourceLoaderTest().run();
  }

}
