/*
 * Copyright (C) 2004, 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util.table;

import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.lang.reflect.Method;

/**
 * Name: BeanColumn<br>
 * Description: A class for columns, holding getter and setter 
 *   methods to support java bean access.
 * 
 * @author lauerc
 */
public class BeanColumn extends DefaultColumn {

  /** The serial version UID. */
  static final long serialVersionUID = 2372815281182304599L;
  
  /** The getter method. */
  private Method getter = null;
  /** The setter method. */
  private Method setter = null;
  
  /**
   * Constructs a BeanColumn instance with specific attributes.
   * @param table The bean table instance this column is attached to.
   * @param name The column name.
   * @param type The column type.
   * @param getter The getter method.
   */
  public BeanColumn(BeanTable table, String name, int type, Method getter) {
    super(table, name, type);
    this.getter = getter;
  }
  
  /**
   * Constructs a BeanColumn instance with specific attributes.
   * @param table The bean table instance this column is attached to.
   * @param name The column name.
   * @param key Tells whether or not the column defines a key value.
   * @param type The column type.
   * @param getter The getter method.
   */
  public BeanColumn(BeanTable table, String name, boolean key, int type, Method getter) {
    super(table, name, key, type);
    this.getter = getter;
  }
  
  /**
   * Gets the getter method.
   * @return The getter method.
   */
  public Method getGetter() {
    return getter;
  }

  /**
   * Gets the setter method.
   * If null is returned, this is a read only column.
   * @return The setter method.
   */
  public Method getSetter() {
    return setter;
  }
  /**
   * Sets the setter method.
   * @param setter The setter method to set.
   */
  public void setSetter(Method setter) {
    this.setter = setter;
  }

  /**
   * Writes the object's data to the given stream.
   * @param s The stream to write to
   * @exception IOException In case the data output failed.
   */
  private void writeObject(ObjectOutputStream s) throws IOException {
    writeData(s);
  }
  /**
   * Reads the object's data from the given stream.
   * @param s The stream to read from.
   * @exception IOException In case the data reading failed.
   * @exception ClassNotFoundException In case the class to deserialize could not be found
   */
  private void readObject(ObjectInputStream s) throws IOException, ClassNotFoundException  {
    readData(s);
  }

}
