/*
 * Copyright (C) 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util.table;

import org.ujac.util.BeanUtils;


/**
 * Name: BetweenRowFilterRule<br>
 * Description: Checks field values for a value between a lower and a upper value.
 * 
 * @author lauerc
 */
public class BetweenRowFilterRule extends BaseRowFilterRule {

  /** The value to compare the column value with. */
  private Comparable from = null;
  /** The value to compare the column value with. */
  private Comparable to = null;
  
  /**
   * Constructs a BetweenRowFilterRule instance with specific attributes.
   * @param columnName The column name.
   * @param from The lower value to compare.
   * @param to The upper value to compare.
   */
  public BetweenRowFilterRule(String columnName, Comparable from, Comparable to) {
    super(columnName);
    this.from = from;
    this.to = to;
  }

  /**
   * @see org.ujac.util.table.RowFilterRule#test(org.ujac.util.table.Row)
   */
  public boolean test(Row row) throws TableException {
    Object value = row.getObject(columnIndex);
    return BeanUtils.between((Comparable) value, from, to);
  }

}
