/*
 * Copyright (C) 2003 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.util.table;

import java.text.Format;

/**
 * Name: Column<br>
 * Description: A class holding definitions of table columns.<br>
 * 
 * @author lauerc
 */
public interface Column extends TableConstants {

  /**
   * Gets the colum name.
   * @return The column name.
   */
  String getName();
  
  /**
   * Tells wheter this column defines a key value or not.
   * @return true if this column defines a key value, else false.
   */
  boolean isKey();
  /**
   * Sets the key flag.
   * @param key The key flag to set.
   * @return A reference to this instance for more convinience.
   */
  Column setKey(boolean key);

  /**
   * Gets the colum name.
   * @return The column type.
   */
  int getType();
  /**
   * Sets the colum type.
   * This method is for internal usage only, please use method
   * Table.setColumnType(int, int) instead.
   * @param typeId The column type to set.
   */
  void setType(int typeId);

  /**
   * Gets the column alias.
   * @return The column alias.
   */
  String getAlias();
  /**
   * Sets the colum alias.
   * @param alias The new column alias.
   * @return A reference to this instance for more convinience.
   */
  Column setAlias(String alias);
  /**
   * Gets the colum format.
   * @return The column format.
   */
  Format getFormat();
  /**
   * Sets the colum format.
   * @param format The new column format.
   * @return A reference to this instance for more convinience.
   */
  Column setFormat(Format format);
  /**
   * Sets the colum format.
   * @param format The format string to use.
   * @return A reference to this instance for more convinience.
   */
  Column setFormat(String format);
  
  /**
   * Gets the colum index.
   * @return The column index.
   */
  int getIndex();
  /**
   * Sets the colum index.
   * @param index The new column index.
   * @return A reference to this instance for more convinience.
   */
  Column setIndex(int index);

  /**
   * Gets the data index.
   * @return The data index.
   */
  int getDataIndex();
  /**
   * Sets the data index.
   * @param dataIndex The new data index.
   * @return A reference to this instance for more convinience.
   */
  Column setDataIndex(int dataIndex);

  /**
   * Gets the layout hints.
   * @return Returns the layout hints.
   */
  LayoutHints getLayoutHints();
  /**
   * Sets the layout hints.
   * @param layoutHints The layout hints to set.
   * @return A reference to this instance for more convinience.
   */
  Column setLayoutHints(LayoutHints layoutHints);

  /**
   * Gets the name of the column type.
   * @return the name of the type or UNKNOWN.
   */
  String getTypeName();

}