/*
 * Copyright (C) 2003 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.util.table;

/**
 * Name: CompareItem<br>
 * Description: A class holding informations needed to sort a table by one specific column in one specific direction.
 * 
 * @author lauerc
 */
public class CompareItem {

  /** Constant for ascending sort direction. */
  public static final int ASC = 1;
  /** Constant for descending sort direction. */
  public static final int DESC = 2;

  /** The ID of the column to sort by. */
  private int column;
  /** The sort direction (ASC|DESC). */
  private int direction;

  /**
   * Constructs a CompareItem instance with specific attributes.
   * @param column The ID of the column to sort by.
   * @param direction The sort direction (ASC|DESC).
   */
  public CompareItem(int column, int direction) {
    this.column = column;
    this.direction = direction;
  }

  /**
   * Gets the column to sort by.
   * @return The index of the column to sort by.
   */
  public int getColumn() {
    return column;
  }
  
  /**
   * Gets the sort direction.
   * @return The sort direction.
   */
  public int getDirection() {
    return direction;
  }
  
}
