/*
 * Copyright (C) 2003 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.util.table;

import java.util.Iterator;
import java.util.NoSuchElementException;

/**
 * Name: DataTableIterator<br>
 * Description: An iterator for DataTable instances.<br>
 * 
 * @author lauerc
 */
public class DataTableIterator implements Iterator {

	/** The table we're iterating. */
	private DataTable table;
	/** The current row. */
	private int currentRow = -1;

	/**
	 * Contructs a DataTableIterator intance with specific attributes.
	 * @param table The table we want to iterate.
	 */
	protected DataTableIterator(DataTable table) {
	  this.table = table;
	}

  /**
   * @see java.util.Iterator#hasNext()
   */
  public boolean hasNext() {
    int tableSize = table.getRowCount();
    return currentRow < (tableSize - 1);
  }

  /**
   * @see java.util.Iterator#next()
   */
  public Object next() {
    try {
      return table.getRow(++currentRow);
    } catch (Exception ex) {
      throw new NoSuchElementException(ex.getMessage());
    }
  }

  /**
   * @see java.util.Iterator#remove()
   */
  public void remove() {
    if (currentRow < 0) {
      throw new IllegalStateException("The the next method has not yet been called.");
    }
    try {
      table.removeRow(currentRow);
    } catch (Exception ex) {
      throw new IllegalStateException(ex.getMessage());
    }
  }
}
