/*
 * Copyright (C) 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util.table;

import org.ujac.util.BeanUtils;


/**
 * Name: EqualsRowFilterRule<br>
 * Description: Test whether or not the checked fields values are equal to the specified value.
 * 
 * @author lauerc
 */
public class EqualsRowFilterRule extends BaseRowFilterRule {

  /** The value to compare the column value with. */
  private Object value = null;
  /** Tells whether or not to compare string values case sensitive (default = true). */
  private boolean caseSensitive = true;
  
  /**
   * Constructs a EqualsRowFilterRule instance with specific attributes.
   * @param columnName The column name.
   * @param value The value to compare.
   */
  public EqualsRowFilterRule(String columnName, Object value) {
    this(columnName, value, true);
  }
  /**
   * Constructs a EqualsRowFilterRule instance with specific attributes.
   * @param columnName The column name.
   * @param value The value to compare.
   * @param caseSensitive Tells whether or not to compare string values case sensitive.
   */
  public EqualsRowFilterRule(String columnName, Object value, boolean caseSensitive) {
    super(columnName);
    this.value = value;
    this.caseSensitive = caseSensitive;
  }

  /**
   * @see org.ujac.util.table.RowFilterRule#test(org.ujac.util.table.Row)
   */
  public boolean test(Row row) throws TableException {
    return BeanUtils.equals(value, row.getObject(columnIndex), caseSensitive);
  }

}
