/*
 * Copyright (C) 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util.table;

import org.ujac.util.exi.ExpressionContext;
import org.ujac.util.exi.ExpressionException;
import org.ujac.util.exi.ExpressionInterpreter;
import org.ujac.util.exi.ExpressionTuple;


/**
 * Name: ExpressionRowFilterRule<br>
 * Description: Test whether or not the specified expression evaluates true for the processed rows.
 * 
 * @author lauerc
 */
public class ExpressionRowFilterRule implements RowFilterRule {

  /** The expression interpreter to use. */
  private ExpressionInterpreter exi = null;
  /** The expression to evaluate. */
  private String expression = null;
  /** The evaluated expression tuple. */
  private ExpressionTuple expressionTuple = null;
  /** The expression context use. */
  private ExpressionContext ctx = null;

  /**
   * Constructs a LikeRowFilterRule instance with specific attributes.
   * @param exi The expression interpreter to use.
   * @param expression The expression to process.
   */
  public ExpressionRowFilterRule(ExpressionInterpreter exi, String expression) {
    this.exi = exi;
    this.expression = expression;
  }

  /** 
   * Sets up the rule. 
   * @param table The table for which set up the rule.
   * @exception TableException  In case the expression tuple could not be evaluated.
   */
  public void setup(Table table) throws TableException {
    try {
      this.expressionTuple = exi.parseExpr(expression);
      this.ctx = new ExpressionContext();
    } catch (ExpressionException ex) {
      throw new TableException("Failed to parse filter rule '" + expression + "': " + ex.getMessage(), ex);
    }
  }

  /**
   * @see org.ujac.util.table.RowFilterRule#test(org.ujac.util.table.Row)
   */
  public boolean test(Row row) throws TableException {
    ctx.setProperty("row", row);
    Object result = null;
    try {
      result = exi.evalExpr(expressionTuple, ctx);
      if (result instanceof Boolean) {
        return ((Boolean) result).booleanValue();
      }
      throw new TableException("Expression '" + expression + "' didn't evaluate to a boolean, was '" + result + "'.");
    } catch (ExpressionException ex) {
      throw new TableException("Failed to evaluate filter rule '" + expression + "': " + ex.getMessage(), ex);
    }
  }

}
