/*
 * Copyright (C) 2003 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util.table;

import java.io.Serializable;

/**
 * Name: FunctionExecutor<br>
 * Description: A common interface for table function executors.
 * 
 * @author lauerc
 */
public interface FunctionExecutor extends Serializable {

  /**
   * Applies the function for the given operand on the given current value.
   * @param currentValue The current value to apply the operand to.
   * @param operand The operand to apply.
   * @return The calculated result.
   * @exception TypeMismatchException In case the given operand type was invalid.
   */
  double execute(double currentValue, Object operand) throws TypeMismatchException;
  
  /**
   * Tells whether the function executor serves integers under guarantee (f.e. count function). 
   * @return true if integers are served under guarantee, else false.
   */
  boolean integersGuaranteed();
}
