/*
 * Copyright (C) 2003, 2004, 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util.table;

import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;

/**
 * Name: GroupRow<br>
 * Description: A table row for group rows.
 * 
 * @author lauerc
 */
public class GroupRow extends DataRow {

  /** The serial version UID. */
  static final long serialVersionUID = 5453737701006063660L;

  /** The group name. */
  private String groupName = null;
  
  /**
   * Constructs a GroupRow instance with specific attributes.
   * Sets all fields invisible by default.
   * @param table The table to create the row for.
   * @param type The row type.
   * @param groupName The group name.
   */
  public GroupRow(Table table, String type, String groupName) {
    super(table, -1);
    this.setType(type);
    this.groupName = groupName;
    try {
      // setting all fields invisible
      int columnCount = table.getColumnCount();
      for (int i = 0; i < columnCount; i++) {
        setVisible(i, false);
      }
    } catch (ColumnNotDefinedException ex) {
      // this should never happen
      throw new RuntimeException(ex.getMessage());
    }
  }

  /**
   * Getter method for the the property groupName.
   * @return The current value of property groupName.
   */
  public String getGroupName() {
    return groupName;
  }
  /**
   * Setter method for the the property groupName.
   * @param groupName The value to set for the property groupName.
   */
  protected void setGroupName(String groupName) {
    this.groupName = groupName;
  }

  /**
   * Writes the object's data to the given stream.
   * @param s The stream to write to
   * @exception IOException In case the data output failed.
   */
  protected void writeData(ObjectOutputStream s) throws IOException {
    super.writeData(s);
    s.writeObject(groupName);
  }
  /**
   * Reads the object's data from the given stream.
   * @param s The stream to read from.
   * @exception IOException In case the data reading failed.
   * @exception ClassNotFoundException In case the class to deserialize could not be found
   */
  protected void readData(ObjectInputStream s) throws IOException, ClassNotFoundException  {
    super.readData(s);
    groupName = (String) s.readObject();
  }

  /**
   * Writes the object's data to the given stream.
   * @param s The stream to write to
   * @exception IOException In case the data output failed.
   */
  private void writeObject(ObjectOutputStream s) throws IOException {
    writeData(s);
  }
  /**
   * Reads the object's data from the given stream.
   * @param s The stream to read from.
   * @exception IOException In case the data reading failed.
   * @exception ClassNotFoundException In case the class to deserialize could not be found
   */
  private void readObject(ObjectInputStream s) throws IOException, ClassNotFoundException  {
    readData(s);
  }

}
