/*
 * Copyright (C) 2003, 2004, 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util.table;

import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.util.Date;

/**
 * Name: HeaderRow<br>
 * Description: A class holding title row data.
 * 
 * @author lauerc
 */
public class HeaderRow extends BaseRow implements Row {
  
  /** The serial version UID. */
  static final long serialVersionUID = 523137629281968928L;

  /**
   * Constructs a HeaderRow instance with specific attributes.
   * @param table The table which contains this row.
   */
  protected HeaderRow(Table table) {
    super(table);
  }

  /**
   * @see org.ujac.util.table.Row#getType()
   */
  public String getType() {
    return TableConstants.ROW_TYPE_HEADER;
  }

  /**
   * @see org.ujac.util.table.Row#getIndex()
   */
  public int getIndex() {
    return -1;
  }

  /**
   * @see org.ujac.util.table.Row#getString(java.lang.String)
   */
  public String getString(String columnName) throws ColumnNotDefinedException, TypeMismatchException {
    Column column = table.getColumn(columnName);
    return getString(column.getIndex());
  }

  /**
   * @see org.ujac.util.table.Row#getString(int)
   */
  public String getString(int columnIdx) throws ColumnNotDefinedException, TypeMismatchException {
    Column column = table.getColumn(columnIdx);
    LayoutHints layoutHints = column.getLayoutHints();
    if (layoutHints != null) {
      return layoutHints.getHeader();
    }
    return null;
  }

  /**
   * @see org.ujac.util.table.Row#setString(java.lang.String, java.lang.String)
   */
  public void setString(String columnName, String value) throws ColumnNotDefinedException, TypeMismatchException {
    Column column = table.getColumn(columnName);
    setString(column.getIndex(), value);
  }

  /**
   * @see org.ujac.util.table.Row#setString(int, java.lang.String)
   */
  public void setString(int columnIdx, String value) throws ColumnNotDefinedException, TypeMismatchException {
    Column column = table.getColumn(columnIdx);
    LayoutHints layoutHints = column.getLayoutHints();
    if (layoutHints == null) {
      layoutHints = new LayoutHints();
      column.setLayoutHints(layoutHints);
    }
    layoutHints.setHeader(value);
  }

  /**
   * @see org.ujac.util.table.Row#getInt(java.lang.String)
   */
  public int getInt(String columnName) throws ColumnNotDefinedException, TypeMismatchException {
    throw new TypeMismatchException("Only Strings are supported for title rows.");
  }

  /**
   * @see org.ujac.util.table.Row#getInt(int)
   */
  public int getInt(int columnIdx) throws ColumnNotDefinedException, TypeMismatchException {
    throw new TypeMismatchException("Only Strings are supported for title rows.");
  }

  /**
   * @see org.ujac.util.table.Row#setInt(java.lang.String, int)
   */
  public void setInt(String columnName, int value) throws ColumnNotDefinedException, TypeMismatchException {
    throw new TypeMismatchException("Only Strings are supported for title rows.");
  }

  /**
   * @see org.ujac.util.table.Row#setInt(int, int)
   */
  public void setInt(int columnIdx, int value) throws ColumnNotDefinedException, TypeMismatchException {
    throw new TypeMismatchException("Only Strings are supported for title rows.");
  }

  /**
   * @see org.ujac.util.table.Row#getLong(java.lang.String)
   */
  public long getLong(String columnName) throws ColumnNotDefinedException, TypeMismatchException {
    throw new TypeMismatchException("Only Strings are supported for title rows.");
  }

  /**
   * @see org.ujac.util.table.Row#getLong(int)
   */
  public long getLong(int columnIdx) throws ColumnNotDefinedException, TypeMismatchException {
    throw new TypeMismatchException("Only Strings are supported for title rows.");
  }

  /**
   * @see org.ujac.util.table.Row#setLong(java.lang.String, long)
   */
  public void setLong(String columnName, long value) throws ColumnNotDefinedException, TypeMismatchException {
    throw new TypeMismatchException("Only Strings are supported for title rows.");
  }

  /**
   * @see org.ujac.util.table.Row#setLong(int, long)
   */
  public void setLong(int columnIdx, long value) throws ColumnNotDefinedException, TypeMismatchException {
    throw new TypeMismatchException("Only Strings are supported for title rows.");
  }

  /**
   * @see org.ujac.util.table.Row#getFloat(java.lang.String)
   */
  public float getFloat(String columnName) throws ColumnNotDefinedException, TypeMismatchException {
    throw new TypeMismatchException("Only Strings are supported for title rows.");
  }

  /**
   * @see org.ujac.util.table.Row#getFloat(int)
   */
  public float getFloat(int columnIdx) throws ColumnNotDefinedException, TypeMismatchException {
    throw new TypeMismatchException("Only Strings are supported for title rows.");
  }

  /**
   * @see org.ujac.util.table.Row#setFloat(java.lang.String, float)
   */
  public void setFloat(String columnName, float value) throws ColumnNotDefinedException, TypeMismatchException {
    throw new TypeMismatchException("Only Strings are supported for title rows.");
  }

  /**
   * @see org.ujac.util.table.Row#setFloat(int, float)
   */
  public void setFloat(int columnIdx, float value) throws ColumnNotDefinedException, TypeMismatchException {
    throw new TypeMismatchException("Only Strings are supported for title rows.");
  }

  /**
   * @see org.ujac.util.table.Row#getDouble(java.lang.String)
   */
  public double getDouble(String columnName) throws ColumnNotDefinedException, TypeMismatchException {
    throw new TypeMismatchException("Only Strings are supported for title rows.");
  }

  /**
   * @see org.ujac.util.table.Row#getDouble(int)
   */
  public double getDouble(int columnIdx) throws ColumnNotDefinedException, TypeMismatchException {
    throw new TypeMismatchException("Only Strings are supported for title rows.");
  }

  /**
   * @see org.ujac.util.table.Row#setDouble(java.lang.String, double)
   */
  public void setDouble(String columnName, double value) throws ColumnNotDefinedException, TypeMismatchException {
    throw new TypeMismatchException("Only Strings are supported for title rows.");
  }

  /**
   * @see org.ujac.util.table.Row#setDouble(int, double)
   */
  public void setDouble(int columnIdx, double value) throws ColumnNotDefinedException, TypeMismatchException {
    throw new TypeMismatchException("Only Strings are supported for title rows.");
  }

  /**
   * @see org.ujac.util.table.Row#getBoolean(java.lang.String)
   */
  public boolean getBoolean(String columnName) throws ColumnNotDefinedException, TypeMismatchException {
    throw new TypeMismatchException("Only Strings are supported for title rows.");
  }

  /**
   * @see org.ujac.util.table.Row#getBoolean(int)
   */
  public boolean getBoolean(int columnIdx) throws ColumnNotDefinedException, TypeMismatchException {
    throw new TypeMismatchException("Only Strings are supported for title rows.");
  }

  /**
   * @see org.ujac.util.table.Row#setBoolean(java.lang.String, boolean)
   */
  public void setBoolean(String columnName, boolean value) throws ColumnNotDefinedException, TypeMismatchException {
    throw new TypeMismatchException("Only Strings are supported for title rows.");
  }

  /**
   * @see org.ujac.util.table.Row#setBoolean(int, boolean)
   */
  public void setBoolean(int columnIdx, boolean value) throws ColumnNotDefinedException, TypeMismatchException {
    throw new TypeMismatchException("Only Strings are supported for title rows.");
  }

  /**
   * @see org.ujac.util.table.Row#getDate(java.lang.String)
   */
  public Date getDate(String columnName) throws ColumnNotDefinedException, TypeMismatchException {
    throw new TypeMismatchException("Only Strings are supported for title rows.");
  }

  /**
   * @see org.ujac.util.table.Row#getDate(int)
   */
  public Date getDate(int columnIdx) throws ColumnNotDefinedException, TypeMismatchException {
    throw new TypeMismatchException("Only Strings are supported for title rows.");
  }

  /**
   * @see org.ujac.util.table.Row#setDate(java.lang.String, java.util.Date)
   */
  public void setDate(String columnName, Date value) throws ColumnNotDefinedException, TypeMismatchException {
    throw new TypeMismatchException("Only Strings are supported for title rows.");
  }

  /**
   * @see org.ujac.util.table.Row#setDate(int, java.util.Date)
   */
  public void setDate(int columnIdx, Date value) throws ColumnNotDefinedException, TypeMismatchException {
    throw new TypeMismatchException("Only Strings are supported for title rows.");
  }

  /**
   * @see org.ujac.util.table.Row#getTime(java.lang.String)
   */
  public Date getTime(String columnName) throws ColumnNotDefinedException, TypeMismatchException {
    throw new TypeMismatchException("Only Strings are supported for title rows.");
  }

  /**
   * @see org.ujac.util.table.Row#getTime(int)
   */
  public Date getTime(int columnIdx) throws ColumnNotDefinedException, TypeMismatchException {
    throw new TypeMismatchException("Only Strings are supported for title rows.");
  }

  /**
   * @see org.ujac.util.table.Row#setTime(java.lang.String, java.util.Date)
   */
  public void setTime(String columnName, Date value) throws ColumnNotDefinedException, TypeMismatchException {
    throw new TypeMismatchException("Only Strings are supported for title rows.");
  }

  /**
   * @see org.ujac.util.table.Row#setTime(int, java.util.Date)
   */
  public void setTime(int columnIdx, Date value) throws ColumnNotDefinedException, TypeMismatchException {
    throw new TypeMismatchException("Only Strings are supported for title rows.");
  }

  /**
   * @see org.ujac.util.table.Row#getTimestamp(java.lang.String)
   */
  public Date getTimestamp(String columnName) throws ColumnNotDefinedException, TypeMismatchException {
    throw new TypeMismatchException("Only Strings are supported for title rows.");
  }

  /**
   * @see org.ujac.util.table.Row#getTimestamp(int)
   */
  public Date getTimestamp(int columnIdx) throws ColumnNotDefinedException, TypeMismatchException {
    throw new TypeMismatchException("Only Strings are supported for title rows.");
  }

  /**
   * @see org.ujac.util.table.Row#setTimestamp(java.lang.String, java.util.Date)
   */
  public void setTimestamp(String columnName, Date value) throws ColumnNotDefinedException, TypeMismatchException {
    throw new TypeMismatchException("Only Strings are supported for title rows.");
  }

  /**
   * @see org.ujac.util.table.Row#setTimestamp(int, java.util.Date)
   */
  public void setTimestamp(int columnIdx, Date value) throws ColumnNotDefinedException, TypeMismatchException {
    throw new TypeMismatchException("Only Strings are supported for title rows.");
  }

  /**
   * @see org.ujac.util.table.Row#getObject(java.lang.String)
   */
  public Object getObject(String columnName) throws ColumnNotDefinedException {
    try {
      return getString(columnName);
    } catch (TypeMismatchException ex) {
      // this should never happen!
      throw new RuntimeException(ex.getMessage());
    }
  }

  /**
   * @see org.ujac.util.table.Row#getObject(int)
   */
  public Object getObject(int columnIdx) throws ColumnNotDefinedException {
    try {
      return getString(columnIdx);
    } catch (TypeMismatchException ex) {
      // this should never happen!
      throw new RuntimeException(ex.getMessage());
    }
  }

  /**
   * @see org.ujac.util.table.Row#setObject(java.lang.String, java.lang.Object)
   */
  public void setObject(String columnName, Object value) throws ColumnNotDefinedException, TypeMismatchException {
    setString(columnName, value.toString());
  }

  /**
   * @see org.ujac.util.table.Row#setObject(int, java.lang.Object)
   */
  public void setObject(int columnIdx, Object value) throws ColumnNotDefinedException, TypeMismatchException {
    setString(columnIdx, value.toString());
  }
  
  /**
   * Gets the field alignment. 
   * @param lh The layout hints.
   * @return The field alignment from the given layout hints.
   */
  protected int getFieldAlignment(LayoutHints lh) {
    if (lh != null) {
      return lh.getHeaderAlign();
    }
    return LayoutHints.LEFT;
  }

  /**
   * Writes the object's data to the given stream.
   * @param s The stream to write to
   * @exception IOException In case the data output failed.
   */
  private void writeObject(ObjectOutputStream s) throws IOException {
    writeData(s);
  }
  /**
   * Reads the object's data from the given stream.
   * @param s The stream to read from.
   * @exception IOException In case the data reading failed.
   * @exception ClassNotFoundException In case the class to deserialize could not be found
   */
  private void readObject(ObjectInputStream s) throws IOException, ClassNotFoundException  {
    readData(s);
  }

}
