/*
 * Copyright (C) 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util.table;

import org.ujac.util.BeanUtils;


/**
 * Name: LessEqualsRowFilterRule<br>
 * Description: Test whether or not the checked fields values are greater or equal than the specified value.
 * 
 * @author lauerc
 */
public class LessEqualsRowFilterRule extends BaseRowFilterRule {

  /** The value to compare the column value with. */
  private Comparable value = null;
  
  /**
   * Constructs a LessEqualsRowFilterRule instance with specific attributes.
   * @param columnName The column name.
   * @param value The value to compare.
   * @exception TableException In case the given column was not defined.
   */
  public LessEqualsRowFilterRule(String columnName, Comparable value) {
    super(columnName);
    this.value = value;
  }

  /**
   * @see org.ujac.util.table.RowFilterRule#test(org.ujac.util.table.Row)
   */
  public boolean test(Row row) throws TableException {
    Object rowValue = row.getObject(columnIndex);
    return BeanUtils.compare((Comparable) rowValue, value) <= 0;
  }

}
