/*
 * Copyright (C) 2003 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.util.table;

import java.util.Comparator;

/**
 * Name: RowComparator<br>
 * Description: Class which compares two rows according to the given compare items.
 * 
 * @author lauerc
 */
public class RowComparator implements Comparator {

  /** The column definition for the sort process. */
  private CompareItem[] compareColumns;

  /**
   * Constructs a RowComparator instance with specific attributes.
   * @param compareColumns The column definition for the sort process.
   */
  public RowComparator(CompareItem[] compareColumns) {
    this.compareColumns = compareColumns;
  }

  /**
   * Compares its two arguments for order.  Returns a negative integer,
   * zero, or a positive integer as the first argument is less than, equal
   * to, or greater than the second.<p>
   * @param a the first object to be compared.
   * @param b the second object to be compared.
   * @return a negative integer, zero, or a positive integer as the
   *   first argument is less than, equal to, or greater than the
   *   second. 
   * @exception ClassCastException if the arguments' types prevent them from
   *   being compared by this Comparator.
   */
  public int compare(Object a, Object b) throws ClassCastException {

    Row rowA = (Row) a;
    Row rowB = (Row) b;
    
    for (int i = 0; i < compareColumns.length; i++) {
      CompareItem item = compareColumns[i];
      int columnIdx = item.getColumn();
      int direction = item.getDirection();

      int cr = 0;
      try {
        Object objA = rowA.getObject(columnIdx);
        Object objB = rowB.getObject(columnIdx);
        cr = ((Comparable) objA).compareTo(objB);
      } catch (TableException ex) {
        throw new RuntimeException(ex.getMessage());
      }
      if (cr != 0) {
        if (direction == CompareItem.DESC) {
          cr *= -1;
        }
        return cr;
      }
    }
    
    return 0;
  }
}
