/*
 * Copyright (C) 2003 - 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util.table;

/**
 * Name: SumReportFunctionExecutor<br>
 * Description: A function executor adding values.
 * 
 * @author lauerc
 */
public class SumFunctionExecutor implements FunctionExecutor {

  /** The serial version UID. */
  static final long serialVersionUID = -6914557080802474766L;

  /**
   * Adds the numeric value of the given object to the current value. 
   * @param currentValue The current value to apply the operand to.
   * @param operand The operand to apply.
   * @return The calculated result.
   * @exception TypeMismatchException In case the given operand type was invalid.
   */
  public double execute(double currentValue, Object operand) throws TypeMismatchException {
    double val = currentValue;
    if (Double.isNaN(val)) {
      val = 0.0;
    }
    if (operand == null) {
      return val;
    }
    if (operand instanceof Number) {
      double operandVal = ((Number) operand).doubleValue();
      if (Double.isNaN(operandVal)) {
        return val;
      }
      val += operandVal;
      return val;
    }
    throw new TypeMismatchException("The SumFunctionExecutor can get only applied to numeric values.");
  }

  /**
   * Tells whether the function executor serves integers under guarantee (f.e. count function). 
   * @return always returns false.
   */
  public boolean integersGuaranteed() {
    return false;
  }
  
}
