/*
 * Copyright (C) 2005 - 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util.table;

import org.ujac.util.UjacTypeHelper;

/**
 * Name: TableHelper<br>
 * Description: Provides global helper methods for table handling.
 * 
 * @author lauerc
 */
public class TableHelper {

  /**
   * Gets the ID from the given column type name.
   * @param columnTypeName The column type name to convert.
   * @return The according type ID.
   * @throws TableException In case the conversion failed.
   */
  public static final int getColumnTypeId(String columnTypeName)
    throws TableException {
    
    int typeId = UjacTypeHelper.getTypeId(columnTypeName);
    if (typeId == -1) {
      throw new TableException("Invalid column type '" + columnTypeName + "'.");
    }
    return typeId;
  }

  /**
   * Gets the ID from the given column type name.
   * @param columnTypeId The column type ID to convert.
   * @return The according type name.
   * @throws TableException In case the conversion failed.
   */
  public static final String getColumnTypeName(int columnTypeId)
    throws TableException {
    
    String typeName = UjacTypeHelper.getTypeName(columnTypeId);
    if (typeName == null) {
      throw new TableException("Invalid column type ID " + columnTypeId + ".");
    }
    return typeName;
  }

  /**
   * Gets the id of the given textual alignment representation.
   * @param align The alignment name to parse.
   * @return The id of the given textual alignment representation.
   */
  public static final int getAlignmentId(String align) {
    if (align == null) {
      return LayoutHints.LEFT;
    }
    String alignLower = align.toLowerCase();
    if ("left".equals(alignLower)) {
      return LayoutHints.LEFT;
    }
    if ("right".equals(alignLower)) {
      return LayoutHints.RIGHT;
    }
    if ("center".equals(alignLower)) {
      return LayoutHints.CENTER;
    }
    return LayoutHints.LEFT;
  }
  
  /**
   * Gets the textual representation of the given alignment value.
   * @param align The alignment id to get the name for.
   * @return The textual representation of the given alignment.
   */
  public static final String getAlignmentName(int align) {
    switch (align) {
      case LayoutHints.LEFT:
        return "left";
      case LayoutHints.RIGHT:
        return "right";
      case LayoutHints.CENTER:
        return "center";
      default:
        return "left";
    }
  }

}
