/*
 * Copyright (C) 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util.table;

import java.io.PrintStream;
import java.io.PrintWriter;

/**
 * Name: TableIterationException<br>
 * Description: An exception class for table iteration failures.
 * 
 * @author lauerc
 */
public class TableIterationException extends RuntimeException {

  /** The serial version UID. */
  private static final long serialVersionUID = 7242307476911799421L;
  
  /** The original exception that caused this exception. */
  private Throwable originalCause;

  /**
   * Constructs a TableIterationException instance with no specific attributes.
   */
  public TableIterationException() {
    super();
  }

  /**
   * Constructs a TableIterationException instance with specific attributes.
   * @param message The error message.
   */
  public TableIterationException(String message) {
    super(message);
  }
  
  /**
   * Constructs a TableIterationException instance with specific attributes.
   * @param message The error message.
   * @param cause The original cause.
   */
  public TableIterationException(String message, Throwable cause) {
    super(message);
    originalCause = cause;
  }
  
  /**
   * Constructs a TableIterationException instance with specific attributes.
   * @param cause The original cause.
   */
  public TableIterationException(Throwable cause) {
    super();
    originalCause = cause;
  }
  
  /**
   * @see java.lang.Throwable#printStackTrace(java.io.PrintStream)
   */
  public void printStackTrace(PrintStream stream) {
    super.printStackTrace(stream);
    if (originalCause != null) {
      stream.println("Caused by:" + originalCause.getMessage());
      originalCause.printStackTrace(stream);
    }
  }

  /**
   * @see java.lang.Throwable#printStackTrace(java.io.PrintWriter)
   */
  public void printStackTrace(PrintWriter writer) {
    super.printStackTrace(writer);
    if (originalCause != null) {
      writer.println("Caused by:" + originalCause.getMessage());
      originalCause.printStackTrace(writer);
    }
  }

}
