/*
 * Copyright (C) 2003 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.util.table.test;

import java.sql.Time;
import java.sql.Timestamp;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import junit.framework.TestCase;

import org.ujac.util.table.BeanTable;
import org.ujac.util.table.ColumnFilter;
import org.ujac.util.table.ColumnNotDefinedException;
import org.ujac.util.table.Table;

/**
 * Name: BeanTableTest<br>
 * Description: Test cases for BeanTable class.<br>
 * 
 * @author lauerc
 */
public class BeanTableTest extends TestCase {
  
  /** The bean list to use. */
  private List beanList = null;

  /**
   * Name: TestBean<br>
   * Description: A test bean for the bean table.
   */
  public static class TestBean {
    
    /** A boolean value. */
    private boolean aBoolean;
    /** An integer value.*/
    private int anInt;
    /** A long value. */
    private long aLong;
    /** A double value. */
    private double aDouble;
    /** A String value. */
    private String aString;
    /** A Date value. */
    private Date aDate;
    /** A Time value. */
    private Time aTime;
    /** A Timestamp value.*/
    private Timestamp aTimestamp;
    /** An object value. */
    private List aList;
    
    /**
     * Constructs a BeanTableTest.TestBean instance with no specific attributes.
     */
    public TestBean() {
    }

    /**
     * Constructs a TestBean instance with specific attributes.
     * @param aBoolean Initial value for property aBoolean.
     * @param anInt Initial value for property anInt.
     * @param aLong Initial value for property aLong.
     * @param aDouble Initial value for property aDouble.
     * @param aString Initial value for property aString.
     * @param aDate Initial value for property aDate.
     * @param aTime Initial value for property aTime.
     * @param aTimestamp Initial value for property aTimestamp.
     * @param aList Initial value for property aList.
     */
    public TestBean(boolean aBoolean, int anInt, long aLong, double aDouble,
                    String aString, Date aDate, Time aTime, Timestamp aTimestamp, 
                    List aList) {
      this.aBoolean = aBoolean;
      this.anInt = anInt;
      this.aLong = aLong;
      this.aDouble = aDouble;
      this.aString = aString;
      this.aDate = aDate;
      this.aTime = aTime;
      this.aTimestamp = aTimestamp;
      this.aList = aList;
    }
    
    /**
     * Getter method for the the property aBoolean.
     * @return The current value of property aBoolean.
     */
    public boolean isABoolean() {
      return aBoolean;
    }
    /**
     * Setter method for the the property aBoolean.
     * @param aBoolean The value to set for the property aBoolean.
     */
    public void setABoolean(boolean aBoolean) {
      this.aBoolean = aBoolean;
    }

    /**
     * Getter method for the the property anInt.
     * @return The current value of property anInt.
     */
    public int getAnInt() {
      return anInt;
    }
    /**
     * Setter method for the the property anInt.
     * @param anInt The value to set for the property anInt.
     */
    public void setAnInt(int anInt) {
      this.anInt = anInt;
    }

    /**
     * Getter method for the the property aLong.
     * @return The current value of property aLong.
     */
    public long getALong() {
      return aLong;
    }
    /**
     * Setter method for the the property aLong.
     * @param aLong The value to set for the property aLong.
     */
    public void setALong(long aLong) {
      this.aLong = aLong;
    }
    
    /**
     * Getter method for the the property aDouble.
     * @return The current value of property aDouble.
     */
    public double getADouble() {
      return aDouble;
    }
    /**
     * Setter method for the the property aDouble.
     * @param aDouble The value to set for the property aDouble.
     */
    public void setADouble(double aDouble) {
      this.aDouble = aDouble;
    }

    /**
     * Getter method for the the property aString.
     * @return The current value of property aString.
     */
    public String getAString() {
      return aString;
    }
    /**
     * Setter method for the the property aString.
     * @param aString The value to set for the property aString.
     */
    public void setAString(String aString) {
      this.aString = aString;
    }

    /**
     * Getter method for the the property aDate.
     * @return The current value of property aDate.
     */
    public Date getADate() {
      return aDate;
    }
    /**
     * Setter method for the the property aDate.
     * @param aDate The value to set for the property aDate.
     */
    public void setADate(Date aDate) {
      this.aDate = aDate;
    }

    /**
     * Getter method for the the property aTime.
     * @return The current value of property aTime.
     */
    public Time getATime() {
      return aTime;
    }
    /**
     * Setter method for the the property aTime.
     * @param aTime The value to set for the property aTime.
     */
    public void setATime(Time aTime) {
      this.aTime = aTime;
    }
    
    /**
     * Getter method for the the property aTimestamp.
     * @return The current value of property aTimestamp.
     */
    public Timestamp getATimestamp() {
      return aTimestamp;
    }
    /**
     * Setter method for the the property aTimestamp.
     * @param aTimestamp The value to set for the property aTimestamp.
     */
    public void setATimestamp(Timestamp aTimestamp) {
      this.aTimestamp = aTimestamp;
    }
    
    /**
     * Getter method for the the property aList.
     * @return The current value of property aList.
     */
    public List getAList() {
      return aList;
    }
    /**
     * Setter method for the the property aList.
     * @param aList The value to set for the property aList.
     */
    public void setAList(List aList) {
      this.aList = aList;
    }
    
  }
  
  /**
   * @see junit.framework.TestCase#setUp()
   */
  protected void setUp() throws Exception {

    // setting up data table
    this.beanList = new ArrayList();
    beanList.add(new TestBean(
        true, 1, 1L, 1.0, "Test 1", new Date(), 
        new Time(System.currentTimeMillis()),
        new Timestamp(System.currentTimeMillis()),
        new ArrayList()
    ));
    beanList.add(new TestBean(
        true, 2, 2L, 2.0, "Test 2", new Date(), 
        new Time(System.currentTimeMillis()),
        new Timestamp(System.currentTimeMillis()),
        new ArrayList()
    ));
    beanList.add(new TestBean(
        true, 3, 3L, 3.0, "Test 3", new Date(), 
        new Time(System.currentTimeMillis()),
        new Timestamp(System.currentTimeMillis()),
        new ArrayList()
    ));
    beanList.add(new TestBean(
        true, 4, 4L, 4.0, "Test 4", new Date(), 
        new Time(System.currentTimeMillis()),
        new Timestamp(System.currentTimeMillis()),
        new ArrayList()
    ));
    beanList.add(new TestBean(
        true, 5, 5L, 5.0, "Test 5", new Date(), 
        new Time(System.currentTimeMillis()),
        new Timestamp(System.currentTimeMillis()),
        new ArrayList()
    ));
    beanList.add(new TestBean(
        true, 6, 6L, 6.0, "Test 6", new Date(), 
        new Time(System.currentTimeMillis()),
        new Timestamp(System.currentTimeMillis()),
        new ArrayList()
    ));
    beanList.add(new TestBean(
        true, 6, 6L, 6.0, "Test 6", new Date(), 
        new Time(System.currentTimeMillis()),
        new Timestamp(System.currentTimeMillis()),
        new ArrayList()
    ));
    beanList.add(new TestBean(
        true, 7, 7L, 7.0, "Test 7", new Date(), 
        new Time(System.currentTimeMillis()),
        new Timestamp(System.currentTimeMillis()),
        new ArrayList()
    ));
    beanList.add(new TestBean(
        true, 8, 8L, 8.0, "Test 8", new Date(), 
        new Time(System.currentTimeMillis()),
        new Timestamp(System.currentTimeMillis()),
        new ArrayList()
    ));
    beanList.add(new TestBean(
        true, 9, 9L, 9.0, "Test 9", new Date(), 
        new Time(System.currentTimeMillis()),
        new Timestamp(System.currentTimeMillis()),
        new ArrayList()
    ));
    beanList.add(new TestBean(
        true, 10, 10L, 10.0, "Test 10", new Date(), 
        new Time(System.currentTimeMillis()),
        new Timestamp(System.currentTimeMillis()),
        new ArrayList()
    ));
  }

  /**
   * Performs the bean table test. 
   */
  public void testBeanTable() {
    long start = System.currentTimeMillis(); 
    try {
      BeanTable table = new BeanTable(beanList);
      System.out.println(table.toString());
    } catch (Exception e) {
      e.printStackTrace();
    }
    long end = System.currentTimeMillis();
    long elapsed = end - start;
    System.out.println("needed " + elapsed + " ms for bean table test.");
  }

  /**
   * Performs the bean table test. 
   */
  public void testBeanTableCopy() {
    long start = System.currentTimeMillis(); 
    try {
      BeanTable table = new BeanTable(beanList);
      Table copy = table.copyTable();
      System.out.println(copy.toString());
      assertEquals(table.getRowCount(), copy.getRowCount());
      assertEquals(table.toString(), copy.toString());
    } catch (Exception e) {
      e.printStackTrace();
    }
    long end = System.currentTimeMillis();
    long elapsed = end - start;
    System.out.println("needed " + elapsed + " ms for bean table test.");
  }

  /**
   * Performs the bean table test. 
   */
  public void testColumnFilter() {
    try {
      BeanTable table = new BeanTable(beanList, new ColumnFilter() {
        public boolean isValid(String name) {
          return "anInt".equals(name) || "aString".equals(name);
        }
      });
      assertEquals(new Integer(2), new Integer(table.getColumnCount()));
      assertTrue(table.getColumn("anInt") != null);
      assertTrue(table.getColumn("aString") != null);
      try {
        table.getColumn("aBoolean");
        assertFalse(true);
      } catch (ColumnNotDefinedException ex) {
        assertTrue(true);
      }
      try {
        table.getColumn("aDate");
        assertFalse(true);
      } catch (ColumnNotDefinedException ex) {
        assertTrue(true);
      }
    } catch (Exception e) {
      e.printStackTrace();
    }
  }

}
