/*
 * Copyright (C) 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util.table.test;

import java.util.Iterator;

import org.ujac.util.CollectionUtils;
import org.ujac.util.UjacTypes;
import org.ujac.util.exi.ExpressionInterpreter;
import org.ujac.util.table.BetweenRowFilterRule;
import org.ujac.util.table.DataTable;
import org.ujac.util.table.EqualsRowFilterRule;
import org.ujac.util.table.ExpressionRowFilterRule;
import org.ujac.util.table.FilteredTable;
import org.ujac.util.table.InRowFilterRule;
import org.ujac.util.table.LayoutHints;
import org.ujac.util.table.LikeRowFilterRule;
import org.ujac.util.table.NotRowFilterRule;
import org.ujac.util.table.Row;
import org.ujac.util.table.RowFilterRule;
import org.ujac.util.table.RowFilterRuleSet;
import org.ujac.util.table.Table;
import org.ujac.util.table.TableException;

import junit.framework.TestCase;

/**
 * Name: FilteredTableTest<br>
 * Description: Tests for the class FilteredTable.
 *  
 * @author lauerc
 */
public class FilteredTableTest extends TestCase {

  /** The data table to use. */
  private Table dataTable = null;

  /**
   * Sets up the test case.
   * @see junit.framework.TestCase#setUp()
   */
  protected void setUp() throws Exception {
    super.setUp();
    
    this.dataTable = new DataTable();
    dataTable.addColumn("department", UjacTypes.TYPE_STRING, new LayoutHints(15, "Department"));
    dataTable.addColumn("group", UjacTypes.TYPE_STRING, new LayoutHints(15, "Group"));
    dataTable.addColumn("name", UjacTypes.TYPE_STRING, new LayoutHints(20, "Name"));
    dataTable.addColumn("value", UjacTypes.TYPE_DOUBLE, new LayoutHints(20, "Value"));
    
    Row row = dataTable.addRow();
    row.setString(0, "Dep1");
    row.setString(1, "Group1.1");
    row.setString(2, "Harry");
    row.setDouble(3, 100);

    row = dataTable.addRow();
    row.setString(0, "Dep1");
    row.setString(1, "Group1.2");
    row.setString(2, "Eric");
    row.setDouble(3, 430);

    row = dataTable.addRow();
    row.setString(0, "Dep1");
    row.setString(1, "Group1.2");
    row.setString(2, "Eric");
    row.setDouble(3, 321);
    
    row = dataTable.addRow();
    row.setString(0, "Dep1");
    row.setString(1, "Group1.2");
    row.setString(2, "Willie");
    row.setDouble(3, 130);

    row = dataTable.addRow();
    row.setString(0, "Dep1");
    row.setString(1, "Group1.2");
    row.setString(2, "Carl");
    row.setDouble(3, 331);

    row = dataTable.addRow();
    row.setString(0, "Dep2");
    row.setString(1, "Group2.1");
    row.setString(2, "Harry");
    row.setDouble(3, 430);

    row = dataTable.addRow();
    row.setString(0, "Dep2");
    row.setString(1, "Group2.2");
    row.setString(2, "Willie");
    row.setDouble(3, 130);

    row = dataTable.addRow();
    row.setString(0, "Dep2");
    row.setString(1, "Group2.2");
    row.setString(2, "Curt");
    row.setDouble(3, 123);

    row = dataTable.addRow();
    row.setString(0, "Dep3");
    row.setString(1, "Group3.1");
    row.setString(2, "Eric");
    row.setDouble(3, 232);

    row = dataTable.addRow();
    row.setString(0, "Dep4");
    row.setString(1, "Group4.1");
    row.setString(2, "Willie");
    row.setDouble(3, 534);
  }

  /**
   * Tests the EqualsRowFilterRule.
   * @throws TableException In case the data table access fails.
   */
  public void testEqualsRowFilterRule() throws TableException {
    RowFilterRule filterRule = new EqualsRowFilterRule("department", "Dep1");
    FilteredTable table = new FilteredTable(
        dataTable, filterRule
    );
    assertEquals("Group1.1", table.getString(0, "group"));

    int count = 0;
    Iterator iterFiltered = table.iterator();
    while (iterFiltered.hasNext()) {
      Row row = (Row) iterFiltered.next();
      assertEquals("Dep1", row.getString(0));
      ++count;
    }
    assertEquals(5, count);
    
    
    filterRule = new EqualsRowFilterRule("department", "Dep2");
    table.setFilterRule(filterRule);
    assertEquals("Group2.1", table.getString(0, "group"));
    
    count = 0;
    iterFiltered = table.iterator();
    while (iterFiltered.hasNext()) {
      Row row = (Row) iterFiltered.next();
      assertEquals("Dep2", row.getString(0));
      ++count;
    }
    assertEquals(3, count);
  }

  /**
   * Tests the LikeRowFilterRule.
   * @throws TableException In case the data table access fails.
   */
  public void testLikeRowFilterRule() throws TableException {
    RowFilterRule filterRule = new LikeRowFilterRule("group", "%.1");
    FilteredTable table = new FilteredTable(
        dataTable, filterRule
    );
    assertEquals("Group1.1", table.getString(0, "group"));

    int count = 0;
    Iterator iterFiltered = table.iterator();
    while (iterFiltered.hasNext()) {
      iterFiltered.next();
      ++count;
    }
    assertEquals(4, count);
    
    
    filterRule = new LikeRowFilterRule("group", "%.2");
    table.setFilterRule(filterRule);
    assertEquals("Group1.2", table.getString(0, "group"));
    
    count = 0;
    iterFiltered = table.iterator();
    while (iterFiltered.hasNext()) {
      iterFiltered.next();
      ++count;
    }
    assertEquals(6, count);
  }

  /**
   * Tests the NotRowFilterRule.
   * @throws TableException In case the data table access fails.
   */
  public void testNotRowFilterRule() throws TableException {
    RowFilterRule filterRule = new NotRowFilterRule(new EqualsRowFilterRule("name", "Harry"));
    FilteredTable table = new FilteredTable(
        dataTable, filterRule
    );
    assertEquals("Eric", table.getString(0, "name"));
  }

  /**
   * Tests the InRowFilterRule.
   * @throws TableException In case the data table access fails.
   */
  public void testInRowFilterRule() throws TableException {
    RowFilterRule filterRule = new InRowFilterRule("name", CollectionUtils.createHashSet(new String[] {
        "Harry", "Eric" 
    }));
    FilteredTable table = new FilteredTable(
        dataTable, filterRule
    );

    int count = 0;
    Iterator iterFiltered = table.iterator();
    while (iterFiltered.hasNext()) {
      Row row = (Row) iterFiltered.next();
      String name = row.getString("name");
      assertTrue("Eric".equals(name) || "Harry".equals(name));
      ++count;
    }
    assertEquals(5, count);
  }

  /**
   * Tests the InRowFilterRule.
   * @throws TableException In case the data table access fails.
   */
  public void testBetweenRowFilterRule() throws TableException {
    RowFilterRule filterRule = new BetweenRowFilterRule("value", new Double(110), new Double(300));
    FilteredTable table = new FilteredTable(
        dataTable, filterRule
    );
    assertEquals("Willie", table.getString(0, "name"));

    int count = 0;
    Iterator iterFiltered = table.iterator();
    while (iterFiltered.hasNext()) {
      Row row = (Row) iterFiltered.next();
      String name = row.getString("name");
      assertTrue("Willie".equals(name) || "Curt".equals(name) || "Eric".equals(name));
      ++count;
    }
    assertEquals(4, count);
  }

  /**
   * Tests the RowFilterRuleSet.
   * @throws TableException In case the data table access fails.
   */
  public void testRowFilterRuleSet() throws TableException {
    RowFilterRuleSet filterRule = new RowFilterRuleSet(new EqualsRowFilterRule("department", "Dep2"))
      .add(RowFilterRuleSet.AND, new NotRowFilterRule(new EqualsRowFilterRule("group", "Group2.2")));
    FilteredTable table = new FilteredTable(
        dataTable, filterRule
    );

    int count = 0;
    Iterator iterFiltered = table.iterator();
    while (iterFiltered.hasNext()) {
      Row row = (Row) iterFiltered.next();
      String name = row.getString("name");
      assertEquals("Harry", name);
      ++count;
    }
    assertEquals(1, count);
  }

  /**
   * Tests the copyTable method for FilteredTables.
   * @throws TableException In case the data table access fails.
   */
  public void testFilteredTableCopy() throws TableException {
    RowFilterRuleSet filterRule = new RowFilterRuleSet(new EqualsRowFilterRule("department", "Dep2"))
      .add(RowFilterRuleSet.AND, new NotRowFilterRule(new EqualsRowFilterRule("group", "Group2.2")));
    FilteredTable table = new FilteredTable(
        dataTable, filterRule
    );
    Table copy = table.copyTable();
    
    assertEquals(1, copy.getRowCount());
  }

  /**
   * Tests the ExpressionRowFilterRule.
   * @throws TableException In case the data table access fails.
   */
  public void testExpressionRowFilterRule() throws TableException {
    ExpressionInterpreter exi = ExpressionInterpreter.createInstance();
    RowFilterRule filterRule = new ExpressionRowFilterRule(exi, "${row.department=='Dep2' and row.group!='Group2.2'}");
    FilteredTable table = new FilteredTable(
        dataTable, filterRule
    );
    
    int count = 0;
    Iterator iterFiltered = table.iterator();
    while (iterFiltered.hasNext()) {
      Row row = (Row) iterFiltered.next();
      String name = row.getString("name");
      assertEquals("Harry", name);
      ++count;
    }
    assertEquals(1, count);
  }

}
