/*
 * Copyright (C) 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util.table.test;

import org.ujac.util.table.CountFunctionExecutor;
import org.ujac.util.table.FunctionExecutor;
import org.ujac.util.table.SumFunctionExecutor;
import org.ujac.util.table.TableException;
import junit.framework.TestCase;

/**
 * Name: FunctionExecutorTest<br>
 * Description: Test cases for function executors.
 * 
 * @author lauerc
 */
public class FunctionExecutorTest extends TestCase {

  /**
   * Constructs a FunctionExecutorTest instance with specific attributes.
   * @param name The name of the test case.
   */
  public FunctionExecutorTest(String name) {
    super(name);
  }
  
  /**
   * Tests the SumFunctionExecutor
   * @throws TableException In case something went wrong.
   */
  public void testSumFunctionExecutor() throws TableException {
    FunctionExecutor fe = new SumFunctionExecutor();
    double value = fe.execute(0.0, null);
    value = fe.execute(value, new Integer(10));
    value = fe.execute(value, new Long(10));
    value = fe.execute(value, null);
    value = fe.execute(value, new Double(12.5));
    value = fe.execute(value, new Float(9.5));
    value = fe.execute(value, null);
    assertEquals(42.0, value, 0.0);
  }
  
  /**
   * Tests the CountFunctionExecutor
   * @throws TableException In case something went wrong.
   */
  public void testCountFunctionExecutor() throws TableException {
    FunctionExecutor fe = new CountFunctionExecutor();
    double value = fe.execute(0.0, null);
    value = fe.execute(value, new Integer(10));
    value = fe.execute(value, new Long(10));
    value = fe.execute(value, null);
    value = fe.execute(value, new Double(12.5));
    value = fe.execute(value, new Float(9.5));
    value = fe.execute(value, null);
    assertEquals(4.0, value, 0.0);
  }
  
}
