/*
 * Copyright (C) 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util.table.test;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.text.DateFormat;

import junit.framework.TestCase;

import org.ujac.util.UjacTypes;
import org.ujac.util.table.Column;
import org.ujac.util.table.DataTable;
import org.ujac.util.table.LayoutHints;
import org.ujac.util.table.Row;
import org.ujac.util.table.Table;
import org.ujac.util.table.TableSerializer;
import org.ujac.util.text.FormatHelper;

/**
 * Name: TableSerializerTest<br>
 * Description: Tests for the TableSerializer.
 * 
 * @author lauerc
 */
public class TableSerializerTest extends TestCase {
  
  /** The data table to use. */
  private Table dataTable = null;

  /**
   * @see junit.framework.TestCase#setUp()
   */
  protected void setUp() throws Exception {

    // setting up data table
    this.dataTable = new DataTable();
    Column idCol = dataTable.addColumn("ID", UjacTypes.TYPE_INT);
    idCol.setLayoutHints(new LayoutHints(10, "ID", LayoutHints.LEFT));
    int idID = idCol.getIndex();
    Column depotCol = dataTable.addColumn("DEPOT", UjacTypes.TYPE_STRING);
    depotCol.setLayoutHints(new LayoutHints(12, "Depot", LayoutHints.LEFT));
    int depotID = depotCol.getIndex();
    Column typeCol = dataTable.addColumn("TYPE", UjacTypes.TYPE_STRING);
    typeCol.setLayoutHints(new LayoutHints(12, "Type", LayoutHints.LEFT));
    int typeID = typeCol.getIndex();
    Column nameCol = dataTable.addColumn("NAME", UjacTypes.TYPE_STRING);
    nameCol.setLayoutHints(new LayoutHints(40, "Name", LayoutHints.LEFT));
    int nameID = nameCol.getIndex();
    Column valueCol = dataTable.addColumn("VALUE", UjacTypes.TYPE_DOUBLE);
    valueCol.setLayoutHints(new LayoutHints(25, "Value", LayoutHints.RIGHT));
    int valueID = valueCol.getIndex();
    Column dateCol = dataTable.addColumn("DATE", UjacTypes.TYPE_DATE);
    dateCol.setLayoutHints(new LayoutHints(25, "Date", LayoutHints.LEFT));
    int dateID = dateCol.getIndex();
    
    // filling data table
    FormatHelper fh = FormatHelper.createInstance();
    DateFormat df = fh.getIsoDateFormat();
    
    Row row = dataTable.addRow();
    row.setInt(idID, 1);
    row.setString(depotID, "Depot 1");
    row.setString(typeID, "S");
    row.setString(nameID, "SAP");
    row.setDouble(valueID, 2725.80);
    row.setDate(dateID, df.parse("2008-02-21"));

    row = dataTable.addRow();
    row.setInt(idID, 2);
    row.setString(depotID, "Depot 1");
    row.setString(typeID, "S");
    row.setString(nameID, "ZOOM TECHNLGIES");
    row.setDouble(valueID, 1235.65);
    row.setDate(dateID, df.parse("2008-01-01"));

    row = dataTable.addRow();
    row.setInt(idID, 3);
    row.setString(depotID, "Depot 1");
    row.setString(typeID, "S");
    row.setString(nameID, "MICRO$OFT");
    row.setDouble(valueID, 455.33);
    row.setDate(dateID, df.parse("2008-05-01"));

    row = dataTable.addRow();
    row.setInt(idID, 4);
    row.setString(depotID, "Depot 1");
    row.setString(typeID, "S");
    row.setString(nameID, "COMTECH TELCOM");
    row.setDouble(valueID, 5465.56);
    row.setDate(dateID, df.parse("2007-12-13"));

    row = dataTable.addRow();
    row.setInt(idID, 5);
    row.setString(depotID, "Depot 1");
    row.setString(typeID, "S");
    row.setString(nameID, "DAIMLER CRYSLER");
    row.setDouble(valueID, 7655.23);
    row.setDate(dateID, df.parse("2007-12-20"));

    row = dataTable.addRow();
    row.setInt(idID, 6);
    row.setString(depotID, "Depot 1");
    row.setString(typeID, "F");
    row.setString(nameID, "NASDAQ 100 TRUST");
    row.setDouble(valueID, 135.50);
    row.setDate(dateID, df.parse("2007-01-01"));
    
    row = dataTable.addRow();
    row.setInt(idID, 7);
    row.setString(depotID, "Depot 1");
    row.setString(typeID, "F");
    row.setString(nameID, "NORDASIA.COM");
    row.setDouble(valueID, 435.23);
    row.setDate(dateID, df.parse("2007-01-01"));

    row = dataTable.addRow();
    row.setInt(idID, 8);
    row.setString(depotID, "Depot 1");
    row.setString(typeID, "F");
    row.setString(nameID, "MERRILL LIIF WLD MINING A");
    row.setDouble(valueID, 1567.54);
    row.setDate(dateID, df.parse("2007-01-01"));

    row = dataTable.addRow();
    row.setInt(idID, 9);
    row.setString(depotID, "Depot 1");
    row.setString(typeID, "F");
    row.setString(nameID, "SPAENGLER LIFE SCIENCE TRUST");
    row.setDouble(valueID, 545.45);
    row.setDate(dateID, df.parse("2007-01-01"));
    
    row = dataTable.addRow();
    row.setInt(idID, 10);
    row.setString(depotID, "Depot 2");
    row.setString(typeID, "F");
    row.setString(nameID, "MMF (Most Miserable Fund)");
    row.setDouble(valueID, 12326.74);
    row.setDate(dateID, df.parse("2007-01-01"));
   
    row = dataTable.addRow();
    row.setInt(idID, 10);
    row.setString(depotID, "Depot 3");
    row.setString(typeID, "S");
    row.setString(nameID, "REHAKLES");
    row.setDouble(valueID, 5546.74);
    row.setDate(dateID, df.parse("2007-01-01"));

    row = dataTable.addRow();
    row.setInt(idID, 11);
    row.setString(depotID, "Depot 3");
    row.setString(typeID, "S");
    row.setString(nameID, "WHEELING PITTS");
    row.setDouble(valueID, 2835.21);
    row.setDate(dateID, df.parse("2007-01-01"));

    row = dataTable.addRow();
    row.setInt(idID, 12);
    row.setString(depotID, "Depot 3");
    row.setString(typeID, "S");
    row.setString(nameID, "NATIONAL VISION");
    row.setDouble(valueID, 7675.12);
    row.setDate(dateID, df.parse("2007-01-01"));

    row = dataTable.addRow();
    row.setInt(idID, 13);
    row.setString(depotID, "Depot 3");
    row.setString(typeID, "S");
    row.setString(nameID, "COMTECH TELCOM");
    row.setDouble(valueID, 865.23);
    row.setDate(dateID, df.parse("2007-01-01"));

    row = dataTable.addRow();
    row.setInt(idID, 14);
    row.setString(depotID, "Depot 3");
    row.setString(typeID, "S");
    row.setString(nameID, "IMMUNOMEDICS");
    row.setDouble(valueID, 876.21);
    row.setDate(dateID, df.parse("2007-01-01"));

    row = dataTable.addRow();
    row.setInt(idID, 15);
    row.setString(depotID, "Depot 3");
    row.setString(typeID, "S");
    row.setString(nameID, "INTEL CORP");
    row.setDouble(valueID, 673.45);
    row.setDate(dateID, df.parse("2007-01-01"));
    
    row = dataTable.addRow();
    row.setInt(idID, 16);
    row.setString(depotID, "Depot 3");
    row.setString(typeID, "F");
    row.setString(nameID, "ROBOTRON");
    row.setDouble(valueID, 435.23);
    row.setDate(dateID, df.parse("2007-01-01"));

    row = dataTable.addRow();
    row.setInt(idID, 17);
    row.setString(depotID, "Depot 3");
    row.setString(typeID, "F");
    row.setString(nameID, "HASTENIX");
    row.setDouble(valueID, 1567.54);
    row.setDate(dateID, df.parse("2007-01-01"));

    row = dataTable.addRow();
    row.setInt(idID, 18);
    row.setString(depotID, "Depot 3");
    row.setString(typeID, "F");
    row.setString(nameID, "Vanguard Global Equity");
    row.setDouble(valueID, 425.53);
    row.setDate(dateID, df.parse("2007-01-01"));

    row = dataTable.addRow();
    row.setInt(idID, 19);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "S");
    row.setString(nameID, "QUIRKS");
    row.setDouble(valueID, 3456.54);
    row.setDate(dateID, df.parse("2007-01-01"));

    row = dataTable.addRow();
    row.setInt(idID, 20);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "S");
    row.setString(nameID, "ZOORO");
    row.setDouble(valueID, 455.25);
    row.setDate(dateID, df.parse("2007-01-01"));

    row = dataTable.addRow();
    row.setInt(idID, 21);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "S");
    row.setString(nameID, "ROBOTRON");
    row.setDouble(valueID, 3545.37);
    row.setDate(dateID, df.parse("2007-01-01"));

    row = dataTable.addRow();
    row.setInt(idID, 22);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "S");
    row.setString(nameID, "PARODENTRON");
    row.setDouble(valueID, 7567.76);
    row.setDate(dateID, df.parse("2007-01-01"));

    row = dataTable.addRow();
    row.setInt(idID, 23);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "S");
    row.setString(nameID, "FORZA");
    row.setDouble(valueID, 3621.21);
    row.setDate(dateID, df.parse("2007-01-01"));

    row = dataTable.addRow();
    row.setInt(idID, 24);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "S");
    row.setString(nameID, "CUPTEC");
    row.setDouble(valueID, 541.34);
    row.setDate(dateID, df.parse("2007-01-01"));

    row = dataTable.addRow();
    row.setInt(idID, 25);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "ZOCKER.COM");
    row.setDouble(valueID, 521.12);
    row.setDate(dateID, df.parse("2007-01-01"));
    
    row = dataTable.addRow();
    row.setInt(idID, 26);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "GAAGLI");
    row.setDouble(valueID, 5464.12);
    row.setDate(dateID, df.parse("2007-01-01"));

    row = dataTable.addRow();
    row.setInt(idID, 27);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "HANSO INC");
    row.setDouble(valueID, 554.34);
    row.setDate(dateID, df.parse("2007-01-01"));

    row = dataTable.addRow();
    row.setInt(idID, 28);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "LOCKER");
    row.setDouble(valueID, 145.32);
    row.setDate(dateID, df.parse("2007-01-01"));

    row = dataTable.addRow();
    row.setInt(idID, 29);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "KOCKEL");
    row.setDouble(valueID, 654.24);
    row.setDate(dateID, df.parse("2007-01-01"));

    row = dataTable.addRow();
    row.setInt(idID, 30);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "FARBIC");
    row.setDouble(valueID, 4564.34);
    row.setDate(dateID, df.parse("2007-01-01"));

    row = dataTable.addRow();
    row.setInt(idID, 31);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "HEGON");
    row.setDouble(valueID, 235.31);
    row.setDate(dateID, df.parse("2007-01-01"));

    row = dataTable.addRow();
    row.setInt(idID, 32);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "REHAKLES");
    row.setDouble(valueID, 1432.32);
    row.setDate(dateID, df.parse("2007-01-01"));

    row = dataTable.addRow();
    row.setInt(idID, 33);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "PATZIKI");
    row.setDouble(valueID, 324.12);
    row.setDate(dateID, df.parse("2007-01-01"));

    row = dataTable.addRow();
    row.setInt(idID, 34);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "GRINSO");
    row.setDouble(valueID, 228.53);
    row.setDate(dateID, df.parse("2007-01-01"));

    row = dataTable.addRow();
    row.setInt(idID, 35);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "GONZOLES");
    row.setDouble(valueID, 458.33);
    row.setDate(dateID, df.parse("2007-01-01"));

    row = dataTable.addRow();
    row.setInt(idID, 36);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "HASTENIX");
    row.setDouble(valueID, 4528.33);
    row.setDate(dateID, df.parse("2007-01-01"));

    row = dataTable.addRow();
    row.setInt(idID, 37);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "ALLESKAPUTT");
    row.setDouble(valueID, 556.54);
    row.setDate(dateID, df.parse("2007-01-01"));

    row = dataTable.addRow();
    row.setInt(idID, 38);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "MIES");
    row.setDouble(valueID, 764.45);
    row.setDate(dateID, df.parse("2007-01-01"));

    row = dataTable.addRow();
    row.setInt(idID, 39);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "MIESER SPEZIAL");
    row.setDouble(valueID, 438.26);
    row.setDate(dateID, df.parse("2007-01-01"));

    row = dataTable.addRow();
    row.setInt(idID, 40);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "AMMIESESTEN");
    row.setDouble(valueID, 342.31);
    //row.setDate(dateID, df.parse("2007-01-01"));
    
  }

  /**
   * Tests table serialization.
   * @throws Exception In case serialization failed.
   */
  public void testSerialization() throws Exception {
    TableSerializer ts = new TableSerializer();
    ByteArrayOutputStream os = new ByteArrayOutputStream();
    ts.write(os, dataTable);
    System.out.println(os.toString());
    
    ByteArrayInputStream is = new ByteArrayInputStream(os.toByteArray());
    Table table = (Table) ts.read(is);
    
    assertEquals(dataTable.toString(), table.toString());
  }

}
