/*
 * Copyright (C) 2003 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.util.table.test;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;

import java.text.DateFormat;
import java.text.ParseException;
import java.util.Set;

import junit.framework.TestCase;

import org.ujac.util.UjacTypes;

import org.ujac.util.table.Column;
import org.ujac.util.table.ColumnAlreadyDefinedException;
import org.ujac.util.table.ColumnNotDefinedException;
import org.ujac.util.table.CompareItem;
import org.ujac.util.table.LayoutHints;
import org.ujac.util.table.OperationNotSupportedException;
import org.ujac.util.table.Row;
import org.ujac.util.table.DataTable;
import org.ujac.util.table.Table;
import org.ujac.util.table.TypeMismatchException;

import org.ujac.util.text.FormatHelper;

/**
 * Name: TableTest.java<br>
 * Description: Description of class.<br>
 * 
 * @author lauerc
 */
public class TableTest extends TestCase {
  
  /** The loop value. */
  private static final int loop = 1000;
  
  /** The data table to use. */
  private Table dataTable = null;

  /**
   * @see junit.framework.TestCase#setUp()
   */
  protected void setUp() throws Exception {

    // setting up data table
    this.dataTable = new DataTable();
    Column idCol = dataTable.addColumn("ID", UjacTypes.TYPE_INT);
    idCol.setLayoutHints(new LayoutHints(10, "ID", LayoutHints.LEFT));
    int idID = idCol.getIndex();
    Column depotCol = dataTable.addColumn("DEPOT", UjacTypes.TYPE_STRING);
    depotCol.setLayoutHints(new LayoutHints(12, "Depot", LayoutHints.LEFT));
    int depotID = depotCol.getIndex();
    Column typeCol = dataTable.addColumn("TYPE", UjacTypes.TYPE_STRING);
    typeCol.setLayoutHints(new LayoutHints(12, "Type", LayoutHints.LEFT));
    int typeID = typeCol.getIndex();
    Column nameCol = dataTable.addColumn("NAME", UjacTypes.TYPE_STRING);
    nameCol.setLayoutHints(new LayoutHints(40, "Name", LayoutHints.LEFT));
    int nameID = nameCol.getIndex();
    Column valueCol = dataTable.addColumn("VALUE", UjacTypes.TYPE_DOUBLE);
    valueCol.setLayoutHints(new LayoutHints(25, "Value", LayoutHints.RIGHT));
    int valueID = valueCol.getIndex();
    
    // filling data table
    Row row = dataTable.addRow();
    row.setInt(idID, 1);
    row.setString(depotID, "Depot 1");
    row.setString(typeID, "S");
    row.setString(nameID, "SAP");
    row.setDouble(valueID, 2725.80);

    row = dataTable.addRow();
    row.setInt(idID, 2);
    row.setString(depotID, "Depot 1");
    row.setString(typeID, "S");
    row.setString(nameID, "ZOOM TECHNLGIES");
    row.setDouble(valueID, 1235.65);

    row = dataTable.addRow();
    row.setInt(idID, 3);
    row.setString(depotID, "Depot 1");
    row.setString(typeID, "S");
    row.setString(nameID, "MICRO$OFT");
    row.setDouble(valueID, 455.33);

    row = dataTable.addRow();
    row.setInt(idID, 4);
    row.setString(depotID, "Depot 1");
    row.setString(typeID, "S");
    row.setString(nameID, "COMTECH TELCOM");
    row.setDouble(valueID, 5465.56);

    row = dataTable.addRow();
    row.setInt(idID, 5);
    row.setString(depotID, "Depot 1");
    row.setString(typeID, "S");
    row.setString(nameID, "DAIMLER CRYSLER");
    row.setDouble(valueID, 7655.23);

    row = dataTable.addRow();
    row.setInt(idID, 6);
    row.setString(depotID, "Depot 1");
    row.setString(typeID, "F");
    row.setString(nameID, "NASDAQ 100 TRUST");
    row.setDouble(valueID, 135.50);
    
    row = dataTable.addRow();
    row.setInt(idID, 7);
    row.setString(depotID, "Depot 1");
    row.setString(typeID, "F");
    row.setString(nameID, "NORDASIA.COM");
    row.setDouble(valueID, 435.23);

    row = dataTable.addRow();
    row.setInt(idID, 8);
    row.setString(depotID, "Depot 1");
    row.setString(typeID, "F");
    row.setString(nameID, "MERRILL LIIF WLD MINING A");
    row.setDouble(valueID, 1567.54);

    row = dataTable.addRow();
    row.setInt(idID, 9);
    row.setString(depotID, "Depot 1");
    row.setString(typeID, "F");
    row.setString(nameID, "SPAENGLER LIFE SCIENCE TRUST");
    row.setDouble(valueID, 545.45);
    
    row = dataTable.addRow();
    row.setInt(idID, 10);
    row.setString(depotID, "Depot 2");
    row.setString(typeID, "F");
    row.setString(nameID, "MMF (Most Miserable Fund)");
    row.setDouble(valueID, 12326.74);
   
    row = dataTable.addRow();
    row.setInt(idID, 10);
    row.setString(depotID, "Depot 3");
    row.setString(typeID, "S");
    row.setString(nameID, "REHAKLES");
    row.setDouble(valueID, 5546.74);

    row = dataTable.addRow();
    row.setInt(idID, 11);
    row.setString(depotID, "Depot 3");
    row.setString(typeID, "S");
    row.setString(nameID, "WHEELING PITTS");
    row.setDouble(valueID, 2835.21);

    row = dataTable.addRow();
    row.setInt(idID, 12);
    row.setString(depotID, "Depot 3");
    row.setString(typeID, "S");
    row.setString(nameID, "NATIONAL VISION");
    row.setDouble(valueID, 7675.12);

    row = dataTable.addRow();
    row.setInt(idID, 13);
    row.setString(depotID, "Depot 3");
    row.setString(typeID, "S");
    row.setString(nameID, "COMTECH TELCOM");
    row.setDouble(valueID, 865.23);

    row = dataTable.addRow();
    row.setInt(idID, 14);
    row.setString(depotID, "Depot 3");
    row.setString(typeID, "S");
    row.setString(nameID, "IMMUNOMEDICS");
    row.setDouble(valueID, 876.21);

    row = dataTable.addRow();
    row.setInt(idID, 15);
    row.setString(depotID, "Depot 3");
    row.setString(typeID, "S");
    row.setString(nameID, "INTEL CORP");
    row.setDouble(valueID, 673.45);
    
    row = dataTable.addRow();
    row.setInt(idID, 16);
    row.setString(depotID, "Depot 3");
    row.setString(typeID, "F");
    row.setString(nameID, "ROBOTRON");
    row.setDouble(valueID, 435.23);

    row = dataTable.addRow();
    row.setInt(idID, 17);
    row.setString(depotID, "Depot 3");
    row.setString(typeID, "F");
    row.setString(nameID, "HASTENIX");
    row.setDouble(valueID, 1567.54);

    row = dataTable.addRow();
    row.setInt(idID, 18);
    row.setString(depotID, "Depot 3");
    row.setString(typeID, "F");
    row.setString(nameID, "Vanguard Global Equity");
    row.setDouble(valueID, 425.53);

    row = dataTable.addRow();
    row.setInt(idID, 19);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "S");
    row.setString(nameID, "QUIRKS");
    row.setDouble(valueID, 3456.54);

    row = dataTable.addRow();
    row.setInt(idID, 20);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "S");
    row.setString(nameID, "ZOORO");
    row.setDouble(valueID, 455.25);

    row = dataTable.addRow();
    row.setInt(idID, 21);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "S");
    row.setString(nameID, "ROBOTRON");
    row.setDouble(valueID, 3545.37);

    row = dataTable.addRow();
    row.setInt(idID, 22);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "S");
    row.setString(nameID, "PARODENTRON");
    row.setDouble(valueID, 7567.76);

    row = dataTable.addRow();
    row.setInt(idID, 23);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "S");
    row.setString(nameID, "FORZA");
    row.setDouble(valueID, 3621.21);

    row = dataTable.addRow();
    row.setInt(idID, 24);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "S");
    row.setString(nameID, "CUPTEC");
    row.setDouble(valueID, 541.34);

    row = dataTable.addRow();
    row.setInt(idID, 25);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "ZOCKER.COM");
    row.setDouble(valueID, 521.12);
    
    row = dataTable.addRow();
    row.setInt(idID, 26);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "GAAGLI");
    row.setDouble(valueID, 5464.12);

    row = dataTable.addRow();
    row.setInt(idID, 27);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "HANSO INC");
    row.setDouble(valueID, 554.34);

    row = dataTable.addRow();
    row.setInt(idID, 28);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "LOCKER");
    row.setDouble(valueID, 145.32);

    row = dataTable.addRow();
    row.setInt(idID, 29);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "KOCKEL");
    row.setDouble(valueID, 654.24);

    row = dataTable.addRow();
    row.setInt(idID, 30);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "FARBIC");
    row.setDouble(valueID, 4564.34);

    row = dataTable.addRow();
    row.setInt(idID, 31);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "HEGON");
    row.setDouble(valueID, 235.31);

    row = dataTable.addRow();
    row.setInt(idID, 32);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "REHAKLES");
    row.setDouble(valueID, 1432.32);

    row = dataTable.addRow();
    row.setInt(idID, 33);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "PATZIKI");
    row.setDouble(valueID, 324.12);

    row = dataTable.addRow();
    row.setInt(idID, 34);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "GRINSO");
    row.setDouble(valueID, 228.53);

    row = dataTable.addRow();
    row.setInt(idID, 35);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "GONZOLES");
    row.setDouble(valueID, 458.33);

    row = dataTable.addRow();
    row.setInt(idID, 36);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "HASTENIX");
    row.setDouble(valueID, 4528.33);

    row = dataTable.addRow();
    row.setInt(idID, 37);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "ALLESKAPUTT");
    row.setDouble(valueID, 556.54);

    row = dataTable.addRow();
    row.setInt(idID, 38);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "MIES");
    row.setDouble(valueID, 764.45);

    row = dataTable.addRow();
    row.setInt(idID, 39);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "MIESER SPEZIAL");
    row.setDouble(valueID, 438.26);

    row = dataTable.addRow();
    row.setInt(idID, 40);
    row.setString(depotID, "Depot 4");
    row.setString(typeID, "F");
    row.setString(nameID, "AMMIESESTEN");
    row.setDouble(valueID, 342.31);
    
  }

  /**
   * Tests table serialization.
   * @throws Exception In case serialization failed.
   */
  public void testSerialization() throws Exception {
    ByteArrayOutputStream os = new ByteArrayOutputStream();
    ObjectOutputStream oos = new ObjectOutputStream(os);
    oos.writeObject(this.dataTable);

    ByteArrayInputStream is = new ByteArrayInputStream(os.toByteArray());
    ObjectInputStream ois = new ObjectInputStream(is);
    Table table = (Table) ois.readObject();
    assertEquals(dataTable.toString(), table.toString());
  }
  
  /**
   * Performs the insert test. 
   */
  public void testInsert() {
    long start = System.currentTimeMillis(); 
    try {
      FormatHelper formatHelper = new FormatHelper();
      DateFormat df = formatHelper.getIsoDateFormat();
      
      DataTable table = new DataTable();
      int rowID = table.addColumn("row", UjacTypes.TYPE_INT).getIndex();
      int idID = table.addColumn("id", UjacTypes.TYPE_INT).getIndex();
      int nameID = table.addColumn("name", UjacTypes.TYPE_STRING).getIndex();
      int firstNameID = table.addColumn("firstName", UjacTypes.TYPE_STRING).getIndex();
      int addressID = table.addColumn("address", UjacTypes.TYPE_STRING).getIndex();
      int zipCodeID = table.addColumn("zipCode", UjacTypes.TYPE_INT).getIndex();
      int cityID = table.addColumn("city", UjacTypes.TYPE_STRING).getIndex();
      int birthdayID = table.addColumn("birthday", UjacTypes.TYPE_DATE).getIndex();

      Row row = null;
      for (int i = 0; i < loop; i++) {
        row = table.addRow();
        row.setInt(idID, i);
        row.setInt(rowID, row.getIndex());
        row.setString(nameID, "Pan");
        row.setString(firstNameID, "Peter");
        row.setString(addressID, "Zwiebelgasse 12");
        row.setInt(zipCodeID, 12345);
        row.setString(cityID, "Wichtelhausen");
        row.setDate(birthdayID, df.parse("1971-02-20"));
      
        row = table.addRow();
        row.setInt(idID, loop + i);
        row.setInt(rowID, row.getIndex());
        row.setString(nameID, "Kunz");
        row.setString(firstNameID, "Heiner");
        row.setString(addressID, "Wurtsweg 23");
        row.setInt(zipCodeID, 12345);
        row.setString(cityID, "Wichtelhausen");
        row.setDate(birthdayID, df.parse("1964-03-24"));
      }      
      int ageID = table.addColumn("age", UjacTypes.TYPE_INT).getIndex();
      row.setInt(ageID, 39);
      //System.out.println(table.toString());
      table.sort(idID, CompareItem.ASC);
      // System.out.println(table.toString());
    } catch (OperationNotSupportedException e) {
      e.printStackTrace();
    } catch (ColumnAlreadyDefinedException e) {
      e.printStackTrace();
    } catch (ColumnNotDefinedException e) {
      e.printStackTrace();
    } catch (TypeMismatchException e) {
      e.printStackTrace();
    } catch (ParseException e) {
      e.printStackTrace();
    }
    long end = System.currentTimeMillis();
    long elapsed = end - start;
    System.out.println("Table: Needed " + elapsed + " ms for simple test");
  }

  /**
   * Performs the ismall tables test. 
   */
  public void testSmallTables() {
    FormatHelper formatHelper = new FormatHelper();
    DateFormat df = formatHelper.getIsoDateFormat();

    long start = System.currentTimeMillis(); 
    try {
      DataTable table = null;
      for (int i = 0; i < loop; i++) {
        table = new DataTable();
        table.addString("name", "Pan")
          .addString("firstName", "Peter")
          .addString("address", "Zwirbelweg 52")
          .addInt("zipCode", 12345)
          .addString("city", "M�hlental")
          .addDate("birthday", df.parse("1967-02-20"));
      }
      //System.out.println(table.toString());
    } catch (Exception e) {
      e.printStackTrace();
    }
    long end = System.currentTimeMillis();
    long elapsed = end - start;
    System.out.println("Table needed " + elapsed + " ms for small table test.");
  }

  /**
   * Tests column ordering.
   * @throws Exception In case the table processing failed.
   */
  public void testOrderColumns() throws Exception {
    this.dataTable.orderColumns(new String[] {"TYPE", "DEPOT", "ID"});

    assertEquals("TYPE", dataTable.getColumn(0).getName());
    assertEquals("ID", dataTable.getColumn(2).getName());
    
    assertEquals("S", dataTable.getString(0, 0));
    assertEquals("1", dataTable.getString(0, 2));
  }

  /**
   * Tests method getDistinctValues.
   * @throws Exception In case the table processing failed.
   */
  public void testDistinctValues() throws Exception {
    Set distinctDepots = dataTable.getDistinctValues("DEPOT");
    assertEquals(4, distinctDepots.size());

    assertTrue(distinctDepots.contains("Depot 1"));
    assertTrue(distinctDepots.contains("Depot 2"));
    assertTrue(distinctDepots.contains("Depot 3"));
    assertTrue(distinctDepots.contains("Depot 4"));
    assertFalse(distinctDepots.contains("Depot 0"));
    assertFalse(distinctDepots.contains("Depot 5"));

    Set distinctIds = dataTable.getDistinctValues("ID");
    assertEquals(40, distinctIds.size());

    Set distinctValues = dataTable.getDistinctValues("VALUE");
    assertEquals(39, distinctValues.size());

    Set distinctNames = dataTable.getDistinctValues("NAME");
    assertEquals(37, distinctNames.size());
  }

  /**
   * The main method for testing purposes.
   * @param args The command line arguments.
   */
  public static final void main(String[] args) {
    TableTest tt = new TableTest();
    try {
      tt.testSerialization();
      tt.testInsert();
      tt.testSmallTables();
    } catch (Exception ex) {
      ex.printStackTrace();
    }
  }

}
