/*
 * Copyright (C) 2005 - 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util.template;

import java.io.IOException;
import java.io.Writer;

import org.ujac.util.exi.ExpressionException;
import org.ujac.util.exi.ExpressionTuple;
import org.ujac.util.exi.Operand;

/**
 * Name: ExpressionToken<br>
 * Description: Represents an expression token.
 * 
 * @author lauerc
 */
public class ExpressionToken extends TemplateToken {
  
  /** The serial version UID. */
  private static final long serialVersionUID = 4051046354594116918L;
  
  /** The expression tuple. */
  private ExpressionTuple tuple = null;
  
  /**
   * Constructs a ElseifToken instance with specific attributes.
   * @param interpreter The template interpreter.
   * @param source The source code.
   * @param position The statement's position in the source code.
   * @param length The length of the token.
   * @param tuple The expression tuple.
   */
  public ExpressionToken(BaseTemplateInterpreter interpreter, char[] source, int position, int length, 
                         ExpressionTuple tuple) {
    super(source, position, length);
    this.interpreter = interpreter;
    this.tuple = tuple;
  }

  /**
   * Sets an argument.
   * @param argument The argument to set.
   * @param idx The argument index.
   */
  public void setArgument(Operand argument, int idx) {
  }

  /**
   * Excecutes the statement token.
   * @param writer The writer to write to.
   * @param ctx The template context.
   * @exception ExpressionException If the token could not be successfuly executed.
   * @exception IOException In case an output failure occurred.
   */
  public void execute(Writer writer, TemplateContext ctx)
    throws ExpressionException, IOException {

    String result = interpreter.evalStringExpr(tuple, ctx);
    if (result != null) {
      writer.write(result);
    }
  }

  
  /**
   * @see java.lang.Object#toString()
   */
  public String toString() {
    return getIndention() + tuple + "\n"; 
  }

  /**
   * Clones the token for caching reasons.
   * @param interpreter The interpreter to use.
   * @param parent The actual parent in the cloned object tree.
   * @return The clone.
   */
  protected TemplateToken cloneToken(BaseTemplateInterpreter interpreter, TemplateTokenContainer parent) {
    ExpressionToken clone = (ExpressionToken) clone();
    clone.interpreter = interpreter;
    clone.parent = parent;
    clone.tuple = (ExpressionTuple) this.tuple.clone();
    return clone;
  }
  
  
  /**
   * @see java.lang.Object#clone()
   */
  public Object clone() {
    try {
      return super.clone();
    } catch (CloneNotSupportedException ex) {
      throw new RuntimeException("Failed to clone template token: " + ex.getMessage(), ex);
    }
  }

}
