/*
 * Copyright (C) 2007 - 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util.template;

/**
 * Name: PageVariablesExpressionFilter<br>
 * Description: A filter for page variable expressions ${pageNumber} and ${pageCount}.
 * 
 * @author lauerc
 */
public class PageVariablesExpressionFilter implements ExpressionFilter {
  
  /**
   * Filters the expression from the given String
   * @param code The code to filter.
   * @param offset The offset to start filtering.
   * @param maxPos The max pos to seek.
   * @return -1 in case no match was found, otherwise the end of the determined static block.
   */
  public int filterExpression(char[] code, int offset, int maxPos) {
    String expression = null;
    char c;
    int depth = 0;
   scanLoop:
    for (int i = offset; i < maxPos; i++) {
      c = code[i];
      if (c == '{') {
        ++depth;
        break;
      } else if (c == '}') {
        --depth;
        if (depth == 0) {
          expression = new String(code, offset, i - offset + 1);
          break scanLoop;
        }
      }
    }
    if (expression == null) {
      return -1;
    }
    if ((expression.indexOf("${pageNumber") != -1) || 
        (expression.indexOf("${pageCount") != -1)) {
      return offset + expression.length();
    }
    return -1;
  }
  
}
