/*
 * Copyright (C) 2005 - 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util.template;

import java.io.IOException;
import java.io.Writer;

import java.util.HashMap;

import org.ujac.util.exi.Operand;

/**
 * Name: TemplateRoot<br>
 * Description: A class for root elements of the template parse tree.
 * 
 * @author lauerc
 */
public class TemplateRoot extends TemplateTokenContainer {
  
  /** The serial version UID. */
  private static final long serialVersionUID = 3761127119958259762L;

  /**
   * Constructs a TemplateRoot instance with specific attributes.
   * @param source The source code.
   * @param position The statement's position in the source code.
   * @param length The length of the token.
   * @exception TemplateException In case the initialization failed.
   */
  public TemplateRoot(char[] source, int position, int length)
    throws TemplateException {
    super();
    this.procedureRegistry = new HashMap();
    initialize(null, source, position, length);
    setBodyStart(position);
  }
  
  /**
   * Sets an argument.
   * @param argument The argument to set.
   * @param idx The argument index.
   */
  public void setArgument(Operand argument, int idx) {
  }

  /**
   * Excecutes the statement token.
   * @param writer The writer to write to.
   * @param ctx The template context.
   * @exception TemplateException If the token could not be successfuly executed.
   * @exception IOException In case an output failure occurred.
   */
  public void execute(Writer writer, TemplateContext ctx)
    throws TemplateException, IOException {

    int numTokens = getTokenCount();
    for (int i = 0; i < numTokens; i++) {
      TemplateToken subToken = getToken(i);
      subToken.execute(writer, ctx);
    }
  }

  /**
   * Clones the token for caching reasons.
   * @param interpreter The interpreter to use.
   * @param parent The actual parent in the cloned object tree.
   * @return The clone.
   */
  protected TemplateToken cloneToken(BaseTemplateInterpreter interpreter, TemplateTokenContainer parent) {
    TemplateRoot clone = (TemplateRoot) clone();
    clone.interpreter = interpreter;
    clone.parent = parent;
    clone.procedureRegistry = new HashMap();
    clone.cloneChildTokens(procedureRegistry, this);
    return clone;
  }
  
  /**
   * @see java.lang.Object#clone()
   */
  public Object clone() {
    try {
      return super.clone();
    } catch (CloneNotSupportedException ex) {
      throw new RuntimeException("Failed to clone template token: " + ex.getMessage(), ex);
    }
  }

}