/*
 * Copyright (C) 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util.template.test;

import java.io.StringWriter;

import java.util.ArrayList;
import java.util.List;


import org.ujac.util.StopWatch;

/**
 * Name: TemplateInterpreterPerformanceTest<br>
 * Description: Executes performance tests for the template interpreter.
 * 
 * @author lauerc
 */
public class PerformanceTest extends BaseTemplateTest {

  /**
   * A class for tree nodes
   */
  public static class TreeNode {
    
    /** The node name. */
    private String name = null;
    /** The child list. */
    private List childs = null;
    
    /**
     * Constructs a TreeNode instance with specific attributes.
     * @param name The name of the node.
     */
    public TreeNode(String name) {
      this.name = name;
    }
    
    /**
     * Gets the name of the node.
     * @return The name of the node.
     */
    public String getName() {
      return name;
    }
    
    /**
     * Gets the childs of the node.
     * @return The childs of the node.
     */
    public List getChilds() {
      return childs;
    }
    
    /**
     * Adds a child to the node.
     * @param child The child to add.
     */
    public void addChild(TreeNode child) {
      if (childs == null) {
        childs = new ArrayList();
      }
      childs.add(child);
    }
    
  }

  /**
   * Executes the performance test.
   */
  public void testPerformance() {
    //long start = System.currentTimeMillis(); 

    try {
      List hugeList = new ArrayList();
      for (int i = 0; i < 1000; i++) {
        hugeList.add(new Integer(i));
      }
      ctx.put("hugeList", hugeList);
      
      // building simple tree structure for recursion test
      TreeNode root = new TreeNode("root");
      TreeNode child1 = new TreeNode("child1");
      TreeNode child2 = new TreeNode("child2");
      TreeNode child3 = new TreeNode("child3");
      root.addChild(child1);
      root.addChild(child2);
      root.addChild(child3);
      child1.addChild(new TreeNode("grandChild1"));
      TreeNode grandChild2 = new TreeNode("grandChild2");
      child2.addChild(grandChild2);
      child3.addChild(new TreeNode("grandChild3"));
      grandChild2.addChild(new TreeNode("grandGrandChild2"));
      ctx.put("rootNode", root);

      // parsing statement
      StopWatch stopWatch = new StopWatch();
      for (int i = 0; i < 1000; i++) {

        //System.out.println("template parsing took " + stopWatch.meantime() + "ms");
        //System.out.println(result.toString());
        
        // executing parsed statement 
        //System.out.println("Evaluating parsed template:");
        StringWriter sw = new StringWriter();
        interpreter.execute(
            "_foreach_(number ${hugeList})" +
            "_if_(numberIdx != 0),_endif_${numberIdx}" +
            "_endfor_",
            sw, ctx
        );
        
        interpreter.execute(
          "_procedure_printItem(item, separator)" +
          "_define_(count, ${count + 1})" +
          "${item.name} #${count}\n" +
          "_if_(item.childs isDefined)" +
          "_foreach_(child ${item.childs})" +
          "${separator}_callproc_(printItem, ${child}, ${separator + ' '})" +
          "_endfor_" +
          "_endif_" +
          "_endproc_" +
          "" +
          "_define_(count, 0)" +
          "_callproc_(printItem, ${rootNode}, ' ')",
          ctx
        );
      }
      //System.out.println(sw.toString());
      System.out.println("overall template execution timg (including parse time): " + stopWatch.stop() + "ms");

    } catch (Exception ex) {
      ex.printStackTrace();
    }
    
  }
  
}
