/*
 * Copyright (C) 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util.test;

import org.ujac.util.BeanUtils;

import junit.framework.TestCase;

/**
 * Name: BeanUtilsTest<br>
 * Description: Tests for the BeanUtils class.
 * 
 * @author lauerc
 */
public class BeanUtilsTest extends TestCase {
  
  /**
   * Name: TestBean<br>
   * Description: Test beans.
   */
  public class TestBean {
    
    /** A test attribute. */
    private String name = null;

    /**
     * Constructs a TestBean instance with specific attributes.
     * @param name The initial name.
     */
    public TestBean(String name) {
      this.name = name;
    }

    /**
     * Gets the name.
     * @return The current name.
     */
    public String getName() {
      return name;
    }
    /**
     * Sets the name.
     * @param name The name to set.
     */
    public void setName(String name) {
      this.name = name;
    }
    
  }
  
  /**
   * @see junit.framework.TestCase#setUp()
   */
  protected void setUp() throws Exception {
  }
  
  /**
   * Tests the equals comparison.
   * @throws Exception In case something went wrong.
   */
  public void testEquals() throws Exception {
    assertTrue(BeanUtils.equals("test1234", "test1234"));
    assertFalse(BeanUtils.equals("Test1234", "1234"));
    assertFalse(BeanUtils.equals("Test1234", "test1234"));
  }

  /**
   * Tests the equals comparison.
   * @throws Exception In case something went wrong.
   */
  public void testEqualsCaseInsensitive() throws Exception {
    assertTrue(BeanUtils.equals("test1234", "test1234", false));
    assertFalse(BeanUtils.equals("Test1234", "1234", false));
    assertTrue(BeanUtils.equals("Test1234", "test1234", false));
  }

  /**
   * Tests the compare method.
   * @throws Exception In case something went wrong.
   */
  public void testCompare() throws Exception {
    assertTrue(BeanUtils.compare("test", "test") == 0);
    assertFalse(BeanUtils.compare("test2", "test1") < 0);
    assertFalse(BeanUtils.compare("test1", "test2") > 0);
  }

  /**
   * Tests the between comparison.
   * @throws Exception In case something went wrong.
   */
  public void testBetween() throws Exception {
    assertTrue(BeanUtils.between(new Integer(5), new Integer(1), new Integer(5)));
    assertFalse(BeanUtils.between(new Integer(5), new Integer(6), new Integer(12)));
    assertFalse(BeanUtils.between(new Integer(15), new Integer(6), new Integer(12)));
  }
  
  /**
   * Tests the getProperty method.
   * @throws Exception In case something went wrong.
   */
  public void testGetProperty() throws Exception {
    TestBean testBean = new TestBean("hallo");
    assertEquals("hallo", BeanUtils.getProperty(testBean, "name"));
  }
  
  /**
   * Tests the setProperty method.
   * @throws Exception In case something went wrong.
   */
  public void testSetProperty() throws Exception {
    TestBean testBean = new TestBean("hallo");
    BeanUtils.setProperty(testBean, "name", "internet");
    assertEquals("internet", testBean.getName());
  }

}
