/*
 * Copyright (C) 2007 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util.test;

import org.ujac.util.StringUtils;

import junit.framework.TestCase;

/**
 * Name: StringUtilsTest<br>
 * Description: Tests for the StringUtils class.
 * 
 * @author lauerc
 */
public class StringUtilsTest extends TestCase {
  
  /**
   * @see junit.framework.TestCase#setUp()
   */
  protected void setUp() throws Exception {
  }
  
  /**
   * Tests the equals comparison.
   * @throws Exception In case something went wrong.
   */
  public void testEquals() throws Exception {
    assertTrue(StringUtils.equals("test1234", "test1234"));
    assertFalse(StringUtils.equals("Test1234", "1234"));
    assertFalse(StringUtils.equals("Test1234", "test1234"));
  }

  /**
   * Tests the equals comparison.
   * @throws Exception In case something went wrong.
   */
  public void testEqualsCaseInsensitive() throws Exception {
    assertTrue(StringUtils.equals("test1234", "test1234", false));
    assertFalse(StringUtils.equals("Test1234", "1234", false));
    assertTrue(StringUtils.equals("Test1234", "test1234", false));
  }

  /**
   * Tests the like comparison.
   * @throws Exception In case something went wrong.
   */
  public void testLike() throws Exception {
    assertTrue(StringUtils.like("test1234", "%1234"));
    assertFalse(StringUtils.like("test1234", "1234"));
    assertTrue(StringUtils.like("test1234", "test%"));
    assertTrue(StringUtils.like("test1234", "%st12%"));
    assertTrue(StringUtils.like("test1234", "test1234"));
  }
  
  /**
   * Tests the like comparison.
   * @throws Exception In case something went wrong.
   */
  public void testLikeCaseInsensitive() throws Exception {
    assertFalse(StringUtils.like("testGoal", "%goal", true));
    assertTrue(StringUtils.like("testGoal", "%goal", false));
    
    assertFalse(StringUtils.like("testGoal1234", "%goal%", true));
    assertTrue(StringUtils.like("testGoal1234", "%goal%", false));

    assertFalse(StringUtils.like("test1234", "1234", false));

    assertFalse(StringUtils.like("TestGoal1234", "test%", true));
    assertTrue(StringUtils.like("TestGoal1234", "test%", false));

    assertFalse(StringUtils.like("TestGoal1234", "%STGO%", true));
    assertTrue(StringUtils.like("TestGoal1234", "%STGO%", false));

    assertFalse(StringUtils.like("TestGoal1234", "testGoal1234", true));
    assertTrue(StringUtils.like("TestGoal1234", "testGoal1234", false));
  }

  /**
   * Tests the trimHead() method.
   * @throws Exception In case something went wrong.
   */
  public void testTrimHead() throws Exception {
    assertEquals("test 1 2 3 4   ", StringUtils.trimHead(" test 1 2 3 4   "));

    assertEquals("test 1 2 3 4   ", StringUtils.trimHead("test 1 2 3 4   "));
  }

  /**
   * Tests the trimTail() method.
   * @throws Exception In case something went wrong.
   */
  public void testTrimTail() throws Exception {
    assertEquals(" test 1 2 3 4", StringUtils.trimTail(" test 1 2 3 4   "));

    assertEquals("  test 1 2 3 4", StringUtils.trimTail("  test 1 2 3 4"));
  }

}
