/*
 * Copyright (C) 2003, 2004, 2005  by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util.text.test;

import java.math.BigDecimal;

import java.text.DecimalFormatSymbols;
import java.text.NumberFormat;
import java.text.ParseException;

import java.util.Locale;

import org.ujac.util.text.BigDecimalFormat;

import junit.framework.TestCase;

/**
 * Name: BigDecimalFormatTest<br>
 * Description: Test cases for the BigDecimalFormat class.
 * 
 * @author lauerc
 */
public class BigDecimalFormatTest extends TestCase {

  /** The german floating point format to test. */
  private NumberFormat decNumberFormatDE = null;
  /** The german integer format to test. */
  private NumberFormat intNumberFormatDE = null;
  /** The US floating point format to test. */
  private NumberFormat decNumberFormatUS = null;
  /** The US integer format to test. */
  private NumberFormat intNumberFormatUS = null;
  
  /**
   * @see junit.framework.TestCase#setUp()
   */
  protected void setUp() throws Exception {
    this.decNumberFormatDE = new BigDecimalFormat("###,###.00", new DecimalFormatSymbols(Locale.GERMANY), BigDecimal.ROUND_HALF_UP);
    this.intNumberFormatDE = new BigDecimalFormat("###,###", new DecimalFormatSymbols(Locale.GERMANY), BigDecimal.ROUND_HALF_UP);
    this.decNumberFormatUS = new BigDecimalFormat("###,###.00", new DecimalFormatSymbols(Locale.US), BigDecimal.ROUND_HALF_UP);
    this.intNumberFormatUS = new BigDecimalFormat("###,###", new DecimalFormatSymbols(Locale.US), BigDecimal.ROUND_HALF_UP);
  }
  
  /**
   * Tests parsing of numbers.
   * @throws ParseException In case the parsing failed.
   */
  public void testParse() throws ParseException {
    Number number = decNumberFormatUS.parse("2500");
    assertEquals(number, new Long(2500));
    
    number = decNumberFormatDE.parse("2500");
    assertEquals(number, new Long(2500));
    
    number = decNumberFormatUS.parse("2500.121");
    assertEquals(number, new Double(2500.121));

    number = decNumberFormatDE.parse("2500,121");
    assertEquals(number, new Double(2500.121));
  }

  /**
   * Tests formatting of numbers.
   */
  public void testFormat() {
    String strNumber = decNumberFormatUS.format(2500);
    assertEquals(strNumber, "2,500.00");
    
    strNumber = decNumberFormatDE.format(2500);
    assertEquals(strNumber, "2.500,00");
    
    strNumber = decNumberFormatUS.format(2500.121);
    assertEquals(strNumber, "2,500.12");

    strNumber = decNumberFormatDE.format(2500.125);
    assertEquals(strNumber, "2.500,13");
  }
  
  /**
   * Tests correct rounding of numbers.
   */
  public void testRound() {
    double number = 2500.0 / 1000.0;
    String strNumber = decNumberFormatUS.format(number);
    assertEquals(strNumber, "2.50");
    
    strNumber = intNumberFormatUS.format(2500.0 / 1000.0);
    assertEquals(strNumber, "3");
    
    strNumber = intNumberFormatDE.format(2500.10 / 1000.0);
    assertEquals(strNumber, "3");
    
    strNumber = intNumberFormatDE.format(2499.99 / 1000.0);
    assertEquals(strNumber, "2");
  }

  /**
   * Tests output of invalid numbers.
   */
  public void testNaN() {
    double number = Double.NaN;
    String strNumber = decNumberFormatUS.format(number);
    System.out.println(number + " --> '" + strNumber + "'");
    //assertEquals(strNumber, "�");

    number = Double.POSITIVE_INFINITY;
    strNumber = decNumberFormatUS.format(number);
    System.out.println(number + " --> '" + strNumber + "'");
    //assertEquals(strNumber, "∞");
  }
}
