/*
 * Copyright (C) 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util.types;

import java.sql.Time;

import java.text.ParseException;

import java.util.Date;

import org.ujac.util.TypeConverterException;
import org.ujac.util.UjacTypes;
import org.ujac.util.text.FormatHelper;

/**
 * Name: TimeType<br>
 * Description: A class handling Time values.
 * 
 * @author lauerc
 */
public class TimeType implements DataType {

  /**
   * @see org.ujac.util.types.DataType#getTypeId()
   */
  public int getTypeId() {
    return UjacTypes.TYPE_TIME;
  }

  /**
   * @see org.ujac.util.types.DataType#convertObject(java.lang.Object, org.ujac.util.text.FormatHelper)
   */
  public Object convertObject(Object value, FormatHelper formatHelper) throws TypeConverterException {
    if (value == null) {
      return null;
    }
    if (value instanceof Time) {
      return value;
    }
    String strVal = value.toString();
    try {
      return formatHelper.getIsoTimeFormat().parse(strVal);
    } catch (ParseException ex) {
      throw new TypeConverterException("Failed to parse Time value out of given value '" + strVal + "'.", ex);
    }
  }
  
  /**
   * @see org.ujac.util.types.DataType#formatValue(java.lang.Object, org.ujac.util.text.FormatHelper)
   */
  public String formatValue(Object value, FormatHelper formatHelper)  throws TypeConverterException {
    return formatHelper.getIsoDateFormat().format((Date) convertObject(value, formatHelper));
  }
  
}
