/*
 * Copyright (C) 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util.xml;

import java.io.Serializable;
import java.lang.reflect.Method;
import org.ujac.util.BeanUtils;

/**
 * Name: AttributeDefinition<br>
 * Description: Definition of bean attributes.
 * 
 * @author lauerc
 */
public class AttributeDefinition implements Serializable, Comparable {
  
  /** The serial version UID.  */
  private static final long serialVersionUID = -2205243147086583100L;
  
  /** The attribute name. */
  private String name = null;
  /** The attribute type. */
  private Class type = null;
  /** The getter method. */
  private Method getter = null;
  /** The setter method. */
  private Method setter = null;

  /**
   * Constructs a AttributeDefinition instance with specific attributes.
   * @param name The attribute name.
   * @param type The attribute type.
   */
  public AttributeDefinition(String name, Class type) {
    this.name = name;
    this.type = type;
  }

  /**
   * Getter method for the the property name.
   * @return The current value of property name.
   */
  public String getName() {
    return name;
  }

  /**
   * Getter method for the the property type.
   * @return The current value of property type.
   */
  public Class getType() {
    return type;
  }

  /**
   * Getter method for the the property getter.
   * @return The current value of property getter.
   */
  public Method getGetter() {
    return getter;
  }
  /**
   * Setter method for the the property getter.
   * @param getter The value to set for the property getter.
   */
  public void setGetter(Method getter) {
    this.getter = getter;
  }

  /**
   * Getter method for the the property setter.
   * @return The current value of property setter.
   */
  public Method getSetter() {
    return setter;
  }

  /**
   * Setter method for the the property setter.
   * @param setter The value to set for the property setter.
   */
  public void setSetter(Method setter) {
    this.setter = setter;
  }

  /**
   * Compares this instanct with the given one.
   * @param arg The object to compare to.
   * @return 0 if the objects equal, -1 if this object is lower, else 1.
   */
  public int compareTo(Object arg) {
    AttributeDefinition other = (AttributeDefinition) arg;
    return BeanUtils.compare(name, other.name);
  }
  
  /**
   * @see java.lang.Object#toString()
   */
  public String toString() {
    return "{name='" + name + "', clazz=" + type + "}";
  }
  
}
