/*
 * Copyright (C) 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.util.xml.test;

import java.io.Serializable;
import org.ujac.util.BeanUtils;

/**
 * Name: Address<br>
 * Description: Defines addresses.
 * 
 * @author lauerc
 */
public class Address implements Serializable {

  /** The serial version UID. */
  private static final long serialVersionUID = 3035235195366283576L;
  
  /** The address. */
  private String address = null;
  /** The zip code. */
  private Integer zipCode = null;
  /** The city. */
  private String city = null;
  /** The country. */
  private String country = null;

  /**
   * Constructs a Address instance with specific attributes.
   */
  public Address() {
  }

  /**
   * Constructs a Address instance with specific attributes.
   * @param address The initial address.
   * @param zipCode The initial zip code.
   * @param city The initial city.
   * @param country The initial country.
   */
  public Address(String address, Integer zipCode, String city, String country) {
    super();
    this.address = address;
    this.zipCode = zipCode;
    this.city = city;
    this.country = country;
  }
  
  /**
   * Getter method for the the property address.
   * @return The current value of property address.
   */
  public String getAddress() {
    return address;
  }
  /**
   * Setter method for the the property address.
   * @param address The value to set for the property address.
   */
  public void setAddress(String address) {
    this.address = address;
  }
  
  /**
   * Getter method for the the property city.
   * @return The current value of property city.
   */
  public String getCity() {
    return city;
  }
  /**
   * Setter method for the the property city.
   * @param city The value to set for the property city.
   */
  public void setCity(String city) {
    this.city = city;
  }
  
  /**
   * Getter method for the the property country.
   * @return The current value of property country.
   */
  public String getCountry() {
    return country;
  }
  /**
   * Setter method for the the property country.
   * @param country The value to set for the property country.
   */
  public void setCountry(String country) {
    this.country = country;
  }
  
  /**
   * Getter method for the the property zipCode.
   * @return The current value of property zipCode.
   */
  public Integer getZipCode() {
    return zipCode;
  }
  /**
   * Setter method for the the property zipCode.
   * @param zipCode The value to set for the property zipCode.
   */
  public void setZipCode(Integer zipCode) {
    this.zipCode = zipCode;
  }
  
  /**
   * @see java.lang.Object#equals(java.lang.Object)
   */
  public boolean equals(Object obj) {
    if (!(obj instanceof Address)) {
      return false;
    }
    Address other = (Address) obj;
    return BeanUtils.equals(address, other.address) &&
        BeanUtils.equals(zipCode, other.zipCode) &&
        BeanUtils.equals(city, other.city) &&
        BeanUtils.equals(country, other.country);
  }
  
  /**
   * @see java.lang.Object#toString()
   */
  public String toString() {
    return "{address='" + address + "', zipCode=" + zipCode +
      ", city='" + city + "', country='" + country + "'}";
  }
  
}
