/*
 * Copyright (C) 2003, 2004, 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.web.tag;

import java.io.IOException;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.PageContext;

import javax.servlet.jsp.tagext.BodyContent;
import javax.servlet.jsp.tagext.BodyTagSupport;


import org.ujac.util.exi.ExpressionException;
import org.ujac.util.template.TemplateContext;
import org.ujac.util.template.TemplateInterpreter;

import org.ujac.web.servlet.TemplateContextHolder;
import org.ujac.web.servlet.TemplateInterpreterHelper;

/**
 * Name: BaseConditionTag<br>
 * Description: Base condition tag implementation.
 * 
 * @author lauerc
 */
public abstract class BaseConditionTag extends BodyTagSupport implements TemplateContextHolder {

  /** The template context. */
  private TemplateContext templateContext = null;
  
  /**
   * Evaluates the condition.
   * @return true in case the body shall be processed, else false.
   * @exception JspException In case something went wrong.
   */
  protected abstract boolean evalCondition() throws JspException;
  
  /**
   * @see javax.servlet.jsp.tagext.Tag#doStartTag()
   */
  public int doStartTag() throws JspException {
    super.doStartTag();

    this.templateContext = null;
    boolean result = evalCondition();
    
    if (result) {
      return EVAL_BODY_BUFFERED;
    }
    return SKIP_BODY;
  }
  
  /**
   * @see javax.servlet.jsp.tagext.IterationTag#doAfterBody()
   */
  public int doAfterBody() throws JspException {
   
    BodyContent bc = this.bodyContent;
    String body = bc.getString();
    try {
      TemplateInterpreter interpreter = TemplateInterpreterHelper.getTemplateInterpreter(pageContext);
      TemplateContext ectx = getTemplateContext();
      interpreter.execute(body, getPreviousOut(), ectx);
    } catch (ExpressionException e) {
      throw new JspException("Error in expression while evaluating body: " + e.getMessage());
    } catch (IOException e) {
      e.printStackTrace();
      throw new JspException("I/O error while evaluating body: " + e.getMessage());
    } catch (Throwable e) {
      e.printStackTrace();
      throw new JspException("Error while evaluating body: " + e.getMessage());
    }
    return EVAL_PAGE;
  }
  
  /**
   * @see javax.servlet.jsp.tagext.BodyTagSupport#doEndTag()
   */
  public int doEndTag() throws JspException {
    return EVAL_PAGE;
  }
  
  /**
   * @see javax.servlet.jsp.tagext.BodyTagSupport#release()
   */
  public void release() {
    super.release();
    templateContext = null;
  }
  
  /**
   * Gets the template context.
   * @return The associated template context.
   */
  public TemplateContext getTemplateContext() {
    if (templateContext != null) {
      return templateContext;
    }
    return TemplateInterpreterHelper.getTemplateContext(pageContext, this);
  }
  /**
   * Sets an attribute, both in template context and request.
   * @param key The attribute key.
   * @param value The attribute value to set.
   * @return The old value.
   */
  public Object setAttribute(String key, Object value) {
    TemplateContext ctx = getTemplateContext();
    if ((key == null) || (value == null)) {
      return null;
    }
    Object oldValue = ctx.setProperty(key, value);
    pageContext.setAttribute(key, value, PageContext.REQUEST_SCOPE);
    return oldValue;
  }

}
