/*
 * Copyright (C) 2007 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.web.tag;

import java.io.Serializable;

/**
 * Name: CellData<br>
 * Description: Holds cell data.<br>.
 * 
 * @author lauerc
 */
public class CellData implements Serializable {

  /** The serial version UID. */
  private static final long serialVersionUID = 4684812449699074143L;
  
  /** The column  name. */
  private String name = null;
  /** The contents. */
  private Object contents = null;
  /** The colspan. */
  private int colspan = 0;
  /** The style. */
  private String style = null;
  /** The cell width. */
  private String width = null;
  /** The cell height. */
  private String height = null;
  /** The horizontal alignment. */
  private String halign = null;
  /** The vertical alignment. */
  private String valign = null;
  /** The left padding. */
  private int paddingLeft = 0;
  /** The right padding. */
  private int paddingRight = 0;
  /** The top padding. */
  private int paddingTop = 0;
  /** The bottom padding. */
  private int paddingBottom = 0;
  /** The visible flag. */
  private boolean visible = true;
  
  /**
   * Constructs a CellData instance with no specific attributes.
   */
  public CellData() {
  }
  
  /**
   * Constructs a CellData instance with specific attributes.
   * @param name The column name.
   * @param contents The initial contents.
   * @param colspan The initial colspan.
   */
  public CellData(String name, Object contents, int colspan) {
    this.name = name;
    this.contents = contents;
    this.colspan = colspan;
  }

  /**
   * Getter method for the the property name.
   * @return The current value of property name.
   */
  public String getName() {
    return name;
  }
  /**
   * Setter method for the the property name.
   * @param name The value to set for the property name.
   */
  public void setName(String name) {
    this.name = name;
  }
  
  /**
   * Getter method for the the property colspan.
   * @return The current value of property colspan.
   */
  public int getColspan() {
    return colspan;
  }
  /**
   * Setter method for the the property colspan.
   * @param colspan The value to set for the property colspan.
   */
  public void setColspan(int colspan) {
    this.colspan = colspan;
  }
  
  /**
   * Getter method for the the property contents.
   * @return The current value of property contents.
   */
  public Object getContents() {
    return contents;
  }
  /**
   * Setter method for the the property contents.
   * @param contents The value to set for the property contents.
   */
  public void setContents(Object contents) {
    this.contents = contents;
  }
  
  /**
   * Getter method for the the property style.
   * @return The current value of property style.
   */
  public String getStyle() {
    return style;
  }
  /**
   * Setter method for the the property style.
   * @param style The value to set for the property style.
   */
  public void setStyle(String style) {
    this.style = style;
  }

  /**
   * Getter method for the the property width.
   * @return The current value of property width.
   */
  public String getWidth() {
    return width;
  }
  /**
   * Setter method for the the property width.
   * @param width The value to set for the property width.
   */
  public void setWidth(String width) {
    this.width = width;
  }

  /**
   * Getter method for the the property height.
   * @return The current value of property height.
   */
  public String getHeight() {
    return height;
  }
  /**
   * Setter method for the the property height.
   * @param height The value to set for the property height.
   */
  public void setHeight(String height) {
    this.height = height;
  }

  /**
   * Getter method for the the property halign.
   * @return The current value of property halign.
   */
  public String getHalign() {
    return halign;
  }
  /**
   * Setter method for the the property halign.
   * @param halign The value to set for the property halign.
   */
  public void setHalign(String halign) {
    this.halign = halign;
  }

  /**
   * Getter method for the the property valign.
   * @return The current value of property valign.
   */
  public String getValign() {
    return valign;
  }
  /**
   * Setter method for the the property valign.
   * @param valign The value to set for the property valign.
   */
  public void setValign(String valign) {
    this.valign = valign;
  }

  /**
   * Getter method for the the property paddingLeft.
   * @return The current value of property paddingLeft.
   */
  public int getPaddingLeft() {
    return paddingLeft;
  }
  /**
   * Setter method for the the property paddingLeft.
   * @param paddingLeft The value to set for the property paddingLeft.
   */
  public void setPaddingLeft(int paddingLeft) {
    this.paddingLeft = paddingLeft;
  }
  
  /**
   * Getter method for the the property paddingRight.
   * @return The current value of property paddingRight.
   */
  public int getPaddingRight() {
    return paddingRight;
  }
  /**
   * Setter method for the the property paddingRight.
   * @param paddingRight The value to set for the property paddingRight.
   */
  public void setPaddingRight(int paddingRight) {
    this.paddingRight = paddingRight;
  }
  
  /**
   * Getter method for the the property paddingTop.
   * @return The current value of property paddingTop.
   */
  public int getPaddingTop() {
    return paddingTop;
  }
  /**
   * Setter method for the the property paddingTop.
   * @param paddingTop The value to set for the property paddingTop.
   */
  public void setPaddingTop(int paddingTop) {
    this.paddingTop = paddingTop;
  }
  
  /**
   * Getter method for the the property paddingBottom.
   * @return The current value of property paddingBottom.
   */
  public int getPaddingBottom() {
    return paddingBottom;
  }
 /**
   * Setter method for the the property paddingBottom.
   * @param paddingBottom The value to set for the property paddingBottom.
   */
  public void setPaddingBottom(int paddingBottom) {
    this.paddingBottom = paddingBottom;
  }

  /**
   * Getter method for the the property visible.
   * @return The current value of property visible.
   */
  public boolean isVisible() {
    return visible;
  }
  /**
   * Setter method for the the property visible.
   * @param visible The value to set for the property visible.
   */
  public void setVisible(boolean visible) {
    this.visible = visible;
  }

}
