/*
 * Copyright (C) 2003, 2004, 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.web.tag;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.PageContext;

/**
 * Name: IfTag<br>
 * Description: A custom tag class implementing the tag &lt;ujac:else&gt;.<br>
 * 
 * @author lauerc
 */
public class ElseTag extends BaseConditionTag {

  /** The serial version UID. */
  private static final long serialVersionUID = 4121134731812418102L;

  /**
   * Evaluates the condition.
   * @return true in case the body shall be processed, else false.
   * @exception JspException In case something went wrong.
   */
  protected boolean evalCondition() throws JspException {

    // Gets the expression interpreter.
    Boolean previousIfResult = (Boolean) pageContext.getAttribute(IfTag.RESULT_ATTRIBUTE, PageContext.PAGE_SCOPE);
    if (previousIfResult == null) {
      throw new JspException("<else> tag must follow an <if> tag!");
    }
    
    return !previousIfResult.booleanValue();
  }
  
  /**
   * Resets the custom tag values.
   */
  public void release() {
    super.release();
  }
  
}
