/*
 * Copyright (C) 2003 - 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.web.tag;

import javax.servlet.jsp.JspException;

import javax.servlet.jsp.tagext.BodyContent;
import javax.servlet.jsp.tagext.Tag;

/**
 * Name: ExtraRowTag<br>
 * Description: Implementation of the &lt;extra-row&gt; tag.
 * 
 * @author lauerc
 */
public class ExtraRowTag extends BaseTag implements RowCellContainer {

  /** The serial version UID. */
  private static final long serialVersionUID = 3257003276385202998L;

  /** The surrounding print-table tag. */
  protected PrintTableTag rowContainer = null;
  /** The surrounding print-row tag. */
  protected PrintRowTag printRowTag = null;

  /** The insert direction. */ 
  private String strDirection = null;
  /** The general style class. */
  private String style = null;
  /** The style class for even rows. */
  private String evenStyle = null;
  /** The style class for odd rows. */
  private String oddStyle = null;
  /** The row height. */
  private String height = null;
  /** The vertical alignment. */
  private String valign = null;
  /** The left padding. */ 
  private float paddingLeft = -1.0F;
  /** The right padding. */ 
  private float paddingRight = -1.0F;
  /** The top padding. */ 
  private float paddingTop = -1.0F;
  /** The bottom padding. */ 
  private float paddingBottom = -1.0F;
  
  /** The registered row cells. */
  protected RowCellHolder[] registeredRowCells = null;
  /** The skip flag. */
  private boolean skipped = false;

  /**
   * The insert direction ('before', 'after').
   * @param direction The insert direction to set.
   */
  public void setDirection(String direction) {
    this.strDirection = direction;
  }

  /**
   * Getter method for the the property style.
   * @return The current value of property style.
   */
  public String getStyle() {
    return style;
  }
  /**
   * Setter method for the the property style.
   * @param style The value to set for the property style.
   */
  public void setStyle(String style) {
    this.style = style;
  }

  /**
   * Getter method for the the property evenStyle.
   * @return The current value of property evenStyle.
   */
  public String getEvenStyle() {
    return evenStyle;
  }
  /**
   * Setter method for the the property evenStyle.
   * @param evenStyle The value to set for the property evenStyle.
   */
  public void setEvenStyle(String evenStyle) {
    this.evenStyle = evenStyle;
  }

  /**
   * Getter method for the the property oddStyle.
   * @return The current value of property oddStyle.
   */
  public String getOddStyle() {
    return oddStyle;
  }
  /**
   * Setter method for the the property oddStyle.
   * @param oddStyle The value to set for the property oddStyle.
   */
  public void setOddStyle(String oddStyle) {
    this.oddStyle = oddStyle;
  }

  /**
   * Getter method for the the property height.
   * @return The current value of property height.
   */
  public String getHeight() {
    return height;
  }
  /**
   * Setter method for the the property height.
   * @param height The value to set for the property height.
   */
  public void setHeight(String height) {
    this.height = height;
  }

  /**
   * Getter method for the the property valign.
   * @return The current value of property valign.
   */
  public String getValign() {
    return valign;
  }
  /**
   * Setter method for the the property valign.
   * @param valign The value to set for the property valign.
   */
  public void setValign(String valign) {
    this.valign = valign;
  }
  
  /**
   * Getter method for the the property paddingLeft.
   * @return The current value of property paddingLeft.
   */
  public float getPaddingLeft() {
    return paddingLeft;
  }
  /**
   * Setter method for the the property paddingLeft.
   * @param paddingLeft The value to set for the property paddingLeft.
   */
  public void setPaddingLeft(float paddingLeft) {
    this.paddingLeft = paddingLeft;
  }

  /**
   * Getter method for the the property paddingRight.
   * @return The current value of property paddingRight.
   */
  public float getPaddingRight() {
    return paddingRight;
  }
  /**
   * Setter method for the the property paddingRight.
   * @param paddingRight The value to set for the property paddingRight.
   */
  public void setPaddingRight(float paddingRight) {
    this.paddingRight = paddingRight;
  }

  /**
   * Getter method for the the property paddingTop.
   * @return The current value of property paddingTop.
   */
  public float getPaddingTop() {
    return paddingTop;
  }
  /**
   * Setter method for the the property paddingTop.
   * @param paddingTop The value to set for the property paddingTop.
   */
  public void setPaddingTop(float paddingTop) {
    this.paddingTop = paddingTop;
  }

  /**
   * Getter method for the the property paddingBottom.
   * @return The current value of property paddingBottom.
   */
  public float getPaddingBottom() {
    return paddingBottom;
  }
  /**
   * Setter method for the the property paddingBottom.
   * @param paddingBottom The value to set for the property paddingBottom.
   */
  public void setPaddingBottom(float paddingBottom) {
    this.paddingBottom = paddingBottom;
  }

  /**
   * Registers the given row cell with the print row tag.
   * @param rowCell The row cell to register.
   */
  public void registerRowCell(RowCellHolder rowCell) {
    int index = rowCell.getColumnIndex();
    if (index < 0) {
      index = this.rowContainer.getColumnIndex(rowCell.getColumnName());
    }
    this.registeredRowCells[index] = rowCell;
  }
  
  /**
   * Getter method for the the property skipped.
   * @return The current value of property skipped.
   */
  protected boolean isSkipped() {
    return skipped;
  }
  /**
   * Setter method for the the property skipped.
   * @param skipped The value to set for the property skipped.
   */
  protected void setSkipped(boolean skipped) {
    this.skipped = skipped;
  }

  /**
   * Produces a td/th tag attribute list according to the given attributes.
   * @param styleClass The style class.
   * @param width The field width.
   * @param height The field height.
   * @param hAlign The horizontal alignment.
   * @param vAlign The vertical alignment.
   * @param colspan The column span.
   * @return The generated attribute list string.
   */
  protected String getCellAttributes(String styleClass, String width, String height, 
                                     String hAlign, String vAlign, int colspan) {
    boolean stylesDefined = false;
    StringBuffer styleBuffer = new StringBuffer(" style=\"");
    StringBuffer attributesBuffer = new StringBuffer();
    if (styleClass != null) {
      attributesBuffer.append(" class=\"" + styleClass + "\"");
    }
    if (hAlign != null) {
      stylesDefined = true;
      styleBuffer.append("text-align:" + hAlign + ";");
      attributesBuffer.append(" align=\"" + hAlign + "\"");
    }
    if (vAlign != null) {
      stylesDefined = true;
      styleBuffer.append("vertical-align:" + vAlign + ";");
      attributesBuffer.append(" valign=\"" + vAlign + "\"");
    }
    if (width != null) {
      stylesDefined = true;
      styleBuffer.append("width:" + width);
      if (!width.endsWith("%")) {
        styleBuffer.append("px");
      }
      styleBuffer.append(";");
      attributesBuffer.append(" width=\"" + width + "\"");
    }
    if (height != null) {
      stylesDefined = true;
      styleBuffer.append("height:" + height);
      if (!height.endsWith("%")) {
        styleBuffer.append("px");
      }
      styleBuffer.append(";");
      attributesBuffer.append(" height=\"" + height + "\"");
    }
    if (colspan > 1) {
      attributesBuffer.append(" colspan=\"" + colspan + "\"");
    }
    styleBuffer.append("\"");
    if (stylesDefined) {
      attributesBuffer.append(styleBuffer.toString());
    }
    return attributesBuffer.toString();
  }
  
  /**
   * @see javax.servlet.jsp.tagext.BodyTagSupport#doStartTag()
   */
  public int doStartTag() throws JspException {
    this.printRowTag = lookupPrintRowTag();
    this.rowContainer = printRowTag.getRowContainer();
//    Row row = rowContainer.getCurrentRow();
//    if (!row.getType().equals(TableConstants.ROW_TYPE_)) {
//      registeredRowCells = new RowCellHolder[rowContainer.getNumColumns()];
//      setSkipped(true);
//      return SKIP_BODY;
//    }
    registeredRowCells = new RowCellHolder[rowContainer.getNumColumns()];
    printTagStart();
    return EVAL_BODY_INCLUDE;
  }

  /**
   * Prints the tag start code.
   */
  protected void printTagStart() {
    setSkipped(false);
  }
  
  /**
   * @see javax.servlet.jsp.tagext.BodyTagSupport#doEndTag()
   */
  public int doEndTag() throws JspException {
    try {
      BodyContent bc = this.bodyContent;
      if (bc != null) {
        bc.clearBody();
      }
      
      int direction = PrintTableTag.DIRECTION_AFTER;
      if ("before".equals(strDirection)) {
        direction = PrintTableTag.DIRECTION_BEFORE;
      }

      printRowTag.insertExtraRow(new ExtraRowHolder(
        rowContainer,
        registeredRowCells,
        style,
        height,
        valign,
        paddingLeft,
        paddingRight,
        paddingTop,
        paddingBottom
      ), direction);
    } catch (ClassCastException ex) {
      throw new JspException("Parent tag of row-cell tag has to be print-row tag.");
    }
    return EVAL_PAGE;
  }
  /**
   * @see javax.servlet.jsp.tagext.BodyTagSupport#release()
   */
  public void release() {
    super.release();
    this.strDirection = null;
    this.evenStyle = "even";
    this.oddStyle = "odd";
    this.valign= null;
    this.paddingLeft = 0.0f;
    this.paddingRight = 0.0f;
    this.paddingTop = 0.0f;
    this.paddingBottom = 0.0f;
    this.registeredRowCells = null;
    this.skipped = false;
  }

  /**
   * Gets the latest PrintRowTag from the tag stack.
   * @return The latest PrintRowTag from the tag stack or null.
   */
  protected PrintRowTag lookupPrintRowTag() {
    Tag parent = getParent(PrintRowTag.class);
    return (PrintRowTag) parent;
  }

}
