/*
 * Copyright (C) 2003, 2004, 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */

package org.ujac.web.tag;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.PageContext;

import org.ujac.util.exi.ExpressionException;

import org.ujac.util.template.TemplateContext;
import org.ujac.util.template.TemplateInterpreter;

import org.ujac.web.servlet.TemplateInterpreterHelper;

/**
 * Name: IfTag<br>
 * Description: A custom tag class implementing the tag &lt;ujac:if&gt;.<br>
 * 
 * @author lauerc
 */
public class IfTag extends BaseConditionTag {

  /** The serial version UID. */
  private static final long serialVersionUID = 3256440292037965106L;

  /** The result attribute name. */
  public static final String RESULT_ATTRIBUTE = "ujac-if-result";
  
  /**
   * The condition to evaluate.
   */
  private String cond = null;
  /**
   * The result of the condition evaluation.
   */
  private boolean result = false;
  
  /**
   * Gets the condition to evaluate.
   * @param cond The condition to set.
   */
  public void setCond(String cond) {
    this.cond = cond;
  }

  /**
   * Gets the evaluation result.
   * @return The evaluation result.
   */
  public boolean getResult() {
    return result;
  }

  /**
   * Evaluates the condition.
   * @return true in case the body shall be processed, else false.
   * @exception JspException In case something went wrong.
   */
  protected boolean evalCondition() throws JspException {

    PageContext ctx = this.pageContext;
    TemplateInterpreter interpreter = TemplateInterpreterHelper.getTemplateInterpreter(ctx);
    TemplateContext templateCtx = getTemplateContext();
    try {
      this.result = interpreter.evalBooleanExpr(cond, templateCtx);
    } catch (ExpressionException ex) {
      throw new JspException("Condition evaluation failed: " + ex.getMessage(), ex);
    }
    
    return result;
  }

  /**
   * @see javax.servlet.jsp.tagext.Tag#doEndTag()
   */
  public int doEndTag() throws JspException {
    int rs = super.doEndTag();
    // setting result attribute for else tag
    pageContext.setAttribute(RESULT_ATTRIBUTE, new Boolean(result));
    return rs;
  }

  /**
   * Resets the custom tag values.
   */
  public void release() {
    super.release();
    this.cond = null;
    this.result = false;
  }

}
