/*
 * Copyright (C) 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.web.tag;

import java.io.Serializable;

/**
 * Name: MarkupAttribute<br>
 * Description: A class defining markup attributes.
 * 
 * @author lauerc
 */
public class MarkupAttribute implements Serializable {
  
  /** The serial version UID. */
  private static final long serialVersionUID = 9171893433924457903L;
  
  /** The attribute name. */
  private String name = null;
  /** The attribute value. */
  private String value = null;
  
  /**
   * Constructs a MarkupAttribute instance with specific attributes.
   */
  public MarkupAttribute() {
  }

  /**
   * Constructs a MarkupAttribute instance with specific attributes.
   * @param name The initial name.
   * @param value The initial value.
   */
  public MarkupAttribute(String name, String value) {
    this.name = name;
    this.value = value;
  }

  /**
   * Getter method for the the property name.
   * @return The current value of property name.
   */
  public String getName() {
    return name;
  }
  /**
   * Setter method for the the property name.
   * @param name The value to set for the property name.
   */
  public void setName(String name) {
    this.name = name;
  }

  /**
   * Getter method for the the property value.
   * @return The current value of property value.
   */
  public String getValue() {
    return value;
  }
  /**
   * Setter method for the the property value.
   * @param value The value to set for the property value.
   */
  public void setValue(String value) {
    this.value = value;
  }

  /**
   * @see java.lang.Object#toString()
   */
  public String toString() {
    return "{name=" + name + ", value=" + value + "}";
  }
  
}
