/*
 * Copyright (C) 2003 - 2008 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.web.tag;

import java.io.IOException;

import java.util.ArrayList;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspWriter;

import javax.servlet.jsp.tagext.Tag;

import org.ujac.util.BeanUtils;
import org.ujac.util.StringUtils;

import org.ujac.util.table.Column;
import org.ujac.util.table.LayoutHints;
import org.ujac.util.table.Row;
import org.ujac.util.table.TableConstants;
import org.ujac.util.table.TableException;

/**
 * Name: PrintRowTag<br>
 * Description: A custom tag class printing normal rows.
 * 
 * @author lauerc
 */
public class PrintRowTag extends BaseTag implements RowCellContainer {

  /** The serial version UID. */
  private static final long serialVersionUID = 3258413945357220153L;

  /** The surrounding print-table tag. */
  protected PrintTableTag rowContainer = null;
  
  /** The general style class. */
  private String style = null;
  /** The style class for even rows. */
  private String evenStyle = null;
  /** The style class for odd rows. */
  private String oddStyle = null;
  /** The row height. */
  private String height = null;
  /** The vertical alignment. */
  private String valign = null;
  /** The left padding. */ 
  private float paddingLeft = -1.0F;
  /** The right padding. */ 
  private float paddingRight = -1.0F;
  /** The top padding. */ 
  private float paddingTop = -1.0F;
  /** The bottom padding. */ 
  private float paddingBottom = -1.0F;

  /** The current style class. */
  private String currentStyle = null;

  /** The cell style item map. */
  protected RowCellHolder[] registeredRowCells = null;
  /** The skip flag. */
  private boolean skipped = false;
  
  /** The extra rows to print before the data row. */
  protected List extraRowsBefore = null;
  /** The extra rows to print after the data row. */
  protected List extraRowsAfter = null;

  /**
   * Getter method for the the property style.
   * @return The current value of property style.
   */
  public String getStyle() {
    return style;
  }
  /**
   * Setter method for the the property style.
   * @param style The value to set for the property style.
   */
  public void setStyle(String style) {
    this.style = style;
  }

  /**
   * Getter method for the the property evenStyle.
   * @return The current value of property evenStyle.
   */
  public String getEvenStyle() {
    return evenStyle;
  }
  /**
   * Setter method for the the property evenStyle.
   * @param evenStyle The value to set for the property evenStyle.
   */
  public void setEvenStyle(String evenStyle) {
    this.evenStyle = evenStyle;
  }

  /**
   * Getter method for the the property oddStyle.
   * @return The current value of property oddStyle.
   */
  public String getOddStyle() {
    return oddStyle;
  }
  /**
   * Setter method for the the property oddStyle.
   * @param oddStyle The value to set for the property oddStyle.
   */
  public void setOddStyle(String oddStyle) {
    this.oddStyle = oddStyle;
  }

  /**
   * Getter method for the the property height.
   * @return The current value of property height.
   */
  public String getHeight() {
    return height;
  }
  /**
   * Setter method for the the property height.
   * @param height The value to set for the property height.
   */
  public void setHeight(String height) {
    this.height = height;
  }

  /**
   * Getter method for the the property valign.
   * @return The current value of property valign.
   */
  public String getValign() {
    return valign;
  }
  /**
   * Setter method for the the property valign.
   * @param valign The value to set for the property valign.
   */
  public void setValign(String valign) {
    this.valign = valign;
  }
  
  /**
   * Getter method for the the property paddingLeft.
   * @return The current value of property paddingLeft.
   */
  public float getPaddingLeft() {
    return paddingLeft;
  }
  /**
   * Setter method for the the property paddingLeft.
   * @param paddingLeft The value to set for the property paddingLeft.
   */
  public void setPaddingLeft(float paddingLeft) {
    this.paddingLeft = paddingLeft;
  }

  /**
   * Getter method for the the property paddingRight.
   * @return The current value of property paddingRight.
   */
  public float getPaddingRight() {
    return paddingRight;
  }
  /**
   * Setter method for the the property paddingRight.
   * @param paddingRight The value to set for the property paddingRight.
   */
  public void setPaddingRight(float paddingRight) {
    this.paddingRight = paddingRight;
  }

  /**
   * Getter method for the the property paddingTop.
   * @return The current value of property paddingTop.
   */
  public float getPaddingTop() {
    return paddingTop;
  }
  /**
   * Setter method for the the property paddingTop.
   * @param paddingTop The value to set for the property paddingTop.
   */
  public void setPaddingTop(float paddingTop) {
    this.paddingTop = paddingTop;
  }

  /**
   * Getter method for the the property paddingBottom.
   * @return The current value of property paddingBottom.
   */
  public float getPaddingBottom() {
    return paddingBottom;
  }
  /**
   * Setter method for the the property paddingBottom.
   * @param paddingBottom The value to set for the property paddingBottom.
   */
  public void setPaddingBottom(float paddingBottom) {
    this.paddingBottom = paddingBottom;
  }

  /**
   * Registers the given row cell with the print row tag.
   * @param rowCell The row cell to register.
   */
  public void registerRowCell(RowCellHolder rowCell) {
    int index = rowCell.getColumnIndex();
    if (index < 0) {
      index = this.rowContainer.getColumnIndex(rowCell.getColumnName());
    }
    if (index < 0) {
      throw new RuntimeException("Failed to register row-cell for undefined column '" + rowCell.getColumnName() + "'.");
    }
    this.registeredRowCells[index] = rowCell;
  }

  /**
   * Checks, whether the current row is a even one or not.
   * @return true, if the current row is a even one, else false.
   */
  private boolean isEvenRow() {
    return (rowContainer.getIterationIdx() % 2) == 0;
  }
  
  /**
   * Getter method for the the property skipped.
   * @return The current value of property skipped.
   */
  protected boolean isSkipped() {
    return skipped;
  }
  /**
   * Setter method for the the property skipped.
   * @param skipped The value to set for the property skipped.
   */
  protected void setSkipped(boolean skipped) {
    this.skipped = skipped;
  }

  /**
   * Getter method for the the property rowContainer.
   * @return The current value of property rowContainer.
   */
  public PrintTableTag getRowContainer() {
    return rowContainer;
  }

  /**
   * Produces a td/th tag attribute list according to the given attributes.
   * @param styleClass The style class.
   * @param width The field width.
   * @param height The field height.
   * @param hAlign The horizontal alignment.
   * @param vAlign The vertical alignment.
   * @param colspan The column span.
   * @param paddingLeft The left padding.
   * @param paddingRight The right padding.
   * @param paddingTop The top padding.
   * @param paddingBottom The bottom padding.
   * @return The generated attribute list string.
   */
  protected String getCellAttributes(String styleClass, String width, String height, 
                                     String hAlign, String vAlign, int colspan,
                                     float paddingLeft, float paddingRight, 
                                     float paddingTop, float paddingBottom) {
    String styleAttributes = getStyleAttribute(
        width, height, hAlign, vAlign, 
        paddingLeft, paddingRight, paddingTop, paddingBottom
    );
    StringBuffer attributesBuffer = new StringBuffer();
    if (styleClass != null) {
      attributesBuffer.append(" class=\"").append(styleClass).append("\"");
    }
    if (hAlign != null) {
      attributesBuffer.append(" align=\"").append(hAlign).append("\"");
    }
    if (vAlign != null) {
      attributesBuffer.append(" valign=\"").append(vAlign).append("\"");
    }
    if (width != null) {
      attributesBuffer.append(" width=\"").append(width).append("\"");
    }
    if (height != null) {
      attributesBuffer.append(" height=\"").append(height).append("\"");
    }
    if (colspan > 1) {
      attributesBuffer.append(" colspan=\"").append(colspan).append("\"");
    }
    if (!StringUtils.isEmpty(styleAttributes)) {
      attributesBuffer.append(" style=").append(styleAttributes).append("\"");
    }
    return attributesBuffer.toString();
  }

  /**
   * Produces a td/th tag attribute list according to the given attributes.
   * @param width The field width.
   * @param height The field height.
   * @param hAlign The horizontal alignment.
   * @param vAlign The vertical alignment.
   * @param paddingLeft The left padding.
   * @param paddingRight The right padding.
   * @param paddingTop The top padding.
   * @param paddingBottom The bottom padding.
   * @return The generated attribute list string.
   */
  protected String getStyleAttribute(String width, String height, 
                                     String hAlign, String vAlign,
                                     float paddingLeft, float paddingRight, 
                                     float paddingTop, float paddingBottom) {
    StringBuffer styleBuffer = new StringBuffer();
    if (hAlign != null) {
      styleBuffer.append("text-align:" + hAlign + ";");
    }
    if (vAlign != null) {
      styleBuffer.append("vertical-align:" + vAlign + ";");
    }
    if (width != null) {
      styleBuffer.append("width:" + width);
      if (!width.endsWith("%")) {
        styleBuffer.append("px");
      }
      styleBuffer.append(";");
    }
    if (height != null) {
      styleBuffer.append("height:" + height);
      if (!height.endsWith("%")) {
        styleBuffer.append("px");
      }
      styleBuffer.append(";");
    }
    if (paddingLeft > 0) {
      styleBuffer.append("padding-left:" + paddingLeft);
      styleBuffer.append("px;");
    }
    if (paddingRight > 0) {
      styleBuffer.append("padding-right:" + paddingRight);
      styleBuffer.append("px;");
    }
    if (paddingTop > 0) {
      styleBuffer.append("padding-top:" + paddingTop);
      styleBuffer.append("px;");
    }
    if (paddingBottom > 0) {
      styleBuffer.append("padding-bottom:" + paddingBottom);
      styleBuffer.append("px;");
    }
    return styleBuffer.toString();
  }

  /**
   * Inserts a extra row.
   * @param extraRow The extra row to insert.
   * @param insertDirection The insert direction.
   */
  public void insertExtraRow(ExtraRowHolder extraRow, int insertDirection) {
    List extraRowList = null;
    if (insertDirection == PrintTableTag.DIRECTION_BEFORE) {
      if (extraRowsBefore == null) {
        extraRowsBefore = new ArrayList();
      }
      extraRowList = extraRowsBefore;
    } else {
      if (extraRowsAfter == null) {
        extraRowsAfter = new ArrayList();
      }
      extraRowList = extraRowsAfter;
    }
    extraRowList.add(extraRow);
  }

  /**
   * @see javax.servlet.jsp.tagext.BodyTagSupport#doStartTag()
   */
  public int doStartTag() throws JspException {
    this.rowContainer = lookupRowContainer();
    Row row = rowContainer.getCurrentRow();
    
    if (!checkRowType(row)) {
      setSkipped(true);
      return SKIP_BODY;
    }
    printTagStart();
    registeredRowCells = new RowCellHolder[rowContainer.getNumColumns()];
    extraRowsBefore = null;
    extraRowsAfter = null;
    
    if (evenStyle == null) {
      evenStyle = rowContainer.getEvenStyle();
    }
    if (oddStyle == null) {
      oddStyle = rowContainer.getOddStyle();
    }
    return EVAL_BODY_INCLUDE;
  }
  
  /**
   * Checks the row type.
   * @param row The row to check.
   * @return true if the row is valid for output, else false.
   */
  protected boolean checkRowType(Row row) {
    return (row != null) && TableConstants.ROW_TYPE_NORMAL.equals(row.getType());
  }

  /**
   * Prints the tag start code.
   */
  protected void printTagStart() {
    setSkipped(false);
  }
  
  /**
   * @see javax.servlet.jsp.tagext.BodyTagSupport#doEndTag()
   */
  public int doEndTag() throws JspException {
    registerColumnStyles();
    
    if (isSkipped()) {
      setSkipped(false);
      return EVAL_PAGE;
    }
    
    currentStyle = alternateRowStyle();
    
    // performing output of leading extra rows.
    if (extraRowsBefore != null) {
      List extraRows = extraRowsBefore;
      int numExtraRows = extraRows.size();
      for (int i = 0; i < numExtraRows; i++) {
        ExtraRowHolder extraRow = (ExtraRowHolder) extraRows.get(i);
        String style = extraRow.getStyle();
        if (style == null) {
          style = currentStyle;
        }
        outputRow(
            extraRow.getRowCells(), style, extraRow.getHeight(), extraRow.getValign(), 
            extraRow.getPaddingLeft(), extraRow.getPaddingRight(), 
            extraRow.getPaddingTop(), extraRow.getPaddingBottom()
        );
      }
    }
    
    // performing output of data row.
    outputRow();

    // performing output of trailing extra rows.
    if (extraRowsAfter != null) {
      List extraRows = extraRowsAfter;
      int numExtraRows = extraRows.size();
      for (int i = 0; i < numExtraRows; i++) {
        ExtraRowHolder extraRow = (ExtraRowHolder) extraRows.get(i);
        String style = extraRow.getStyle();
        if (style == null) {
          style = currentStyle;
        }
        outputRow(
            extraRow.getRowCells(), style, extraRow.getHeight(), extraRow.getValign(), 
            extraRow.getPaddingLeft(), extraRow.getPaddingRight(), 
            extraRow.getPaddingTop(), extraRow.getPaddingBottom()
        );
      }
    }
  
    return EVAL_PAGE;
  }
  
  /**
   * Registers column styles at the parent tag.
   */
  private void registerColumnStyles() {
    PrintTableTag parent = (PrintTableTag) getParent(PrintTableTag.class);
    Column[] columns = parent.getVisibleColumns();
    for (int i = 0; i < columns.length; i++) {
      Column column = columns[i];
      int columnIdx = column.getIndex();
      
      LayoutHints layoutHints = column.getLayoutHints();
      RowCellHolder rowCell = null;
      if (registeredRowCells != null) {
        rowCell = registeredRowCells[i];
      }
      String width = null;
      String height = this.getHeight();
      String valign = this.valign;
      String halign = null;
      if (columnIdx != -1) {
        switch (layoutHints.getAlign()) {
          case LayoutHints.LEFT:
            halign = "left";
            break;
          case LayoutHints.RIGHT:
            halign = "right";
            break;
          case LayoutHints.CENTER:
            halign = "center";
            break;
          default:
            halign = "left";
            break;
        }
      }
      
      float paddingLeft = this.paddingLeft;
      float paddingRight = this.paddingRight;
      float paddingTop = this.paddingTop;
      float paddingBottom = this.paddingBottom;
      if (rowCell != null) {
        width = rowCell.getWidth();
        if (rowCell.getHeight() != null) {
          height = rowCell.getHeight();
        }
        if (rowCell.getValign() != null) {
          valign = rowCell.getValign();
        }
        String tmpHalign = rowCell.getHalign();
        if (tmpHalign != null) {
          halign = tmpHalign;
        }
        if (rowCell.getPaddingLeft() >= 0.0F) {
          paddingLeft = rowCell.getPaddingLeft();
        }
        if (rowCell.getPaddingRight() >= 0.0F) {
          paddingRight = rowCell.getPaddingRight();
        }
        if (rowCell.getPaddingTop() >= 0.0F) {
          paddingTop = rowCell.getPaddingTop();
        }
        if (rowCell.getPaddingBottom() >= 0.0F) {
          paddingBottom = rowCell.getPaddingBottom();
        }
      }
      if ((width == null) && (layoutHints.getWidth() > 0)) {
        width = Integer.toString((int) layoutHints.getWidth()) + '%';
      }
      // registering cell column styles
      String styleAttributes = getStyleAttribute(
          width, height, halign, valign, 
          paddingLeft, paddingRight, paddingTop, paddingBottom
      );
      
      List columnAttributes = new ArrayList();
      if (halign != null) {
        columnAttributes.add(new MarkupAttribute("align", halign));
      }
      if (valign != null) {
        columnAttributes.add(new MarkupAttribute("valign", valign));
      }
      if (width != null) {
        columnAttributes.add(new MarkupAttribute("width", width));
      }
      if (height != null) {
        columnAttributes.add(new MarkupAttribute("height", height));
      }
      if (!StringUtils.isEmpty(styleAttributes)) {
        columnAttributes.add(new MarkupAttribute("style", styleAttributes));
      }

      if (!StringUtils.isEmpty(styleAttributes)) {
        parent.setColumnAttributes(column, columnAttributes);
      }
    }

  }

  /**
   * Performs the row output.
   * @exception JspException Thrown in case something went wrong while closing the foreach item.
   */
  protected void outputRow()
    throws JspException {

    // processing style
    String rowStyle = alternateRowStyle();
    
    outputRow(registeredRowCells, rowStyle, height, valign, paddingLeft, paddingRight, paddingTop, paddingBottom);
  }  
  
  /**
   * Performs the row output.
   * @param rowCells The row cells to render.
   * @param style The style class.
   * @param height The field height.
   * @param hAlign The horizontal alignment.
   * @param paddingLeft The left padding.
   * @param paddingRight The right padding.
   * @param paddingTop The top padding.
   * @param paddingBottom The bottom padding.
   * @exception JspException Thrown in case something went wrong while closing the foreach item.
   */
  protected void outputRow(RowCellHolder[] rowCells, String style, String height, String vAlign, 
                           float paddingLeft, float paddingRight, 
                           float paddingTop, float paddingBottom)
    throws JspException {
    
    try {
      boolean evenRow = isEvenRow();
      PrintTableTag parent = getRowContainer();
      String template = parent.getTemplate();

      if (BeanUtils.isEmpty(template)) {
        JspWriter out = pageContext.getOut();
  
        out.print("  <tr");
        if (style != null) {
          out.print(" class=\"" + style + "\"");
        }
        out.println(">");
  
        parent.setEvenStyle(evenStyle);
        parent.setOddStyle(oddStyle);
        
        Row row = parent.getCurrentRow();
        if (row == null) {
          return; 
        }
        Column[] columns = parent.getVisibleColumns();
        for (int i = 0; i < columns.length; i++) {
          Column column = columns[i];
          int columnIdx = column.getIndex();
          
          LayoutHints layoutHints = column.getLayoutHints();
          RowCellHolder rowCell = rowCells[i];
          String width = null;
          String cellHeight = height;
          String cellStyle = style;
          String evenStyle = this.evenStyle;
          String oddStyle = this.oddStyle;
          String valign = this.valign;
          String halign = null;
          if (columnIdx != -1) {
            switch (row.getAlign(columnIdx)) {
              case LayoutHints.LEFT:
                halign = "left";
                break;
              case LayoutHints.RIGHT:
                halign = "right";
                break;
              case LayoutHints.CENTER:
                halign = "center";
                break;
              default:
                halign = "left";
                break;
            }
          }
          
          float cellPaddingLeft = paddingLeft;
          float cellPaddingRight = paddingRight;
          float cellPaddingTop = paddingTop;
          float cellPaddingBottom = paddingBottom;
          String content = null;
          int colspan = 1;
          if (rowCell != null) {
            width = rowCell.getWidth();
            if (rowCell.getHeight() != null) {
              cellHeight = rowCell.getHeight();
            }
            if (rowCell.getStyle() != null) {
              cellStyle = rowCell.getStyle();
            }
            if (rowCell.getEvenStyle() != null) {
              evenStyle = rowCell.getEvenStyle();
            }
            if (rowCell.getOddStyle() != null) {
              oddStyle = rowCell.getOddStyle();
            }
            if (rowCell.getValign() != null) {
              valign = rowCell.getValign();
            }
            String tmpHalign = rowCell.getHalign();
            if (tmpHalign != null) {
              halign = tmpHalign;
            }
            if (rowCell.getPaddingLeft() >= 0.0F) {
              cellPaddingLeft = rowCell.getPaddingLeft();
            }
            if (rowCell.getPaddingRight() >= 0.0F) {
              cellPaddingRight = rowCell.getPaddingRight();
            }
            if (rowCell.getPaddingTop() >= 0.0F) {
              cellPaddingTop = rowCell.getPaddingTop();
            }
            if (rowCell.getPaddingBottom() >= 0.0F) {
              cellPaddingBottom = rowCell.getPaddingBottom();
            }
            if (rowCell.hasContent()) {
              content = rowContainer.evalTemplate(rowCell.getContent());
            }
            if (rowCell.getColspan() > 0) {
              colspan = rowCell.getColspan();
            }
            if (rowCell.isFillRow()) {
              colspan = columns.length - i;
            }
          }
          if (evenRow) {
            if (evenStyle != null) {
              cellStyle = evenStyle;
            }
          } else {
            if (oddStyle != null) {
              cellStyle = oddStyle;
            }
          }
          if ((width == null) && (layoutHints.getWidth() > 0)) {
            width = Integer.toString((int) layoutHints.getWidth()) + '%';
          }
          if (content == null) {
            if ((columnIdx != -1) && row.isVisible(columnIdx)) {
              content = row.getString(columnIdx);
            } else {
              content = parent.getDefaultContent(i);
              if (content != null) {
                content = rowContainer.evalTemplate(content);
              }
            }
          }
          if (content == null) {
            content = "&nbsp;";
          }
          // printing cell
          out.print("    <td");
          out.print(getCellAttributes(
              cellStyle, width, cellHeight, halign, valign, colspan, 
              cellPaddingLeft, cellPaddingRight, cellPaddingTop, cellPaddingBottom
          ));
          out.print(">");
          out.print(content);
          out.println("</td>");
          if (colspan > 1) {
            i += colspan - 1;
          }
        }
        out.println("  </tr>");
      } else {
        try {
          setAttribute(PrintTableTag.ATTRIBUTE_TABLE_ROW_STYLE, style);
          setAttribute(PrintTableTag.ATTRIBUTE_TABLE_ROW_HEIGHT, height);

          List actualCells = new ArrayList();
          Row row = parent.getCurrentRow();
          if (row == null) {
            return;
          }
          setAttribute(PrintTableTag.ATTRIBUTE_TABLE_ROW_TYPE, row.getType());
          Column[] columns = parent.getVisibleColumns();
          for (int i = 0; i < columns.length; i++) {
            Column column = columns[i];
            int columnIdx = column.getIndex();
            
            boolean visible = true;
            if (columnIdx >= 0) {
              visible = row.isVisible(columnIdx);
            }
            String cellStyle = style;
            LayoutHints layoutHints = column.getLayoutHints();
            RowCellHolder rowCell = rowCells[i];
            String width = null;
            String cellHeight = height;
            String valign = this.valign;
            String halign = null;
            if (columnIdx != -1) {
              switch (row.getAlign(columnIdx)) {
                case LayoutHints.LEFT:
                  halign = "left";
                  break;
                case LayoutHints.RIGHT:
                  halign = "right";
                  break;
                case LayoutHints.CENTER:
                  halign = "center";
                  break;
                default:
                  halign = "left";
                  break;
              }
            }
            
            float cellPaddingLeft = paddingLeft;
            float cellPaddingRight = paddingRight;
            float cellPaddingTop = paddingTop;
            float cellPaddingBottom = paddingBottom;
            Object content = null;
            int colspan = 1;
            if (rowCell != null) {
              visible = true;
              width = rowCell.getWidth();
              if (rowCell.getHeight() != null) {
                cellHeight = rowCell.getHeight();
              }
              if (rowCell.getStyle() != null) {
                cellStyle = rowCell.getStyle();
              }
              if (rowCell.getEvenStyle() != null) {
                if (evenRow) {
                  cellStyle = rowCell.getEvenStyle();
                }
              }
              if (rowCell.getOddStyle() != null) {
                if (!evenRow) {
                  cellStyle = rowCell.getOddStyle();
                }
              }
              if (rowCell.getValign() != null) {
                valign = rowCell.getValign();
              }
              String tmpHalign = rowCell.getHalign();
              if (tmpHalign != null) {
                halign = tmpHalign;
              }
              if (rowCell.getPaddingLeft() >= 0.0F) {
                cellPaddingLeft = rowCell.getPaddingLeft();
              }
              if (rowCell.getPaddingRight() >= 0.0F) {
                cellPaddingRight = rowCell.getPaddingRight();
              }
              if (rowCell.getPaddingTop() >= 0.0F) {
                cellPaddingTop = rowCell.getPaddingTop();
              }
              if (rowCell.getPaddingBottom() >= 0.0F) {
                cellPaddingBottom = rowCell.getPaddingBottom();
              }
              if (rowCell.hasContent()) {
                content = rowContainer.evalTemplate(rowCell.getContent());
              }
              if (rowCell.getColspan() > 0) {
                colspan = rowCell.getColspan();
              }
              if (rowCell.isFillRow()) {
                colspan = columns.length - i;
              }
            }
            if ((width == null) && (layoutHints.getWidth() > 0)) {
              width = Integer.toString((int) layoutHints.getWidth());
            }
            if (content == null) {
              content = parent.getDefaultContent(i);
              if (!BeanUtils.isEmpty((String) content)) {
                content = rowContainer.evalTemplate(content.toString());
              } else if ((columnIdx != -1) && row.isVisible(columnIdx)) {
                content = row.getObject(columnIdx);
              }
            }
            if (content == null) {
              content = "&nbsp;";
            }
            
            // setting cell
            CellData cellData = new CellData(column.getName(), content, colspan);
            cellData.setVisible(visible);
            cellData.setStyle(cellStyle);
            cellData.setWidth(width);
            cellData.setHeight(cellHeight);
            cellData.setHalign(halign);
            cellData.setValign(valign);
            cellData.setPaddingLeft((int) cellPaddingLeft);
            cellData.setPaddingRight((int) cellPaddingRight);
            cellData.setPaddingTop((int) cellPaddingTop);
            cellData.setPaddingBottom((int) cellPaddingBottom);
            actualCells.add(cellData);
            if (colspan > 1) {
              i += colspan - 1;
            }
          }

          setAttribute(PrintTableTag.ATTRIBUTE_TABLE_CELLS, actualCells);

          pageContext.include(template + "-row.jsp");
        } catch (ServletException ex) {
          throw new JspException("Failed to include template file '" + template + "-body.jsp'.");
        }
      }
    } catch (IOException ex) {
      throw new JspException("Unable to print table row: " + ex.getMessage(), ex);
    } catch (TableException ex) {
      throw new JspException("Unable to print table row: " + ex.getMessage(), ex);
    } catch (ClassCastException ex) {
      throw new JspException("Type cast problem detected: " + ex.getMessage(), ex);
    }
  }

  /**
   * @see javax.servlet.jsp.tagext.BodyTagSupport#release()
   */
  public void release() {
    super.release();
    this.style = null;
    this.currentStyle = null;
    this.evenStyle = "even";
    this.oddStyle = "odd";
    this.height = null;
    this.valign= null;
    this.paddingLeft = 0.0f;
    this.paddingRight = 0.0f;
    this.paddingTop = 0.0f;
    this.paddingBottom = 0.0f;
    this.registeredRowCells = null;
    this.skipped = false;
    this.extraRowsBefore = null;
    this.extraRowsAfter = null;
  }
  
  /**
   * Gets the latest row container from the tag stack.
   * @return The latest row container from the tag stack or null.
   */
  protected PrintTableTag lookupRowContainer() {
    Tag parent = getParent(PrintTableTag.class);
    return (PrintTableTag) parent;
  }
  
  /**
   * Alternates the row style.
   * @return The style to use for the current row.
   */
  protected String alternateRowStyle() {
    String style = this.style;
    if (style != null) {
      return style;
    }
    boolean evenRow = isEvenRow();
    if (evenRow) {
      if (evenStyle != null) {
        style = evenStyle;
      }
    } else {
      if (oddStyle != null) {
        style = oddStyle;
      }
    }
    return style;
  }
  
}
