/*
 * Copyright (C) 2003, 2004 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.web.tag;

/**
 * Name: RowCellHolder<br>
 * Description: A class holding row-cell data.
 * 
 * @author lauerc
 */
public class RowCellHolder {

  /** The field name to define the style for. */
  private String name = null;
  /** The column index. */
  protected int index = -1;
  /** The column span to use. */
  private int colspan = 0;
  /** Tells whether to fill the current row or not. */ 
  protected boolean fillRow = false;
  /** The general style class. */
  private String style = null;
  /** The style class for even rows. */
  private String evenStyle = null;
  /** The style class for odd rows. */
  private String oddStyle = null;
  /** The field width. */
  private String width = null;
  /** The row height. */
  private String height = null;
  /** The horizontal alignment. */
  private String halign = null;
  /** The vertical alignment. */
  private String valign = null;
  /** The left padding. */ 
  private float paddingLeft = -1.0F;
  /** The right padding. */ 
  private float paddingRight = -1.0F;
  /** The top padding. */ 
  private float paddingTop = -1.0F;
  /** The bottom padding. */ 
  private float paddingBottom = -1.0F;
  /** The content of the tag. */
  private String content = null;
  
  /**
   * Constructs a RowCellHolder instance with specific attributes.
   * @param name The column name.
   * @param index The column index.
   * @param colspan The column span size.
   * @param fillRow Tells whether or not to fill the current row.
   * @param style The cell style.
   * @param evenStyle The even style
   * @param oddStyle The odd style
   * @param width The cell width
   * @param height The cell height.
   * @param halign The horizontal alignment.
   * @param valign The vertical alignment.
   * @param paddingLeft The left padding.
   * @param paddingRight The right padding.
   * @param paddingTop The top padding.
   * @param paddingBottom The bottom padding.
   * @param content The cell content.
   */
  public RowCellHolder(String name, int index, int colspan, boolean fillRow, String style,
                       String evenStyle, String oddStyle, String width, String height,
                       String halign, String valign, float paddingLeft, float paddingRight,
                       float paddingTop, float paddingBottom, String content) {
    this.name = name;
    this.index = index;
    this.colspan = colspan;
    this.fillRow = fillRow;
    this.style = style;
    this.evenStyle = evenStyle;
    this.oddStyle = oddStyle;
    this.width = width;
    this.height = height;
    this.halign = halign;
    this.valign = valign;
    this.paddingLeft = paddingLeft;
    this.paddingRight = paddingRight;
    this.paddingTop = paddingTop;
    this.paddingBottom = paddingBottom;
    this.content = content;
  }
  
  /**
   * Getter method for the the property name.
   * @return The current value of property name.
   */
  public String getColumnName() {
    return name;
  }
  /**
   * Setter method for the the property name.
   * @param name The value to set for the property name.
   */
  public void setName(String name) {
    this.name = name;
  }

  /**
   * Getter method for the the property index.
   * @return The current value of property index.
   */
  public int getColumnIndex() {
    return index;
  }
  /**
   * Setter method for the the property index.
   * @param index The value to set for the property index.
   */
  public void setIndex(int index) {
    this.index = index;
  }

  /**
   * Getter method for the the property colspan.
   * @return The current value of property colspan.
   */
  public int getColspan() {
    return colspan;
  }
  /**
   * Setter method for the the property colspan.
   * @param colspan The value to set for the property colspan.
   */
  public void setColspan(int colspan) {
    this.colspan = colspan;
  }

  /**
   * Getter method for the the property fillRow.
   * @return The current value of property fillRow.
   */
  public boolean isFillRow() {
    return fillRow;
  }
  /**
   * Setter method for the the property fillRow.
   * @param fillRow The value to set for the property fillRow.
   */
  public void setFillRow(boolean fillRow) {
    this.fillRow = fillRow;
  }
  
  /**
   * Getter method for the the property style.
   * @return The current value of property style.
   */
  public String getStyle() {
    return style;
  }
  /**
   * Setter method for the the property style.
   * @param style The value to set for the property style.
   */
  public void setStyle(String style) {
    this.style = style;
  }

  /**
   * Getter method for the the property evenStyle.
   * @return The current value of property evenStyle.
   */
  public String getEvenStyle() {
    return evenStyle;
  }
  /**
   * Setter method for the the property evenStyle.
   * @param evenStyle The value to set for the property evenStyle.
   */
  public void setEvenStyle(String evenStyle) {
    this.evenStyle = evenStyle;
  }

  /**
   * Getter method for the the property oddStyle.
   * @return The current value of property oddStyle.
   */
  public String getOddStyle() {
    return oddStyle;
  }
  /**
   * Setter method for the the property oddStyle.
   * @param oddStyle The value to set for the property oddStyle.
   */
  public void setOddStyle(String oddStyle) {
    this.oddStyle = oddStyle;
  }

  /**
   * Getter method for the the property width.
   * @return The current value of property width.
   */
  public String getWidth() {
    return width;
  }

  /**
   * Setter method for the the property width.
   * @param width The value to set for the property width.
   */
  public void setWidth(String width) {
    this.width = width;
  }
  
  /**
   * Getter method for the the property height.
   * @return The current value of property height.
   */
  public String getHeight() {
    return height;
  }
  /**
   * Setter method for the the property height.
   * @param height The value to set for the property height.
   */
  public void setHeight(String height) {
    this.height = height;
  }

  /**
   * Getter method for the the property paddingLeft.
   * @return The current value of property paddingLeft.
   */
  public float getPaddingLeft() {
    return paddingLeft;
  }
  /**
   * Setter method for the the property paddingLeft.
   * @param paddingLeft The value to set for the property paddingLeft.
   */
  public void setPaddingLeft(float paddingLeft) {
    this.paddingLeft = paddingLeft;
  }

  /**
   * Getter method for the the property paddingRight.
   * @return The current value of property paddingRight.
   */
  public float getPaddingRight() {
    return paddingRight;
  }
  /**
   * Setter method for the the property paddingRight.
   * @param paddingRight The value to set for the property paddingRight.
   */
  public void setPaddingRight(float paddingRight) {
    this.paddingRight = paddingRight;
  }

  /**
   * Getter method for the the property paddingTop.
   * @return The current value of property paddingTop.
   */
  public float getPaddingTop() {
    return paddingTop;
  }
  /**
   * Setter method for the the property paddingTop.
   * @param paddingTop The value to set for the property paddingTop.
   */
  public void setPaddingTop(float paddingTop) {
    this.paddingTop = paddingTop;
  }

  /**
   * Getter method for the the property paddingBottom.
   * @return The current value of property paddingBottom.
   */
  public float getPaddingBottom() {
    return paddingBottom;
  }
  /**
   * Setter method for the the property paddingBottom.
   * @param paddingBottom The value to set for the property paddingBottom.
   */
  public void setPaddingBottom(float paddingBottom) {
    this.paddingBottom = paddingBottom;
  }

  /**
   * Getter method for the the property halign.
   * @return The current value of property halign.
   */
  public String getHalign() {
    return halign;
  }
  /**
   * Setter method for the the property halign.
   * @param halign The value to set for the property halign.
   */
  public void setHalign(String halign) {
    this.halign = halign;
  }
  
  /**
   * Getter method for the the property valign.
   * @return The current value of property valign.
   */
  public String getValign() {
    return valign;
  }
  /**
   * Setter method for the the property valign.
   * @param valign The value to set for the property valign.
   */
  public void setValign(String valign) {
    this.valign = valign;
  }
  
  /**
   * Gets the tag's content.
   * @return The content of the current tag.
   */
  public boolean hasContent() {
    return (content != null) && (content.length() > 0);
  }

  /**
   * Gets the tag's content.
   * @return The content of the current tag.
   */
  public String getContent() {
    return content;
  }
  
}
