/*
 * Copyright (C) 2003 - 2007 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.web.tag;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.tagext.BodyContent;

import org.ujac.print.DocumentHandlerException;

import org.ujac.util.template.TemplateContext;
import org.ujac.util.template.TemplateException;
import org.ujac.util.template.TemplateInterpreter;

import org.ujac.web.servlet.TemplateInterpreterHelper;

/**
 * Name: SetPropertyTag<br>
 * Description: Class handling the set-property tag.
 * 
 * @author lauerc
 */
public class SetPropertyTag extends BaseTag {

  /** The serial version UID. */
  private static final long serialVersionUID = 5400375917926910911L;
  
  /** The property name. */
  private String name = null;
  /** The property type. */
  private String type = null;
    
  /**
   * Getter method for the the property name.
   * @return The current value of property name.
   */
  public String getName() {
    return name;
  }
  /**
   * Setter method for the the property name.
   * @param name The value to set for the property name.
   */
  public void setName(String name) {
    this.name = name;
  }

  /**
   * Getter method for the the property type.
   * @return The current value of property type.
   */
  public String getType() {
    return type;
  }
  /**
   * Setter method for the the property type.
   * @param type The value to set for the property type.
   */
  public void setType(String type) {
    this.type = type;
  }

  /**
   * @see javax.servlet.jsp.tagext.BodyTagSupport#doEndTag()
   */
  public int doEndTag() throws JspException {

    // getting body
    String body = null;
    BodyContent bc = this.bodyContent;
    if (bc != null) {
      body = bc.getString();
    }

    // getting the property value
    TemplateContext tctx = getTemplateContext();
    Object value = typeCastValue(tctx, body, type);
    // setting the document property
    setAttribute(name, value);
    
    return EVAL_PAGE;
  }

  /**
   * @see org.ujac.print.BaseDocumentTag#isStructureChecksDisabled()
   */
  public boolean isStructureChecksDisabled() {
    return true;
  }

  /**
   * Gets a well typed value for the given one.
   * @param text The text to parse the value from.
   * @param type The type name to cast to.
   * @return The correctly typed value.
   * @throws DocumentHandlerException In case the type conversion failed.
   */
  protected Object typeCastValue(TemplateContext tctx, String text, String type) throws JspException {
    TemplateInterpreter ti = TemplateInterpreterHelper.getTemplateInterpreter(pageContext);
    try {
      if (type == null) {
        // no type defined, getting the value as a String
        return ti.execute(text, tctx);
      }
      if (type.equalsIgnoreCase("boolean")) {
        return new Boolean(ti.evalBooleanExpr(text, tctx));
      } else if (type.equalsIgnoreCase("int")) {
        return new Integer(ti.evalIntExpr(text, tctx));
      } else if (type.equalsIgnoreCase("long")) {
        return new Long(ti.evalLongExpr(text, tctx));
      } else if (type.equalsIgnoreCase("float")) {
        return new Float(ti.evalFloatExpr(text, tctx));
      } else if (type.equalsIgnoreCase("double")) {
        return new Double(ti.evalDoubleExpr(text, tctx));
      } else if (type.equalsIgnoreCase("Date")) {
        return ti.evalDateExpr(text, tctx);
      } else if (type.equalsIgnoreCase("Time")) {
        return ti.evalTimeExpr(text, tctx);
      } else if (type.equalsIgnoreCase("Timestamp")) {
        return ti.evalTimestampExpr(text, tctx);
      } else if (type.equalsIgnoreCase("Object")) {
        return ti.evalObjectExpr(text, tctx);
      }
      // if all else failes, getting the value as a String
      return ti.execute(text, tctx);
    } catch (TemplateException ex) {
      throw new JspException(ex.getMessage(), ex);
    }
  }

}
