/*
 * Copyright (C) 2005 by Christian Lauer.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://sourceforge.net/projects/ujac
 */
 
package org.ujac.web.tag;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.PageContext;

import org.ujac.util.exi.ExpressionException;

import org.ujac.util.template.TemplateContext;
import org.ujac.util.template.TemplateInterpreter;

import org.ujac.web.servlet.TemplateInterpreterHelper;

/**
 * Name: SwitchTag<br>
 * Description: A custom tag class implementing the tag &lt;ujac:switch&gt;.<br>.
 * 
 * @author lauerc
 */
public class SwitchTag extends BaseTag {

  /** The serial version UID. */
  private static final long serialVersionUID = 3258412811586386230L;
  
  /** The value to match. */
  private String value = null;

  /** Tells whether a case matched the value so far. */
  private boolean caseMatched = false;
  /** The evaluated value. */
  private String evaluated = null;

  /**
   * Setter method for the the property value.
   * @param value The value to set for the property value.
   */
  public void setValue(String value) {
    this.value = value;
  }
  
  /**
   * Tells whether the given value matches the defined value.
   * @param value The value to check.
   * @return true if the given value matches the defined value else false.
   */
  public boolean matches(String value) {
    if (value.equals(evaluated)) {
      caseMatched = true;
      return true;
    }
    return false;
  }
  
  /**
   * Tells whether or not a case has already matched the value so far.
   * @return true if a case has been successfuly checked so far, else false.
   */
  public boolean isCaseMatched() {
    return caseMatched;
  }
  
  /**
   * @see javax.servlet.jsp.tagext.Tag#doStartTag()
   */
  public int doStartTag() throws JspException {
    
    // resetting matched flag.
    this.caseMatched = false;
   
    try {
      PageContext ctx = this.pageContext;
      TemplateInterpreter interpreter = TemplateInterpreterHelper.getTemplateInterpreter(ctx);
      TemplateContext templateCtx = getTemplateContext();
      this.evaluated = interpreter.evalStringExpr(value, templateCtx);
    } catch (ExpressionException ex) {
      throw new JspException("Evaluation of switch value '" + value + "' failed: " + ex.getMessage(), ex);
    }
    
    return EVAL_BODY_INCLUDE;
  }

}
